--- groff-1.18.orig/src/include/config.hin
+++ groff-1.18/src/include/config.hin
@@ -145,3 +145,9 @@
 /* Define uintmax_t to `unsigned long' or `unsigned long long' if <inttypes.h>
    does not exist. */
 #undef uintmax_t
+
+/* Define if you want to use Japanese extension. */
+#undef NIPPON
+
+/* Define if you have a nl_langinfo(CODESET). */
+#undef HAVE_LANGINFO_CODESET
--- groff-1.18.orig/src/include/device.h
+++ groff-1.18/src/include/device.h
@@ -18,4 +18,9 @@
 with groff; see the file COPYING.  If not, write to the Free Software
 Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 
+#ifndef _DEVICE_H
+#define _DEVICE_H
+
 extern const char *device;
+
+#endif /* _DEVICE_H */
--- groff-1.18.orig/src/include/driver.h
+++ groff-1.18/src/include/driver.h
@@ -27,6 +27,7 @@
 #include <errno.h>
 #include <assert.h>
 #include <math.h>
+#include "encoding.h" // XXX: ukai
 #include "errarg.h"
 #include "error.h"
 #include "font.h"
--- groff-1.18.orig/src/include/font.h
+++ groff-1.18/src/include/font.h
@@ -18,6 +18,8 @@
 with groff; see the file COPYING.  If not, write to the Free Software
 Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 
+#include "encoding.h"
+
 typedef void (*FONT_COMMAND_HANDLER)(const char *, const char *,
 				     const char *, int);
 
@@ -53,6 +55,9 @@
   const char *get_special_device_encoding(int index);
   const char *get_name();
   const char *get_internal_name();
+#ifdef	NIPPON
+  const char *get_subfont_name(int index);
+#endif
 
   static int scan_papersize(const char *, const char **, double *, double *);
 
@@ -62,6 +67,9 @@
   static int load_desc();
   static int name_to_index(const char *);
   static int number_to_index(int);
+#ifdef	NIPPON
+  static int wchar_index(wchar);
+#endif
   static FONT_COMMAND_HANDLER
     set_unknown_desc_command_handler(FONT_COMMAND_HANDLER);
 
@@ -76,6 +84,10 @@
   static int spare2;
   static int sizescale;
   static int tcommand;
+#ifdef	NIPPON
+  static int lowerwchar;
+  static int wcharkern;
+#endif
   static int pass_filenames;
   static int use_charnames_in_special;
 
@@ -83,6 +95,9 @@
   static const char **style_table;
   static const char *family;
   static int *sizes;
+#ifdef	NIPPON
+  static const char **on_demand_fonts;
+#endif
 private:
   unsigned ligatures;
   font_kern_list **kern_hash_table;
--- groff-1.18.orig/src/include/lib.h
+++ groff-1.18/src/include/lib.h
@@ -88,8 +88,15 @@
 
 extern char invalid_char_table[];
 
+#include "encoding.h" /* XXX: ukai */
+
 inline int invalid_input_char(int c)
 {
+#ifdef NIPPON
+  if (encoding->is_wchar_byte(c))
+      return 0;
+  else
+#endif
   return c >= 0 && invalid_char_table[c];
 }
 
--- groff-1.18.orig/src/include/printer.h
+++ groff-1.18/src/include/printer.h
@@ -38,6 +38,8 @@
 
 #include "color.h"
 
+#include "encoding.h"
+
 struct environment {
   int fontno;
   int size;
@@ -63,6 +65,9 @@
   printer();
   virtual ~printer();
   void load_font(int i, const char *name);
+#ifdef	NIPPON
+  void set_wchar_char(wchar c, const environment *env, int *widthp = 0);
+#endif
   void set_ascii_char(unsigned char c, const environment *env,
 		      int *widthp = 0);
   void set_special_char(const char *nm, const environment *env,
--- groff-1.18.orig/src/include/encoding.h
+++ groff-1.18/src/include/encoding.h
@@ -0,0 +1,157 @@
+// -*- C++ -*-
+/* Copyright (c) 2001 Fumitoshi UKAI <ukai@debian.or.jp>
+
+This file is part of groff.
+
+groff is free software; you can redistribute it and/or modify it under
+the terms of the GNU General Public License as published by the Free
+Software Foundation; either version 2, or (at your option) any later
+version.
+
+groff is distributed in the hope that it will be useful, but WITHOUT ANY
+WARRANTY; without even the implied warranty of MERCHANTABILITY or
+FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+
+#ifndef ENCODING_H
+#define ENCODING_H
+
+#include <config.h>
+
+#ifdef NIPPON
+typedef unsigned int wchar;
+#else
+typedef char wchar;
+#endif
+
+#include <stdio.h>
+
+#ifdef __cplusplus
+class encoding_istream {
+public:
+  encoding_istream() {};
+  virtual ~encoding_istream() {};
+  virtual int getbyte() = 0;
+  virtual int peekbyte() = 0;
+  virtual void ungetbyte(int ch) = 0;
+};
+
+class encoding_istream_str: public encoding_istream {
+private:
+  const unsigned char *s;
+  int *i;
+  encoding_istream_str() {};
+public:
+  encoding_istream_str(const unsigned char *s0, int *i0) : s(s0), i(i0) {};
+  ~encoding_istream_str() {};
+  inline int getbyte() { return s[(*i)++]; };
+  inline int peekbyte() { return s[(*i)]; };
+  inline void ungetbyte(int ch) { --(*i); };
+};
+
+class encoding_istream_fp: public encoding_istream {
+private:
+  FILE *fp;
+public:
+  encoding_istream_fp(FILE *fp0) : fp(fp0) {};
+  ~encoding_istream_fp() {};
+  inline int getbyte() { return fgetc(fp); };
+  inline int peekbyte() { int ch = fgetc(fp); ungetc(ch, fp); return ch; };
+  inline void ungetbyte(int ch) { ungetc(ch, fp); };
+};
+
+class encoding_ostream {
+public:
+  encoding_ostream() {};
+  virtual ~encoding_ostream() {};
+  virtual void putbyte(unsigned char ch) = 0;
+};
+
+class encoding_ostream_str: public encoding_ostream {
+private:
+  unsigned char *s;
+  int *i;
+  int len;
+  encoding_ostream_str() {};
+public:
+  encoding_ostream_str(unsigned char *s0, int *i0, int max) : s(s0), i(i0), len(max) {};
+  ~encoding_ostream_str() {};
+  inline void putbyte(unsigned char ch) {
+    if (*i < len)
+      s[(*i)++] = ch;
+  }
+};
+
+class encoding_ostream_fp: public encoding_ostream {
+private:
+  FILE *fp;
+  const char *format;
+public:
+  encoding_ostream_fp(FILE *ofp, const char *fmt = "%c") : fp(ofp), format(fmt) {};
+  ~encoding_ostream_fp() {};
+  inline void putbyte(unsigned char ch) {
+    fprintf(fp, format, ch);
+  }
+};
+
+class encoding_handler {
+protected:
+  wchar wc;
+public:
+  encoding_handler() {};
+  virtual ~encoding_handler() {};
+
+  virtual int is_wchar_code(wchar wc) { return 0; };
+  virtual int is_wchar_byte(unsigned char c) { return 0; };
+  virtual wchar make_wchar(unsigned char c0, encoding_istream& in) {
+    return wchar(c0);
+  }
+  virtual wchar make_wchar(unsigned char c0, FILE *fp) { 
+    encoding_istream_fp in(fp);
+    return make_wchar(c0, in);
+  }
+  virtual wchar make_wchar(unsigned char c0, const unsigned char *s, int *i) {
+    encoding_istream_str in(s, i);
+    return make_wchar(c0, in); 
+  }
+
+  virtual int put_wchar(wchar wc, encoding_ostream& out) {
+    out.putbyte((unsigned char)wc);
+    return 1;
+  }
+
+  virtual int put_wchar(wchar wc, FILE *fp, const char *fmt = "%c") {
+    encoding_ostream_fp out(fp, fmt);
+    return put_wchar(wc, out);
+  }
+  virtual int put_wchar(wchar wc, unsigned char *s, int *i, int maxlen) {
+    encoding_ostream_str out(s, i, maxlen);
+    return put_wchar(wc, out);
+  }
+  virtual int max_wchar_len() { return 1; };
+
+  virtual void foreach_wchar(void (*iter)(wchar wc, void *arg), void *arg) {};
+  virtual int wchar_iter_first(wchar *wc) { return 0; };
+  virtual int wchar_iter_next(wchar *wc) { return 0; };
+
+  // for indexer
+  virtual int wchar_index(wchar wc) { return 0; };
+  virtual void set_wchar_index(wchar wc, int index) { return; };
+
+  // for troff/input.cc
+  virtual int wchar_table_index(wchar wc) { return 0; };
+  virtual void* init_table() { return NULL;};
+};
+
+encoding_handler* new_encoding_handler(const char* encoding_name);
+extern encoding_handler* encoding;
+encoding_handler *init_encoding_handler();
+
+#endif
+
+#endif ENCODING_H
+
--- groff-1.18.orig/src/include/eucmac.h
+++ groff-1.18/src/include/eucmac.h
@@ -0,0 +1,88 @@
+// -*- C++ -*-
+/* Copyright (C) 1994 Free Software Foundation, Inc.
+     Written by Toshiyuki Kitagawa (kitagawa@bsd2.kb.nec.co.jp)
+
+This file is part of groff.
+
+groff is free software; you can redistribute it and/or modify it under
+the terms of the GNU General Public License as published by the Free
+Software Foundation; either version 2, or (at your option) any later
+version.
+
+groff is distributed in the hope that it will be useful, but WITHOUT ANY
+WARRANTY; without even the implied warranty of MERCHANTABILITY or
+FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+for more details.
+
+You should have received a copy of the GNU General Public License along
+with groff; see the file COPYING.  If not, write to the Free Software
+Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */
+
+
+#ifndef _EUCMAC_H
+#define _EUCMAC_H
+
+#include <string.h>
+#include "device.h"
+
+#ifdef NIPPON
+typedef unsigned int	wchar;
+#else
+typedef char	wchar;
+#endif
+
+static const int WCTABLE_OFFSET = 0xa1;
+static const int WCTABLE_SIZE = 94;
+static const int EUCMASK = 0x8080;
+
+
+inline int is_euc_code(wchar wc)
+{
+  if ( device ) {
+       if ((strncmp(device, "latin1", 6) == 0) ||
+           (strncmp(device, "ascii8", 6) == 0)) {
+               return(0);
+       }
+  }
+  return((wc & EUCMASK) == (wchar)EUCMASK);
+}
+
+inline int is_euc_byte(unsigned char c)
+{
+  if ( device ) {
+       if ((strncmp(device, "latin1", 6) == 0) ||
+           (strncmp(device, "ascii8", 6) == 0)) {
+               return(0);
+       }
+  }
+  return(c >= 0xa1 && c <= 0xfe);
+}
+
+inline wchar make_euc_code(unsigned char ubyte, unsigned char lbyte)
+{
+  wchar wc;
+
+  wc = (ubyte & 0xff) << 8;
+  wc |= (lbyte & 0xff);
+  return(wc);
+}
+
+inline unsigned int euc_ubyte(wchar wc)
+{
+  return((unsigned int)((wc >> 8) & 0xff));
+}
+
+inline unsigned int euc_lbyte(wchar wc)
+{
+  return((unsigned int)(wc & 0xff));
+}
+
+inline wchar calc_euccode(int ku, int ten)
+{
+  wchar code = 0;
+
+  code = ((ku + WCTABLE_OFFSET) << 8) & 0xff00;
+  code |= (ten + WCTABLE_OFFSET) & 0xff;
+  return (code);
+}
+#endif	/* _EUCMAC_H */
--- groff-1.18.orig/src/include/config.h
+++ groff-1.18/src/include/config.h
@@ -0,0 +1,154 @@
+/* src/include/config.h.  Generated by configure.  */
+/* src/include/config.hin.  Generated automatically from configure.ac by autoheader.  */
+
+/* Define if your C++ doesn't understand `delete []'. */
+/* #undef ARRAY_DELETE_NEEDS_SIZE */
+
+/* Define if you have a C++ <limits.h>. */
+#define HAVE_CC_LIMITS_H 1
+
+/* Define if you have a C++ <osfcn.h>. */
+/* #undef HAVE_CC_OSFCN_H */
+
+/* Define if you have the <dirent.h> header file. */
+#define HAVE_DIRENT_H 1
+
+/* Define if you have the `fmod' function. */
+#define HAVE_FMOD 1
+
+/* Define if you have the `getcwd' function. */
+#define HAVE_GETCWD 1
+
+/* Define if you have the `getpagesize' function. */
+#define HAVE_GETPAGESIZE 1
+
+/* Define if you have the `gettimeofday' function. */
+#define HAVE_GETTIMEOFDAY 1
+
+/* Define if you have the <limits.h> header file. */
+#define HAVE_LIMITS_H 1
+
+/* Define if you have the <math.h> header file. */
+#define HAVE_MATH_H 1
+
+/* Define if you have mkstemp(). */
+#define HAVE_MKSTEMP 1
+
+/* Define if you have a working `mmap' system call. */
+#define HAVE_MMAP 1
+
+/* Define if you have the `putenv' function. */
+#define HAVE_PUTENV 1
+
+/* Define if you have the `rename' function. */
+#define HAVE_RENAME 1
+
+/* Define if you have the `snprintf' function. */
+#define HAVE_SNPRINTF 1
+
+/* Define if you have the <stdint.h> header file. */
+#define HAVE_STDINT_H 1
+
+/* Define if you have the <stdlib.h> header file. */
+#define HAVE_STDLIB_H 1
+
+/* Define if you have the `strcasecmp' function. */
+#define HAVE_STRCASECMP 1
+
+/* Define if you have the `strerror' function. */
+#define HAVE_STRERROR 1
+
+/* Define if you have the <strings.h> header file. */
+#define HAVE_STRINGS_H 1
+
+/* Define if you have the <string.h> header file. */
+#define HAVE_STRING_H 1
+
+/* Define if you have the `strncasecmp' function. */
+#define HAVE_STRNCASECMP 1
+
+/* Define if you have the `strsep' function. */
+#define HAVE_STRSEP 1
+
+/* Define if you have the `strtol' function. */
+#define HAVE_STRTOL 1
+
+/* Define if <math.h> defines struct exception. */
+#define HAVE_STRUCT_EXCEPTION 1
+
+/* Define if you have the <sys/dir.h> header file. */
+#define HAVE_SYS_DIR_H 1
+
+/* Define if you have sys_errlist in <errno.h> or in <stdio.h>. */
+#define HAVE_SYS_ERRLIST 1
+
+/* Define if you have sysnerr in <errno.h> or <stdio.h>. */
+#define HAVE_SYS_NERR 1
+
+/* Define if you have the <sys/time.h> header file. */
+#define HAVE_SYS_TIME_H 1
+
+/* Define if you have the <unistd.h> header file. */
+#define HAVE_UNISTD_H 1
+
+/* Define if the host's encoding is EBCDIC. */
+/* #undef IS_EBCDIC_HOST */
+
+/* Define if localtime() takes a long * not a time_t *. */
+/* #undef LONG_FOR_TIME_T */
+
+/* Define if your C++ doesn't declare gettimeofday(). */
+/* #undef NEED_DECLARATION_GETTIMEOFDAY */
+
+/* Define if your C++ doesn't declare hypot(). */
+/* #undef NEED_DECLARATION_HYPOT */
+
+/* Define if your C++ doesn't declare pclose(). */
+/* #undef NEED_DECLARATION_PCLOSE */
+
+/* Define if your C++ doesn't declare popen(). */
+/* #undef NEED_DECLARATION_POPEN */
+
+/* Define if your C++ doesn't declare putenv(). */
+/* #undef NEED_DECLARATION_PUTENV */
+
+/* Define if your C++ doesn't declare strcasecmp(). */
+/* #undef NEED_DECLARATION_STRCASECMP */
+
+/* Define if your C++ doesn't declare strncasecmp(). */
+/* #undef NEED_DECLARATION_STRNCASECMP */
+
+/* Define if the printer's page size is A4. */
+#define PAGEA4 1
+
+/* Define as the return type of signal handlers (`int' or `void'). */
+#define RETSIGTYPE void
+
+/* Define if srand() returns void not int. */
+#define RET_TYPE_SRAND_IS_VOID 1
+
+/* Define if `sys_siglist' is declared by <signal.h> or <unistd.h>. */
+#define SYS_SIGLIST_DECLARED 1
+
+/* Define if your C++ compiler uses a traditional (Reiser) preprocessor. */
+/* #undef TRADITIONAL_CPP */
+
+/* Define if the 0200 bit of the status returned by wait() indicates whether a
+   core image was produced for a process that was terminated by a signal. */
+/* #undef WCOREFLAG */
+
+/* Define if -D_POSIX_SOURCE is necessary. */
+/* #undef _POSIX_SOURCE */
+
+/* Define if you have ISC 3.x or 4.x. */
+/* #undef _SYSV3 */
+
+/* Define uintmax_t to `unsigned long' or `unsigned long long' if <inttypes.h>
+   does not exist. */
+/* #undef uintmax_t */
+
+/* Define if you want to use Japanese extension. */
+#define NIPPON 1
+
+/* Define if you have a nl_langinfo(CODESET). */
+#define HAVE_LANGINFO_CODESET 1
--- groff-1.18.orig/src/libs/libgroff/Makefile.sub
+++ groff-1.18/src/libs/libgroff/Makefile.sub
@@ -6,6 +6,7 @@
   color.o \
   cset.o \
   device.o \
+  encoding.o \
   errarg.o \
   error.o \
   fatal.o \
@@ -45,6 +46,7 @@
   $(srcdir)/color.cc \
   $(srcdir)/cset.cc \
   $(srcdir)/device.cc \
+  $(srcdir)/encoding.cc \
   $(srcdir)/errarg.cc \
   $(srcdir)/error.cc \
   $(srcdir)/fatal.cc \
--- groff-1.18.orig/src/libs/libgroff/font.cc
+++ groff-1.18/src/libs/libgroff/font.cc
@@ -25,6 +25,7 @@
 #include <assert.h>
 #include <math.h>
 #include <stdlib.h>
+#include "encoding.h" // XXX: ukai
 #include "errarg.h"
 #include "error.h"
 #include "cset.h"
@@ -43,6 +44,9 @@
   int italic_correction;
   int subscript_correction;
   char *special_device_coding;
+#ifdef NIPPON
+  char *subfont_name;
+#endif
 };
 
 struct font_kern_list {
@@ -397,6 +401,14 @@
   return( ch[ch_index[c]].special_device_coding );
 }
 
+#ifdef	NIPPON
+const char *font::get_subfont_name(int c)
+{
+  assert(c >= 0 && c < nindices && ch_index[c] >= 0);
+  return ch[ch_index[c]].subfont_name;
+}
+#endif
+
 void font::alloc_ch_index(int index)
 {
   if (nindices == 0) {
@@ -542,7 +554,7 @@
 	fgets(line, 254, f);
 	fclose(f);
 	test_file = 0;
-	char *linep = line;
+	char *linep = strchr(line, '\0');
 	// skip final newline, if any
 	if (*(--linep) == '\n')
 	  *linep = '\0';
@@ -554,12 +566,17 @@
   return 0;
 }
 
+
 // If the font can't be found, then if not_found is non-NULL, it will be set
 // to 1 otherwise a message will be printed.
 
+
 int font::load(int *not_found)
 {
   char *path;
+#ifdef NIPPON
+  int had_fixedkanji = 0;
+#endif
   FILE *fp;
   if ((fp = open_file(name, &path)) == NULL) {
     if (not_found)
@@ -630,6 +647,60 @@
     else if (strcmp(p, "special") == 0) {
       special = 1;
     }
+#ifdef NIPPON
+    else if (strcmp(p, "fixedkanji") == 0) {
+      font_char_metric metric;
+      int last_index;
+
+      had_fixedkanji = 1;
+
+      metric.height = 0;
+      metric.depth = 0;
+      metric.pre_math_space = 0;
+      metric.italic_correction = 0;
+      metric.subscript_correction = 0;
+      metric.special_device_coding = NULL;
+      metric.subfont_name = NULL;
+      p = strtok(0, WS);
+      if (p == 0) {
+	  t.error("missing metric infomation");
+	  return 0;
+      }
+      int nparms = sscanf(p, "%d,%d,%d,%d,%d,%d",
+			  &metric.width, &metric.height, &metric.depth,
+			  &metric.italic_correction,
+			  &metric.pre_math_space,
+			  &metric.subscript_correction);
+      if (nparms < 1) {
+	  t.error("bad width");
+	  return 0;
+      }
+      p = strtok(0, WS);
+      if (p == 0) {
+	  t.error("missing character type");
+	  return 0;
+      }
+      int type;
+      if (sscanf(p, "%d", &type) != 1) {
+	  t.error("bad character type");
+	  return 0;
+      }
+      if (type < 0 || type > 255) {
+	  t.error("character type `%1' out of range", type);
+	  return 0;
+      }
+      metric.type = type;
+
+      wchar wc;
+
+      for (encoding->wchar_iter_first(&wc); encoding->wchar_iter_next(&wc);) {
+	metric.code = wc;
+	last_index = wchar_index(wc);
+	add_entry(last_index, metric);
+	copy_entry(number_to_index(metric.code), last_index);
+      }
+    }
+#endif
     else if (strcmp(p, "kernpairs") != 0 && strcmp(p, "charset") != 0) {
       char *command = p;
       p = strtok(0, "\n");
@@ -680,6 +751,10 @@
       }
     }
     else if (strcmp(command, "charset") == 0) {
+#ifdef	NIPPON
+      if (had_fixedkanji)
+	goto end;
+#endif
       had_charset = 1;
       int last_index = -1;
       for (;;) {
@@ -718,6 +793,10 @@
 	  metric.pre_math_space = 0;
 	  metric.italic_correction = 0;
 	  metric.subscript_correction = 0;
+#ifdef NIPPON
+	  metric.special_device_coding = NULL;
+	  metric.subfont_name = NULL;
+#endif
 	  int nparms = sscanf(p, "%d,%d,%d,%d,%d,%d",
 			      &metric.width, &metric.height, &metric.depth,
 			      &metric.italic_correction,
@@ -747,6 +826,16 @@
 	    t.error("missing code for `%1'", nm);
 	    return 0;
 	  }
+#ifdef	NIPPON
+	  char *subp = strchr(p, ':');
+	  if (subp) {
+	    *subp++ = '\0';
+	    metric.subfont_name = new char[strlen(subp) + 1];
+	    strcpy(metric.subfont_name, subp);
+	  } else {
+	    metric.subfont_name = NULL;
+	  }
+#endif
 	  char *ptr;
 	  metric.code = (int)strtol(p, &ptr, 0);
 	  if (metric.code == 0 && ptr == p) {
@@ -791,6 +880,9 @@
     t.error("missing charset command");
     return 0;
   }
+#ifdef	NIPPON
+ end:
+#endif
   if (space_width == 0)
     space_width = scale_round(unitwidth, res, 72*3*sizescale);
   compact();
@@ -811,6 +903,11 @@
   { "biggestfont", &font::biggestfont },
   { "spare2", &font::spare2 },
   { "sizescale", &font::sizescale }
+#ifdef	NIPPON
+  ,
+  { "lowerwchar", &font::lowerwchar },
+  { "wcharkern", &font::wcharkern }
+#endif
   };
 
 int font::load_desc()
@@ -888,16 +985,22 @@
 	t.error("papersize command requires an argument");
 	return 0;
       }
-      double unscaled_paperwidth, unscaled_paperlength;
-      if (!scan_papersize(p, &papersize, &unscaled_paperlength,
-			  &unscaled_paperwidth)) {
+      int found_paper = 0;
+      while (p) {
+	double unscaled_paperwidth, unscaled_paperlength;
+	if (scan_papersize(p, &papersize, &unscaled_paperlength,
+			   &unscaled_paperwidth)) {
+	  paperwidth = int(unscaled_paperwidth * res + 0.5);
+	  paperlength = int(unscaled_paperlength * res + 0.5);
+	  found_paper = 1;
+	  break;
+	}
+	p = strtok(0, WS);
+      }
+      if (!found_paper) {
 	t.error("bad paper size");
 	return 0;
       }
-      else {
-	paperwidth = int(unscaled_paperwidth * res + 0.5);
-	paperlength = int(unscaled_paperlength * res + 0.5);
-      }
     }
     else if (strcmp("pass_filenames", p) == 0)
       pass_filenames = 1;
@@ -975,6 +1078,24 @@
       tcommand = 1;
     else if (strcmp("use_charnames_in_special", p) == 0)
       use_charnames_in_special = 1;
+#ifdef	NIPPON
+    else if (strcmp("ondemand", p) == 0) { 
+      int table_size = 3;	// enough room for M and G.
+      on_demand_fonts = (const char **)new char *[table_size];
+      for (int j = 0; j < table_size; j++)
+	on_demand_fonts[j] = 0;
+      int i = 0;
+      for (;;) {
+	p = strtok(0, WS);
+	if (p == 0)
+	  break;
+	assert(i + 1 < table_size);	// scamped work  *^_^*
+	char *tem = new char[strlen(p) + 1];
+	strcpy(tem, p);
+	on_demand_fonts[i++] = tem;
+      }
+    }
+#endif
     else if (strcmp("charset", p) == 0)
       break;
     else if (unknown_desc_command_handler) {
--- groff-1.18.orig/src/libs/libgroff/fontfile.cc
+++ groff-1.18/src/libs/libgroff/fontfile.cc
@@ -24,6 +24,7 @@
 #include <assert.h>
 #include <stdlib.h>
 #include <errno.h>
+#include "encoding.h" // XXX: ukai
 #include "font.h"
 #include "searchpath.h"
 #include "device.h"
@@ -36,6 +37,10 @@
 int font::res = 0;
 int font::hor = 1;
 int font::vert = 1;
+#ifdef	NIPPON
+int font::lowerwchar = 0;
+int font::wcharkern = 0;
+#endif
 int font::unitwidth = 0;
 int font::paperwidth = 0;
 int font::paperlength = 0;
@@ -50,6 +55,9 @@
 int *font::sizes = 0;
 const char *font::family = 0;
 const char **font::style_table = 0;
+#ifdef	NIPPON
+const char **font::on_demand_fonts = 0;
+#endif
 FONT_COMMAND_HANDLER font::unknown_desc_command_handler = 0;
 
 void font::command_line_font_dir(const char *dir)
--- groff-1.18.orig/src/libs/libgroff/nametoindex.cc
+++ groff-1.18/src/libs/libgroff/nametoindex.cc
@@ -24,6 +24,7 @@
 #include <ctype.h>
 #include <assert.h>
 #include <stdlib.h>
+#include "encoding.h" // XXX: ukai
 #include "errarg.h"
 #include "error.h"
 #include "font.h"
@@ -37,6 +38,9 @@
   character_indexer();
   ~character_indexer();
   int ascii_char_index(unsigned char);
+#ifdef	NIPPON
+  int wchar_index(wchar);
+#endif
   int named_char_index(const char *);
   int numbered_char_index(int);
 private:
@@ -68,6 +72,15 @@
   return ascii_index[c];
 }
 
+#ifdef	NIPPON
+int character_indexer::wchar_index(wchar wc)
+{
+  if (encoding->wchar_index(wc) < 0)
+    encoding->set_wchar_index(wc, next_index++);
+  return encoding->wchar_index(wc);
+}
+#endif
+
 int character_indexer::numbered_char_index(int n)
 {
   if (n >= 0 && n < NSMALL) {
@@ -103,6 +116,15 @@
 int font::name_to_index(const char *s)
 {
   assert(s != 0 && s[0] != '\0' && s[0] != ' ');
+#ifdef	NIPPON
+ {
+   int i = 1;
+   wchar wc = encoding->make_wchar(s[0], (const unsigned char *)s, &i);
+   if (encoding->is_wchar_code(wc)) {
+    return indexer.wchar_index(wc);
+   }
+ }
+#endif
   if (s[1] == '\0')
     return indexer.ascii_char_index(s[0]);
   /* char128 and \200 are synonyms */
@@ -115,3 +137,9 @@
   return indexer.named_char_index(s);
 }
 
+#ifdef	NIPPON
+int font::wchar_index(wchar wc)
+{
+  return indexer.wchar_index(wc);
+}
+#endif
--- groff-1.18.orig/src/libs/libgroff/searchpath.cc
+++ groff-1.18/src/libs/libgroff/searchpath.cc
@@ -19,6 +19,7 @@
 with groff; see the file COPYING.  If not, write to the Free Software
 Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 
+#include "encoding.h"
 #include "lib.h"
 
 #include <stdlib.h>
--- groff-1.18.orig/src/libs/libgroff/tmpfile.cc
+++ groff-1.18/src/libs/libgroff/tmpfile.cc
@@ -24,6 +24,7 @@
 #include <errno.h>
 #include <stdlib.h>
 
+#include "encoding.h"
 #include "posix.h"
 #include "errarg.h"
 #include "error.h"
--- groff-1.18.orig/src/libs/libgroff/encoding.cc
+++ groff-1.18/src/libs/libgroff/encoding.cc
@@ -0,0 +1,234 @@
+// -*- C++ -*-
+/* Copyright (C) 2001 Fumitoshi UKAI <ukai@debian.or.jp>
+
+This file is part of groff.
+
+groff is free software; you can redistribute it and/or modify it under
+the terms of the GNU General Public License as published by the Free
+Software Foundation; either version 2, or (at your option) any later
+version.
+
+groff is distributed in the hope that it will be useful, but WITHOUT ANY
+WARRANTY; without even the implied warranty of MERCHANTABILITY or
+FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+
+#include "encoding.h"
+#include <string.h>
+#ifdef NIPPON
+#include <locale.h>
+#if HAVE_LANGINFO_CODESET
+#include <langinfo.h>
+#else
+#include <stdlib.h>
+#endif
+#endif
+
+class ascii8_handler : public encoding_handler {
+public:
+  ascii8_handler() {}
+  ~ascii8_handler() {}
+
+  inline int is_wchar_code(wchar wc) { return 0; }
+  inline int is_wchar_byte(unsigned char c) { return 0; }
+
+  inline wchar make_wchar(unsigned char c0, encoding_istream& in) {
+    return wchar(c0);
+  }
+  inline int put_wchar(wchar wc, encoding_ostream& out) {
+    out.putbyte((unsigned char)wc);
+    return 1;
+  }
+  inline int max_wchar_len() { return 1; };
+
+  inline void foreach_wchar(void (*iter)(wchar wc, void *arg), void *arg) {
+    return;
+  }
+  inline int wchar_iter_first(wchar *wc) {
+    return 0;
+  }
+  inline int wchar_iter_next(wchar *wc) {
+    return 0;
+  }
+
+  inline int wchar_index(wchar wc) {
+    return 0;
+  }
+
+  inline void set_wchar_index(wchar wc, int index) {
+    return;
+  }
+
+  inline int wchar_table_index(wchar wc) { return 0; }
+  inline void* init_table() { return NULL;  }
+};
+
+#ifdef NIPPON
+class euc_handler : public encoding_handler {
+  static const int WCTABLE_OFFSET = 0xa1;
+  static const int WCTABLE_SIZE = 94;
+  static const int EUCMASK = 0x8080;
+
+private:
+  int euc_index[WCTABLE_SIZE][WCTABLE_SIZE];
+  int iter_ku, iter_ten;
+
+public:
+  euc_handler() {
+    for (int i = 0; i < WCTABLE_SIZE; i++) {
+      for (int j = 0; j < WCTABLE_SIZE; j++) {
+	euc_index[i][j] = -1;
+      }
+    }
+  };
+  ~euc_handler() {};
+
+  inline int is_wchar_code(wchar wc) {
+    return ((wc & EUCMASK) == (wchar)EUCMASK);
+  }
+
+  inline int is_wchar_byte(unsigned char c) {
+    return (c >= 0xa1 && c <= 0xfe);
+  }
+
+  inline wchar make_wchar(unsigned char c0, encoding_istream& in) {
+    wchar wc;
+    if (! is_wchar_byte(c0)) {
+      return c0;
+    }
+    int c1 = in.peekbyte();
+    if (! is_wchar_byte(c1)) {
+      return c0;
+    }
+    c1 = in.getbyte();
+    wc = (c0 & 0xff) << 8;
+    wc |= (c1 & 0xff);
+
+    if (wc == 0xa1a1)
+      wc = ' ';
+    return wc;
+  }
+
+  inline int put_wchar(wchar wc, encoding_ostream& out) {
+    if (is_wchar_code(wc)) {
+      out.putbyte((wc >> 8) & 0x0ff);
+      out.putbyte((wc >> 0) & 0x0ff);
+      return 2;    
+    } else {
+      out.putbyte(wc & 0x0ff);
+      return 1;
+    }
+  }
+  inline int max_wchar_len() { return 2; }; /* XXX */
+
+  inline void foreach_wchar(void (*iter)(wchar wc, void *arg), void *arg) {
+    int ku, ten;
+    wchar wc;
+    for (ku = 0; ku < WCTABLE_SIZE; ku++) {
+      for (ten = 0; ten < WCTABLE_SIZE; ten++) {
+	wc = 0;
+	wc = ((ku + WCTABLE_OFFSET) << 8) & 0xff00;
+	wc |= (ten + WCTABLE_OFFSET) & 0xff;
+	iter(wc, arg);
+      }
+    }
+  }
+  inline int wchar_iter_first(wchar *wc) {
+    iter_ku = iter_ten = 0;
+    *wc = 0;
+    *wc = ((iter_ku + WCTABLE_OFFSET) << 8) & 0xff00;
+    *wc |= (iter_ten + WCTABLE_OFFSET) & 0xff;
+    return 1;
+  }
+  inline int wchar_iter_next(wchar *wc) {
+    *wc = 0;
+    iter_ten++;
+    if (iter_ten >= WCTABLE_SIZE) {
+      iter_ten = 0; 
+      iter_ku++;
+      if (iter_ku >= WCTABLE_SIZE) {
+	return 0;
+      }
+    }
+    *wc = ((iter_ku + WCTABLE_OFFSET) << 8) & 0xff00;
+    *wc |= (iter_ten + WCTABLE_OFFSET) & 0xff;
+    return 1;
+  }
+
+  inline int wchar_index(wchar wc) {
+    int ku = ((wc >> 8) & 0xff) - WCTABLE_OFFSET;
+    int ten = (wc & 0xff) - WCTABLE_OFFSET;
+    return euc_index[ku][ten];
+  }
+
+  inline void set_wchar_index(wchar wc, int index) {
+    int ku = ((wc >> 8) & 0xff) - WCTABLE_OFFSET;
+    int ten = (wc & 0xff) - WCTABLE_OFFSET;
+    euc_index[ku][ten] = index;
+  }
+
+  inline int wchar_table_index(wchar wc) {
+    int ku = ((wc >> 8) & 0xff) - WCTABLE_OFFSET;
+    int ten = (wc & 0xff) - WCTABLE_OFFSET;
+    return ku * WCTABLE_SIZE + ten;
+  }
+  inline void* init_table() { 
+    void *tbl = new void*[WCTABLE_SIZE * WCTABLE_SIZE];
+    memset(tbl, 0, WCTABLE_SIZE * WCTABLE_SIZE);
+    return tbl;
+  }
+};
+#endif
+
+static ascii8_handler ascii8;
+#ifdef NIPPON
+static euc_handler eucjp;
+#endif
+
+encoding_handler *encoding = &ascii8;
+
+encoding_handler *
+new_encoding_handler(const char *encoding_name)
+{
+#ifdef NIPPON
+  // printf("encoding request: [%s]\n", encoding_name);
+  if (strcmp(encoding_name, "EUC-JP") == 0) {
+    // printf("encoding: [EUC-JP]\n");
+    encoding = &eucjp;
+    return &eucjp;
+  }
+#endif
+  // default
+  encoding = &ascii8;
+  return &ascii8;
+}
+
+encoding_handler *
+init_encoding_handler()
+{
+#ifdef NIPPON
+  const char *locale;
+  setlocale(LC_ALL, "");
+#if HAVE_LANGINFO_CODESET
+  locale = nl_langinfo(CODESET);
+#else
+  /* Emulation taken from gettext's locale_charset() function. */
+  locale = setlocale(LC_CTYPE, NULL);
+  if (locale == NULL || locale[0] == '\0') {
+    locale = getenv("LC_ALL");
+    if (locale == NULL || locale[0] == '\0') {
+      locale = getenv("LC_CTYPE");
+      if (locale == NULL || locale[0] == '\0')
+	locale = getenv("LANG");
+    }
+  }
+#endif
+  new_encoding_handler(locale);
+#endif
+
+  return encoding;
+}
--- groff-1.18.orig/src/libs/libdriver/input.cc
+++ groff-1.18/src/libs/libdriver/input.cc
@@ -250,6 +250,7 @@
 
 #include "driver.h"
 #include "device.h"
+#include "encoding.h"
 
 #include <stdlib.h>
 #include <errno.h>
@@ -1512,6 +1513,17 @@
   return stopped;
 }
 
+////////////////////////////////////////////////////////////////
+#ifdef	NIPPON
+class encoding_istream_current_file : public encoding_istream {
+public:
+  encoding_istream_current_file() {};
+  ~encoding_istream_current_file() {};
+  int getbyte() { return getc(current_file); };
+  int peekbyte() { int ch = getc(current_file); ungetc(ch, current_file); return ch; };
+  void ungetbyte(int c) { ungetc(c, current_file); };
+};
+#endif
 
 /**********************************************************************
                      exported part (by driver.h)
@@ -1758,6 +1770,16 @@
 	size_t i = 0;
 	while ((c = str_arg[i++]) != '\0') {
 	  EnvInt w;
+#ifdef	NIPPON
+ 	  if (encoding->is_wchar_byte(c)) {
+ 	    wchar wc = encoding->make_wchar(c, (const unsigned char *)str_arg, (int *)&i);
+ 	    if (encoding->is_wchar_code(wc)) {
+ 	      pr->set_wchar_char(wc, current_env, &w);
+ 	    } else {
+ 	      pr->set_ascii_char((unsigned char) c, current_env, &w);
+ 	    }
+ 	  } else
+#endif
 	  pr->set_ascii_char((unsigned char) c, current_env, &w);
 	  current_env->hpos += w;
 	}
--- groff-1.18.orig/src/libs/libdriver/printer.cc
+++ groff-1.18/src/libs/libdriver/printer.cc
@@ -27,6 +27,7 @@
 */
 
 #include "driver.h"
+#include "encoding.h"
 
 printer *pr = 0;
 
@@ -137,6 +138,19 @@
     *widthp = w;
   }
 }
+
+#ifdef	NIPPON
+void printer::set_wchar_char(wchar c, const environment *env, int *widthp)
+{
+  int len = encoding->max_wchar_len() + 1;
+  unsigned char *buf = new unsigned char[len];
+  memset(buf, 0, len);
+  int i = 0;
+  encoding->put_wchar(c, buf, &i, len);
+  set_special_char((const char *)buf, env, widthp);
+  delete [] buf;
+}
+#endif
 
 void printer::set_special_char(const char *nm, const environment *env,
 			       int *widthp)
--- groff-1.18.orig/src/roff/groff/groff.cc
+++ groff-1.18/src/roff/groff/groff.cc
@@ -106,6 +106,7 @@
   program_name = argv[0];
   static char stderr_buf[BUFSIZ];
   setbuf(stderr, stderr_buf);
+  init_encoding_handler();
   assert(NCOMMANDS <= MAX_COMMANDS);
   string Pargs, Largs, Fargs;
   int vflag = 0;
--- groff-1.18.orig/src/roff/groff/groff.man
+++ groff-1.18/src/roff/groff/groff.man
@@ -948,6 +948,10 @@
 Text output using the EBCDIC code page IBM cp1047 (e.g. OS/390 Unix).
 .
 .TP
+.B nippon
+Text output using the Japanese-EUC character set.
+.
+.TP
 .B dvi
 TeX DVI format.
 .
@@ -955,6 +959,12 @@
 .B html
 HTML output.
 .
+.TP
+.B ascii8
+For typewriter-like devices.  Unlike
+.BR ascii ,
+this device is 8 bit clean.  This device is intended to be used
+for codesets other than ASCII and ISO-8859-1.
 .TP
 .B latin1
 Text output using the ISO Latin-1 (ISO 8859-1) character set; see
--- groff-1.18.orig/src/roff/groff/pipeline.h
+++ groff-1.18/src/roff/groff/pipeline.h
@@ -24,7 +24,7 @@
 #endif
 
 /* run_pipeline can handle at most this many commands */
-#define MAX_COMMANDS 10
+#define MAX_COMMANDS 12
 
 /* Children exit with this status if execvp fails. */
 #define EXEC_FAILED_EXIT_STATUS 0xff
--- groff-1.18.orig/src/roff/troff/charinfo.h
+++ groff-1.18/src/roff/troff/charinfo.h
@@ -29,9 +29,16 @@
   macro *mac;
   unsigned char special_translation;
   unsigned char hyphenation_code;
+#ifdef NIPPON
+  unsigned short flags;
+#else
   unsigned char flags;
+#endif
   unsigned char ascii_code;
   unsigned char asciify_code;
+#ifdef NIPPON
+  wchar wchar_code;
+#endif
   char not_found;
   char transparent_translate;	// non-zero means translation applies
 				// to transparent throughput
@@ -47,6 +54,11 @@
     OVERLAPS_VERTICALLY = 16,
     TRANSPARENT = 32,
     NUMBERED = 64
+#ifdef	NIPPON
+    ,
+    DONT_BREAK_BEFORE = 0x100,	// 256, pre kinsoku
+    DONT_BREAK_AFTER = 0x200	// 512, post kinsoku
+#endif
     };
   enum {
     TRANSLATE_NONE,
@@ -74,7 +86,11 @@
   int get_translation_input();
   charinfo *get_translation(int = 0);
   void set_translation(charinfo *, int, int);
+#ifdef NIPPON
+  void set_flags(unsigned short);
+#else
   void set_flags(unsigned char);
+#endif
   void set_special_translation(int, int);
   int get_special_translation(int = 0);
   macro *set_macro(macro *, int = 0);
@@ -84,6 +100,12 @@
   int get_number();
   int numbered();
   int is_fallback();
+#ifdef	NIPPON
+  wchar get_wchar_code();
+  void set_wchar_code(wchar);
+  int cannot_break_before(); // pre kinsoku
+  int cannot_break_after(); // post kinsoku
+#endif
   symbol *get_symbol();
 };
 
@@ -131,6 +153,19 @@
   return fallback;
 }
 
+#ifdef	NIPPON
+inline int charinfo::cannot_break_before()
+{
+  return flags & DONT_BREAK_BEFORE;
+}
+
+inline int charinfo::cannot_break_after()
+{
+  return flags & DONT_BREAK_AFTER;
+}
+
+#endif
+
 inline charinfo *charinfo::get_translation(int transparent_throughput)
 {
   return (transparent_throughput && !transparent_translate
@@ -153,7 +188,18 @@
   return (translate_input ? asciify_code : 0);
 }
 
+#ifdef	NIPPON
+inline wchar charinfo::get_wchar_code()
+{
+  return wchar_code;
+}
+#endif
+
+#ifdef	NIPPON
+inline void charinfo::set_flags(unsigned short c)
+#else
 inline void charinfo::set_flags(unsigned char c)
+#endif
 {
   flags = c;
 }
--- groff-1.18.orig/src/roff/troff/env.cc
+++ groff-1.18/src/roff/troff/env.cc
@@ -32,6 +32,7 @@
 #include "charinfo.h"
 #include "macropath.h"
 #include "input.h"
+#include "font.h" // NIPPON only?
 #include <math.h>
 
 symbol default_family("T");
@@ -286,10 +287,82 @@
   else {
     if (line == 0)
       start_line();
+#ifdef	NIPPON
+    if (!ci->get_wchar_code()) {
+      /*
+       * This node is a ASCII character node.
+       */
+      if (!pre_char_is_ascii && enable_wcharkern && !hwkern.is_zero()) {
+	/*
+	 * Insert a little space node between EUC and ASCII.
+	 */
+	word_space_node *ws;
+
+	if (ci->ends_sentence() || ci->transparent() || ci->cannot_break_before())
+	  ws = new unbreakable_space_node(hwkern.to_units());
+	else
+	  ws = new word_space_node(hwkern.to_units(),
+				   new width_list(env_space_width(this),
+						  env_sentence_space_width(this)));
+	curenv->add_node(ws);
+      }
+      pre_char_is_ascii = 1;
+      pre_wchar_cannot_break_after = 0;
+    } else {
+      /*
+       * This node is a EUC charcater node.
+       */
+      if (!pre_char_is_ascii && line->get_node_type() == NODE_NEWLINE_SPACE) {
+	/*
+	 * remove a newline-node.
+	 */
+	node *ns_node = line;
+	line = line->next;
+	width_total -= ns_node->width();
+	space_total -= ns_node->nspaces();
+	delete ns_node;
+      }
+
+      if (!pre_wchar_cannot_break_after && !ci->cannot_break_before()) {
+	/*
+	 * add a zero-width-space-node before EUC charcater node.
+	 */
+	add_node(new kword_space_node());
+	met_with_kword_space = 1;
+      }
+      pre_wchar_cannot_break_after = ci->cannot_break_after();
+
+      if (pre_char_is_ascii && enable_wcharkern && !hwkern.is_zero()) {
+	/*
+	 * Insert a little space node between ASCII and EUC.
+	 */
+	unbreakable_space_node *ws =
+	  new unbreakable_space_node(hwkern.to_units());
+	curenv->add_node(ws);
+      }
+      pre_char_is_ascii = 0;
+
+      if (!vlower.is_zero()) {
+	/*
+	 * Lower a EUC charcater node.
+	 */
+	curenv->add_node(new vmotion_node(vlower.to_units())); // lower
+      }
+    }
+#endif
     if (ci != hyphen_indicator_char)
       line = line->add_char(ci, this, &width_total, &space_total);
     else
       line = line->add_discretionary_hyphen();
+#ifdef	NIPPON
+    enable_wcharkern = 1;
+    if (!vlower.is_zero() && ci->get_wchar_code()) {
+      /*
+       * Raise a EUC charcater node.
+       */
+      curenv->add_node(new vmotion_node(-vlower.to_units())); // raise
+    }
+#endif
   }
 }
 
@@ -394,7 +467,11 @@
     width_total += x;
     return;
   }
+#ifdef	NIPPON
+  add_node(new newline_space_node(x)); // This node may be removed.
+#else
   add_node(new word_space_node(x, w));
+#endif
   possibly_break_line(0, spread_flag);
   spread_flag = 0;
 }
@@ -479,6 +556,27 @@
     warning(WARN_FONT, "bad font number");
 }
 
+#ifdef	NIPPON
+void environment::change_curfont(symbol nm)
+{
+  int n = symbol_fontno(nm);
+  if (n < 0) {
+    n = next_available_font_position();
+    if (!mount_font(n, nm))
+      return;
+  }
+  fontno = n;
+}
+
+void environment::change_curfont(int n)
+{
+  if (is_good_fontno(n))
+    fontno = n;
+  else
+    error("bad font number");
+}
+#endif /* NIPPON */
+
 void environment::set_family(symbol fam)
 {
   if (interrupted)
@@ -648,6 +746,16 @@
   control_char('.'),
   no_break_control_char('\''),
   hyphen_indicator_char(0)
+#ifdef	NIPPON
+  ,
+  stretch_threshold(0),
+  pre_wchar_cannot_break_after(0),
+  pre_char_is_ascii(-1),
+  enable_wcharkern(0),
+  met_with_kword_space(0),
+  hwkern(font::wcharkern),
+  vlower(font::lowerwchar)
+#endif
 {
   prev_family = family = lookup_family(default_family);
   prev_fontno = fontno = 1;
@@ -738,6 +846,16 @@
   control_char(e->control_char),
   no_break_control_char(e->no_break_control_char),
   hyphen_indicator_char(e->hyphen_indicator_char)
+#ifdef	NIPPON
+  ,
+  stretch_threshold(e->stretch_threshold),
+  pre_wchar_cannot_break_after(0),
+  pre_char_is_ascii(-1),
+  enable_wcharkern(0),
+  met_with_kword_space(0),
+  hwkern(font::wcharkern),
+  vlower(font::lowerwchar)
+#endif
 {
 }
 
@@ -1779,6 +1897,9 @@
   target_text_length = line_length - saved_indent;
   width_total = H0;
   space_total = 0;
+#ifdef	NIPPON
+  enable_wcharkern = 0;
+#endif
 }
 
 hunits environment::get_hyphenation_space()
@@ -1817,6 +1938,23 @@
   skip_line();
 }
 
+#ifdef NIPPON
+void stretch_threshold_request()
+{
+  int n;
+  if (has_arg() && get_integer(&n)) {
+      if (n < 0 || n > 100) {
+	  warning(WARN_RANGE, "stretch threshold value %1 out of range", n);
+      } else {
+	  curenv->stretch_threshold = n;
+      }
+  } else {
+      curenv->stretch_threshold = 0;
+  }
+  skip_line();
+}
+#endif
+
 breakpoint *environment::choose_breakpoint()
 {
   hunits x = width_total;
@@ -2012,6 +2150,30 @@
 	     // When a macro follows a paragraph in fill mode, the
 	     // current line should not be empty.
 	     || (width_total - line->width()) > target_text_length)) {
+#ifdef NIPPON
+    if (met_with_kword_space) {
+      node *linep = line;
+      node *prep = 0;
+      while (linep->next) {
+      if (linep->next->get_node_type() == NODE_GLYPH)
+        prep = 0;
+      else if (linep->next->get_node_type() == NODE_KWORD_SPACE)
+        prep = linep;
+        linep = linep->next;
+      }
+      if (prep) {
+        /*
+         * delete a kword_space_node which is in the top of line.
+         */
+        linep = prep->next;
+        prep->next = linep->next;
+        width_total -= linep->width();
+        space_total -= linep->nspaces();
+        delete linep;
+      }
+      met_with_kword_space = 0;
+    }
+#endif
     hyphenate_line(start_here);
     breakpoint *bp = choose_breakpoint();
     if (bp == 0)
@@ -2024,6 +2186,15 @@
     bp->nd->split(bp->index, &pre, &post);
     *ndp = post;
     hunits extra_space_width = H0;
+#ifdef NIPPON
+    int sv_adjust_mode = adjust_mode;
+    if (stretch_threshold) {
+	int ratio = bp->width * 100 / target_text_length;
+	if ( ratio < stretch_threshold) {
+	    adjust_mode = ADJUST_LEFT;
+	}
+    }
+#endif
     switch(adjust_mode) {
     case ADJUST_BOTH:
       if (bp->nspaces != 0)
@@ -2039,6 +2210,9 @@
       saved_indent += target_text_length - bp->width;
       break;
     }
+#ifdef NIPPON
+    adjust_mode = sv_adjust_mode;
+#endif
     distribute_space(pre, bp->nspaces, extra_space_width);
     hunits output_width = bp->width + extra_space_width;
     input_line_start -= output_width;
@@ -3230,6 +3404,9 @@
   init_request("hys", hyphenation_space_request);
   init_request("hym", hyphenation_margin_request);
   init_request("pvs", post_vertical_spacing);
+#ifdef NIPPON
+  init_request("stt", stretch_threshold_request);
+#endif
   init_int_env_reg(".f", get_font);
   init_int_env_reg(".b", get_bold);
   init_hunits_env_reg(".i", get_indent);
--- groff-1.18.orig/src/roff/troff/env.h
+++ groff-1.18/src/roff/troff/env.h
@@ -183,6 +183,15 @@
 #ifdef WIDOW_CONTROL
   int widow_control;
 #endif /* WIDOW_CONTROL */
+#ifdef	NIPPON
+  int stretch_threshold;
+  int pre_wchar_cannot_break_after;
+  int pre_char_is_ascii;
+  int enable_wcharkern;
+  int met_with_kword_space;
+  hunits hwkern;
+  vunits vlower;
+#endif
   int ignore_next_eol;
   int emitted_node;    // have we emitted a node since the last html eol tag?
   color *cur_glyph_color;
@@ -279,6 +288,10 @@
   void wrap_up_tab();
   void set_font(int);
   void set_font(symbol);
+#ifdef	NIPPON
+  void change_curfont(int);
+  void change_curfont(symbol);
+#endif
   void set_family(symbol);
   void set_size(int);
   void set_char_height(int);
@@ -347,6 +360,9 @@
 #ifdef WIDOW_CONTROL
   friend void widow_control_request();
 #endif /* WIDOW_CONTROL */
+#ifdef	NIPPON
+  friend void stretch_threshold_request();
+#endif
 
   friend void do_divert(int append, int boxing);
 };
--- groff-1.18.orig/src/roff/troff/input.cc
+++ groff-1.18/src/roff/troff/input.cc
@@ -35,6 +35,7 @@
 #include "macropath.h"
 #include "defs.h"
 #include "input.h"
+#include "encoding.h" // XXX: ukai
 
 // Needed for getpid().
 #include "posix.h"
@@ -100,6 +101,27 @@
 charinfo *charset_table[256];
 unsigned char hpf_code_table[256];
 
+#ifdef	NIPPON
+charinfo **wcharset_table = NULL;
+
+charinfo *wcharset_table_entry(wchar wc)
+{
+  return wcharset_table[encoding->wchar_table_index(wc)];
+}
+
+static int mount_on_demand(const char *font_name)
+{
+  const char **p = font::on_demand_fonts;
+
+  while (p && *p) {
+    if (strcmp(*p, font_name) == 0)
+      return(1);
+    p++;
+  }
+  return(0);
+}    
+#endif /* NIPPON */
+
 static int warning_mask = DEFAULT_WARNING_MASK;
 static int inhibit_errors = 0;
 static int ignoring = 0;
@@ -1533,6 +1555,19 @@
   type = TOKEN_NEWLINE;
 }
 
+#ifdef NIPPON
+class encoding_istream_input : public encoding_istream {
+private:
+  node **np;
+public:
+  encoding_istream_input(node **n) : np(n) {};
+  ~encoding_istream_input() {};
+  int getbyte() { return input_stack::get(np); };
+  int peekbyte() { return input_stack::peek(); };
+  void ungetbyte(int ch) { return; };
+};
+#endif
+
 void token::next()
 {
   if (nd) {
@@ -1542,6 +1577,10 @@
   units x;
   for (;;) {
     node *n;
+#ifdef NIPPON
+    encoding_istream_input einput(&n);
+#endif
+
     int cc = input_stack::get(&n);
     if (cc != escape_char || escape_char == 0) {
     handle_normal_char:
@@ -1693,8 +1732,22 @@
 	}
 	return;
       default:
+#ifdef	NIPPON
+	wc = encoding->make_wchar(cc, einput);
+	if (encoding->is_wchar_code(wc)) {
+	  type = TOKEN_WCHAR;
+	  c = 0;
+	} else if (wc == ' ') {
+	  type = TOKEN_SPACE;
+	  c = cc;
+	} else {
+	  type = TOKEN_CHAR;
+	  c = cc;
+	}
+#else
 	type = TOKEN_CHAR;
 	c = cc;
+#endif
 	return;
       }
     }
@@ -2063,6 +2116,10 @@
   switch(type) {
   case TOKEN_CHAR:
     return c == t.c;
+#ifdef	NIPPON
+  case TOKEN_WCHAR:
+    return wc == t.wc;
+#endif
   case TOKEN_SPECIAL:
     return nm == t.nm;
   case TOKEN_NUMBERED_CHAR:
@@ -2530,6 +2587,9 @@
 {
   int_stack trap_bol_stack;
   int bol = 1;
+#ifdef NIPPON
+  int fontno;
+#endif
   for (;;) {
     int suppress_next = 0;
     switch (tok.type) {
@@ -2569,6 +2629,33 @@
 	}
 	break;
       }
+#ifdef	NIPPON
+    case token::TOKEN_WCHAR:
+      {
+	wchar wch = tok.wc;
+
+	if (possibly_handle_first_page_transition())
+	  ;
+	else {
+	  for (;;) {
+	    fontno = curenv->get_font(); // save a current font #
+	    if (is_boldfont(fontno))
+	      curenv->change_curfont(symbol("G")); // set Gothic font
+	    else
+	      curenv->change_curfont(symbol("M")); // set Mintyo font
+	    curenv->add_char(wcharset_table_entry(wch));
+	    curenv->change_curfont(fontno); // restore a saved font #
+	    tok.next();
+	    if (tok.type != token::TOKEN_WCHAR)
+	      break;
+	    wch = tok.wc;
+	  }
+	  suppress_next = 1;
+	  bol = 0;
+	}
+	break;
+      }
+#endif	/* NIPPON */
     case token::TOKEN_TRANSPARENT:
       {
 	if (bol) {
@@ -5520,6 +5607,37 @@
   }
 }
 
+#ifdef NIPPON
+static void init_wchar_charinfo(wchar wc, void *arg)
+{
+  char buf[16];
+  charinfo *ci;
+  sprintf(buf, "wchar%x", wc);
+  wcharset_table[encoding->wchar_table_index(wc)] = get_charinfo(symbol(buf));
+  ci = wcharset_table[encoding->wchar_table_index(wc)];
+  ci->set_wchar_code(wc);
+}
+
+#if 0
+void encoding_request()
+{
+  symbol nm = get_long_name(1);
+  if (nm.is_null())
+    skip_line();
+  else {
+    while (!tok.newline() && !tok.eof())
+      tok.next();
+    if (wcharset_table)
+      delete [] wcharset_table;
+    new_encoding_handler(nm.contents());
+    wcharset_table = (charinfo**)encoding->init_table();
+    encoding->foreach_wchar(init_wchar_charinfo, wcharset_table);
+    tok.next();
+  }
+}
+#endif
+#endif
+
 const char *asciify(int c)
 {
   static char buf[3];
@@ -6023,6 +6141,10 @@
 {
   if (type == TOKEN_CHAR)
     return charset_table[c];
+#ifdef	NIPPON
+  if (type == TOKEN_WCHAR)
+    return wcharset_table_entry(wc);
+#endif
   if (type == TOKEN_SPECIAL)
     return get_charinfo(nm);
   if (type == TOKEN_NUMBERED_CHAR)
@@ -6071,10 +6193,24 @@
   hunits w;
   int s;
   node *n = 0;
+#ifdef NIPPON
+  int fontno;
+#endif
   switch (type) {
   case TOKEN_CHAR:
     *pp = (*pp)->add_char(charset_table[c], curenv, &w, &s);
     break;
+#ifdef	NIPPON
+  case TOKEN_WCHAR:
+    fontno = curenv->get_font(); // save a current font #
+    if (is_boldfont(fontno))
+      curenv->change_curfont(symbol("G")); // set Gothic font
+    else
+      curenv->change_curfont(symbol("M")); // set Mintyo font
+    *pp = (*pp)->add_char(wcharset_table_entry(wc), curenv, &w, &s);
+    curenv->change_curfont(fontno); // restore a saved font #
+    break;
+#endif
   case TOKEN_DUMMY:
     n = new dummy_node;
     break;
@@ -6134,6 +6270,9 @@
 
 void token::process()
 {
+#ifdef NIPPON
+  int fontno;
+#endif
   if (possibly_handle_first_page_transition())
     return;
   switch (type) {
@@ -6143,6 +6282,17 @@
   case TOKEN_CHAR:
     curenv->add_char(charset_table[c]);
     break;
+#ifdef	NIPPON
+  case TOKEN_WCHAR:
+    fontno = curenv->get_font(); // save a current font #
+    if (is_boldfont(fontno))
+      curenv->change_curfont(symbol("G")); // set Gothic font
+    else
+      curenv->change_curfont(symbol("M")); // set Mintyo font
+    curenv->add_char(wcharset_table_entry(wc));
+    curenv->change_curfont(fontno); // restore a saved font #
+    break;
+#endif
   case TOKEN_DUMMY:
     curenv->add_node(new dummy_node);
     break;
@@ -6768,6 +6918,7 @@
   program_name = argv[0];
   static char stderr_buf[BUFSIZ];
   setbuf(stderr, stderr_buf);
+  init_encoding_handler();
   int c;
   string_list *macros = 0;
   string_list *register_assignments = 0;
@@ -6901,6 +7052,10 @@
   set_string(".T", device);
   init_charset_table();
   init_hpf_code_table();
+#ifdef NIPPON
+  wcharset_table = (charinfo**)encoding->init_table();
+  encoding->foreach_wchar(init_wchar_charinfo, wcharset_table);
+#endif
   if (!font::load_desc())
     fatal("sorry, I can't continue");
   units_per_inch = font::res;
@@ -6923,6 +7078,9 @@
     // In the DESC file a font name of 0 (zero) means leave this
     // position empty.
     if (strcmp(font::font_name_table[i], "0") != 0)
+#ifdef NIPPON
+      if (!mount_on_demand(font::font_name_table[i]))
+#endif
       mount_font(j, symbol(font::font_name_table[i]));
   curdiv = topdiv = new top_level_diversion;
   if (nflag)
@@ -7103,6 +7261,9 @@
   init_request("pi", pipe_output);
   init_request("pm", print_macros);
   init_request("psbb", ps_bbox_request);
+#if 0 /* def NIPPON */
+  init_request("encoding", encoding_request);
+#endif
 #ifndef POPEN_MISSING
   init_request("pso", pipe_source);
 #endif /* not POPEN_MISSING */
@@ -7545,6 +7706,9 @@
 charinfo::charinfo(symbol s)
 : translation(0), mac(0), special_translation(TRANSLATE_NONE),
   hyphenation_code(0), flags(0), ascii_code(0), asciify_code(0),
+#ifdef NIPPON
+  wchar_code(0),
+#endif
   not_found(0), transparent_translate(1), translate_input(0),
   fallback(0), nm(s)
 {
@@ -7589,6 +7753,13 @@
   asciify_code = c;
 }
 
+#ifdef NIPPON
+void charinfo::set_wchar_code(wchar wc)
+{
+  wchar_code = wc;
+}
+#endif
+
 macro *charinfo::set_macro(macro *m, int f)
 {
   macro *tem = mac;
@@ -7644,6 +7815,13 @@
 int font::name_to_index(const char *nm)
 {
   charinfo *ci;
+#ifdef	NIPPON
+  int i = 1;
+  wchar wc = encoding->make_wchar(nm[0], (const unsigned char *)nm, &i);
+  if (encoding->is_wchar_code(wc)) {
+    ci = wcharset_table_entry(wc);
+  } else
+#endif
   if (nm[1] == 0)
     ci = charset_table[nm[0] & 0xff];
   else if (nm[0] == '\\' && nm[2] == 0)
@@ -7660,3 +7838,10 @@
 {
   return get_charinfo_by_number(n)->get_index();
 }
+
+#ifdef	NIPPON
+int font::wchar_index(wchar wc)
+{
+  return(wcharset_table_entry(wc)->get_index());
+}
+#endif
--- groff-1.18.orig/src/roff/troff/node.cc
+++ groff-1.18/src/roff/troff/node.cc
@@ -38,6 +38,7 @@
 #include "input.h"
 #include "div.h"
 #include "geometry.h"
+#include "encoding.h"
 
 #include "nonposix.h"
 
@@ -151,6 +152,9 @@
   int is_special();
   int is_style();
   friend symbol get_font_name(int, environment *);
+#ifdef NIPPON
+  friend int is_boldfont(int);
+#endif
 };
 
 class tfont_spec {
@@ -399,6 +403,15 @@
   return f;
 }
 
+#ifdef	NIPPON
+int is_boldfont(int fontno)
+{
+  hunits h;
+  return font_table[fontno]->get_bold(&h);
+}
+#endif
+
+
 hunits font_info::get_space_width(font_size fs, int space_size)
 {
   if (is_constant_spaced == CONSTANT_SPACE_NONE)
@@ -746,7 +759,11 @@
   symbol *font_position;
   int nfont_positions;
   enum { TBUF_SIZE = 256 };
+#ifdef	NIPPON
+  wchar tbuf[TBUF_SIZE];
+#else
   char tbuf[TBUF_SIZE];
+#endif
   int tbuf_len;
   int tbuf_kern;
   int begun_page;
@@ -756,6 +773,9 @@
   void put(int i);
   void put(unsigned int i);
   void put(const char *s);
+#ifdef	NIPPON
+  void putw(const wchar wc);
+#endif
   void set_font(tfont *tf);
   void flush_tbuf();
 public:
@@ -799,6 +819,13 @@
   putc(c, fp);
 }
 
+#ifdef	NIPPON
+inline void troff_output_file::putw(const wchar wc)
+{
+  encoding->put_wchar(wc, fp);
+}
+#endif
+
 inline void troff_output_file::put(unsigned char c)
 {
   putc(c, fp);
@@ -961,7 +988,11 @@
   check_output_limits(hpos, vpos - current_size);
 
   for (int i = 0; i < tbuf_len; i++)
+#ifdef NIPPON
+    putw(tbuf[i]);
+#else
     put(tbuf[i]);
+#endif
   put('\n');
   tbuf_len = 0;
 }
@@ -992,7 +1023,13 @@
     flush_tbuf();
     set_font(tf);
   }
+#ifdef NIPPON
+  wchar c = ci->get_wchar_code();
+  if (c == '\0')
+    c = ci->get_ascii_code();
+#else
   char c = ci->get_ascii_code();
+#endif
   if (c == '\0') {
     flush_tbuf();
     do_motion();
@@ -1040,13 +1077,21 @@
     if (vpos == output_vpos && n > 0 && n < 100 && !force_motion) {
       put(char(n/10 + '0'));
       put(char(n%10 + '0'));
+#ifdef NIPPON
+      putw(c);
+#else
       put(c);
+#endif
       output_hpos = hpos;
     }
     else {
       do_motion();
       put('c');
+#ifdef NIPPON
+      putw(c);
+#else
       put(c);
+#endif
     }
     hpos += w.to_units() + kk;
   }
@@ -1060,7 +1105,13 @@
 
   if (tf != current_tfont)
     set_font(tf);
+#ifdef	NIPPON
+  wchar c = ci->get_wchar_code();
+  if (c == '\0')
+    c = ci->get_ascii_code();
+#else
   char c = ci->get_ascii_code();
+#endif
   if (c == '\0') {
     do_motion();
     if (ci->numbered()) {
@@ -1084,13 +1135,21 @@
     if (vpos == output_vpos && n > 0 && n < 100) {
       put(char(n/10 + '0'));
       put(char(n%10 + '0'));
+#ifdef NIPPON
+      putw(c);
+#else
       put(c);
+#endif
       output_hpos = hpos;
     }
     else {
       do_motion();
       put('c');
+#ifdef NIPPON
+      putw(c);
+#else
       put(c);
+#endif
     }
   }
 }
@@ -1764,6 +1823,9 @@
   int same(node *);
   const char *type();
   int force_tprint();
+#ifdef	NIPPON
+  node_type get_node_type();
+#endif
 };
 
 glyph_node *glyph_node::free_list = 0;
@@ -2818,6 +2880,7 @@
   bracket_node *on = new bracket_node;
   node *last = 0;
   node *tem;
+  list->last = 0;
   for (tem = list; tem; tem = tem->next) {
     if (tem->next)
       tem->next->last = tem;
@@ -5228,6 +5291,49 @@
 {
   return 0;
 }
+
+#ifdef	NIPPON
+kword_space_node::kword_space_node(node *x) : word_space_node(0, new width_list(0, 0), x)
+{}
+
+node *kword_space_node::copy()
+{
+    return new kword_space_node(0);
+}
+newline_space_node::newline_space_node(hunits d, node *x) : word_space_node(d, new width_list(0, 0), x)
+{}
+
+node *newline_space_node::copy()
+{
+    return new newline_space_node(n);
+}
+
+const char *kword_space_node::type()
+{
+  return "kword_space_node";
+}
+const char *newline_space_node::type()
+{
+  return "newline_space_node";
+}
+
+node_type node::get_node_type()
+{
+    return NODE_ANOTHER;
+}
+node_type glyph_node::get_node_type()
+{
+    return NODE_GLYPH;
+}
+node_type kword_space_node::get_node_type()
+{
+    return NODE_KWORD_SPACE;
+}
+node_type newline_space_node::get_node_type()
+{
+    return NODE_NEWLINE_SPACE;
+}
+#endif
 
 int unbreakable_space_node::same(node *nd)
 {
--- groff-1.18.orig/src/roff/troff/node.h
+++ groff-1.18/src/roff/troff/node.h
@@ -31,6 +31,9 @@
 void hyphenate(hyphen_list *, unsigned);
 
 enum hyphenation_type { HYPHEN_MIDDLE, HYPHEN_BOUNDARY, HYPHEN_INHIBIT };
+#ifdef	NIPPON
+enum node_type {NODE_GLYPH, NODE_KWORD_SPACE, NODE_NEWLINE_SPACE, NODE_ANOTHER};
+#endif
 
 class ascii_output_file;
 
@@ -104,6 +107,9 @@
 
   virtual int same(node *) = 0;
   virtual const char *type() = 0;
+#ifdef	NIPPON
+  virtual node_type get_node_type();
+#endif
 };
 
 inline node::node() : next(0), last(0)
@@ -207,6 +213,24 @@
   int force_tprint();
 };
 
+#ifdef	NIPPON
+class kword_space_node : public word_space_node {
+public:
+  kword_space_node(node * = 0);
+  node *copy();
+  const char *type();
+  node_type get_node_type();
+};
+
+class newline_space_node : public word_space_node {
+public:
+  newline_space_node(hunits, node * = 0);
+  node *copy();
+  const char *type();
+  node_type get_node_type();
+};
+#endif
+
 class unbreakable_space_node : public word_space_node {
   unbreakable_space_node(hunits, int, node * = 0);
 public:
@@ -608,3 +632,7 @@
 
 font_family *lookup_family(symbol);
 symbol get_font_name(int, environment *);
+#ifdef NIPPON
+int is_boldfont(int);
+#endif
+
--- groff-1.18.orig/src/roff/troff/token.h
+++ groff-1.18/src/roff/troff/token.h
@@ -28,12 +28,18 @@
   symbol nm;
   node *nd;
   unsigned char c;
+#ifdef	NIPPON
+  wchar wc;
+#endif
   int val;
   units dim;
   enum token_type {
     TOKEN_BACKSPACE,
     TOKEN_BEGIN_TRAP,
     TOKEN_CHAR,			// a normal printing character
+#ifdef	NIPPON
+    TOKEN_WCHAR,		// a japanese EUC character
+#endif
     TOKEN_DUMMY,		// \&
     TOKEN_EMPTY,		// this is the initial value
     TOKEN_END_TRAP,
--- groff-1.18.orig/src/roff/troff/troff.h
+++ groff-1.18/src/roff/troff/troff.h
@@ -20,6 +20,9 @@
 Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 
 
+#ifdef	NIPPON
+# include "eucmac.h"
+#endif
 #include "lib.h"
 
 #include <ctype.h>
--- groff-1.18.orig/src/roff/nroff/nroff.man
+++ groff-1.18/src/roff/nroff/nroff.man
@@ -53,8 +53,10 @@
 command using groff.
 Only 
 .BR ascii ,
+.BR ascii8 ,
 .BR latin1 ,
 .BR utf8 ,
+.BR nippon ,
 and
 .B cp1047
 are valid arguments for the
--- groff-1.18.orig/src/roff/nroff/nroff.sh
+++ groff-1.18/src/roff/nroff/nroff.sh
@@ -12,6 +12,8 @@
     T=-Tlatin1 ;;
   IBM-1047)
     T=-Tcp1047 ;;
+  EUC-JP)
+    T=-Tnippon ;;
   *)
     case "${LC_ALL-${LC_CTYPE-${LANG}}}" in
       *.UTF-8)
@@ -20,6 +22,8 @@
         T=-Tlatin1 ;;
       *.IBM-1047)
         T=-Tcp1047 ;;
+      ja_JP.ujis | ja_JP.eucJP)
+	T=-Tnippon ;;
       *)
         case "$LESSCHARSET" in
           utf-8)
@@ -28,8 +32,10 @@
             T=-Tlatin1 ;;
           cp1047)
             T=-Tcp1047 ;;
+          japanese)
+	    T=-Tnippon ;;
           *)
-            T=-Tascii ;;
+            T=-Tascii8 ;;
           esac ;;
      esac ;;
 esac
@@ -52,7 +58,7 @@
       exit 1 ;;
     -[iptSUC] | -[mrno]*)
       opts="$opts $1" ;;
-    -Tascii | -Tlatin1 | -Tutf8 | -Tcp1047)
+    -Tascii | -Tlatin1 | -Tutf8 | -Tcp1047 | -Tascii8 | -Tnippon)
       T=$1 ;;
     -T*)
       # ignore other devices
--- groff-1.18.orig/src/preproc/eqn/eqn.h
+++ groff-1.18/src/preproc/eqn/eqn.h
@@ -23,6 +23,9 @@
 #include <assert.h>
 #include <stdlib.h>
 #include <errno.h>
+#ifdef	NIPPON
+# include "eucmac.h"
+#endif
 #include "cset.h"
 #include "errarg.h"
 #include "error.h"
--- groff-1.18.orig/src/preproc/eqn/eqn.y
+++ groff-1.18/src/preproc/eqn/eqn.y
@@ -21,6 +21,7 @@
 #include <string.h>
 #include <stdlib.h>
 
+#include "encoding.h" /* XXX */
 #include "lib.h"
 #include "box.h"
 extern int non_empty_flag;
--- groff-1.18.orig/src/preproc/eqn/lex.cc
+++ groff-1.18/src/preproc/eqn/lex.cc
@@ -23,6 +23,7 @@
 #include "eqn_tab.h"
 #include "stringclass.h"
 #include "ptable.h"
+#include "encoding.h"
 
 struct definition {
   char is_macro;
@@ -375,6 +376,11 @@
 	lex_error("invalid input character code %1", c);
       else {
 	line += char(c);
+#ifdef	NIPPON
+	if (encoding->is_wchar_byte(c)) {
+	  line += char(getc(fp));
+	}
+#endif
 	if (c == '\n') 
 	  break;
       }
--- groff-1.18.orig/src/preproc/eqn/main.cc
+++ groff-1.18/src/preproc/eqn/main.cc
@@ -258,6 +258,7 @@
   program_name = argv[0];
   static char stderr_buf[BUFSIZ];
   setbuf(stderr, stderr_buf);
+  init_encoding_handler();
   int opt;
   int load_startup_file = 1;
   static const struct option long_options[] = {
--- groff-1.18.orig/src/preproc/eqn/text.cc
+++ groff-1.18/src/preproc/eqn/text.cc
@@ -21,13 +21,20 @@
 #include "eqn.h"
 #include "pbox.h"
 #include "ptable.h"
+#include "encoding.h"
 
 class char_box : public simple_box {
   unsigned char c;
+#ifdef	NIPPON
+  wchar wc;
+#endif
   char next_is_italic;
   char prev_is_italic;
 public:
   char_box(unsigned char);
+#ifdef	NIPPON
+  char_box(unsigned char, wchar);
+#endif
   void debug_print();
   void output();
   int is_char();
@@ -166,10 +173,20 @@
 
 char_box::char_box(unsigned char cc)
 : c(cc), next_is_italic(0), prev_is_italic(0)
+#ifdef	NIPPON
+, wc(cc)
+#endif
 {
   spacing_type = char_table[c].spacing_type;
 }
 
+#ifdef	NIPPON
+char_box::char_box(unsigned char cc, wchar wc)
+: c(cc), wc(wc), prev_is_italic(0), next_is_italic(0)
+{
+}
+#endif
+
 void char_box::hint(unsigned flags)
 {
   if (flags & HINT_PREV_IS_ITALIC)
@@ -188,7 +205,11 @@
   if (c == '\\')
     fputs("\\e", stdout);
   else
+#ifdef	NIPPON
+    encoding->put_wchar(wc, stdout);
+#else
     putchar(c);
+#endif
   if (!next_is_italic)
     fputs("\\/", stdout);
   else
@@ -497,6 +518,14 @@
       break;
     default:
     normal_char:
+#ifdef	NIPPON
+      if (encoding->is_wchar_byte(c)) {
+        int i = 1;
+	wchar wc = encoding->make_wchar(c, (unsigned char *)s, &i);
+	b = new char_box('A', wc); // char_info of wc is same the 'A'.
+	s += i;
+      } else
+#endif
       b = new char_box(c);
       break;
     }
--- groff-1.18.orig/src/preproc/html/pre-html.cc
+++ groff-1.18/src/preproc/html/pre-html.cc
@@ -238,12 +238,13 @@
       char *p = linebuf + 9;
       while (*p == ' ' || *p == '\t')
 	p++;
-      if (font::scan_papersize(p, 0, &length, 0)) {
-	fclose(f);
-	return int(length * postscriptRes + 0.5);
+      for (p = strtok(p, " \t"); p; p = strtok(0, " \t")) {
+	if (font::scan_papersize(p, 0, &length, 0)) {
+	  fclose(f);
+	  return int(length * postscriptRes + 0.5);
+	}
       }
-      else
-	fatal("bad argument to `papersize' keyword in devps/DESC");
+      fatal("bad argument to `papersize' keyword in devps/DESC");
     }
   }
   fatal("can't find `papersize' or `paperlength' keyword in devps/DESC");
--- groff-1.18.orig/src/devices/grops/ps.cc
+++ groff-1.18/src/devices/grops/ps.cc
@@ -24,6 +24,7 @@
 #include "cset.h"
 #include "nonposix.h"
 #include "paper.h"
+#include "encoding.h"
 
 #include "ps.h"
 #include <time.h>
@@ -193,12 +194,20 @@
   return *this;
 }
 
+#ifdef NIPPON
+ps_output &ps_output::put_string(const wchar *s, int n)
+#else
 ps_output &ps_output::put_string(const char *s, int n)
+#endif
 {
   int len = 0;
   int i;
   for (i = 0; i < n; i++) {
+#ifdef NIPPON
+    wchar c = s[i];
+#else
     char c = s[i];
+#endif
     if (is_ascii(c) && csprint(c)) {
       if (c == '(' || c == ')' || c == '\\')
 	len += 2;
@@ -224,8 +233,13 @@
 	putc('\n', fp);
 	col = 0;
       }
+#ifdef	NIPPON
+      int nb = encoding->put_wchar(s[i], fp, "%02x");
+      col += nb * 2;
+#else
       fprintf(fp, "%02x", s[i] & 0377);
       col += 2;
+#endif
     }
     putc('>', fp);
     col++;
@@ -487,7 +501,11 @@
   int paper_length;
   int equalise_spaces;
   enum { SBUF_SIZE = 256 };
+#ifdef	NIPPON
+  wchar sbuf[SBUF_SIZE];
+#else
   char sbuf[SBUF_SIZE];
+#endif
   int sbuf_len;
   int sbuf_start_hpos;
   int sbuf_vpos;
@@ -606,7 +624,11 @@
 {
   if (i == space_char_index || invis_count > 0)
     return;
+#ifdef	NIPPON
+  wchar code = f->get_code(i);
+#else
   unsigned char code = f->get_code(i);
+#endif
   style sty(f, env->size, env->height, env->slant);
   if (sty.slant != 0) {
     if (sty.slant > 80 || sty.slant < -80) {
@@ -1555,6 +1577,7 @@
   string env;
   static char stderr_buf[BUFSIZ];
   setbuf(stderr, stderr_buf);
+  init_encoding_handler();
   int c;
   static const struct option long_options[] = {
     { "help", no_argument, 0, CHAR_MAX + 1 },
--- groff-1.18.orig/src/devices/grops/ps.h
+++ groff-1.18/src/devices/grops/ps.h
@@ -18,10 +18,16 @@
 with groff; see the file COPYING.  If not, write to the Free Software
 Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 
+#include "encoding.h" // XXX
+
 class ps_output {
 public:
   ps_output(FILE *, int max_line_length);
+#ifdef	NIPPON
+  ps_output &put_string(const wchar *, int);
+#else
   ps_output &put_string(const char *, int);
+#endif
   ps_output &put_number(int);
   ps_output &put_fix_number(int);
   ps_output &put_float(double);
--- groff-1.18.orig/src/devices/grotty/grotty.man
+++ groff-1.18/src/devices/grotty/grotty.man
@@ -50,7 +50,9 @@
 command
 with a
 .BR \-Tascii ,
-.B \-Tlatin1
+.BR \-Tascii8 ,
+.BR \-Tlatin1 ,
+.B \-Tnippon
 or
 .B \-Tutf8
 option on ASCII based systems, and with
@@ -235,8 +237,10 @@
 .I name
 is the name of the device, usually
 .BR ascii ,
+.BR ascii8 ,
 .BR latin1 ,
 .BR utf8 ,
+.B  nippon
 or
 .BR cp1047 .
 .TP
@@ -315,9 +319,19 @@
 device.
 .
 .TP
+.B @FONTDIR@/devascii8/DESC
+Device description file for
+.B ascii8
+device.
+.TP
 .B @FONTDIR@/devlatin1/DESC
 Device description file for
 .B latin1
+device.
+.TP
+.B @FONTDIR@/devnippon/DESC
+Device description file for
+.B nippon
 device.
 .
 .TP
--- groff-1.18.orig/src/devices/grotty/tty.cc
+++ groff-1.18/src/devices/grotty/tty.cc
@@ -20,6 +20,7 @@
 
 #include "driver.h"
 #include "device.h"
+#include "encoding.h"
 
 extern "C" const char *Version_string;
 
@@ -51,8 +52,21 @@
   HDRAW_MODE = 0x08,
   CU_MODE = 0x10,
   COLOR_CHANGE = 0x20
+#ifdef NIPPON
+  , WCHAR_MODE = 0x100
+#endif
 };
 
+#ifdef NIPPON
+# ifdef putchar
+#  undef putchar
+# endif
+inline void putchar(wchar wc)
+{
+  encoding->put_wchar(wc, stdout);
+}
+#endif
+
 // Mode to use for bold-underlining.
 static unsigned char bold_underline_mode = BOLD_MODE|UNDERLINE_MODE;
 
@@ -98,8 +112,26 @@
   }
   const char *num = f->get_internal_name();
   long n;
+#ifdef	NIPPON
+  if (num != 0) {
+    n = strtol(num, 0, 0);
+    switch (n) {
+    case 1:
+      f->mode = int(UNDERLINE_MODE);
+      break;
+    case 2:
+    case 5:
+      f->mode = int(BOLD_MODE);
+      break;
+    case 3:
+      f->mode = int(BOLD_MODE|UNDERLINE_MODE);
+      break;
+    }
+  }
+#else
   if (num != 0 && (n = strtol(num, 0, 0)) != 0)
     f->mode = int(n & (BOLD_MODE|UNDERLINE_MODE));
+#endif
   if (!underline_flag)
     f->mode &= ~UNDERLINE_MODE;
   if (!bold_flag)
@@ -242,8 +274,18 @@
 void tty_printer::make_underline()
 {
   if (old_drawing_scheme) {
+#if 0 /* def NIPPON XXX: not necessary? */
+    if ((p->mode & WCHAR_MODE)) {
+	putchar('_'); putchar('_');
+	putchar('\b'); putchar('\b');
+    } else {
+	putchar('_');
+	putchar('\b');
+    }
+#else
     putchar('_');
     putchar('\b');
+#endif
   }
   else {
     if (!is_underline) {
@@ -285,8 +327,10 @@
 void tty_printer::set_char(int i, font *f, const environment *env,
 			   int w, const char *name)
 {
+#ifndef NIPPON
   if (w != font::hor)
     fatal("width of character not equal to horizontal resolution");
+#endif
   add_char(f->get_code(i),
 	   env->hpos, env->vpos,
 	   env->col, env->fill,
@@ -338,6 +382,10 @@
   g->code = c;
   g->fore_color_idx = color_to_idx(fore);
   g->back_color_idx = color_to_idx(back);
+#ifdef NIPPON
+  if (encoding->is_wchar_code(c))
+    mode |= WCHAR_MODE;
+#endif
   g->mode = mode;
 
   // The list will be reversed later.  After reversal, it must be in
@@ -629,6 +677,11 @@
 	}
       }
       put_char(p->code);
+#ifdef	NIPPON
+      if (encoding->is_wchar_code(p->code))
+	hpos += 2;
+      else
+#endif
       hpos++;
     }
     if (!old_drawing_scheme
@@ -667,6 +720,7 @@
   if (getenv("GROFF_NO_SGR"))
     old_drawing_scheme = 1;
   setbuf(stderr, stderr_buf);
+  init_encoding_handler();
   int c;
   static const struct option long_options[] = {
     { "help", no_argument, 0, CHAR_MAX + 1 },
--- groff-1.18.orig/src/devices/grodvi/dvi.cc
+++ groff-1.18/src/devices/grodvi/dvi.cc
@@ -104,6 +104,9 @@
 struct output_font {
   dvi_font *f;
   int point_size;
+#ifdef	NIPPON
+  const char *sf;		// subfont name
+#endif
   output_font() : f(0) { }
 };
 
@@ -121,6 +124,9 @@
   output_font output_font_table[FONTS_MAX];
   font *cur_font;
   int cur_point_size;
+#ifdef NIPPON
+  const char *cur_subfont;
+#endif
   color cur_color;
   int pushed;
   int pushed_h;
@@ -341,9 +347,18 @@
   if (*env->col != cur_color)
     set_color(env->col);
   int code = f->get_code(index);
+#ifdef NIPPON
+  const char *sf = f->get_subfont_name(index);
+  if (env->size != cur_point_size || f != cur_font ||
+     (sf != cur_subfont && strcmp(sf, cur_subfont))) {
+#else
   if (env->size != cur_point_size || f != cur_font) {
+#endif
     cur_font = f;
     cur_point_size = env->size;
+#ifdef NIPPON
+    cur_subfont = sf;
+#endif
     int i;
     for (i = 0;; i++) {
       if (i >= FONTS_MAX) {
@@ -352,9 +367,16 @@
       if (output_font_table[i].f == 0) {
 	output_font_table[i].f = (dvi_font *)cur_font;
 	output_font_table[i].point_size = cur_point_size;
+#ifdef	NIPPON
+	output_font_table[i].sf = cur_subfont;
+#endif
 	define_font(i);
       }
       if (output_font_table[i].f == cur_font
+#ifdef	NIPPON
+	  && (output_font_table[i].sf == cur_subfont ||
+	      strcmp(output_font_table[i].sf, cur_subfont) == 0)
+#endif
 	  && output_font_table[i].point_size == cur_point_size)
 	break;
     }
@@ -398,7 +420,13 @@
   out4(f->checksum);
   out4(output_font_table[i].point_size*RES_7227);
   out4(int((double(f->design_size)/(1<<20))*RES_7227*100 + .5));
+#ifdef	NIPPON
+  const char *nm;
+  if (!(nm = output_font_table[i].sf))
+    nm = f->get_internal_name();
+#else
   const char *nm = f->get_internal_name();
+#endif
   out1(0);
   out_string(nm);
 }
@@ -889,6 +917,7 @@
   program_name = argv[0];
   static char stderr_buf[BUFSIZ];
   setbuf(stderr, stderr_buf);
+  init_encoding_handler();
   int c;
   static const struct option long_options[] = {
     { "help", no_argument, 0, CHAR_MAX + 1 },
--- groff-1.18.orig/src/devices/grohtml/html.h
+++ groff-1.18/src/devices/grohtml/html.h
@@ -49,6 +49,9 @@
 class simple_output {
 public:
   simple_output(FILE *, int max_line_length);
+#ifdef NIPPON
+  simple_output &put_string(const wchar *, int);
+#endif
   simple_output &put_string(const char *, int);
   simple_output &put_string(const char *s);
   simple_output &put_string(const string &s);
--- groff-1.18.orig/src/devices/grohtml/post-html.cc
+++ groff-1.18/src/devices/grohtml/post-html.cc
@@ -29,6 +29,7 @@
 #include "html.h"
 #include "html-text.h"
 #include "html-table.h"
+#include "encoding.h" // XXX: ukai
 
 #include <time.h>
 
@@ -314,6 +315,7 @@
   }
 
   old_used = tail->used;
+  /* XXX: encoding - ukai */
   do {
     tail->buffer[tail->used] = s[i];
     tail->used++;
@@ -2906,6 +2908,11 @@
   } else if (strcmp(fontname, "CR") == 0) {
     current_paragraph->done_tt();
   }
+#ifdef NIPPON
+  else if (strcmp(fontname, "G") == 0) {
+    current_paragraph->done_bold();
+  }
+#endif
 }
 
 /*
@@ -2931,6 +2938,15 @@
     }
     current_paragraph->do_tt();
   }
+#ifdef NIPPON
+  else if (strcmp(fontname, "M") == 0) {
+    current_paragraph->done_bold();
+    current_paragraph->done_italic();
+    current_paragraph->done_tt();
+  } else if (strcmp(fontname, "G") == 0) {
+    current_paragraph->do_bold();
+  }
+#endif
 }
 
 /*
@@ -3601,6 +3617,7 @@
   program_name = argv[0];
   static char stderr_buf[BUFSIZ];
   setbuf(stderr, stderr_buf);
+  init_encoding_handler();
   int c;
   static const struct option long_options[] = {
     { "help", no_argument, 0, CHAR_MAX + 1 },
--- groff-1.18.orig/src/xditview/Dvi.c
+++ groff-1.18/src/xditview/Dvi.c
@@ -49,6 +49,8 @@
 NBI	-adobe-new century schoolbook-bold-i-normal--*-100-*-*-*-*-iso8859-1\n\
 S	-adobe-symbol-medium-r-normal--*-100-*-*-*-*-adobe-fontspecific\n\
 SS	-adobe-symbol-medium-r-normal--*-100-*-*-*-*-adobe-fontspecific\n\
+M	-misc-fixed-medium-r-normal--*-100-*-*-*-*-jisx0208.1983-0\n\
+G	-misc-fixed-medium-r-normal--*-100-*-*-*-*-jisx0208.1983-0\
 ";
 
 #define offset(field) XtOffset(DviWidget, field)
--- groff-1.18.orig/src/xditview/DviChar.c
+++ groff-1.18/src/xditview/DviChar.c
@@ -6,6 +6,7 @@
  */
 
 #include   "DviChar.h"
+#include "encoding.h"
 
 extern char *xmalloc();
 
@@ -120,7 +121,16 @@
 {
 	int		i;
 	DviCharNameHash	*h;
+#if 0 /* def	NIPPON */
+	unsigned char ub = *name, lb = *(name + 1);
 
+	if (is_euc_byte(ub) && is_euc_byte(lb)) {
+	  int wc;
+	  wc = (name[0] & 0xff) << 8;
+	  wc |= (name[1] & 0xff);
+	  return(wc);
+	}
+#endif
 	i = hash_name (name) % DVI_HASH_SIZE;
 	for (h = map->buckets[i]; h; h=h->next)
 		if (!strcmp (h->name, name))
@@ -128,6 +138,15 @@
 	return -1;
 }
 
+#if 0 /* def	NIPPON */
+static DviCharNameMap JISX0208_1983_0_map = {
+	"jisx0208.1983-0",
+	0,
+{
+{	"DummyEntry",		/* 0 */},
+}};
+#endif
+
 static DviCharNameMap ISO8859_1_map = {
 	"iso8859-1",
 	0,
@@ -659,4 +678,7 @@
 	standard_maps_loaded = 1;
 	DviRegisterMap (&ISO8859_1_map);
 	DviRegisterMap (&Adobe_Symbol_map);
+#if 0 /* def	NIPPON */
+	DviRegisterMap (&JISX0208_1983_0_map);
+#endif
 }
--- groff-1.18.orig/src/xditview/DviP.h
+++ groff-1.18/src/xditview/DviP.h
@@ -89,9 +89,17 @@
 #define DVI_CHAR_CACHE_SIZE	1024
 
 typedef struct _dviCharCache {
+#if 0 /* def	NIPPON */
+	XTextItem16	cache[DVI_TEXT_CACHE_SIZE];
+#else
 	XTextItem	cache[DVI_TEXT_CACHE_SIZE];
+#endif
 	char		adjustable[DVI_TEXT_CACHE_SIZE];
+#if 0 /* def	NIPPON */
+	XChar2b		char_cache[DVI_CHAR_CACHE_SIZE];
+#else
 	char		char_cache[DVI_CHAR_CACHE_SIZE];
+#endif
 	int		index;
 	int		max;
 	int		char_index;
--- groff-1.18.orig/src/xditview/GXditview-ad.h
+++ groff-1.18/src/xditview/GXditview-ad.h
@@ -50,3 +50,24 @@
 "GXditview.promptShell.promptDialog.cancel.label: Cancel",
 "GXditview.promptShell.promptDialog.cancel.translations: #override \
 	<BtnUp>:	Cancel() unset()",
+"GXditview*fontMap: \
+TR	-adobe-times-medium-r-normal--*-100-*-*-*-*-iso8859-1\\n\
+TI	-adobe-times-medium-i-normal--*-100-*-*-*-*-iso8859-1\\n\
+TB	-adobe-times-bold-r-normal--*-100-*-*-*-*-iso8859-1\\n\
+TBI	-adobe-times-bold-i-normal--*-100-*-*-*-*-iso8859-1\\n\
+CR	-adobe-courier-medium-r-normal--*-100-*-*-*-*-iso8859-1\\n\
+CI	-adobe-courier-medium-o-normal--*-100-*-*-*-*-iso8859-1\\n\
+CB	-adobe-courier-bold-r-normal--*-100-*-*-*-*-iso8859-1\\n\
+CBI	-adobe-courier-bold-o-normal--*-100-*-*-*-*-iso8859-1\\n\
+HR	-adobe-helvetica-medium-r-normal--*-100-*-*-*-*-iso8859-1\\n\
+HI	-adobe-helvetica-medium-o-normal--*-100-*-*-*-*-iso8859-1\\n\
+HB	-adobe-helvetica-bold-r-normal--*-100-*-*-*-*-iso8859-1\\n\
+HBI	-adobe-helvetica-bold-o-normal--*-100-*-*-*-*-iso8859-1\\n\
+NR	-adobe-new century schoolbook-medium-r-normal--*-100-*-*-*-*-iso8859-1\\n\
+NI	-adobe-new century schoolbook-medium-i-normal--*-100-*-*-*-*-iso8859-1\\n\
+NB	-adobe-new century schoolbook-bold-r-normal--*-100-*-*-*-*-iso8859-1\\n\
+NBI	-adobe-new century schoolbook-bold-i-normal--*-100-*-*-*-*-iso8859-1\\n\
+S	-adobe-symbol-medium-r-normal--*-100-*-*-*-*-adobe-fontspecific\\n\
+SS	-adobe-symbol-medium-r-normal--*-100-*-*-*-*-adobe-fontspecific\\n\
+M	-misc-fixed-medium-r-normal--*-100-*-*-*-*-jisx0208.1983-0\\n\
+G	-misc-fixed-medium-r-normal--*-100-*-*-*-*-jisx0208.1983-0",
--- groff-1.18.orig/src/xditview/GXditview.ad
+++ groff-1.18/src/xditview/GXditview.ad
@@ -55,3 +55,25 @@
 GXditview.promptShell.promptDialog.cancel.label: Cancel
 GXditview.promptShell.promptDialog.cancel.translations: #override \
 	<BtnUp>:	Cancel() unset()
+
+GXditview*fontMap: \
+TR	-adobe-times-medium-r-normal--*-100-*-*-*-*-iso8859-1\n\
+TI	-adobe-times-medium-i-normal--*-100-*-*-*-*-iso8859-1\n\
+TB	-adobe-times-bold-r-normal--*-100-*-*-*-*-iso8859-1\n\
+TBI	-adobe-times-bold-i-normal--*-100-*-*-*-*-iso8859-1\n\
+CR	-adobe-courier-medium-r-normal--*-100-*-*-*-*-iso8859-1\n\
+CI	-adobe-courier-medium-o-normal--*-100-*-*-*-*-iso8859-1\n\
+CB	-adobe-courier-bold-r-normal--*-100-*-*-*-*-iso8859-1\n\
+CBI	-adobe-courier-bold-o-normal--*-100-*-*-*-*-iso8859-1\n\
+HR	-adobe-helvetica-medium-r-normal--*-100-*-*-*-*-iso8859-1\n\
+HI	-adobe-helvetica-medium-o-normal--*-100-*-*-*-*-iso8859-1\n\
+HB	-adobe-helvetica-bold-r-normal--*-100-*-*-*-*-iso8859-1\n\
+HBI	-adobe-helvetica-bold-o-normal--*-100-*-*-*-*-iso8859-1\n\
+NR	-adobe-new century schoolbook-medium-r-normal--*-100-*-*-*-*-iso8859-1\n\
+NI	-adobe-new century schoolbook-medium-i-normal--*-100-*-*-*-*-iso8859-1\n\
+NB	-adobe-new century schoolbook-bold-r-normal--*-100-*-*-*-*-iso8859-1\n\
+NBI	-adobe-new century schoolbook-bold-i-normal--*-100-*-*-*-*-iso8859-1\n\
+S	-adobe-symbol-medium-r-normal--*-100-*-*-*-*-adobe-fontspecific\n\
+SS	-adobe-symbol-medium-r-normal--*-100-*-*-*-*-adobe-fontspecific\n\
+M	-misc-fixed-medium-r-normal--*-100-*-*-*-*-jisx0208.1983-0\n\
+G	-misc-fixed-medium-r-normal--*-100-*-*-*-*-jisx0208.1983-0
--- groff-1.18.orig/src/xditview/draw.c
+++ groff-1.18/src/xditview/draw.c
@@ -17,6 +17,7 @@
 #endif
 
 #include "DviP.h"
+#include "encoding.h" /* XXX */
 
 #define DeviceToX(dw, n) ((int)((n) * (dw)->dvi.scale_factor + .5))
 #define XPos(dw) (DeviceToX((dw), (dw)->dvi.state->x - \
@@ -99,9 +100,15 @@
 {
 	if (dw->dvi.cache.char_index != 0) {
 		AdjustCacheDeltas (dw);
+#if 0 /* def	NIPPON */
+		XDrawText16 (XtDisplay (dw), XtWindow (dw), dw->dvi.normal_GC,
+			   dw->dvi.cache.start_x, dw->dvi.cache.start_y,
+			   dw->dvi.cache.cache, dw->dvi.cache.index + 1);
+#else
 		XDrawText (XtDisplay (dw), XtWindow (dw), dw->dvi.normal_GC,
 			   dw->dvi.cache.start_x, dw->dvi.cache.start_y,
 			   dw->dvi.cache.cache, dw->dvi.cache.index + 1);
+#endif
 	}	
 	dw->dvi.cache.index = 0;
 	dw->dvi.cache.max = DVI_TEXT_CACHE_SIZE;
@@ -129,12 +136,27 @@
 	dw->dvi.word_flag = 1;
 }
 
+#if 0 /* def	NIPPON */
+int charWidth(fi, c)
+XFontStruct *fi;
+int	c;
+{
+	if (is_euc_code(c)) {
+		return fi->max_bounds.width;
+	} else {
+		return fi->per_char ?
+			fi->per_char[c - fi->min_char_or_byte2].width :
+			fi->max_bounds.width;
+	}
+}
+#else
 #define charWidth(fi,c) (\
     (fi)->per_char ?\
 	(fi)->per_char[(c) - (fi)->min_char_or_byte2].width\
     :\
 	(fi)->max_bounds.width\
 )
+#endif /* NIPPON */
  
 
 static
@@ -144,6 +166,10 @@
 {
 	XCharStruct *p;
 
+#if 0 /* def	NIPPON */
+	if (is_euc_code(c))
+		return 1;	/* Neglect ;-P */
+#endif
 	if (fi->per_char == NULL ||
 	    c < fi->min_char_or_byte2 || c > fi->max_char_or_byte2)
 		return 0;
@@ -159,7 +185,11 @@
 	int wid;    /* width in device units */
 {
 	register XFontStruct	*font;
+#if 0 /* def	NIPPON */
+	register XTextItem16	*text;
+#else
 	register XTextItem	*text;
+#endif
 	int	x, y;
 	
 	x = XPos(dw);
@@ -227,7 +257,21 @@
 	}
 	if (charExists(font, c)) {
 		int w;
+#if 0 /* def	NIPPON */
+		if (is_euc_code(c)) {
+			dw->dvi.cache.char_cache[dw->dvi.cache.char_index].
+				byte1 =	(unsigned char)jis_ubyte(c);
+			dw->dvi.cache.char_cache[dw->dvi.cache.char_index++].
+				byte2 =	(unsigned char)jis_lbyte(c);
+		} else {
+			dw->dvi.cache.char_cache[dw->dvi.cache.char_index].
+				byte1 =	(unsigned char)'\0';
+			dw->dvi.cache.char_cache[dw->dvi.cache.char_index++].
+				byte2 =	(unsigned char)c;
+		}
+#else
 		dw->dvi.cache.char_cache[dw->dvi.cache.char_index++] = (char) c;
+#endif
 		++text->nchars;
 		w = charWidth(font, c);
 		dw->dvi.cache.x += w;
--- groff-1.18.orig/src/xditview/parse.c
+++ groff-1.18/src/xditview/parse.c
@@ -10,6 +10,7 @@
 #include <stdio.h>
 #include <ctype.h>
 #include "DviP.h"
+#include "encoding.h"
 
 static int StopSeen = 0;
 static ParseDrawFunction(), ParseDeviceControl();
@@ -62,6 +63,13 @@
 			    break;
 			Buffer[0] = c;
 			Buffer[1] = '\0';
+#if 0 /* def	NIPPON */
+			if (is_euc_byte(c)) {
+				DviGetC(dw,&c);
+				Buffer[1] = c;
+				Buffer[2] = '\0';
+			}
+#endif
 			(void) PutCharacter (dw, Buffer);
 			break;
 		case 'C':
@@ -73,6 +81,13 @@
 			while (DviGetC (dw, &c) != EOF
 			       && c != ' ' && c != '\n') {
 				Buffer[0] = c;
+#if 0 /* def	NIPPON */
+				if (is_euc_byte(c)) {
+					DviGetC(dw,&c);
+					Buffer[1] = c;
+					Buffer[2] = '\0';
+				}
+#endif
 				HorizontalMove (dw, PutCharacter (dw, Buffer));
 			}
 			break;
--- groff-1.18.orig/src/xditview/xtotroff.c
+++ groff-1.18/src/xditview/xtotroff.c
@@ -171,6 +171,47 @@
 			fprintf (out, "spacewidth %d\n", w);
 	}
 	fprintf (out, "charset\n");
+#if 0 /* def	NIPPON */
+	if (fi->min_byte1 != 0 || fi->max_byte1 != 0) {
+		/*
+		 * 2 byte code font.
+		 */
+		int N;
+		int D = fi->max_char_or_byte2 -	fi->min_char_or_byte2 + 1;
+		int max = (fi->max_byte1 - fi->min_byte1 + 1) *
+			(fi->max_char_or_byte2 - fi->min_char_or_byte2 + 1);
+		unsigned byte1;
+		unsigned byte2;
+		unsigned int euc_code;
+
+		for (N = 0; N < max; N++) {
+			byte1 = N / D + fi->min_byte1;
+			byte2 = N % D + fi->min_char_or_byte2;
+			euc_code = ((byte1 << 8) | byte2) & 0xffff | 0x8080;
+			wid = fi->max_bounds.width;
+			fputc(byte1 & 0xff | 0x80, out);/* output EUC code */
+			fputc(byte2 & 0xff | 0x80, out);/* output EUC code */
+			fprintf (out, "\t%d", wid);
+			if (groff_flag) {
+				int	param[5];
+				param[0] = fi->max_bounds.ascent;
+				param[1] = fi->max_bounds.descent;
+				param[2] = 0 /* charRBearing (fi, c) - wid */;
+				param[3] = 0 /* charLBearing (fi, c) */;
+				param[4] = 0; /* XXX */
+				for (j = 0; j < 5; j++)
+					if (param[j] < 0)
+						param[j] = 0;
+				for (j = 4; j >= 0; j--)
+					if (param[j] != 0)
+						break;
+				for (k = 0; k <= j; k++)
+					fprintf (out, ",%d", param[k]);
+			}
+			fprintf (out, "\t0\t%#x\n", euc_code);
+		}
+	} else
+#endif /* NIPPON */
 	for (c = fi->min_char_or_byte2; c <= fi->max_char_or_byte2; c++) {
 		char *name = DviCharName (char_map,c,0);
 		if (charExists (fi, c) && (groff_flag || name)) {
--- groff-1.18.orig/src/xditview/FontMap.jisx0208
+++ groff-1.18/src/xditview/FontMap.jisx0208
@@ -0,0 +1,2 @@
+M	-misc-fixed-medium-r-normal--*-100-*-*-*-*-jisx0208.1983-0
+G	-misc-fixed-medium-r-normal--*-100-*-*-*-*-jisx0208.1983-0
--- groff-1.18.orig/src/xditview/encoding.h
+++ groff-1.18/src/xditview/encoding.h
@@ -0,0 +1,37 @@
+// -*- C++ -*-
+/* Copyright (c) 2001 Fumitoshi UKAI <ukai@debian.or.jp>
+
+This file is part of groff.
+
+groff is free software; you can redistribute it and/or modify it under
+the terms of the GNU General Public License as published by the Free
+Software Foundation; either version 2, or (at your option) any later
+version.
+
+groff is distributed in the hope that it will be useful, but WITHOUT ANY
+WARRANTY; without even the implied warranty of MERCHANTABILITY or
+FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+
+#ifndef ENCODING_H
+#define ENCODING_H
+
+#ifdef NIPPON
+typedef unsigned int wchar;
+#else
+typedef char wchar;
+#endif
+
+#if 0
+#define EUCMASK	0x8080
+#define is_euc_code(c)	(((c) & EUCMASK) == EUCMASK)
+#define is_euc_byte(c)  ((c) >= 0xa1 && (c) <= 0xfe)
+#define jis_ubyte(wc)	(((wc) >> 8) & 0x7f)
+#define jis_lbyte(wc)	((wc) & 0x7f)
+#endif	/* 0 */
+
+#endif
--- groff-1.18.orig/src/xditview/eucmac.h
+++ groff-1.18/src/xditview/eucmac.h
@@ -0,0 +1,14 @@
+/* 
+ * eucmac.h - japanese enhancement support module.
+ */
+
+#ifndef _EUCMAC_H
+#define _EUCMAC_H
+
+#define EUCMASK	0x8080
+#define is_euc_code(c)	(((c) & EUCMASK) == EUCMASK)
+#define is_euc_byte(c)  ((c) >= 0xa1 && (c) <= 0xfe)
+#define jis_ubyte(wc)	(((wc) >> 8) & 0x7f)
+#define jis_lbyte(wc)	((wc) & 0x7f)
+
+#endif	/* _EUCMAC_H */
--- groff-1.18.orig/font/devps/DESC.in
+++ groff-1.18/font/devps/DESC.in
@@ -1,11 +1,14 @@
 res 72000
 hor 1
 vert 1
+lowerwchar 300
+wcharkern 400
 sizescale 1000
 unitwidth 1000
 sizes 1000-10000000 0
 styles R I B BI
 family T
-fonts 9 0 0 0 0 0 SS S ZD ZDR
+fonts 11 0 0 0 0 0 SS S ZD ZDR M G
+ondemand M G
 tcommand
 postpro grops
--- groff-1.18.orig/font/devps/Makefile.sub
+++ groff-1.18/font/devps/Makefile.sub
@@ -2,23 +2,23 @@
 DISTFILES=text.enc download \
   S ZD ZDR SS AB ABI AI AR BMB BMBI BMI BMR \
   CB CBI CI CR HB HBI HI HR HNB HNBI HNI HNR \
-  NB NBI NI NR PB PBI PI PR TB TBI TI TR ZCMI
+  NB NBI NI NR PB PBI PI PR TB TBI TI TR ZCMI M G
 PSFILES=prologue symbolsl.pfa zapfdr.pfa
 DEVGENFILES=generate/Makefile generate/afmname generate/dingbats.map \
   generate/dingbats.rmap generate/lgreekmap generate/symbol.sed \
   generate/symbolchars generate/symbolsl.afm generate/textmap
 DEVFILES=DESC $(PSFILES) $(DISTFILES) $(DEVGENFILES)
 
-CLEANADD=DESC $(PSFILES)
+CLEANADD=DESC $(PSFILES) M G
 
 DESC: DESC.in
 	-rm -f DESC
 	cat $(srcdir)/DESC.in >DESC
 	echo broken $(BROKEN_SPOOLER_FLAGS) >>DESC
 	if test "$(PAGE)" = A4; then \
-	  echo "papersize a4" >>DESC; \
+	  echo "papersize /etc/papersize a4" >>DESC; \
 	else \
-	  echo "papersize letter" >>DESC; \
+	  echo "papersize /etc/papersize letter" >>DESC; \
 	fi
 	test -z '$(PSPRINT)' ||	echo print '$(PSPRINT)' >>DESC
 
@@ -33,3 +33,14 @@
 $(PSFILES):
 	-rm -f $@
 	sed -f $(srcdir)/psstrip.sed $? >$@
+
+M: M.header
+	@echo Making M
+	@-rm -f M
+	@(cat $(srcdir)/M.header; echo charset) > M
+
+G: M
+	@echo Making G
+	@-rm -f G
+	@sed -e 's/name M/name G/' \
+	    -e 's/internalname Ryumin-Light-EUC-H/internalname GothicBBB-Medium-EUC-H/' M > G
--- groff-1.18.orig/font/devps/M.header
+++ groff-1.18/font/devps/M.header
@@ -0,0 +1,4 @@
+name M
+internalname Ryumin-Light-EUC-H
+spacewidth 1000
+fixedkanji 1000,880,120 3
--- groff-1.18.orig/font/devdvi/FixMetric.sed
+++ groff-1.18/font/devdvi/FixMetric.sed
@@ -0,0 +1,77 @@
+s/1006514,.*0x212b$/370845,815360,145600	1	0x212b/
+s/1006514,.*0x212c$/370845,815360,145600	1	0x212c/
+s/1006514,.*0x2126$/370845,815360,145600	1	0x2126/
+s/1006514,.*0x2127$/370845,815360,145600	1	0x2127/
+s/1006514,.*0x2128$/370845,815360,145600	1	0x2128/
+s/1006514,.*0x212a$/370845,815360,145600	1	0x212a/
+s/1006514,.*0x212d$/370845,815360,145600	1	0x212d/
+s/1006514,.*0x212e$/370845,815360,145600	1	0x212e/
+s/1006514,.*0x213e$/370845,815360,145600	1	0x213e/
+s/1006514,.*0x2142$/370845,815360,145600	1	0x2142/
+s/1006514,.*0x2143$/370845,815360,145600	1	0x2143/
+s/1006514,.*0x2146$/370845,815360,145600	1	0x2146/
+s/1006514,.*0x2147$/370845,815360,145600	1	0x2147/
+s/1006514,.*0x2124$/370845,815360,145600	1	0x2124/
+s/1006514,.*0x2125$/370845,815360,145600	1	0x2125/
+s/1006514,.*0x214b$/528496,815360,145600	1	0x214b/
+s/1006514,.*0x214d$/528496,815360,145600	1	0x214d/
+s/1006514,.*0x214f$/528496,815360,145600	1	0x214f/
+s/1006514,.*0x2151$/528496,815360,145600	1	0x2151/
+s/1006514,.*0x2153$/528496,815360,145600	1	0x2153/
+s/1006514,.*0x2155$/528496,815360,145600	1	0x2155/
+s/1006514,.*0x2157$/528496,815360,145600	1	0x2157/
+s/1006514,.*0x2159$/528496,815360,145600	1	0x2159/
+s/1006514,.*0x215b$/528496,815360,145600	1	0x215b/
+s/1006514,.*0x2129$/528496,815360,145600	1	0x2129/
+s/1006514,.*0x212f$/528496,815360,145600	1	0x212f/
+s/1006514,.*0x2130$/528496,815360,145600	1	0x2130/
+s/1006514,.*0x2133$/528496,815360,145600	1	0x2133/
+s/1006514,.*0x2135$/528496,815360,145600	1	0x2135/
+s/1006514,.*0x2148$/528496,815360,145600	1	0x2148/
+s/1006514,.*0x2149$/528496,815360,145600	1	0x2149/
+s/1006514,.*0x216b$/528496,815360,145600	1	0x216b/
+s/1006514,.*0x216c$/528496,815360,145600	1	0x216c/
+s/1006514,.*0x216d$/528496,815360,145600	1	0x216d/
+s/1006514,.*0x2178$/528496,815360,145600	1	0x2178/
+s/1006514,.*0x214a$/528496,815360,145600	1	0x214a/
+s/1006514,.*0x214c$/528496,815360,145600	1	0x214c/
+s/1006514,.*0x214e$/528496,815360,145600	1	0x214e/
+s/1006514,.*0x2150$/528496,815360,145600	1	0x2150/
+s/1006514,.*0x2152$/528496,815360,145600	1	0x2152/
+s/1006514,.*0x2154$/528496,815360,145600	1	0x2154/
+s/1006514,.*0x2156$/528496,815360,145600	1	0x2156/
+s/1006514,.*0x2158$/528496,815360,145600	1	0x2158/
+s/1006514,.*0x215a$/528496,815360,145600	1	0x215a/
+s/1006514,.*0x2122$/528496,815360,145600	1	0x2122/
+s/1006514,.*0x2123$/528496,815360,145600	1	0x2123/
+s/1006514,.*0x2136$/783741,815360,145600	1	0x2136/
+s/1006514,.*0x2137$/783741,815360,145600	1	0x2137/
+s/1006514,.*0x2139$/783741,815360,145600	1	0x2139/
+s/1006514,.*0x2168$/783741,815360,145600	1	0x2168/
+s/1006514,.*0x2169$/783741,815360,145600	1	0x2169/
+s/1006514,.*0x216a$/783741,815360,145600	1	0x216a/
+s/1006514,.*0x2170$/783741,815360,145600	1	0x2170/
+s/1006514,.*0x2171$/783741,815360,145600	1	0x2171/
+s/1006514,.*0x2172$/783741,815360,145600	1	0x2172/
+s/1006514,.*0x2421$/783741,815360,145600	1	0x2421/
+s/1006514,.*0x2423$/783741,815360,145600	1	0x2423/
+s/1006514,.*0x2425$/783741,815360,145600	1	0x2425/
+s/1006514,.*0x2427$/783741,815360,145600	1	0x2427/
+s/1006514,.*0x2429$/783741,815360,145600	1	0x2429/
+s/1006514,.*0x2443$/783741,815360,145600	1	0x2443/
+s/1006514,.*0x2463$/783741,815360,145600	1	0x2463/
+s/1006514,.*0x2465$/783741,815360,145600	1	0x2465/
+s/1006514,.*0x2467$/783741,815360,145600	1	0x2467/
+s/1006514,.*0x246e$/783741,815360,145600	1	0x246e/
+s/1006514,.*0x2521$/783741,815360,145600	1	0x2521/
+s/1006514,.*0x2523$/783741,815360,145600	1	0x2523/
+s/1006514,.*0x2525$/783741,815360,145600	1	0x2525/
+s/1006514,.*0x2527$/783741,815360,145600	1	0x2527/
+s/1006514,.*0x2529$/783741,815360,145600	1	0x2529/
+s/1006514,.*0x2543$/783741,815360,145600	1	0x2543/
+s/1006514,.*0x2563$/783741,815360,145600	1	0x2563/
+s/1006514,.*0x2565$/783741,815360,145600	1	0x2565/
+s/1006514,.*0x2567$/783741,815360,145600	1	0x2567/
+s/1006514,.*0x256e$/783741,815360,145600	1	0x256e/
+s/1006514,.*0x2575$/783741,815360,145600	1	0x2575/
+s/1006514,.*0x2576$/783741,815360,145600	1	0x2576/
--- groff-1.18.orig/font/devdvi/M.proto-ASCII
+++ groff-1.18/font/devdvi/M.proto-ASCII
@@ -0,0 +1,4 @@
+name M
+internalname min10
+checksum -375402250
+designsize 10485760
--- groff-1.18.orig/font/devdvi/M.proto-NTT
+++ groff-1.18/font/devdvi/M.proto-NTT
@@ -0,0 +1,6882 @@
+name M
+internalname dmj10
+checksum 0
+designsize 10485760
+charset
+	F	1:0
+	F	2:0
+	F	3:0
+	F	4:0
+	F	5:0
+	F	6:0
+	F	7:0
+	F	8:0
+	F	9:0
+	F	10:0
+	F	11:0
+	F	12:0
+	F	13:0
+	F	14:0
+	F	15:0
+	F	16:0
+	F	17:0
+	F	18:0
+	F	19:0
+	F	20:0
+	F	21:0
+	F	22:0
+	F	23:0
+	F	24:0
+	F	25:0
+	F	26:0
+	F	27:0
+	F	28:0
+	F	29:0
+	F	30:0
+	F	31:0
+	F	32:0
+	F	33:0
+	F	34:0
+	F	35:0
+	F	36:0
+	F	37:0
+	F	38:0
+	F	39:0
+	F	40:0
+	F	41:0
+	F	42:0
+	F	43:0
+	F	44:0
+	F	45:0
+	F	46:0
+	F	47:0
+	F	48:0
+	F	49:0
+	F	50:0
+	F	51:0
+	F	52:0
+	F	53:0
+	F	54:0
+	F	55:0
+	F	56:0
+	F	57:0
+	F	58:0
+	F	59:0
+	F	60:0
+	F	61:0
+	F	62:0
+	F	63:0
+	F	64:0
+	F	65:0
+	F	66:0
+	F	67:0
+	F	68:0
+	F	69:0
+	F	70:0
+	F	71:0
+	F	72:0
+	F	73:0
+	F	74:0
+	F	75:0
+	F	76:0
+	F	77:0
+	F	78:0
+	F	79:0
+	F	80:0
+	F	81:0
+	F	82:0
+	F	83:0
+	F	84:0
+	F	85:0
+	F	86:0
+	F	87:0
+	F	88:0
+	F	89:0
+	F	90:0
+	F	91:0
+	F	92:0
+	F	93:0
+	F	94:0
+	F	101:0
+	F	102:0
+	F	103:0
+	F	104:0
+	F	105:0
+	F	106:0
+	F	107:0
+	F	108:0
+	F	109:0
+	F	110:0
+	F	111:0
+	F	112:0
+	F	113:0
+	F	114:0
+	F	126:0
+	F	127:0
+	F	128:0
+	F	129:0
+	F	130:0
+	F	131:0
+	F	132:0
+	F	133:0
+	F	142:0
+	F	143:0
+	F	144:0
+	F	145:0
+	F	146:0
+	F	147:0
+	F	148:0
+	F	160:0
+	F	161:0
+	F	162:0
+	F	163:0
+	F	164:0
+	F	165:0
+	F	166:0
+	F	167:0
+	F	168:0
+	F	169:0
+	F	170:0
+	F	171:0
+	F	172:0
+	F	173:0
+	F	174:0
+	F	182:0
+	F	183:0
+	F	184:0
+	F	185:0
+	F	186:0
+	F	187:0
+	F	188:0
+	F	189:0
+	F	194:0
+	F	48:1
+	F	49:1
+	F	50:1
+	F	51:1
+	F	52:1
+	F	53:1
+	F	54:1
+	F	55:1
+	F	56:1
+	F	57:1
+	F	65:1
+	F	66:1
+	F	67:1
+	F	68:1
+	F	69:1
+	F	70:1
+	F	71:1
+	F	72:1
+	F	73:1
+	F	74:1
+	F	75:1
+	F	76:1
+	F	77:1
+	F	78:1
+	F	79:1
+	F	80:1
+	F	81:1
+	F	82:1
+	F	83:1
+	F	84:1
+	F	85:1
+	F	86:1
+	F	87:1
+	F	88:1
+	F	89:1
+	F	90:1
+	F	97:1
+	F	98:1
+	F	99:1
+	F	100:1
+	F	101:1
+	F	102:1
+	F	103:1
+	F	104:1
+	F	105:1
+	F	106:1
+	F	107:1
+	F	108:1
+	F	109:1
+	F	110:1
+	F	111:1
+	F	112:1
+	F	113:1
+	F	114:1
+	F	115:1
+	F	116:1
+	F	117:1
+	F	118:1
+	F	119:1
+	F	120:1
+	F	121:1
+	F	122:1
+	F	1:2
+	F	2:2
+	F	3:2
+	F	4:2
+	F	5:2
+	F	6:2
+	F	7:2
+	F	8:2
+	F	9:2
+	F	10:2
+	F	11:2
+	F	12:2
+	F	13:2
+	F	14:2
+	F	15:2
+	F	16:2
+	F	17:2
+	F	18:2
+	F	19:2
+	F	20:2
+	F	21:2
+	F	22:2
+	F	23:2
+	F	24:2
+	F	25:2
+	F	26:2
+	F	27:2
+	F	28:2
+	F	29:2
+	F	30:2
+	F	31:2
+	F	32:2
+	F	33:2
+	F	34:2
+	F	35:2
+	F	36:2
+	F	37:2
+	F	38:2
+	F	39:2
+	F	40:2
+	F	41:2
+	F	42:2
+	F	43:2
+	F	44:2
+	F	45:2
+	F	46:2
+	F	47:2
+	F	48:2
+	F	49:2
+	F	50:2
+	F	51:2
+	F	52:2
+	F	53:2
+	F	54:2
+	F	55:2
+	F	56:2
+	F	57:2
+	F	58:2
+	F	59:2
+	F	60:2
+	F	61:2
+	F	62:2
+	F	63:2
+	F	64:2
+	F	65:2
+	F	66:2
+	F	67:2
+	F	68:2
+	F	69:2
+	F	70:2
+	F	71:2
+	F	72:2
+	F	73:2
+	F	74:2
+	F	75:2
+	F	76:2
+	F	77:2
+	F	78:2
+	F	79:2
+	F	80:2
+	F	81:2
+	F	82:2
+	F	83:2
+	F	1:3
+	F	2:3
+	F	3:3
+	F	4:3
+	F	5:3
+	F	6:3
+	F	7:3
+	F	8:3
+	F	9:3
+	F	10:3
+	F	11:3
+	F	12:3
+	F	13:3
+	F	14:3
+	F	15:3
+	F	16:3
+	F	17:3
+	F	18:3
+	F	19:3
+	F	20:3
+	F	21:3
+	F	22:3
+	F	23:3
+	F	24:3
+	F	25:3
+	F	26:3
+	F	27:3
+	F	28:3
+	F	29:3
+	F	30:3
+	F	31:3
+	F	32:3
+	F	33:3
+	F	34:3
+	F	35:3
+	F	36:3
+	F	37:3
+	F	38:3
+	F	39:3
+	F	40:3
+	F	41:3
+	F	42:3
+	F	43:3
+	F	44:3
+	F	45:3
+	F	46:3
+	F	47:3
+	F	48:3
+	F	49:3
+	F	50:3
+	F	51:3
+	F	52:3
+	F	53:3
+	F	54:3
+	F	55:3
+	F	56:3
+	F	57:3
+	F	58:3
+	F	59:3
+	F	60:3
+	F	61:3
+	F	62:3
+	F	63:3
+	F	64:3
+	F	65:3
+	F	66:3
+	F	67:3
+	F	68:3
+	F	69:3
+	F	70:3
+	F	71:3
+	F	72:3
+	F	73:3
+	F	74:3
+	F	75:3
+	F	76:3
+	F	77:3
+	F	78:3
+	F	79:3
+	F	80:3
+	F	81:3
+	F	82:3
+	F	83:3
+	F	84:3
+	F	85:3
+	F	86:3
+	F	1:4
+	F	2:4
+	F	3:4
+	F	4:4
+	F	5:4
+	F	6:4
+	F	7:4
+	F	8:4
+	F	9:4
+	F	10:4
+	F	11:4
+	F	12:4
+	F	13:4
+	F	14:4
+	F	15:4
+	F	16:4
+	F	17:4
+	F	18:4
+	F	19:4
+	F	20:4
+	F	21:4
+	F	22:4
+	F	23:4
+	F	24:4
+	F	33:4
+	F	34:4
+	F	35:4
+	F	36:4
+	F	37:4
+	F	38:4
+	F	39:4
+	F	40:4
+	F	41:4
+	F	42:4
+	F	43:4
+	F	44:4
+	F	45:4
+	F	46:4
+	F	47:4
+	F	48:4
+	F	49:4
+	F	50:4
+	F	51:4
+	F	52:4
+	F	53:4
+	F	54:4
+	F	55:4
+	F	56:4
+	F	1:5
+	F	2:5
+	F	3:5
+	F	4:5
+	F	5:5
+	F	6:5
+	F	7:5
+	F	8:5
+	F	9:5
+	F	10:5
+	F	11:5
+	F	12:5
+	F	13:5
+	F	14:5
+	F	15:5
+	F	16:5
+	F	17:5
+	F	18:5
+	F	19:5
+	F	20:5
+	F	21:5
+	F	22:5
+	F	23:5
+	F	24:5
+	F	25:5
+	F	26:5
+	F	27:5
+	F	28:5
+	F	29:5
+	F	30:5
+	F	31:5
+	F	32:5
+	F	33:5
+	F	49:5
+	F	50:5
+	F	51:5
+	F	52:5
+	F	53:5
+	F	54:5
+	F	55:5
+	F	56:5
+	F	57:5
+	F	58:5
+	F	59:5
+	F	60:5
+	F	61:5
+	F	62:5
+	F	63:5
+	F	64:5
+	F	65:5
+	F	66:5
+	F	67:5
+	F	68:5
+	F	69:5
+	F	70:5
+	F	71:5
+	F	72:5
+	F	73:5
+	F	74:5
+	F	75:5
+	F	76:5
+	F	77:5
+	F	78:5
+	F	79:5
+	F	80:5
+	F	81:5
+	F	1:6
+	F	2:6
+	F	3:6
+	F	4:6
+	F	5:6
+	F	6:6
+	F	7:6
+	F	8:6
+	F	9:6
+	F	10:6
+	F	11:6
+	F	12:6
+	F	13:6
+	F	14:6
+	F	15:6
+	F	16:6
+	F	17:6
+	F	18:6
+	F	19:6
+	F	20:6
+	F	21:6
+	F	22:6
+	F	23:6
+	F	24:6
+	F	25:6
+	F	26:6
+	F	27:6
+	F	28:6
+	F	29:6
+	F	30:6
+	F	31:6
+	F	32:6
+	F	0:a
+	F	1:a
+	F	2:a
+	F	3:a
+	F	4:a
+	F	5:a
+	F	6:a
+	F	7:a
+	F	8:a
+	F	9:a
+	F	10:a
+	F	11:a
+	F	12:a
+	F	13:a
+	F	14:a
+	F	15:a
+	F	16:a
+	F	17:a
+	F	18:a
+	F	19:a
+	F	20:a
+	F	21:a
+	F	22:a
+	F	23:a
+	F	24:a
+	F	25:a
+	F	26:a
+	F	27:a
+	F	28:a
+	F	29:a
+	F	30:a
+	F	31:a
+	F	32:a
+	F	33:a
+	F	34:a
+	F	35:a
+	F	36:a
+	F	37:a
+	F	38:a
+	F	39:a
+	F	40:a
+	F	41:a
+	F	42:a
+	F	43:a
+	F	44:a
+	F	45:a
+	F	46:a
+	F	47:a
+	F	48:a
+	F	49:a
+	F	50:a
+	F	51:a
+	F	52:a
+	F	53:a
+	F	54:a
+	F	55:a
+	F	56:a
+	F	57:a
+	F	58:a
+	F	59:a
+	F	60:a
+	F	61:a
+	F	62:a
+	F	63:a
+	F	64:a
+	F	65:a
+	F	66:a
+	F	67:a
+	F	68:a
+	F	69:a
+	F	70:a
+	F	71:a
+	F	72:a
+	F	73:a
+	F	74:a
+	F	75:a
+	F	76:a
+	F	77:a
+	F	78:a
+	F	79:a
+	F	80:a
+	F	81:a
+	F	82:a
+	F	83:a
+	F	84:a
+	F	85:a
+	F	86:a
+	F	87:a
+	F	88:a
+	F	89:a
+	F	90:a
+	F	91:a
+	F	92:a
+	F	93:a
+	F	94:a
+	F	95:a
+	F	96:a
+	F	97:a
+	F	98:a
+	F	99:a
+	F	100:a
+	F	101:a
+	F	102:a
+	F	103:a
+	F	104:a
+	F	105:a
+	F	106:a
+	F	107:a
+	F	108:a
+	F	109:a
+	F	110:a
+	F	111:a
+	F	112:a
+	F	113:a
+	F	114:a
+	F	115:a
+	F	116:a
+	F	117:a
+	F	118:a
+	F	119:a
+	F	120:a
+	F	121:a
+	F	122:a
+	F	123:a
+	F	124:a
+	F	125:a
+	F	126:a
+	F	127:a
+	F	128:a
+	F	129:a
+	F	130:a
+	F	131:a
+	F	132:a
+	F	133:a
+	F	134:a
+	F	135:a
+	F	136:a
+	F	137:a
+	F	138:a
+	F	139:a
+	F	140:a
+	F	141:a
+	F	142:a
+	F	143:a
+	F	144:a
+	F	145:a
+	F	146:a
+	F	147:a
+	F	148:a
+	F	149:a
+	F	150:a
+	F	151:a
+	F	152:a
+	F	153:a
+	F	154:a
+	F	155:a
+	F	156:a
+	F	157:a
+	F	158:a
+	F	159:a
+	F	160:a
+	F	161:a
+	F	162:a
+	F	163:a
+	F	164:a
+	F	165:a
+	F	166:a
+	F	167:a
+	F	168:a
+	F	169:a
+	F	170:a
+	F	171:a
+	F	172:a
+	F	173:a
+	F	174:a
+	F	175:a
+	F	176:a
+	F	177:a
+	F	178:a
+	F	179:a
+	F	180:a
+	F	181:a
+	F	182:a
+	F	183:a
+	F	184:a
+	F	185:a
+	F	186:a
+	F	187:a
+	F	188:a
+	F	189:a
+	F	190:a
+	F	191:a
+	F	192:a
+	F	193:a
+	F	194:a
+	F	195:a
+	F	196:a
+	F	197:a
+	F	198:a
+	F	199:a
+	F	200:a
+	F	201:a
+	F	202:a
+	F	203:a
+	F	204:a
+	F	205:a
+	F	206:a
+	F	207:a
+	F	208:a
+	F	209:a
+	F	210:a
+	F	211:a
+	F	212:a
+	F	213:a
+	F	214:a
+	F	215:a
+	F	216:a
+	F	217:a
+	F	218:a
+	F	219:a
+	F	220:a
+	F	221:a
+	F	222:a
+	F	223:a
+	F	224:a
+	F	225:a
+	F	226:a
+	F	227:a
+	F	228:a
+	F	229:a
+	F	230:a
+	F	231:a
+	F	232:a
+	F	233:a
+	F	234:a
+	F	235:a
+	F	236:a
+	F	237:a
+	F	238:a
+	F	239:a
+	F	240:a
+	F	241:a
+	F	242:a
+	F	243:a
+	F	244:a
+	F	245:a
+	F	246:a
+	F	247:a
+	F	248:a
+	F	249:a
+	F	250:a
+	F	251:a
+	F	252:a
+	F	253:a
+	F	254:a
+	F	255:a
+	F	0:b
+	F	1:b
+	F	2:b
+	F	3:b
+	F	4:b
+	F	5:b
+	F	6:b
+	F	7:b
+	F	8:b
+	F	9:b
+	F	10:b
+	F	11:b
+	F	12:b
+	F	13:b
+	F	14:b
+	F	15:b
+	F	16:b
+	F	17:b
+	F	18:b
+	F	19:b
+	F	20:b
+	F	21:b
+	F	22:b
+	F	23:b
+	F	24:b
+	F	25:b
+	F	26:b
+	F	27:b
+	F	28:b
+	F	29:b
+	F	30:b
+	F	31:b
+	F	32:b
+	F	33:b
+	F	34:b
+	F	35:b
+	F	36:b
+	F	37:b
+	F	38:b
+	F	39:b
+	F	40:b
+	F	41:b
+	F	42:b
+	F	43:b
+	F	44:b
+	F	45:b
+	F	46:b
+	F	47:b
+	F	48:b
+	F	49:b
+	F	50:b
+	F	51:b
+	F	52:b
+	F	53:b
+	F	54:b
+	F	55:b
+	F	56:b
+	F	57:b
+	F	58:b
+	F	59:b
+	F	60:b
+	F	61:b
+	F	62:b
+	F	63:b
+	F	64:b
+	F	65:b
+	F	66:b
+	F	67:b
+	F	68:b
+	F	69:b
+	F	70:b
+	F	71:b
+	F	72:b
+	F	73:b
+	F	74:b
+	F	75:b
+	F	76:b
+	F	77:b
+	F	78:b
+	F	79:b
+	F	80:b
+	F	81:b
+	F	82:b
+	F	83:b
+	F	84:b
+	F	85:b
+	F	86:b
+	F	87:b
+	F	88:b
+	F	89:b
+	F	90:b
+	F	91:b
+	F	92:b
+	F	93:b
+	F	94:b
+	F	95:b
+	F	96:b
+	F	97:b
+	F	98:b
+	F	99:b
+	F	100:b
+	F	101:b
+	F	102:b
+	F	103:b
+	F	104:b
+	F	105:b
+	F	106:b
+	F	107:b
+	F	108:b
+	F	109:b
+	F	110:b
+	F	111:b
+	F	112:b
+	F	113:b
+	F	114:b
+	F	115:b
+	F	116:b
+	F	117:b
+	F	118:b
+	F	119:b
+	F	120:b
+	F	121:b
+	F	122:b
+	F	123:b
+	F	124:b
+	F	125:b
+	F	126:b
+	F	127:b
+	F	128:b
+	F	129:b
+	F	130:b
+	F	131:b
+	F	132:b
+	F	133:b
+	F	134:b
+	F	135:b
+	F	136:b
+	F	137:b
+	F	138:b
+	F	139:b
+	F	140:b
+	F	141:b
+	F	142:b
+	F	143:b
+	F	144:b
+	F	145:b
+	F	146:b
+	F	147:b
+	F	148:b
+	F	149:b
+	F	150:b
+	F	151:b
+	F	152:b
+	F	153:b
+	F	154:b
+	F	155:b
+	F	156:b
+	F	157:b
+	F	158:b
+	F	159:b
+	F	160:b
+	F	161:b
+	F	162:b
+	F	163:b
+	F	164:b
+	F	165:b
+	F	166:b
+	F	167:b
+	F	168:b
+	F	169:b
+	F	170:b
+	F	171:b
+	F	172:b
+	F	173:b
+	F	174:b
+	F	175:b
+	F	176:b
+	F	177:b
+	F	178:b
+	F	179:b
+	F	180:b
+	F	181:b
+	F	182:b
+	F	183:b
+	F	184:b
+	F	185:b
+	F	186:b
+	F	187:b
+	F	188:b
+	F	189:b
+	F	190:b
+	F	191:b
+	F	192:b
+	F	193:b
+	F	194:b
+	F	195:b
+	F	196:b
+	F	197:b
+	F	198:b
+	F	199:b
+	F	200:b
+	F	201:b
+	F	202:b
+	F	203:b
+	F	204:b
+	F	205:b
+	F	206:b
+	F	207:b
+	F	208:b
+	F	209:b
+	F	210:b
+	F	211:b
+	F	212:b
+	F	213:b
+	F	214:b
+	F	215:b
+	F	216:b
+	F	217:b
+	F	218:b
+	F	219:b
+	F	220:b
+	F	221:b
+	F	222:b
+	F	223:b
+	F	224:b
+	F	225:b
+	F	226:b
+	F	227:b
+	F	228:b
+	F	229:b
+	F	230:b
+	F	231:b
+	F	232:b
+	F	233:b
+	F	234:b
+	F	235:b
+	F	236:b
+	F	237:b
+	F	238:b
+	F	239:b
+	F	240:b
+	F	241:b
+	F	242:b
+	F	243:b
+	F	244:b
+	F	245:b
+	F	246:b
+	F	247:b
+	F	248:b
+	F	249:b
+	F	250:b
+	F	251:b
+	F	252:b
+	F	253:b
+	F	254:b
+	F	255:b
+	F	0:c
+	F	1:c
+	F	2:c
+	F	3:c
+	F	4:c
+	F	5:c
+	F	6:c
+	F	7:c
+	F	8:c
+	F	9:c
+	F	10:c
+	F	11:c
+	F	12:c
+	F	13:c
+	F	14:c
+	F	15:c
+	F	16:c
+	F	17:c
+	F	18:c
+	F	19:c
+	F	20:c
+	F	21:c
+	F	22:c
+	F	23:c
+	F	24:c
+	F	25:c
+	F	26:c
+	F	27:c
+	F	28:c
+	F	29:c
+	F	30:c
+	F	31:c
+	F	32:c
+	F	33:c
+	F	34:c
+	F	35:c
+	F	36:c
+	F	37:c
+	F	38:c
+	F	39:c
+	F	40:c
+	F	41:c
+	F	42:c
+	F	43:c
+	F	44:c
+	F	45:c
+	F	46:c
+	F	47:c
+	F	48:c
+	F	49:c
+	F	50:c
+	F	51:c
+	F	52:c
+	F	53:c
+	F	54:c
+	F	55:c
+	F	56:c
+	F	57:c
+	F	58:c
+	F	59:c
+	F	60:c
+	F	61:c
+	F	62:c
+	F	63:c
+	F	64:c
+	F	65:c
+	F	66:c
+	F	67:c
+	F	68:c
+	F	69:c
+	F	70:c
+	F	71:c
+	F	72:c
+	F	73:c
+	F	74:c
+	F	75:c
+	F	76:c
+	F	77:c
+	F	78:c
+	F	79:c
+	F	80:c
+	F	81:c
+	F	82:c
+	F	83:c
+	F	84:c
+	F	85:c
+	F	86:c
+	F	87:c
+	F	88:c
+	F	89:c
+	F	90:c
+	F	91:c
+	F	92:c
+	F	93:c
+	F	94:c
+	F	95:c
+	F	96:c
+	F	97:c
+	F	98:c
+	F	99:c
+	F	100:c
+	F	101:c
+	F	102:c
+	F	103:c
+	F	104:c
+	F	105:c
+	F	106:c
+	F	107:c
+	F	108:c
+	F	109:c
+	F	110:c
+	F	111:c
+	F	112:c
+	F	113:c
+	F	114:c
+	F	115:c
+	F	116:c
+	F	117:c
+	F	118:c
+	F	119:c
+	F	120:c
+	F	121:c
+	F	122:c
+	F	123:c
+	F	124:c
+	F	125:c
+	F	126:c
+	F	127:c
+	F	128:c
+	F	129:c
+	F	130:c
+	F	131:c
+	F	132:c
+	F	133:c
+	F	134:c
+	F	135:c
+	F	136:c
+	F	137:c
+	F	138:c
+	F	139:c
+	F	140:c
+	F	141:c
+	F	142:c
+	F	143:c
+	F	144:c
+	F	145:c
+	F	146:c
+	F	147:c
+	F	148:c
+	F	149:c
+	F	150:c
+	F	151:c
+	F	152:c
+	F	153:c
+	F	154:c
+	F	155:c
+	F	156:c
+	F	157:c
+	F	158:c
+	F	159:c
+	F	160:c
+	F	161:c
+	F	162:c
+	F	163:c
+	F	164:c
+	F	165:c
+	F	166:c
+	F	167:c
+	F	168:c
+	F	169:c
+	F	170:c
+	F	171:c
+	F	172:c
+	F	173:c
+	F	174:c
+	F	175:c
+	F	176:c
+	F	177:c
+	F	178:c
+	F	179:c
+	F	180:c
+	F	181:c
+	F	182:c
+	F	183:c
+	F	184:c
+	F	185:c
+	F	186:c
+	F	187:c
+	F	188:c
+	F	189:c
+	F	190:c
+	F	191:c
+	F	192:c
+	F	193:c
+	F	194:c
+	F	195:c
+	F	196:c
+	F	197:c
+	F	198:c
+	F	199:c
+	F	200:c
+	F	201:c
+	F	202:c
+	F	203:c
+	F	204:c
+	F	205:c
+	F	206:c
+	F	207:c
+	F	208:c
+	F	209:c
+	F	210:c
+	F	211:c
+	F	212:c
+	F	213:c
+	F	214:c
+	F	215:c
+	F	216:c
+	F	217:c
+	F	218:c
+	F	219:c
+	F	220:c
+	F	221:c
+	F	222:c
+	F	223:c
+	F	224:c
+	F	225:c
+	F	226:c
+	F	227:c
+	F	228:c
+	F	229:c
+	F	230:c
+	F	231:c
+	F	232:c
+	F	233:c
+	F	234:c
+	F	235:c
+	F	236:c
+	F	237:c
+	F	238:c
+	F	239:c
+	F	240:c
+	F	241:c
+	F	242:c
+	F	243:c
+	F	244:c
+	F	245:c
+	F	246:c
+	F	247:c
+	F	248:c
+	F	249:c
+	F	250:c
+	F	251:c
+	F	252:c
+	F	253:c
+	F	254:c
+	F	255:c
+	F	0:d
+	F	1:d
+	F	2:d
+	F	3:d
+	F	4:d
+	F	5:d
+	F	6:d
+	F	7:d
+	F	8:d
+	F	9:d
+	F	10:d
+	F	11:d
+	F	12:d
+	F	13:d
+	F	14:d
+	F	15:d
+	F	16:d
+	F	17:d
+	F	18:d
+	F	19:d
+	F	20:d
+	F	21:d
+	F	22:d
+	F	23:d
+	F	24:d
+	F	25:d
+	F	26:d
+	F	27:d
+	F	28:d
+	F	29:d
+	F	30:d
+	F	31:d
+	F	32:d
+	F	33:d
+	F	34:d
+	F	35:d
+	F	36:d
+	F	37:d
+	F	38:d
+	F	39:d
+	F	40:d
+	F	41:d
+	F	42:d
+	F	43:d
+	F	44:d
+	F	45:d
+	F	46:d
+	F	47:d
+	F	48:d
+	F	49:d
+	F	50:d
+	F	51:d
+	F	52:d
+	F	53:d
+	F	54:d
+	F	55:d
+	F	56:d
+	F	57:d
+	F	58:d
+	F	59:d
+	F	60:d
+	F	61:d
+	F	62:d
+	F	63:d
+	F	64:d
+	F	65:d
+	F	66:d
+	F	67:d
+	F	68:d
+	F	69:d
+	F	70:d
+	F	71:d
+	F	72:d
+	F	73:d
+	F	74:d
+	F	75:d
+	F	76:d
+	F	77:d
+	F	78:d
+	F	79:d
+	F	80:d
+	F	81:d
+	F	82:d
+	F	83:d
+	F	84:d
+	F	85:d
+	F	86:d
+	F	87:d
+	F	88:d
+	F	89:d
+	F	90:d
+	F	91:d
+	F	92:d
+	F	93:d
+	F	94:d
+	F	95:d
+	F	96:d
+	F	97:d
+	F	98:d
+	F	99:d
+	F	100:d
+	F	101:d
+	F	102:d
+	F	103:d
+	F	104:d
+	F	105:d
+	F	106:d
+	F	107:d
+	F	108:d
+	F	109:d
+	F	110:d
+	F	111:d
+	F	112:d
+	F	113:d
+	F	114:d
+	F	115:d
+	F	116:d
+	F	117:d
+	F	118:d
+	F	119:d
+	F	120:d
+	F	121:d
+	F	122:d
+	F	123:d
+	F	124:d
+	F	125:d
+	F	126:d
+	F	127:d
+	F	128:d
+	F	129:d
+	F	130:d
+	F	131:d
+	F	132:d
+	F	133:d
+	F	134:d
+	F	135:d
+	F	136:d
+	F	137:d
+	F	138:d
+	F	139:d
+	F	140:d
+	F	141:d
+	F	142:d
+	F	143:d
+	F	144:d
+	F	145:d
+	F	146:d
+	F	147:d
+	F	148:d
+	F	149:d
+	F	150:d
+	F	151:d
+	F	152:d
+	F	153:d
+	F	154:d
+	F	155:d
+	F	156:d
+	F	157:d
+	F	158:d
+	F	159:d
+	F	160:d
+	F	161:d
+	F	162:d
+	F	163:d
+	F	164:d
+	F	165:d
+	F	166:d
+	F	167:d
+	F	168:d
+	F	169:d
+	F	170:d
+	F	171:d
+	F	172:d
+	F	173:d
+	F	174:d
+	F	175:d
+	F	176:d
+	F	177:d
+	F	178:d
+	F	179:d
+	F	180:d
+	F	181:d
+	F	182:d
+	F	183:d
+	F	184:d
+	F	185:d
+	F	186:d
+	F	187:d
+	F	188:d
+	F	189:d
+	F	190:d
+	F	191:d
+	F	192:d
+	F	193:d
+	F	194:d
+	F	195:d
+	F	196:d
+	F	197:d
+	F	198:d
+	F	199:d
+	F	200:d
+	F	201:d
+	F	202:d
+	F	203:d
+	F	204:d
+	F	205:d
+	F	206:d
+	F	207:d
+	F	208:d
+	F	209:d
+	F	210:d
+	F	211:d
+	F	212:d
+	F	213:d
+	F	214:d
+	F	215:d
+	F	216:d
+	F	217:d
+	F	218:d
+	F	219:d
+	F	220:d
+	F	221:d
+	F	222:d
+	F	223:d
+	F	224:d
+	F	225:d
+	F	226:d
+	F	227:d
+	F	228:d
+	F	229:d
+	F	230:d
+	F	231:d
+	F	232:d
+	F	233:d
+	F	234:d
+	F	235:d
+	F	236:d
+	F	237:d
+	F	238:d
+	F	239:d
+	F	240:d
+	F	241:d
+	F	242:d
+	F	243:d
+	F	244:d
+	F	245:d
+	F	246:d
+	F	247:d
+	F	248:d
+	F	249:d
+	F	250:d
+	F	251:d
+	F	252:d
+	F	253:d
+	F	254:d
+	F	255:d
+	F	0:e
+	F	1:e
+	F	2:e
+	F	3:e
+	F	4:e
+	F	5:e
+	F	6:e
+	F	7:e
+	F	8:e
+	F	9:e
+	F	10:e
+	F	11:e
+	F	12:e
+	F	13:e
+	F	14:e
+	F	15:e
+	F	16:e
+	F	17:e
+	F	18:e
+	F	19:e
+	F	20:e
+	F	21:e
+	F	22:e
+	F	23:e
+	F	24:e
+	F	25:e
+	F	26:e
+	F	27:e
+	F	28:e
+	F	29:e
+	F	30:e
+	F	31:e
+	F	32:e
+	F	33:e
+	F	34:e
+	F	35:e
+	F	36:e
+	F	37:e
+	F	38:e
+	F	39:e
+	F	40:e
+	F	41:e
+	F	42:e
+	F	43:e
+	F	44:e
+	F	45:e
+	F	46:e
+	F	47:e
+	F	48:e
+	F	49:e
+	F	50:e
+	F	51:e
+	F	52:e
+	F	53:e
+	F	54:e
+	F	55:e
+	F	56:e
+	F	57:e
+	F	58:e
+	F	59:e
+	F	60:e
+	F	61:e
+	F	62:e
+	F	63:e
+	F	64:e
+	F	65:e
+	F	66:e
+	F	67:e
+	F	68:e
+	F	69:e
+	F	70:e
+	F	71:e
+	F	72:e
+	F	73:e
+	F	74:e
+	F	75:e
+	F	76:e
+	F	77:e
+	F	78:e
+	F	79:e
+	F	80:e
+	F	81:e
+	F	82:e
+	F	83:e
+	F	84:e
+	F	85:e
+	F	86:e
+	F	87:e
+	F	88:e
+	F	89:e
+	F	90:e
+	F	91:e
+	F	92:e
+	F	93:e
+	F	94:e
+	F	95:e
+	F	96:e
+	F	97:e
+	F	98:e
+	F	99:e
+	F	100:e
+	F	101:e
+	F	102:e
+	F	103:e
+	F	104:e
+	F	105:e
+	F	106:e
+	F	107:e
+	F	108:e
+	F	109:e
+	F	110:e
+	F	111:e
+	F	112:e
+	F	113:e
+	F	114:e
+	F	115:e
+	F	116:e
+	F	117:e
+	F	118:e
+	F	119:e
+	F	120:e
+	F	121:e
+	F	122:e
+	F	123:e
+	F	124:e
+	F	125:e
+	F	126:e
+	F	127:e
+	F	128:e
+	F	129:e
+	F	130:e
+	F	131:e
+	F	132:e
+	F	133:e
+	F	134:e
+	F	135:e
+	F	136:e
+	F	137:e
+	F	138:e
+	F	139:e
+	F	140:e
+	F	141:e
+	F	142:e
+	F	143:e
+	F	144:e
+	F	145:e
+	F	146:e
+	F	147:e
+	F	148:e
+	F	149:e
+	F	150:e
+	F	151:e
+	F	152:e
+	F	153:e
+	F	154:e
+	F	155:e
+	F	156:e
+	F	157:e
+	F	158:e
+	F	159:e
+	F	160:e
+	F	161:e
+	F	162:e
+	F	163:e
+	F	164:e
+	F	165:e
+	F	166:e
+	F	167:e
+	F	168:e
+	F	169:e
+	F	170:e
+	F	171:e
+	F	172:e
+	F	173:e
+	F	174:e
+	F	175:e
+	F	176:e
+	F	177:e
+	F	178:e
+	F	179:e
+	F	180:e
+	F	181:e
+	F	182:e
+	F	183:e
+	F	184:e
+	F	185:e
+	F	186:e
+	F	187:e
+	F	188:e
+	F	189:e
+	F	190:e
+	F	191:e
+	F	192:e
+	F	193:e
+	F	194:e
+	F	195:e
+	F	196:e
+	F	197:e
+	F	198:e
+	F	199:e
+	F	200:e
+	F	201:e
+	F	202:e
+	F	203:e
+	F	204:e
+	F	205:e
+	F	206:e
+	F	207:e
+	F	208:e
+	F	209:e
+	F	210:e
+	F	211:e
+	F	212:e
+	F	213:e
+	F	214:e
+	F	215:e
+	F	216:e
+	F	217:e
+	F	218:e
+	F	219:e
+	F	220:e
+	F	221:e
+	F	222:e
+	F	223:e
+	F	224:e
+	F	225:e
+	F	226:e
+	F	227:e
+	F	228:e
+	F	229:e
+	F	230:e
+	F	231:e
+	F	232:e
+	F	233:e
+	F	234:e
+	F	235:e
+	F	236:e
+	F	237:e
+	F	238:e
+	F	239:e
+	F	240:e
+	F	241:e
+	F	242:e
+	F	243:e
+	F	244:e
+	F	245:e
+	F	246:e
+	F	247:e
+	F	248:e
+	F	249:e
+	F	250:e
+	F	251:e
+	F	252:e
+	F	253:e
+	F	254:e
+	F	255:e
+	F	0:f
+	F	1:f
+	F	2:f
+	F	3:f
+	F	4:f
+	F	5:f
+	F	6:f
+	F	7:f
+	F	8:f
+	F	9:f
+	F	10:f
+	F	11:f
+	F	12:f
+	F	13:f
+	F	14:f
+	F	15:f
+	F	16:f
+	F	17:f
+	F	18:f
+	F	19:f
+	F	20:f
+	F	21:f
+	F	22:f
+	F	23:f
+	F	24:f
+	F	25:f
+	F	26:f
+	F	27:f
+	F	28:f
+	F	29:f
+	F	30:f
+	F	31:f
+	F	32:f
+	F	33:f
+	F	34:f
+	F	35:f
+	F	36:f
+	F	37:f
+	F	38:f
+	F	39:f
+	F	40:f
+	F	41:f
+	F	42:f
+	F	43:f
+	F	44:f
+	F	45:f
+	F	46:f
+	F	47:f
+	F	48:f
+	F	49:f
+	F	50:f
+	F	51:f
+	F	52:f
+	F	53:f
+	F	54:f
+	F	55:f
+	F	56:f
+	F	57:f
+	F	58:f
+	F	59:f
+	F	60:f
+	F	61:f
+	F	62:f
+	F	63:f
+	F	64:f
+	F	65:f
+	F	66:f
+	F	67:f
+	F	68:f
+	F	69:f
+	F	70:f
+	F	71:f
+	F	72:f
+	F	73:f
+	F	74:f
+	F	75:f
+	F	76:f
+	F	77:f
+	F	78:f
+	F	79:f
+	F	80:f
+	F	81:f
+	F	82:f
+	F	83:f
+	F	84:f
+	F	85:f
+	F	86:f
+	F	87:f
+	F	88:f
+	F	89:f
+	F	90:f
+	F	91:f
+	F	92:f
+	F	93:f
+	F	94:f
+	F	95:f
+	F	96:f
+	F	97:f
+	F	98:f
+	F	99:f
+	F	100:f
+	F	101:f
+	F	102:f
+	F	103:f
+	F	104:f
+	F	105:f
+	F	106:f
+	F	107:f
+	F	108:f
+	F	109:f
+	F	110:f
+	F	111:f
+	F	112:f
+	F	113:f
+	F	114:f
+	F	115:f
+	F	116:f
+	F	117:f
+	F	118:f
+	F	119:f
+	F	120:f
+	F	121:f
+	F	122:f
+	F	123:f
+	F	124:f
+	F	125:f
+	F	126:f
+	F	127:f
+	F	128:f
+	F	129:f
+	F	130:f
+	F	131:f
+	F	132:f
+	F	133:f
+	F	134:f
+	F	135:f
+	F	136:f
+	F	137:f
+	F	138:f
+	F	139:f
+	F	140:f
+	F	141:f
+	F	142:f
+	F	143:f
+	F	144:f
+	F	145:f
+	F	146:f
+	F	147:f
+	F	148:f
+	F	149:f
+	F	150:f
+	F	151:f
+	F	152:f
+	F	153:f
+	F	154:f
+	F	155:f
+	F	156:f
+	F	157:f
+	F	158:f
+	F	159:f
+	F	160:f
+	F	161:f
+	F	162:f
+	F	163:f
+	F	164:f
+	F	165:f
+	F	166:f
+	F	167:f
+	F	168:f
+	F	169:f
+	F	170:f
+	F	171:f
+	F	172:f
+	F	173:f
+	F	174:f
+	F	175:f
+	F	176:f
+	F	177:f
+	F	178:f
+	F	179:f
+	F	180:f
+	F	181:f
+	F	182:f
+	F	183:f
+	F	184:f
+	F	185:f
+	F	186:f
+	F	187:f
+	F	188:f
+	F	189:f
+	F	190:f
+	F	191:f
+	F	192:f
+	F	193:f
+	F	194:f
+	F	195:f
+	F	196:f
+	F	197:f
+	F	198:f
+	F	199:f
+	F	200:f
+	F	201:f
+	F	202:f
+	F	203:f
+	F	204:f
+	F	205:f
+	F	206:f
+	F	207:f
+	F	208:f
+	F	209:f
+	F	210:f
+	F	211:f
+	F	212:f
+	F	213:f
+	F	214:f
+	F	215:f
+	F	216:f
+	F	217:f
+	F	218:f
+	F	219:f
+	F	220:f
+	F	221:f
+	F	222:f
+	F	223:f
+	F	224:f
+	F	225:f
+	F	226:f
+	F	227:f
+	F	228:f
+	F	229:f
+	F	230:f
+	F	231:f
+	F	232:f
+	F	233:f
+	F	234:f
+	F	235:f
+	F	236:f
+	F	237:f
+	F	238:f
+	F	239:f
+	F	240:f
+	F	241:f
+	F	242:f
+	F	243:f
+	F	244:f
+	F	245:f
+	F	246:f
+	F	247:f
+	F	248:f
+	F	249:f
+	F	250:f
+	F	251:f
+	F	252:f
+	F	253:f
+	F	254:f
+	F	255:f
+	F	0:g
+	F	1:g
+	F	2:g
+	F	3:g
+	F	4:g
+	F	5:g
+	F	6:g
+	F	7:g
+	F	8:g
+	F	9:g
+	F	10:g
+	F	11:g
+	F	12:g
+	F	13:g
+	F	14:g
+	F	15:g
+	F	16:g
+	F	17:g
+	F	18:g
+	F	19:g
+	F	20:g
+	F	21:g
+	F	22:g
+	F	23:g
+	F	24:g
+	F	25:g
+	F	26:g
+	F	27:g
+	F	28:g
+	F	29:g
+	F	30:g
+	F	31:g
+	F	32:g
+	F	33:g
+	F	34:g
+	F	35:g
+	F	36:g
+	F	37:g
+	F	38:g
+	F	39:g
+	F	40:g
+	F	41:g
+	F	42:g
+	F	43:g
+	F	44:g
+	F	45:g
+	F	46:g
+	F	47:g
+	F	48:g
+	F	49:g
+	F	50:g
+	F	51:g
+	F	52:g
+	F	53:g
+	F	54:g
+	F	55:g
+	F	56:g
+	F	57:g
+	F	58:g
+	F	59:g
+	F	60:g
+	F	61:g
+	F	62:g
+	F	63:g
+	F	64:g
+	F	65:g
+	F	66:g
+	F	67:g
+	F	68:g
+	F	69:g
+	F	70:g
+	F	71:g
+	F	72:g
+	F	73:g
+	F	74:g
+	F	75:g
+	F	76:g
+	F	77:g
+	F	78:g
+	F	79:g
+	F	80:g
+	F	81:g
+	F	82:g
+	F	83:g
+	F	84:g
+	F	85:g
+	F	86:g
+	F	87:g
+	F	88:g
+	F	89:g
+	F	90:g
+	F	91:g
+	F	92:g
+	F	93:g
+	F	94:g
+	F	95:g
+	F	96:g
+	F	97:g
+	F	98:g
+	F	99:g
+	F	100:g
+	F	101:g
+	F	102:g
+	F	103:g
+	F	104:g
+	F	105:g
+	F	106:g
+	F	107:g
+	F	108:g
+	F	109:g
+	F	110:g
+	F	111:g
+	F	112:g
+	F	113:g
+	F	114:g
+	F	115:g
+	F	116:g
+	F	117:g
+	F	118:g
+	F	119:g
+	F	120:g
+	F	121:g
+	F	122:g
+	F	123:g
+	F	124:g
+	F	125:g
+	F	126:g
+	F	127:g
+	F	128:g
+	F	129:g
+	F	130:g
+	F	131:g
+	F	132:g
+	F	133:g
+	F	134:g
+	F	135:g
+	F	136:g
+	F	137:g
+	F	138:g
+	F	139:g
+	F	140:g
+	F	141:g
+	F	142:g
+	F	143:g
+	F	144:g
+	F	145:g
+	F	146:g
+	F	147:g
+	F	148:g
+	F	149:g
+	F	150:g
+	F	151:g
+	F	152:g
+	F	153:g
+	F	154:g
+	F	155:g
+¡	F	156:g
+¢	F	157:g
+£	F	158:g
+¤	F	159:g
+¥	F	160:g
+¦	F	161:g
+§	F	162:g
+¨	F	163:g
+©	F	164:g
+ª	F	165:g
+«	F	166:g
+¬	F	167:g
+­	F	168:g
+®	F	169:g
+¯	F	170:g
+°	F	171:g
+±	F	172:g
+²	F	173:g
+³	F	174:g
+´	F	175:g
+µ	F	176:g
+¶	F	177:g
+·	F	178:g
+¸	F	179:g
+¹	F	180:g
+º	F	181:g
+»	F	182:g
+¼	F	183:g
+½	F	184:g
+¾	F	185:g
+¿	F	186:g
+	F	187:g
+	F	188:g
+	F	189:g
+	F	190:g
+	F	191:g
+	F	192:g
+	F	193:g
+	F	194:g
+	F	195:g
+	F	196:g
+	F	197:g
+	F	198:g
+	F	199:g
+	F	200:g
+	F	201:g
+	F	202:g
+	F	203:g
+	F	204:g
+	F	205:g
+	F	206:g
+	F	207:g
+	F	208:g
+	F	209:g
+	F	210:g
+	F	211:g
+	F	212:g
+	F	213:g
+	F	214:g
+	F	215:g
+	F	216:g
+	F	217:g
+	F	218:g
+	F	219:g
+	F	220:g
+	F	221:g
+	F	222:g
+	F	223:g
+	F	224:g
+	F	225:g
+	F	226:g
+	F	227:g
+	F	228:g
+	F	229:g
+	F	230:g
+	F	231:g
+	F	232:g
+	F	233:g
+	F	234:g
+	F	235:g
+	F	236:g
+	F	237:g
+	F	238:g
+	F	239:g
+	F	240:g
+	F	241:g
+	F	242:g
+	F	243:g
+	F	244:g
+	F	245:g
+	F	246:g
+	F	247:g
+	F	248:g
+	F	249:g
+á	F	250:g
+â	F	251:g
+ã	F	252:g
+ä	F	253:g
+å	F	254:g
+æ	F	255:g
+ç	F	0:h
+è	F	1:h
+é	F	2:h
+ê	F	3:h
+ë	F	4:h
+ì	F	5:h
+í	F	6:h
+î	F	7:h
+ï	F	8:h
+ð	F	9:h
+ñ	F	10:h
+ò	F	11:h
+ó	F	12:h
+ô	F	13:h
+õ	F	14:h
+ö	F	15:h
+÷	F	16:h
+ø	F	17:h
+ù	F	18:h
+ú	F	19:h
+û	F	20:h
+ü	F	21:h
+ý	F	22:h
+þ	F	23:h
+ÿ	F	24:h
+	F	25:h
+	F	26:h
+	F	27:h
+	F	28:h
+	F	29:h
+	F	30:h
+	F	31:h
+	F	32:h
+	F	33:h
+	F	34:h
+	F	35:h
+	F	36:h
+	F	37:h
+	F	38:h
+	F	39:h
+	F	40:h
+	F	41:h
+	F	42:h
+	F	43:h
+	F	44:h
+	F	45:h
+	F	46:h
+	F	47:h
+	F	48:h
+	F	49:h
+	F	50:h
+	F	51:h
+	F	52:h
+	F	53:h
+	F	54:h
+	F	55:h
+	F	56:h
+	F	57:h
+	F	58:h
+	F	59:h
+	F	60:h
+	F	61:h
+	F	62:h
+	F	63:h
+	F	64:h
+	F	65:h
+	F	66:h
+	F	67:h
+	F	68:h
+	F	69:h
+	F	70:h
+	F	71:h
+	F	72:h
+	F	73:h
+	F	74:h
+	F	75:h
+	F	76:h
+	F	77:h
+	F	78:h
+	F	79:h
+	F	80:h
+	F	81:h
+	F	82:h
+	F	83:h
+	F	84:h
+	F	85:h
+	F	86:h
+	F	87:h
+ġ	F	88:h
+Ģ	F	89:h
+ģ	F	90:h
+Ĥ	F	91:h
+ĥ	F	92:h
+Ħ	F	93:h
+ħ	F	94:h
+Ĩ	F	95:h
+ĩ	F	96:h
+Ī	F	97:h
+ī	F	98:h
+Ĭ	F	99:h
+ĭ	F	100:h
+Į	F	101:h
+į	F	102:h
+İ	F	103:h
+ı	F	104:h
+Ĳ	F	105:h
+ĳ	F	106:h
+Ĵ	F	107:h
+ĵ	F	108:h
+Ķ	F	109:h
+ķ	F	110:h
+ĸ	F	111:h
+Ĺ	F	112:h
+ĺ	F	113:h
+Ļ	F	114:h
+ļ	F	115:h
+Ľ	F	116:h
+ľ	F	117:h
+Ŀ	F	118:h
+	F	119:h
+	F	120:h
+	F	121:h
+	F	122:h
+	F	123:h
+	F	124:h
+	F	125:h
+	F	126:h
+	F	127:h
+	F	128:h
+	F	129:h
+	F	130:h
+	F	131:h
+	F	132:h
+	F	133:h
+	F	134:h
+	F	135:h
+	F	136:h
+	F	137:h
+	F	138:h
+	F	139:h
+	F	140:h
+	F	141:h
+	F	142:h
+	F	143:h
+	F	144:h
+	F	145:h
+	F	146:h
+	F	147:h
+	F	148:h
+	F	149:h
+	F	150:h
+	F	151:h
+	F	152:h
+	F	153:h
+	F	154:h
+	F	155:h
+	F	156:h
+	F	157:h
+	F	158:h
+	F	159:h
+	F	160:h
+	F	161:h
+	F	162:h
+	F	163:h
+	F	164:h
+	F	165:h
+	F	166:h
+	F	167:h
+	F	168:h
+	F	169:h
+	F	170:h
+	F	171:h
+	F	172:h
+	F	173:h
+	F	174:h
+	F	175:h
+	F	176:h
+	F	177:h
+	F	178:h
+	F	179:h
+	F	180:h
+	F	181:h
+š	F	182:h
+Ţ	F	183:h
+ţ	F	184:h
+Ť	F	185:h
+ť	F	186:h
+Ŧ	F	187:h
+ŧ	F	188:h
+Ũ	F	189:h
+ũ	F	190:h
+Ū	F	191:h
+ū	F	192:h
+Ŭ	F	193:h
+ŭ	F	194:h
+Ů	F	195:h
+ů	F	196:h
+Ű	F	197:h
+ű	F	198:h
+Ų	F	199:h
+ų	F	200:h
+Ŵ	F	201:h
+ŵ	F	202:h
+Ŷ	F	203:h
+ŷ	F	204:h
+Ÿ	F	205:h
+Ź	F	206:h
+ź	F	207:h
+Ż	F	208:h
+ż	F	209:h
+Ž	F	210:h
+ž	F	211:h
+ſ	F	212:h
+	F	213:h
+	F	214:h
+	F	215:h
+	F	216:h
+	F	217:h
+	F	218:h
+	F	219:h
+	F	220:h
+	F	221:h
+	F	222:h
+	F	223:h
+	F	224:h
+	F	225:h
+	F	226:h
+	F	227:h
+	F	228:h
+	F	229:h
+	F	230:h
+	F	231:h
+	F	232:h
+	F	233:h
+	F	234:h
+	F	235:h
+	F	236:h
+	F	237:h
+	F	238:h
+	F	239:h
+	F	240:h
+	F	241:h
+	F	242:h
+	F	243:h
+	F	244:h
+	F	245:h
+	F	246:h
+	F	247:h
+	F	248:h
+	F	249:h
+	F	250:h
+	F	251:h
+	F	252:h
+	F	253:h
+	F	254:h
+	F	255:h
+	F	0:i
+	F	1:i
+	F	2:i
+	F	3:i
+	F	4:i
+	F	5:i
+	F	6:i
+	F	7:i
+	F	8:i
+	F	9:i
+	F	10:i
+	F	11:i
+	F	12:i
+	F	13:i
+	F	14:i
+	F	15:i
+	F	16:i
+	F	17:i
+	F	18:i
+	F	19:i
+ơ	F	20:i
+Ƣ	F	21:i
+ƣ	F	22:i
+Ƥ	F	23:i
+ƥ	F	24:i
+Ʀ	F	25:i
+Ƨ	F	26:i
+ƨ	F	27:i
+Ʃ	F	28:i
+ƪ	F	29:i
+ƫ	F	30:i
+Ƭ	F	31:i
+ƭ	F	32:i
+Ʈ	F	33:i
+Ư	F	34:i
+ư	F	35:i
+Ʊ	F	36:i
+Ʋ	F	37:i
+Ƴ	F	38:i
+ƴ	F	39:i
+Ƶ	F	40:i
+ƶ	F	41:i
+Ʒ	F	42:i
+Ƹ	F	43:i
+ƹ	F	44:i
+ƺ	F	45:i
+ƻ	F	46:i
+Ƽ	F	47:i
+ƽ	F	48:i
+ƾ	F	49:i
+ƿ	F	50:i
+	F	51:i
+	F	52:i
+	F	53:i
+	F	54:i
+	F	55:i
+	F	56:i
+	F	57:i
+	F	58:i
+	F	59:i
+	F	60:i
+	F	61:i
+	F	62:i
+	F	63:i
+	F	64:i
+	F	65:i
+	F	66:i
+	F	67:i
+	F	68:i
+	F	69:i
+	F	70:i
+	F	71:i
+	F	72:i
+	F	73:i
+	F	74:i
+	F	75:i
+	F	76:i
+	F	77:i
+	F	78:i
+	F	79:i
+	F	80:i
+	F	81:i
+	F	82:i
+	F	83:i
+	F	84:i
+	F	85:i
+	F	86:i
+	F	87:i
+	F	88:i
+	F	89:i
+	F	90:i
+	F	91:i
+	F	92:i
+	F	93:i
+	F	94:i
+	F	95:i
+	F	96:i
+	F	97:i
+	F	98:i
+	F	99:i
+	F	100:i
+	F	101:i
+	F	102:i
+	F	103:i
+	F	104:i
+	F	105:i
+	F	106:i
+	F	107:i
+	F	108:i
+	F	109:i
+	F	110:i
+	F	111:i
+	F	112:i
+	F	113:i
+ǡ	F	114:i
+Ǣ	F	115:i
+ǣ	F	116:i
+Ǥ	F	117:i
+ǥ	F	118:i
+Ǧ	F	119:i
+ǧ	F	120:i
+Ǩ	F	121:i
+ǩ	F	122:i
+Ǫ	F	123:i
+ǫ	F	124:i
+Ǭ	F	125:i
+ǭ	F	126:i
+Ǯ	F	127:i
+ǯ	F	128:i
+ǰ	F	129:i
+Ǳ	F	130:i
+ǲ	F	131:i
+ǳ	F	132:i
+Ǵ	F	133:i
+ǵ	F	134:i
+Ƕ	F	135:i
+Ƿ	F	136:i
+Ǹ	F	137:i
+ǹ	F	138:i
+Ǻ	F	139:i
+ǻ	F	140:i
+Ǽ	F	141:i
+ǽ	F	142:i
+Ǿ	F	143:i
+ǿ	F	144:i
+	F	145:i
+	F	146:i
+	F	147:i
+	F	148:i
+	F	149:i
+	F	150:i
+	F	151:i
+	F	152:i
+	F	153:i
+	F	154:i
+	F	155:i
+	F	156:i
+	F	157:i
+	F	158:i
+	F	159:i
+	F	160:i
+	F	161:i
+	F	162:i
+	F	163:i
+	F	164:i
+	F	165:i
+	F	166:i
+	F	167:i
+	F	168:i
+	F	169:i
+	F	170:i
+	F	171:i
+	F	172:i
+	F	173:i
+	F	174:i
+	F	175:i
+	F	176:i
+	F	177:i
+	F	178:i
+	F	179:i
+	F	180:i
+	F	181:i
+	F	182:i
+	F	183:i
+	F	184:i
+	F	185:i
+	F	186:i
+	F	187:i
+	F	188:i
+	F	189:i
+	F	190:i
+	F	191:i
+	F	192:i
+	F	193:i
+	F	194:i
+	F	195:i
+	F	196:i
+	F	197:i
+	F	198:i
+	F	199:i
+	F	200:i
+	F	201:i
+	F	202:i
+	F	203:i
+	F	204:i
+	F	205:i
+	F	206:i
+	F	207:i
+ȡ	F	208:i
+Ȣ	F	209:i
+ȣ	F	210:i
+Ȥ	F	211:i
+ȥ	F	212:i
+Ȧ	F	213:i
+ȧ	F	214:i
+Ȩ	F	215:i
+ȩ	F	216:i
+Ȫ	F	217:i
+ȫ	F	218:i
+Ȭ	F	219:i
+ȭ	F	220:i
+Ȯ	F	221:i
+ȯ	F	222:i
+Ȱ	F	223:i
+ȱ	F	224:i
+Ȳ	F	225:i
+ȳ	F	226:i
+ȴ	F	227:i
+ȵ	F	228:i
+ȶ	F	229:i
+ȷ	F	230:i
+ȸ	F	231:i
+ȹ	F	232:i
+Ⱥ	F	233:i
+Ȼ	F	234:i
+ȼ	F	235:i
+Ƚ	F	236:i
+Ⱦ	F	237:i
+ȿ	F	238:i
+	F	239:i
+	F	240:i
+	F	241:i
+	F	242:i
+	F	243:i
+	F	244:i
+	F	245:i
+	F	246:i
+	F	247:i
+	F	248:i
+	F	249:i
+	F	250:i
+	F	251:i
+	F	252:i
+	F	253:i
+	F	254:i
+	F	255:i
+	F	0:j
+	F	1:j
+	F	2:j
+	F	3:j
+	F	4:j
+	F	5:j
+	F	6:j
+	F	7:j
+	F	8:j
+	F	9:j
+	F	10:j
+	F	11:j
+	F	12:j
+	F	13:j
+	F	14:j
+	F	15:j
+	F	16:j
+	F	17:j
+	F	18:j
+	F	19:j
+	F	20:j
+	F	21:j
+	F	22:j
+	F	23:j
+	F	24:j
+	F	25:j
+	F	26:j
+	F	27:j
+	F	28:j
+	F	29:j
+	F	30:j
+	F	31:j
+	F	32:j
+	F	33:j
+	F	34:j
+	F	35:j
+	F	36:j
+	F	37:j
+	F	38:j
+	F	39:j
+	F	40:j
+	F	41:j
+	F	42:j
+	F	43:j
+	F	44:j
+	F	45:j
+ɡ	F	46:j
+ɢ	F	47:j
+ɣ	F	48:j
+ɤ	F	49:j
+ɥ	F	50:j
+ɦ	F	51:j
+ɧ	F	52:j
+ɨ	F	53:j
+ɩ	F	54:j
+ɪ	F	55:j
+ɫ	F	56:j
+ɬ	F	57:j
+ɭ	F	58:j
+ɮ	F	59:j
+ɯ	F	60:j
+ɰ	F	61:j
+ɱ	F	62:j
+ɲ	F	63:j
+ɳ	F	64:j
+ɴ	F	65:j
+ɵ	F	66:j
+ɶ	F	67:j
+ɷ	F	68:j
+ɸ	F	69:j
+ɹ	F	70:j
+ɺ	F	71:j
+ɻ	F	72:j
+ɼ	F	73:j
+ɽ	F	74:j
+ɾ	F	75:j
+ɿ	F	76:j
+	F	77:j
+	F	78:j
+	F	79:j
+	F	80:j
+	F	81:j
+	F	82:j
+	F	83:j
+	F	84:j
+	F	85:j
+	F	86:j
+	F	87:j
+	F	88:j
+	F	89:j
+	F	90:j
+	F	91:j
+	F	92:j
+	F	93:j
+	F	94:j
+	F	95:j
+	F	96:j
+	F	97:j
+	F	98:j
+	F	99:j
+	F	100:j
+	F	101:j
+	F	102:j
+	F	103:j
+	F	104:j
+	F	105:j
+	F	106:j
+	F	107:j
+	F	108:j
+	F	109:j
+	F	110:j
+	F	111:j
+	F	112:j
+	F	113:j
+	F	114:j
+	F	115:j
+	F	116:j
+	F	117:j
+	F	118:j
+	F	119:j
+	F	120:j
+	F	121:j
+	F	122:j
+	F	123:j
+	F	124:j
+	F	125:j
+	F	126:j
+	F	127:j
+	F	128:j
+	F	129:j
+	F	130:j
+	F	131:j
+	F	132:j
+	F	133:j
+	F	134:j
+	F	135:j
+	F	136:j
+	F	137:j
+	F	138:j
+	F	139:j
+ʡ	F	140:j
+ʢ	F	141:j
+ʣ	F	142:j
+ʤ	F	143:j
+ʥ	F	144:j
+ʦ	F	145:j
+ʧ	F	146:j
+ʨ	F	147:j
+ʩ	F	148:j
+ʪ	F	149:j
+ʫ	F	150:j
+ʬ	F	151:j
+ʭ	F	152:j
+ʮ	F	153:j
+ʯ	F	154:j
+ʰ	F	155:j
+ʱ	F	156:j
+ʲ	F	157:j
+ʳ	F	158:j
+ʴ	F	159:j
+ʵ	F	160:j
+ʶ	F	161:j
+ʷ	F	162:j
+ʸ	F	163:j
+ʹ	F	164:j
+ʺ	F	165:j
+ʻ	F	166:j
+ʼ	F	167:j
+ʽ	F	168:j
+ʾ	F	169:j
+ʿ	F	170:j
+	F	171:j
+	F	172:j
+	F	173:j
+	F	174:j
+	F	175:j
+	F	176:j
+	F	177:j
+	F	178:j
+	F	179:j
+	F	180:j
+	F	181:j
+	F	182:j
+	F	183:j
+	F	184:j
+	F	185:j
+	F	186:j
+	F	187:j
+	F	188:j
+	F	189:j
+	F	190:j
+	F	191:j
+	F	192:j
+	F	193:j
+	F	194:j
+	F	195:j
+	F	196:j
+	F	197:j
+	F	198:j
+	F	199:j
+	F	200:j
+	F	201:j
+	F	202:j
+	F	203:j
+	F	204:j
+	F	205:j
+	F	206:j
+	F	207:j
+	F	208:j
+	F	209:j
+	F	210:j
+	F	211:j
+	F	212:j
+	F	213:j
+	F	214:j
+	F	215:j
+	F	216:j
+	F	217:j
+	F	218:j
+	F	219:j
+	F	220:j
+	F	221:j
+	F	222:j
+	F	223:j
+	F	224:j
+	F	225:j
+	F	226:j
+	F	227:j
+	F	228:j
+	F	229:j
+	F	230:j
+	F	231:j
+	F	232:j
+	F	233:j
+ˡ	F	234:j
+ˢ	F	235:j
+ˣ	F	236:j
+ˤ	F	237:j
+˥	F	238:j
+˦	F	239:j
+˧	F	240:j
+˨	F	241:j
+˩	F	242:j
+˪	F	243:j
+˫	F	244:j
+ˬ	F	245:j
+˭	F	246:j
+ˮ	F	247:j
+˯	F	248:j
+˰	F	249:j
+˱	F	250:j
+˲	F	251:j
+˳	F	252:j
+˴	F	253:j
+˵	F	254:j
+˶	F	255:j
+˷	F	0:k
+˸	F	1:k
+˹	F	2:k
+˺	F	3:k
+˻	F	4:k
+˼	F	5:k
+˽	F	6:k
+˾	F	7:k
+˿	F	8:k
+	F	9:k
+	F	10:k
+	F	11:k
+	F	12:k
+	F	13:k
+	F	14:k
+	F	15:k
+	F	16:k
+	F	17:k
+	F	18:k
+	F	19:k
+	F	20:k
+	F	21:k
+	F	22:k
+	F	23:k
+	F	24:k
+	F	25:k
+	F	26:k
+	F	27:k
+	F	28:k
+	F	29:k
+	F	30:k
+	F	31:k
+	F	32:k
+	F	33:k
+	F	34:k
+	F	35:k
+	F	36:k
+	F	37:k
+	F	38:k
+	F	39:k
+	F	40:k
+	F	41:k
+	F	42:k
+	F	43:k
+	F	44:k
+	F	45:k
+	F	46:k
+	F	47:k
+	F	48:k
+	F	49:k
+	F	50:k
+	F	51:k
+	F	52:k
+	F	53:k
+	F	54:k
+	F	55:k
+	F	56:k
+	F	57:k
+	F	58:k
+	F	59:k
+	F	60:k
+	F	61:k
+	F	62:k
+	F	63:k
+	F	64:k
+	F	65:k
+	F	66:k
+	F	67:k
+	F	68:k
+	F	69:k
+	F	70:k
+	F	71:k
+̡	F	72:k
+̢	F	73:k
+̣	F	74:k
+̤	F	75:k
+̥	F	76:k
+̦	F	77:k
+̧	F	78:k
+̨	F	79:k
+̩	F	80:k
+̪	F	81:k
+̫	F	82:k
+̬	F	83:k
+̭	F	84:k
+̮	F	85:k
+̯	F	86:k
+̰	F	87:k
+̱	F	88:k
+̲	F	89:k
+̳	F	90:k
+̴	F	91:k
+̵	F	92:k
+̶	F	93:k
+̷	F	94:k
+̸	F	95:k
+̹	F	96:k
+̺	F	97:k
+̻	F	98:k
+̼	F	99:k
+̽	F	100:k
+̾	F	101:k
+̿	F	102:k
+	F	103:k
+	F	104:k
+	F	105:k
+	F	106:k
+	F	107:k
+	F	108:k
+	F	109:k
+	F	110:k
+	F	111:k
+	F	112:k
+	F	113:k
+	F	114:k
+	F	115:k
+	F	116:k
+	F	117:k
+	F	118:k
+	F	119:k
+	F	120:k
+	F	121:k
+	F	122:k
+	F	123:k
+	F	124:k
+	F	125:k
+	F	126:k
+	F	127:k
+	F	128:k
+	F	129:k
+	F	130:k
+	F	131:k
+	F	132:k
+	F	133:k
+	F	134:k
+	F	135:k
+	F	136:k
+	F	137:k
+	F	138:k
+	F	139:k
+	F	140:k
+	F	141:k
+	F	142:k
+	F	143:k
+	F	144:k
+	F	145:k
+	F	146:k
+	F	147:k
+	F	148:k
+	F	149:k
+	F	150:k
+	F	151:k
+	F	152:k
+	F	153:k
+	F	154:k
+	F	155:k
+	F	156:k
+	F	157:k
+	F	158:k
+	F	159:k
+	F	160:k
+	F	161:k
+	F	162:k
+	F	163:k
+	F	164:k
+	F	165:k
+͡	F	166:k
+͢	F	167:k
+ͣ	F	168:k
+ͤ	F	169:k
+ͥ	F	170:k
+ͦ	F	171:k
+ͧ	F	172:k
+ͨ	F	173:k
+ͩ	F	174:k
+ͪ	F	175:k
+ͫ	F	176:k
+ͬ	F	177:k
+ͭ	F	178:k
+ͮ	F	179:k
+ͯ	F	180:k
+Ͱ	F	181:k
+ͱ	F	182:k
+Ͳ	F	183:k
+ͳ	F	184:k
+ʹ	F	185:k
+͵	F	186:k
+Ͷ	F	187:k
+ͷ	F	188:k
+͸	F	189:k
+͹	F	190:k
+ͺ	F	191:k
+ͻ	F	192:k
+ͼ	F	193:k
+ͽ	F	194:k
+;	F	195:k
+Ϳ	F	196:k
+	F	197:k
+	F	198:k
+	F	199:k
+	F	200:k
+	F	201:k
+	F	202:k
+	F	203:k
+	F	204:k
+	F	205:k
+	F	206:k
+	F	207:k
+	F	208:k
+	F	209:k
+	F	210:k
+	F	211:k
+	F	212:k
+	F	213:k
+	F	214:k
+	F	215:k
+	F	216:k
+	F	217:k
+	F	218:k
+	F	219:k
+	F	220:k
+	F	221:k
+	F	222:k
+	F	223:k
+	F	224:k
+	F	225:k
+	F	226:k
+	F	227:k
+	F	228:k
+	F	229:k
+	F	230:k
+	F	231:k
+	F	232:k
+	F	233:k
+	F	234:k
+	F	235:k
+	F	236:k
+	F	237:k
+	F	238:k
+	F	239:k
+	F	240:k
+	F	241:k
+	F	242:k
+	F	243:k
+	F	244:k
+	F	245:k
+	F	246:k
+	F	247:k
+	F	248:k
+	F	249:k
+	F	250:k
+	F	251:k
+	F	252:k
+	F	253:k
+	F	254:k
+	F	255:k
+	F	0:l
+	F	1:l
+	F	2:l
+	F	3:l
+Ρ	F	4:l
+΢	F	5:l
+Σ	F	6:l
+Τ	F	7:l
+Υ	F	8:l
+Φ	F	9:l
+Χ	F	10:l
+Ψ	F	11:l
+Ω	F	12:l
+Ϊ	F	13:l
+Ϋ	F	14:l
+ά	F	15:l
+έ	F	16:l
+ή	F	17:l
+ί	F	18:l
+ΰ	F	19:l
+α	F	20:l
+β	F	21:l
+γ	F	22:l
+δ	F	23:l
+ε	F	24:l
+ζ	F	25:l
+η	F	26:l
+θ	F	27:l
+ι	F	28:l
+κ	F	29:l
+λ	F	30:l
+μ	F	31:l
+ν	F	32:l
+ξ	F	33:l
+ο	F	34:l
+	F	35:l
+	F	36:l
+	F	37:l
+	F	38:l
+	F	39:l
+	F	40:l
+	F	41:l
+	F	42:l
+	F	43:l
+	F	44:l
+	F	45:l
+	F	46:l
+	F	47:l
+	F	48:l
+	F	49:l
+	F	50:l
+	F	51:l
+	F	52:l
+	F	53:l
+	F	54:l
+	F	55:l
+	F	56:l
+	F	57:l
+	F	58:l
+	F	59:l
+	F	60:l
+	F	61:l
+	F	62:l
+	F	63:l
+	F	64:l
+	F	65:l
+	F	66:l
+	F	67:l
+	F	68:l
+	F	69:l
+	F	70:l
+	F	71:l
+	F	72:l
+	F	73:l
+	F	74:l
+	F	75:l
+	F	76:l
+	F	77:l
+	F	78:l
+	F	79:l
+	F	80:l
+	F	81:l
+	F	82:l
+	F	83:l
+	F	84:l
+	F	85:l
+	F	86:l
+	F	87:l
+	F	88:l
+	F	89:l
+	F	90:l
+	F	91:l
+	F	92:l
+	F	93:l
+	F	94:l
+	F	95:l
+	F	96:l
+	F	97:l
+ϡ	F	98:l
+Ϣ	F	99:l
+ϣ	F	100:l
+Ϥ	F	101:l
+ϥ	F	102:l
+Ϧ	F	103:l
+ϧ	F	104:l
+Ϩ	F	105:l
+ϩ	F	106:l
+Ϫ	F	107:l
+ϫ	F	108:l
+Ϭ	F	109:l
+ϭ	F	110:l
+Ϯ	F	111:l
+ϯ	F	112:l
+ϰ	F	113:l
+ϱ	F	114:l
+ϲ	F	115:l
+ϳ	F	116:l
+ϴ	F	117:l
+ϵ	F	118:l
+϶	F	119:l
+Ϸ	F	120:l
+ϸ	F	121:l
+Ϲ	F	122:l
+Ϻ	F	123:l
+ϻ	F	124:l
+ϼ	F	125:l
+Ͻ	F	126:l
+Ͼ	F	127:l
+Ͽ	F	128:l
+	F	129:l
+	F	130:l
+	F	131:l
+	F	132:l
+	F	133:l
+	F	134:l
+	F	135:l
+	F	136:l
+	F	137:l
+	F	138:l
+	F	139:l
+	F	140:l
+	F	141:l
+	F	142:l
+	F	143:l
+	F	144:l
+	F	145:l
+	F	146:l
+	F	147:l
+	F	148:l
+С	F	0:m
+Т	F	1:m
+У	F	2:m
+Ф	F	3:m
+Х	F	4:m
+Ц	F	5:m
+Ч	F	6:m
+Ш	F	7:m
+Щ	F	8:m
+Ъ	F	9:m
+Ы	F	10:m
+Ь	F	11:m
+Э	F	12:m
+Ю	F	13:m
+Я	F	14:m
+а	F	15:m
+б	F	16:m
+в	F	17:m
+г	F	18:m
+д	F	19:m
+е	F	20:m
+ж	F	21:m
+з	F	22:m
+и	F	23:m
+й	F	24:m
+к	F	25:m
+л	F	26:m
+м	F	27:m
+н	F	28:m
+о	F	29:m
+п	F	30:m
+	F	31:m
+	F	32:m
+	F	33:m
+	F	34:m
+	F	35:m
+	F	36:m
+	F	37:m
+	F	38:m
+	F	39:m
+	F	40:m
+	F	41:m
+	F	42:m
+	F	43:m
+	F	44:m
+	F	45:m
+	F	46:m
+	F	47:m
+	F	48:m
+	F	49:m
+	F	50:m
+	F	51:m
+	F	52:m
+	F	53:m
+	F	54:m
+	F	55:m
+	F	56:m
+	F	57:m
+	F	58:m
+	F	59:m
+	F	60:m
+	F	61:m
+	F	62:m
+	F	63:m
+	F	64:m
+	F	65:m
+	F	66:m
+	F	67:m
+	F	68:m
+	F	69:m
+	F	70:m
+	F	71:m
+	F	72:m
+	F	73:m
+	F	74:m
+	F	75:m
+	F	76:m
+	F	77:m
+	F	78:m
+	F	79:m
+	F	80:m
+	F	81:m
+	F	82:m
+	F	83:m
+	F	84:m
+	F	85:m
+	F	86:m
+	F	87:m
+	F	88:m
+	F	89:m
+	F	90:m
+	F	91:m
+	F	92:m
+	F	93:m
+ѡ	F	94:m
+Ѣ	F	95:m
+ѣ	F	96:m
+Ѥ	F	97:m
+ѥ	F	98:m
+Ѧ	F	99:m
+ѧ	F	100:m
+Ѩ	F	101:m
+ѩ	F	102:m
+Ѫ	F	103:m
+ѫ	F	104:m
+Ѭ	F	105:m
+ѭ	F	106:m
+Ѯ	F	107:m
+ѯ	F	108:m
+Ѱ	F	109:m
+ѱ	F	110:m
+Ѳ	F	111:m
+ѳ	F	112:m
+Ѵ	F	113:m
+ѵ	F	114:m
+Ѷ	F	115:m
+ѷ	F	116:m
+Ѹ	F	117:m
+ѹ	F	118:m
+Ѻ	F	119:m
+ѻ	F	120:m
+Ѽ	F	121:m
+ѽ	F	122:m
+Ѿ	F	123:m
+ѿ	F	124:m
+	F	125:m
+	F	126:m
+	F	127:m
+	F	128:m
+	F	129:m
+	F	130:m
+	F	131:m
+	F	132:m
+	F	133:m
+	F	134:m
+	F	135:m
+	F	136:m
+	F	137:m
+	F	138:m
+	F	139:m
+	F	140:m
+	F	141:m
+	F	142:m
+	F	143:m
+	F	144:m
+	F	145:m
+	F	146:m
+	F	147:m
+	F	148:m
+	F	149:m
+	F	150:m
+	F	151:m
+	F	152:m
+	F	153:m
+	F	154:m
+	F	155:m
+	F	156:m
+	F	157:m
+	F	158:m
+	F	159:m
+	F	160:m
+	F	161:m
+	F	162:m
+	F	163:m
+	F	164:m
+	F	165:m
+	F	166:m
+	F	167:m
+	F	168:m
+	F	169:m
+	F	170:m
+	F	171:m
+	F	172:m
+	F	173:m
+	F	174:m
+	F	175:m
+	F	176:m
+	F	177:m
+	F	178:m
+	F	179:m
+	F	180:m
+	F	181:m
+	F	182:m
+	F	183:m
+	F	184:m
+	F	185:m
+	F	186:m
+	F	187:m
+ҡ	F	188:m
+Ң	F	189:m
+ң	F	190:m
+Ҥ	F	191:m
+ҥ	F	192:m
+Ҧ	F	193:m
+ҧ	F	194:m
+Ҩ	F	195:m
+ҩ	F	196:m
+Ҫ	F	197:m
+ҫ	F	198:m
+Ҭ	F	199:m
+ҭ	F	200:m
+Ү	F	201:m
+ү	F	202:m
+Ұ	F	203:m
+ұ	F	204:m
+Ҳ	F	205:m
+ҳ	F	206:m
+Ҵ	F	207:m
+ҵ	F	208:m
+Ҷ	F	209:m
+ҷ	F	210:m
+Ҹ	F	211:m
+ҹ	F	212:m
+Һ	F	213:m
+һ	F	214:m
+Ҽ	F	215:m
+ҽ	F	216:m
+Ҿ	F	217:m
+ҿ	F	218:m
+	F	219:m
+	F	220:m
+	F	221:m
+	F	222:m
+	F	223:m
+	F	224:m
+	F	225:m
+	F	226:m
+	F	227:m
+	F	228:m
+	F	229:m
+	F	230:m
+	F	231:m
+	F	232:m
+	F	233:m
+	F	234:m
+	F	235:m
+	F	236:m
+	F	237:m
+	F	238:m
+	F	239:m
+	F	240:m
+	F	241:m
+	F	242:m
+	F	243:m
+	F	244:m
+	F	245:m
+	F	246:m
+	F	247:m
+	F	248:m
+	F	249:m
+	F	250:m
+	F	251:m
+	F	252:m
+	F	253:m
+	F	254:m
+	F	255:m
+	F	0:n
+	F	1:n
+	F	2:n
+	F	3:n
+	F	4:n
+	F	5:n
+	F	6:n
+	F	7:n
+	F	8:n
+	F	9:n
+	F	10:n
+	F	11:n
+	F	12:n
+	F	13:n
+	F	14:n
+	F	15:n
+	F	16:n
+	F	17:n
+	F	18:n
+	F	19:n
+	F	20:n
+	F	21:n
+	F	22:n
+	F	23:n
+	F	24:n
+	F	25:n
+ӡ	F	26:n
+Ӣ	F	27:n
+ӣ	F	28:n
+Ӥ	F	29:n
+ӥ	F	30:n
+Ӧ	F	31:n
+ӧ	F	32:n
+Ө	F	33:n
+ө	F	34:n
+Ӫ	F	35:n
+ӫ	F	36:n
+Ӭ	F	37:n
+ӭ	F	38:n
+Ӯ	F	39:n
+ӯ	F	40:n
+Ӱ	F	41:n
+ӱ	F	42:n
+Ӳ	F	43:n
+ӳ	F	44:n
+Ӵ	F	45:n
+ӵ	F	46:n
+Ӷ	F	47:n
+ӷ	F	48:n
+Ӹ	F	49:n
+ӹ	F	50:n
+Ӻ	F	51:n
+ӻ	F	52:n
+Ӽ	F	53:n
+ӽ	F	54:n
+Ӿ	F	55:n
+ӿ	F	56:n
+	F	57:n
+	F	58:n
+	F	59:n
+	F	60:n
+	F	61:n
+	F	62:n
+	F	63:n
+	F	64:n
+	F	65:n
+	F	66:n
+	F	67:n
+	F	68:n
+	F	69:n
+	F	70:n
+	F	71:n
+	F	72:n
+	F	73:n
+	F	74:n
+	F	75:n
+	F	76:n
+	F	77:n
+	F	78:n
+	F	79:n
+	F	80:n
+	F	81:n
+	F	82:n
+	F	83:n
+	F	84:n
+	F	85:n
+	F	86:n
+	F	87:n
+	F	88:n
+	F	89:n
+	F	90:n
+	F	91:n
+	F	92:n
+	F	93:n
+	F	94:n
+	F	95:n
+	F	96:n
+	F	97:n
+	F	98:n
+	F	99:n
+	F	100:n
+	F	101:n
+	F	102:n
+	F	103:n
+	F	104:n
+	F	105:n
+	F	106:n
+	F	107:n
+	F	108:n
+	F	109:n
+	F	110:n
+	F	111:n
+	F	112:n
+	F	113:n
+	F	114:n
+	F	115:n
+	F	116:n
+	F	117:n
+	F	118:n
+	F	119:n
+ԡ	F	120:n
+Ԣ	F	121:n
+ԣ	F	122:n
+Ԥ	F	123:n
+ԥ	F	124:n
+Ԧ	F	125:n
+ԧ	F	126:n
+Ԩ	F	127:n
+ԩ	F	128:n
+Ԫ	F	129:n
+ԫ	F	130:n
+Ԭ	F	131:n
+ԭ	F	132:n
+Ԯ	F	133:n
+ԯ	F	134:n
+԰	F	135:n
+Ա	F	136:n
+Բ	F	137:n
+Գ	F	138:n
+Դ	F	139:n
+Ե	F	140:n
+Զ	F	141:n
+Է	F	142:n
+Ը	F	143:n
+Թ	F	144:n
+Ժ	F	145:n
+Ի	F	146:n
+Լ	F	147:n
+Խ	F	148:n
+Ծ	F	149:n
+Կ	F	150:n
+	F	151:n
+	F	152:n
+	F	153:n
+	F	154:n
+	F	155:n
+	F	156:n
+	F	157:n
+	F	158:n
+	F	159:n
+	F	160:n
+	F	161:n
+	F	162:n
+	F	163:n
+	F	164:n
+	F	165:n
+	F	166:n
+	F	167:n
+	F	168:n
+	F	169:n
+	F	170:n
+	F	171:n
+	F	172:n
+	F	173:n
+	F	174:n
+	F	175:n
+	F	176:n
+	F	177:n
+	F	178:n
+	F	179:n
+	F	180:n
+	F	181:n
+	F	182:n
+	F	183:n
+	F	184:n
+	F	185:n
+	F	186:n
+	F	187:n
+	F	188:n
+	F	189:n
+	F	190:n
+	F	191:n
+	F	192:n
+	F	193:n
+	F	194:n
+	F	195:n
+	F	196:n
+	F	197:n
+	F	198:n
+	F	199:n
+	F	200:n
+	F	201:n
+	F	202:n
+	F	203:n
+	F	204:n
+	F	205:n
+	F	206:n
+	F	207:n
+	F	208:n
+	F	209:n
+	F	210:n
+	F	211:n
+	F	212:n
+	F	213:n
+ա	F	214:n
+բ	F	215:n
+գ	F	216:n
+դ	F	217:n
+ե	F	218:n
+զ	F	219:n
+է	F	220:n
+ը	F	221:n
+թ	F	222:n
+ժ	F	223:n
+ի	F	224:n
+լ	F	225:n
+խ	F	226:n
+ծ	F	227:n
+կ	F	228:n
+հ	F	229:n
+ձ	F	230:n
+ղ	F	231:n
+ճ	F	232:n
+մ	F	233:n
+յ	F	234:n
+ն	F	235:n
+շ	F	236:n
+ո	F	237:n
+չ	F	238:n
+պ	F	239:n
+ջ	F	240:n
+ռ	F	241:n
+ս	F	242:n
+վ	F	243:n
+տ	F	244:n
+	F	245:n
+	F	246:n
+	F	247:n
+	F	248:n
+	F	249:n
+	F	250:n
+	F	251:n
+	F	252:n
+	F	253:n
+	F	254:n
+	F	255:n
+	F	0:o
+	F	1:o
+	F	2:o
+	F	3:o
+	F	4:o
+	F	5:o
+	F	6:o
+	F	7:o
+	F	8:o
+	F	9:o
+	F	10:o
+	F	11:o
+	F	12:o
+	F	13:o
+	F	14:o
+	F	15:o
+	F	16:o
+	F	17:o
+	F	18:o
+	F	19:o
+	F	20:o
+	F	21:o
+	F	22:o
+	F	23:o
+	F	24:o
+	F	25:o
+	F	26:o
+	F	27:o
+	F	28:o
+	F	29:o
+	F	30:o
+	F	31:o
+	F	32:o
+	F	33:o
+	F	34:o
+	F	35:o
+	F	36:o
+	F	37:o
+	F	38:o
+	F	39:o
+	F	40:o
+	F	41:o
+	F	42:o
+	F	43:o
+	F	44:o
+	F	45:o
+	F	46:o
+	F	47:o
+	F	48:o
+	F	49:o
+	F	50:o
+	F	51:o
+֡	F	52:o
+֢	F	53:o
+֣	F	54:o
+֤	F	55:o
+֥	F	56:o
+֦	F	57:o
+֧	F	58:o
+֨	F	59:o
+֩	F	60:o
+֪	F	61:o
+֫	F	62:o
+֬	F	63:o
+֭	F	64:o
+֮	F	65:o
+֯	F	66:o
+ְ	F	67:o
+ֱ	F	68:o
+ֲ	F	69:o
+ֳ	F	70:o
+ִ	F	71:o
+ֵ	F	72:o
+ֶ	F	73:o
+ַ	F	74:o
+ָ	F	75:o
+ֹ	F	76:o
+ֺ	F	77:o
+ֻ	F	78:o
+ּ	F	79:o
+ֽ	F	80:o
+־	F	81:o
+ֿ	F	82:o
+	F	83:o
+	F	84:o
+	F	85:o
+	F	86:o
+	F	87:o
+	F	88:o
+	F	89:o
+	F	90:o
+	F	91:o
+	F	92:o
+	F	93:o
+	F	94:o
+	F	95:o
+	F	96:o
+	F	97:o
+	F	98:o
+	F	99:o
+	F	100:o
+	F	101:o
+	F	102:o
+	F	103:o
+	F	104:o
+	F	105:o
+	F	106:o
+	F	107:o
+	F	108:o
+	F	109:o
+	F	110:o
+	F	111:o
+	F	112:o
+	F	113:o
+	F	114:o
+	F	115:o
+	F	116:o
+	F	117:o
+	F	118:o
+	F	119:o
+	F	120:o
+	F	121:o
+	F	122:o
+	F	123:o
+	F	124:o
+	F	125:o
+	F	126:o
+	F	127:o
+	F	128:o
+	F	129:o
+	F	130:o
+	F	131:o
+	F	132:o
+	F	133:o
+	F	134:o
+	F	135:o
+	F	136:o
+	F	137:o
+	F	138:o
+	F	139:o
+	F	140:o
+	F	141:o
+	F	142:o
+	F	143:o
+	F	144:o
+	F	145:o
+ס	F	146:o
+ע	F	147:o
+ף	F	148:o
+פ	F	149:o
+ץ	F	150:o
+צ	F	151:o
+ק	F	152:o
+ר	F	153:o
+ש	F	154:o
+ת	F	155:o
+׫	F	156:o
+׬	F	157:o
+׭	F	158:o
+׮	F	159:o
+ׯ	F	160:o
+װ	F	161:o
+ױ	F	162:o
+ײ	F	163:o
+׳	F	164:o
+״	F	165:o
+׵	F	166:o
+׶	F	167:o
+׷	F	168:o
+׸	F	169:o
+׹	F	170:o
+׺	F	171:o
+׻	F	172:o
+׼	F	173:o
+׽	F	174:o
+׾	F	175:o
+׿	F	176:o
+	F	177:o
+	F	178:o
+	F	179:o
+	F	180:o
+	F	181:o
+	F	182:o
+	F	183:o
+	F	184:o
+	F	185:o
+	F	186:o
+	F	187:o
+	F	188:o
+	F	189:o
+	F	190:o
+	F	191:o
+	F	192:o
+	F	193:o
+	F	194:o
+	F	195:o
+	F	196:o
+	F	197:o
+	F	198:o
+	F	199:o
+	F	200:o
+	F	201:o
+	F	202:o
+	F	203:o
+	F	204:o
+	F	205:o
+	F	206:o
+	F	207:o
+	F	208:o
+	F	209:o
+	F	210:o
+	F	211:o
+	F	212:o
+	F	213:o
+	F	214:o
+	F	215:o
+	F	216:o
+	F	217:o
+	F	218:o
+	F	219:o
+	F	220:o
+	F	221:o
+	F	222:o
+	F	223:o
+	F	224:o
+	F	225:o
+	F	226:o
+	F	227:o
+	F	228:o
+	F	229:o
+	F	230:o
+	F	231:o
+	F	232:o
+	F	233:o
+	F	234:o
+	F	235:o
+	F	236:o
+	F	237:o
+	F	238:o
+	F	239:o
+ء	F	240:o
+آ	F	241:o
+أ	F	242:o
+ؤ	F	243:o
+إ	F	244:o
+ئ	F	245:o
+ا	F	246:o
+ب	F	247:o
+ة	F	248:o
+ت	F	249:o
+ث	F	250:o
+ج	F	251:o
+ح	F	252:o
+خ	F	253:o
+د	F	254:o
+ذ	F	255:o
+ر	F	0:p
+ز	F	1:p
+س	F	2:p
+ش	F	3:p
+ص	F	4:p
+ض	F	5:p
+ط	F	6:p
+ظ	F	7:p
+ع	F	8:p
+غ	F	9:p
+ػ	F	10:p
+ؼ	F	11:p
+ؽ	F	12:p
+ؾ	F	13:p
+ؿ	F	14:p
+	F	15:p
+	F	16:p
+	F	17:p
+	F	18:p
+	F	19:p
+	F	20:p
+	F	21:p
+	F	22:p
+	F	23:p
+	F	24:p
+	F	25:p
+	F	26:p
+	F	27:p
+	F	28:p
+	F	29:p
+	F	30:p
+	F	31:p
+	F	32:p
+	F	33:p
+	F	34:p
+	F	35:p
+	F	36:p
+	F	37:p
+	F	38:p
+	F	39:p
+	F	40:p
+	F	41:p
+	F	42:p
+	F	43:p
+	F	44:p
+	F	45:p
+	F	46:p
+	F	47:p
+	F	48:p
+	F	49:p
+	F	50:p
+	F	51:p
+	F	52:p
+	F	53:p
+	F	54:p
+	F	55:p
+	F	56:p
+	F	57:p
+	F	58:p
+	F	59:p
+	F	60:p
+	F	61:p
+	F	62:p
+	F	63:p
+	F	64:p
+	F	65:p
+	F	66:p
+	F	67:p
+	F	68:p
+	F	69:p
+	F	70:p
+	F	71:p
+	F	72:p
+	F	73:p
+	F	74:p
+	F	75:p
+	F	76:p
+	F	77:p
+١	F	78:p
+٢	F	79:p
+٣	F	80:p
+٤	F	81:p
+٥	F	82:p
+٦	F	83:p
+٧	F	84:p
+٨	F	85:p
+٩	F	86:p
+٪	F	87:p
+٫	F	88:p
+٬	F	89:p
+٭	F	90:p
+ٮ	F	91:p
+ٯ	F	92:p
+ٰ	F	93:p
+ٱ	F	94:p
+ٲ	F	95:p
+ٳ	F	96:p
+ٴ	F	97:p
+ٵ	F	98:p
+ٶ	F	99:p
+ٷ	F	100:p
+ٸ	F	101:p
+ٹ	F	102:p
+ٺ	F	103:p
+ٻ	F	104:p
+ټ	F	105:p
+ٽ	F	106:p
+پ	F	107:p
+ٿ	F	108:p
+	F	109:p
+	F	110:p
+	F	111:p
+	F	112:p
+	F	113:p
+	F	114:p
+	F	115:p
+	F	116:p
+	F	117:p
+	F	118:p
+	F	119:p
+	F	120:p
+	F	121:p
+	F	122:p
+	F	123:p
+	F	124:p
+	F	125:p
+	F	126:p
+	F	127:p
+	F	128:p
+	F	129:p
+	F	130:p
+	F	131:p
+	F	132:p
+	F	133:p
+	F	134:p
+	F	135:p
+	F	136:p
+	F	137:p
+	F	138:p
+	F	139:p
+	F	140:p
+	F	141:p
+	F	142:p
+	F	143:p
+	F	144:p
+	F	145:p
+	F	146:p
+	F	147:p
+	F	148:p
+	F	149:p
+	F	150:p
+	F	151:p
+	F	152:p
+	F	153:p
+	F	154:p
+	F	155:p
+	F	156:p
+	F	157:p
+	F	158:p
+	F	159:p
+	F	160:p
+	F	161:p
+	F	162:p
+	F	163:p
+	F	164:p
+	F	165:p
+	F	166:p
+	F	167:p
+	F	168:p
+	F	169:p
+	F	170:p
+	F	171:p
+ڡ	F	172:p
+ڢ	F	173:p
+ڣ	F	174:p
+ڤ	F	175:p
+ڥ	F	176:p
+ڦ	F	177:p
+ڧ	F	178:p
+ڨ	F	179:p
+ک	F	180:p
+ڪ	F	181:p
+ګ	F	182:p
+ڬ	F	183:p
+ڭ	F	184:p
+ڮ	F	185:p
+گ	F	186:p
+ڰ	F	187:p
+ڱ	F	188:p
+ڲ	F	189:p
+ڳ	F	190:p
+ڴ	F	191:p
+ڵ	F	192:p
+ڶ	F	193:p
+ڷ	F	194:p
+ڸ	F	195:p
+ڹ	F	196:p
+ں	F	197:p
+ڻ	F	198:p
+ڼ	F	199:p
+ڽ	F	200:p
+ھ	F	201:p
+ڿ	F	202:p
+	F	203:p
+	F	204:p
+	F	205:p
+	F	206:p
+	F	207:p
+	F	208:p
+	F	209:p
+	F	210:p
+	F	211:p
+	F	212:p
+	F	213:p
+	F	214:p
+	F	215:p
+	F	216:p
+	F	217:p
+	F	218:p
+	F	219:p
+	F	220:p
+	F	221:p
+	F	222:p
+	F	223:p
+	F	224:p
+	F	225:p
+	F	226:p
+	F	227:p
+	F	228:p
+	F	229:p
+	F	230:p
+	F	231:p
+	F	232:p
+	F	233:p
+	F	234:p
+	F	235:p
+	F	236:p
+	F	237:p
+	F	238:p
+	F	239:p
+	F	240:p
+	F	241:p
+	F	242:p
+	F	243:p
+	F	244:p
+	F	245:p
+	F	246:p
+	F	247:p
+	F	248:p
+	F	249:p
+	F	250:p
+	F	251:p
+	F	252:p
+	F	253:p
+	F	254:p
+	F	255:p
+	F	0:q
+	F	1:q
+	F	2:q
+	F	3:q
+	F	4:q
+	F	5:q
+	F	6:q
+	F	7:q
+	F	8:q
+	F	9:q
+ۡ	F	10:q
+ۢ	F	11:q
+ۣ	F	12:q
+ۤ	F	13:q
+ۥ	F	14:q
+ۦ	F	15:q
+ۧ	F	16:q
+ۨ	F	17:q
+۩	F	18:q
+۪	F	19:q
+۫	F	20:q
+۬	F	21:q
+ۭ	F	22:q
+ۮ	F	23:q
+ۯ	F	24:q
+۰	F	25:q
+۱	F	26:q
+۲	F	27:q
+۳	F	28:q
+۴	F	29:q
+۵	F	30:q
+۶	F	31:q
+۷	F	32:q
+۸	F	33:q
+۹	F	34:q
+ۺ	F	35:q
+ۻ	F	36:q
+ۼ	F	37:q
+۽	F	38:q
+۾	F	39:q
+ۿ	F	40:q
+	F	41:q
+	F	42:q
+	F	43:q
+	F	44:q
+	F	45:q
+	F	46:q
+	F	47:q
+	F	48:q
+	F	49:q
+	F	50:q
+	F	51:q
+	F	52:q
+	F	53:q
+	F	54:q
+	F	55:q
+	F	56:q
+	F	57:q
+	F	58:q
+	F	59:q
+	F	60:q
+	F	61:q
+	F	62:q
+	F	63:q
+	F	64:q
+	F	65:q
+	F	66:q
+	F	67:q
+	F	68:q
+	F	69:q
+	F	70:q
+	F	71:q
+	F	72:q
+	F	73:q
+	F	74:q
+	F	75:q
+	F	76:q
+	F	77:q
+	F	78:q
+	F	79:q
+	F	80:q
+	F	81:q
+	F	82:q
+	F	83:q
+	F	84:q
+	F	85:q
+	F	86:q
+	F	87:q
+	F	88:q
+	F	89:q
+	F	90:q
+	F	91:q
+	F	92:q
+	F	93:q
+	F	94:q
+	F	95:q
+	F	96:q
+	F	97:q
+	F	98:q
+	F	99:q
+	F	100:q
+	F	101:q
+	F	102:q
+	F	103:q
+ܡ	F	104:q
+ܢ	F	105:q
+ܣ	F	106:q
+ܤ	F	107:q
+ܥ	F	108:q
+ܦ	F	109:q
+ܧ	F	110:q
+ܨ	F	111:q
+ܩ	F	112:q
+ܪ	F	113:q
+ܫ	F	114:q
+ܬ	F	115:q
+ܭ	F	116:q
+ܮ	F	117:q
+ܯ	F	118:q
+ܰ	F	119:q
+ܱ	F	120:q
+ܲ	F	121:q
+ܳ	F	122:q
+ܴ	F	123:q
+ܵ	F	124:q
+ܶ	F	125:q
+ܷ	F	126:q
+ܸ	F	127:q
+ܹ	F	128:q
+ܺ	F	129:q
+ܻ	F	130:q
+ܼ	F	131:q
+ܽ	F	132:q
+ܾ	F	133:q
+ܿ	F	134:q
+	F	135:q
+	F	136:q
+	F	137:q
+	F	138:q
+	F	139:q
+	F	140:q
+	F	141:q
+	F	142:q
+	F	143:q
+	F	144:q
+	F	145:q
+	F	146:q
+	F	147:q
+	F	148:q
+	F	149:q
+	F	150:q
+	F	151:q
+	F	152:q
+	F	153:q
+	F	154:q
+	F	155:q
+	F	156:q
+	F	157:q
+	F	158:q
+	F	159:q
+	F	160:q
+	F	161:q
+	F	162:q
+	F	163:q
+	F	164:q
+	F	165:q
+	F	166:q
+	F	167:q
+	F	168:q
+	F	169:q
+	F	170:q
+	F	171:q
+	F	172:q
+	F	173:q
+	F	174:q
+	F	175:q
+	F	176:q
+	F	177:q
+	F	178:q
+	F	179:q
+	F	180:q
+	F	181:q
+	F	182:q
+	F	183:q
+	F	184:q
+	F	185:q
+	F	186:q
+	F	187:q
+	F	188:q
+	F	189:q
+	F	190:q
+	F	191:q
+	F	192:q
+	F	193:q
+	F	194:q
+	F	195:q
+	F	196:q
+	F	197:q
+ݡ	F	198:q
+ݢ	F	199:q
+ݣ	F	200:q
+ݤ	F	201:q
+ݥ	F	202:q
+ݦ	F	203:q
+ݧ	F	204:q
+ݨ	F	205:q
+ݩ	F	206:q
+ݪ	F	207:q
+ݫ	F	208:q
+ݬ	F	209:q
+ݭ	F	210:q
+ݮ	F	211:q
+ݯ	F	212:q
+ݰ	F	213:q
+ݱ	F	214:q
+ݲ	F	215:q
+ݳ	F	216:q
+ݴ	F	217:q
+ݵ	F	218:q
+ݶ	F	219:q
+ݷ	F	220:q
+ݸ	F	221:q
+ݹ	F	222:q
+ݺ	F	223:q
+ݻ	F	224:q
+ݼ	F	225:q
+ݽ	F	226:q
+ݾ	F	227:q
+ݿ	F	228:q
+	F	229:q
+	F	230:q
+	F	231:q
+	F	232:q
+	F	233:q
+	F	234:q
+	F	235:q
+	F	236:q
+	F	237:q
+	F	238:q
+	F	239:q
+	F	240:q
+	F	241:q
+	F	242:q
+	F	243:q
+	F	244:q
+	F	245:q
+	F	246:q
+	F	247:q
+	F	248:q
+	F	249:q
+	F	250:q
+	F	251:q
+	F	252:q
+	F	253:q
+	F	254:q
+	F	255:q
+	F	0:r
+	F	1:r
+	F	2:r
+	F	3:r
+	F	4:r
+	F	5:r
+	F	6:r
+	F	7:r
+	F	8:r
+	F	9:r
+	F	10:r
+	F	11:r
+	F	12:r
+	F	13:r
+	F	14:r
+	F	15:r
+	F	16:r
+	F	17:r
+	F	18:r
+	F	19:r
+	F	20:r
+	F	21:r
+	F	22:r
+	F	23:r
+	F	24:r
+	F	25:r
+	F	26:r
+	F	27:r
+	F	28:r
+	F	29:r
+	F	30:r
+	F	31:r
+	F	32:r
+	F	33:r
+	F	34:r
+	F	35:r
+ޡ	F	36:r
+ޢ	F	37:r
+ޣ	F	38:r
+ޤ	F	39:r
+ޥ	F	40:r
+ަ	F	41:r
+ާ	F	42:r
+ި	F	43:r
+ީ	F	44:r
+ު	F	45:r
+ޫ	F	46:r
+ެ	F	47:r
+ޭ	F	48:r
+ޮ	F	49:r
+ޯ	F	50:r
+ް	F	51:r
+ޱ	F	52:r
+޲	F	53:r
+޳	F	54:r
+޴	F	55:r
+޵	F	56:r
+޶	F	57:r
+޷	F	58:r
+޸	F	59:r
+޹	F	60:r
+޺	F	61:r
+޻	F	62:r
+޼	F	63:r
+޽	F	64:r
+޾	F	65:r
+޿	F	66:r
+	F	67:r
+	F	68:r
+	F	69:r
+	F	70:r
+	F	71:r
+	F	72:r
+	F	73:r
+	F	74:r
+	F	75:r
+	F	76:r
+	F	77:r
+	F	78:r
+	F	79:r
+	F	80:r
+	F	81:r
+	F	82:r
+	F	83:r
+	F	84:r
+	F	85:r
+	F	86:r
+	F	87:r
+	F	88:r
+	F	89:r
+	F	90:r
+	F	91:r
+	F	92:r
+	F	93:r
+	F	94:r
+	F	95:r
+	F	96:r
+	F	97:r
+	F	98:r
+	F	99:r
+	F	100:r
+	F	101:r
+	F	102:r
+	F	103:r
+	F	104:r
+	F	105:r
+	F	106:r
+	F	107:r
+	F	108:r
+	F	109:r
+	F	110:r
+	F	111:r
+	F	112:r
+	F	113:r
+	F	114:r
+	F	115:r
+	F	116:r
+	F	117:r
+	F	118:r
+	F	119:r
+	F	120:r
+	F	121:r
+	F	122:r
+	F	123:r
+	F	124:r
+	F	125:r
+	F	126:r
+	F	127:r
+	F	128:r
+	F	129:r
+ߡ	F	130:r
+ߢ	F	131:r
+ߣ	F	132:r
+ߤ	F	133:r
+ߥ	F	134:r
+ߦ	F	135:r
+ߧ	F	136:r
+ߨ	F	137:r
+ߩ	F	138:r
+ߪ	F	139:r
+߫	F	140:r
+߬	F	141:r
+߭	F	142:r
+߮	F	143:r
+߯	F	144:r
+߰	F	145:r
+߱	F	146:r
+߲	F	147:r
+߳	F	148:r
+ߴ	F	149:r
+ߵ	F	150:r
+߶	F	151:r
+߷	F	152:r
+߸	F	153:r
+߹	F	154:r
+ߺ	F	155:r
+߻	F	156:r
+߼	F	157:r
+߽	F	158:r
+߾	F	159:r
+߿	F	160:r
+	F	161:r
+	F	162:r
+	F	163:r
+	F	164:r
+	F	165:r
+	F	166:r
+	F	167:r
+	F	168:r
+	F	169:r
+	F	170:r
+	F	171:r
+	F	172:r
+	F	173:r
+	F	174:r
+	F	175:r
+	F	176:r
+	F	177:r
+	F	178:r
+	F	179:r
+	F	180:r
+	F	181:r
+	F	182:r
+	F	183:r
+	F	184:r
+	F	185:r
+	F	186:r
+	F	187:r
+	F	188:r
+	F	189:r
+	F	190:r
+	F	191:r
+	F	192:r
+	F	193:r
+	F	194:r
+	F	195:r
+	F	196:r
+	F	197:r
+	F	198:r
+	F	199:r
+	F	200:r
+	F	201:r
+	F	202:r
+	F	203:r
+	F	204:r
+	F	205:r
+	F	206:r
+	F	207:r
+	F	208:r
+	F	209:r
+	F	210:r
+	F	211:r
+	F	212:r
+	F	213:r
+	F	214:r
+	F	215:r
+	F	216:r
+	F	217:r
+	F	218:r
+	F	219:r
+	F	220:r
+	F	221:r
+	F	222:r
+	F	223:r
+	F	224:r
+	F	225:r
+	F	226:r
+	F	227:r
+	F	228:r
+	F	229:r
+	F	230:r
+	F	231:r
+	F	232:r
+	F	233:r
+	F	234:r
+	F	235:r
+	F	236:r
+	F	237:r
+	F	238:r
+	F	239:r
+	F	240:r
+	F	241:r
+	F	242:r
+	F	243:r
+	F	244:r
+	F	245:r
+	F	246:r
+	F	247:r
+	F	248:r
+	F	249:r
+	F	250:r
+	F	251:r
+	F	252:r
+	F	253:r
+	F	254:r
+	F	255:r
+	F	0:s
+	F	1:s
+	F	2:s
+	F	3:s
+	F	4:s
+	F	5:s
+	F	6:s
+	F	7:s
+	F	8:s
+	F	9:s
+	F	10:s
+	F	11:s
+	F	12:s
+	F	13:s
+	F	14:s
+	F	15:s
+	F	16:s
+	F	17:s
+	F	18:s
+	F	19:s
+	F	20:s
+	F	21:s
+	F	22:s
+	F	23:s
+	F	24:s
+	F	25:s
+	F	26:s
+	F	27:s
+	F	28:s
+	F	29:s
+	F	30:s
+	F	31:s
+	F	32:s
+	F	33:s
+	F	34:s
+	F	35:s
+	F	36:s
+	F	37:s
+	F	38:s
+	F	39:s
+	F	40:s
+	F	41:s
+	F	42:s
+	F	43:s
+	F	44:s
+	F	45:s
+	F	46:s
+	F	47:s
+	F	48:s
+	F	49:s
+	F	50:s
+	F	51:s
+	F	52:s
+	F	53:s
+	F	54:s
+	F	55:s
+	F	56:s
+	F	57:s
+	F	58:s
+	F	59:s
+	F	60:s
+	F	61:s
+	F	62:s
+	F	63:s
+	F	64:s
+	F	65:s
+	F	66:s
+	F	67:s
+	F	68:s
+	F	69:s
+	F	70:s
+	F	71:s
+	F	72:s
+	F	73:s
+	F	74:s
+	F	75:s
+	F	76:s
+	F	77:s
+	F	78:s
+	F	79:s
+	F	80:s
+	F	81:s
+	F	82:s
+	F	83:s
+	F	84:s
+	F	85:s
+	F	86:s
+	F	87:s
+	F	88:s
+	F	89:s
+	F	90:s
+	F	91:s
+	F	92:s
+	F	93:s
+	F	94:s
+	F	95:s
+	F	96:s
+	F	97:s
+	F	98:s
+	F	99:s
+	F	100:s
+	F	101:s
+	F	102:s
+	F	103:s
+	F	104:s
+	F	105:s
+	F	106:s
+	F	107:s
+	F	108:s
+	F	109:s
+	F	110:s
+	F	111:s
+	F	112:s
+	F	113:s
+	F	114:s
+	F	115:s
+	F	116:s
+	F	117:s
+	F	118:s
+	F	119:s
+	F	120:s
+	F	121:s
+	F	122:s
+	F	123:s
+	F	124:s
+	F	125:s
+	F	126:s
+	F	127:s
+	F	128:s
+	F	129:s
+	F	130:s
+	F	131:s
+	F	132:s
+	F	133:s
+	F	134:s
+	F	135:s
+	F	136:s
+	F	137:s
+	F	138:s
+	F	139:s
+	F	140:s
+	F	141:s
+	F	142:s
+	F	143:s
+	F	144:s
+	F	145:s
+	F	146:s
+	F	147:s
+	F	148:s
+	F	149:s
+	F	150:s
+	F	151:s
+	F	152:s
+	F	153:s
+	F	154:s
+	F	155:s
+	F	156:s
+	F	157:s
+	F	158:s
+	F	159:s
+	F	160:s
+	F	161:s
+	F	162:s
+	F	163:s
+	F	164:s
+	F	165:s
+	F	166:s
+	F	167:s
+	F	168:s
+	F	169:s
+	F	170:s
+	F	171:s
+	F	172:s
+	F	173:s
+	F	174:s
+	F	175:s
+	F	176:s
+	F	177:s
+	F	178:s
+	F	179:s
+	F	180:s
+	F	181:s
+	F	182:s
+	F	183:s
+	F	184:s
+	F	185:s
+	F	186:s
+	F	187:s
+	F	188:s
+	F	189:s
+	F	190:s
+	F	191:s
+	F	192:s
+	F	193:s
+	F	194:s
+	F	195:s
+	F	196:s
+	F	197:s
+	F	198:s
+	F	199:s
+	F	200:s
+	F	201:s
+	F	202:s
+	F	203:s
+	F	204:s
+	F	205:s
+	F	206:s
+	F	207:s
+	F	208:s
+	F	209:s
+	F	210:s
+	F	211:s
+	F	212:s
+	F	213:s
+	F	214:s
+	F	215:s
+	F	216:s
+	F	217:s
+	F	218:s
+	F	219:s
+	F	220:s
+	F	221:s
+	F	222:s
+	F	223:s
+	F	224:s
+	F	225:s
+	F	226:s
+	F	227:s
+	F	228:s
+	F	229:s
+	F	230:s
+	F	231:s
+	F	232:s
+	F	233:s
+	F	234:s
+	F	235:s
+	F	236:s
+	F	237:s
+	F	238:s
+	F	239:s
+	F	240:s
+	F	241:s
+	F	242:s
+	F	243:s
+	F	244:s
+	F	245:s
+	F	246:s
+	F	247:s
+	F	248:s
+	F	249:s
+	F	250:s
+	F	251:s
+	F	252:s
+	F	253:s
+	F	254:s
+	F	255:s
+	F	0:t
+	F	1:t
+	F	2:t
+	F	3:t
+	F	4:t
+	F	5:t
+	F	6:t
+	F	7:t
+	F	8:t
+	F	9:t
+	F	10:t
+	F	11:t
+	F	12:t
+	F	13:t
+	F	14:t
+	F	15:t
+	F	16:t
+	F	17:t
+	F	18:t
+	F	19:t
+	F	20:t
+	F	21:t
+	F	22:t
+	F	23:t
+	F	24:t
+	F	25:t
+	F	26:t
+	F	27:t
+	F	28:t
+	F	29:t
+	F	30:t
+	F	31:t
+	F	32:t
+	F	33:t
+	F	34:t
+	F	35:t
+	F	36:t
+	F	37:t
+	F	38:t
+	F	39:t
+	F	40:t
+	F	41:t
+	F	42:t
+	F	43:t
+	F	44:t
+	F	45:t
+	F	46:t
+	F	47:t
+	F	48:t
+	F	49:t
+	F	50:t
+	F	51:t
+	F	52:t
+	F	53:t
+	F	54:t
+	F	55:t
+	F	56:t
+	F	57:t
+	F	58:t
+	F	59:t
+	F	60:t
+	F	61:t
+	F	62:t
+	F	63:t
+	F	64:t
+	F	65:t
+	F	66:t
+	F	67:t
+	F	68:t
+	F	69:t
+	F	70:t
+	F	71:t
+	F	72:t
+	F	73:t
+	F	74:t
+	F	75:t
+	F	76:t
+	F	77:t
+	F	78:t
+	F	79:t
+	F	80:t
+	F	81:t
+	F	82:t
+	F	83:t
+	F	84:t
+	F	85:t
+	F	86:t
+	F	87:t
+	F	88:t
+	F	89:t
+	F	90:t
+	F	91:t
+	F	92:t
+	F	93:t
+	F	94:t
+	F	95:t
+	F	96:t
+	F	97:t
+	F	98:t
+	F	99:t
+	F	100:t
+	F	101:t
+	F	102:t
+	F	103:t
+	F	104:t
+	F	105:t
+	F	106:t
+	F	107:t
+	F	108:t
+	F	109:t
+	F	110:t
+	F	111:t
+	F	112:t
+	F	113:t
+	F	114:t
+	F	115:t
+	F	116:t
+	F	117:t
+	F	118:t
+	F	119:t
+	F	120:t
+	F	121:t
+	F	122:t
+	F	123:t
+	F	124:t
+	F	125:t
+	F	126:t
+	F	127:t
+	F	128:t
+	F	129:t
+	F	130:t
+	F	131:t
+	F	132:t
+	F	133:t
+	F	134:t
+	F	135:t
+	F	136:t
+	F	137:t
+	F	138:t
+	F	139:t
+	F	140:t
+	F	141:t
+	F	142:t
+	F	143:t
+	F	144:t
+	F	145:t
+	F	146:t
+	F	147:t
+	F	148:t
+	F	149:t
+	F	150:t
+	F	151:t
+	F	152:t
+	F	153:t
+	F	154:t
+	F	155:t
+	F	156:t
+	F	157:t
+	F	158:t
+	F	159:t
+	F	160:t
+	F	161:t
+	F	162:t
+	F	163:t
+	F	164:t
+	F	165:t
+	F	166:t
+	F	167:t
+	F	168:t
+	F	169:t
+	F	170:t
+	F	171:t
+	F	172:t
+	F	173:t
+	F	174:t
+	F	175:t
+	F	176:t
+	F	177:t
+	F	178:t
+	F	179:t
+	F	180:t
+	F	181:t
+	F	182:t
+	F	183:t
+	F	184:t
+	F	185:t
+	F	186:t
+	F	187:t
+	F	188:t
+	F	189:t
+	F	190:t
+	F	191:t
+	F	192:t
+	F	193:t
+	F	194:t
+	F	195:t
+	F	196:t
+	F	197:t
+	F	198:t
+	F	199:t
+	F	200:t
+	F	201:t
+	F	202:t
+	F	203:t
+	F	204:t
+	F	205:t
+	F	206:t
+	F	207:t
+	F	208:t
+	F	209:t
+	F	210:t
+	F	211:t
+	F	212:t
+	F	213:t
+	F	214:t
+	F	215:t
+	F	216:t
+	F	217:t
+	F	218:t
+	F	219:t
+	F	220:t
+	F	221:t
+	F	222:t
+	F	223:t
+	F	224:t
+	F	225:t
+	F	226:t
+	F	227:t
+	F	228:t
+	F	229:t
+	F	230:t
+	F	231:t
+	F	232:t
+	F	233:t
+	F	234:t
+	F	235:t
+	F	236:t
+	F	237:t
+	F	238:t
+	F	239:t
+	F	240:t
+	F	241:t
+	F	242:t
+	F	243:t
+	F	244:t
+	F	245:t
+	F	246:t
+	F	247:t
+	F	248:t
+	F	249:t
+	F	250:t
+	F	251:t
+	F	252:t
+	F	253:t
+	F	254:t
+	F	255:t
+	F	0:u
+	F	1:u
+	F	2:u
+	F	3:u
+	F	4:u
+	F	5:u
+	F	6:u
+	F	7:u
+	F	8:u
+	F	9:u
+	F	10:u
+	F	11:u
+	F	12:u
+	F	13:u
+	F	14:u
+	F	15:u
+	F	16:u
+	F	17:u
+	F	18:u
+	F	19:u
+	F	20:u
+	F	21:u
+	F	22:u
+	F	23:u
+	F	24:u
+	F	25:u
+	F	26:u
+	F	27:u
+	F	28:u
+	F	29:u
+	F	30:u
+	F	31:u
+	F	32:u
+	F	33:u
+	F	34:u
+	F	35:u
+	F	36:u
+	F	37:u
+	F	38:u
+	F	39:u
+	F	40:u
+	F	41:u
+	F	42:u
+	F	43:u
+	F	44:u
+	F	45:u
+	F	46:u
+	F	47:u
+	F	48:u
+	F	49:u
+	F	50:u
+	F	51:u
+	F	52:u
+	F	53:u
+	F	54:u
+	F	55:u
+	F	56:u
+	F	57:u
+	F	58:u
+	F	59:u
+	F	60:u
+	F	61:u
+	F	62:u
+	F	63:u
+	F	64:u
+	F	65:u
+	F	66:u
+	F	67:u
+	F	68:u
+	F	69:u
+	F	70:u
+	F	71:u
+	F	72:u
+	F	73:u
+	F	74:u
+	F	75:u
+	F	76:u
+	F	77:u
+	F	78:u
+	F	79:u
+	F	80:u
+	F	81:u
+	F	82:u
+	F	83:u
+	F	84:u
+	F	85:u
+	F	86:u
+	F	87:u
+	F	88:u
+	F	89:u
+	F	90:u
+	F	91:u
+	F	92:u
+	F	93:u
+	F	94:u
+	F	95:u
+	F	96:u
+	F	97:u
+	F	98:u
+	F	99:u
+	F	100:u
+	F	101:u
+	F	102:u
+	F	103:u
+	F	104:u
+	F	105:u
+	F	106:u
+	F	107:u
+	F	108:u
+	F	109:u
+	F	110:u
+	F	111:u
+	F	112:u
+	F	113:u
+	F	114:u
+	F	115:u
+	F	116:u
+	F	117:u
+	F	118:u
+	F	119:u
+	F	120:u
+	F	121:u
+	F	122:u
+	F	123:u
+	F	124:u
+	F	125:u
+	F	126:u
+	F	127:u
+	F	128:u
+	F	129:u
+	F	130:u
+	F	131:u
+	F	132:u
+	F	133:u
+	F	134:u
+	F	135:u
+	F	136:u
+	F	137:u
+	F	138:u
+	F	139:u
+	F	140:u
+	F	141:u
+	F	142:u
+	F	143:u
+	F	144:u
+	F	145:u
+	F	146:u
+	F	147:u
+	F	148:u
+	F	149:u
+	F	150:u
+	F	151:u
+	F	152:u
+	F	153:u
+	F	154:u
+	F	155:u
+	F	156:u
+	F	157:u
+	F	158:u
+	F	159:u
+	F	160:u
+	F	161:u
+	F	162:u
+	F	163:u
+	F	164:u
+	F	165:u
+	F	166:u
+	F	167:u
+	F	168:u
+	F	169:u
+	F	170:u
+	F	171:u
+	F	172:u
+	F	173:u
+	F	174:u
+	F	175:u
+	F	176:u
+	F	177:u
+	F	178:u
+	F	179:u
+	F	180:u
+	F	181:u
+	F	182:u
+	F	183:u
+	F	184:u
+	F	185:u
+	F	186:u
+	F	187:u
+	F	188:u
+	F	189:u
+	F	190:u
+	F	191:u
+	F	192:u
+	F	193:u
+	F	194:u
+	F	195:u
+	F	196:u
+	F	197:u
+	F	198:u
+	F	199:u
+	F	200:u
+	F	201:u
+	F	202:u
+	F	203:u
+	F	204:u
+	F	205:u
+	F	206:u
+	F	207:u
+	F	208:u
+	F	209:u
+	F	210:u
+	F	211:u
+	F	212:u
+	F	213:u
+	F	214:u
+	F	215:u
+	F	216:u
+	F	217:u
+	F	218:u
+	F	219:u
+	F	220:u
+	F	221:u
+	F	222:u
+	F	223:u
+	F	224:u
+	F	225:u
+	F	226:u
+	F	227:u
+	F	228:u
+	F	229:u
+	F	230:u
+	F	231:u
+	F	232:u
+	F	233:u
+	F	234:u
+	F	235:u
+	F	236:u
+	F	237:u
+	F	238:u
+	F	239:u
+	F	240:u
+	F	241:u
+	F	242:u
+	F	243:u
+	F	244:u
+	F	245:u
+	F	246:u
+	F	247:u
+	F	248:u
+	F	249:u
+	F	250:u
+	F	251:u
+	F	252:u
+	F	253:u
+	F	254:u
+	F	255:u
+	F	0:v
+	F	1:v
+	F	2:v
+	F	3:v
+	F	4:v
+	F	5:v
+	F	6:v
+	F	7:v
+	F	8:v
+	F	9:v
+	F	10:v
+	F	11:v
+	F	12:v
+	F	13:v
+	F	14:v
+	F	15:v
+	F	16:v
+	F	17:v
+	F	18:v
+	F	19:v
+	F	20:v
+	F	21:v
+	F	22:v
+	F	23:v
+	F	24:v
+	F	25:v
+	F	26:v
+	F	27:v
+	F	28:v
+	F	29:v
+	F	30:v
+	F	31:v
+	F	32:v
+	F	33:v
+	F	34:v
+	F	35:v
+	F	36:v
+	F	37:v
+	F	38:v
+	F	39:v
+	F	40:v
+	F	41:v
+	F	42:v
+	F	43:v
+	F	44:v
+	F	45:v
+	F	46:v
+	F	47:v
+	F	48:v
+	F	49:v
+	F	50:v
+	F	51:v
+	F	52:v
+	F	53:v
+	F	54:v
+	F	55:v
+	F	56:v
+	F	57:v
+	F	58:v
+	F	59:v
+	F	60:v
+	F	61:v
+	F	62:v
+	F	63:v
+	F	64:v
+	F	65:v
+	F	66:v
+	F	67:v
+	F	68:v
+	F	69:v
+	F	70:v
+	F	71:v
+	F	72:v
+	F	73:v
+	F	74:v
+	F	75:v
+	F	76:v
+	F	77:v
+	F	78:v
+	F	79:v
+	F	80:v
+	F	81:v
+	F	82:v
+	F	83:v
+	F	84:v
+	F	85:v
+	F	86:v
+	F	87:v
+	F	88:v
+	F	89:v
+	F	90:v
+	F	91:v
+	F	92:v
+	F	93:v
+	F	94:v
+	F	95:v
+	F	96:v
+	F	97:v
+	F	98:v
+	F	99:v
+	F	100:v
+	F	101:v
+	F	102:v
+	F	103:v
+	F	104:v
+	F	105:v
+	F	106:v
+	F	107:v
+	F	108:v
+	F	109:v
+	F	110:v
+	F	111:v
+	F	112:v
+	F	113:v
+	F	114:v
+	F	115:v
+	F	116:v
+	F	117:v
+	F	118:v
+	F	119:v
+	F	120:v
+	F	121:v
+	F	122:v
+	F	123:v
+	F	124:v
+	F	125:v
+	F	126:v
+	F	127:v
+	F	128:v
+	F	129:v
+	F	130:v
+	F	131:v
+	F	132:v
+	F	133:v
+	F	134:v
+	F	135:v
+	F	136:v
+	F	137:v
+	F	138:v
+	F	139:v
+	F	140:v
+	F	141:v
+	F	142:v
+	F	143:v
+	F	144:v
+	F	145:v
+	F	146:v
+	F	147:v
+	F	148:v
+	F	149:v
+	F	150:v
+	F	151:v
+	F	152:v
+	F	153:v
+	F	154:v
+	F	155:v
+	F	156:v
+	F	157:v
+	F	158:v
+	F	159:v
+	F	160:v
+	F	161:v
+	F	162:v
+	F	163:v
+	F	164:v
+	F	165:v
+	F	166:v
+	F	167:v
+	F	168:v
+	F	169:v
+	F	170:v
+	F	171:v
+	F	172:v
+	F	173:v
+	F	174:v
+	F	175:v
+	F	176:v
+	F	177:v
+	F	178:v
+	F	179:v
+	F	180:v
+	F	181:v
+	F	182:v
+	F	183:v
+	F	184:v
+	F	185:v
+	F	186:v
+	F	187:v
+	F	188:v
+	F	189:v
+	F	190:v
+	F	191:v
+	F	192:v
+	F	193:v
+	F	194:v
+	F	195:v
+	F	196:v
+	F	197:v
+	F	198:v
+	F	199:v
+	F	200:v
+	F	201:v
+	F	202:v
+	F	203:v
+	F	204:v
+	F	205:v
+	F	206:v
+	F	207:v
+	F	208:v
+	F	209:v
+	F	210:v
+	F	211:v
+	F	212:v
+	F	213:v
+	F	214:v
+	F	215:v
+	F	216:v
+	F	217:v
+	F	218:v
+	F	219:v
+	F	220:v
+	F	221:v
+	F	222:v
+	F	223:v
+	F	224:v
+	F	225:v
+	F	226:v
+	F	227:v
+	F	228:v
+	F	229:v
+	F	230:v
+	F	231:v
+	F	232:v
+	F	233:v
+	F	234:v
+	F	235:v
+	F	236:v
+	F	237:v
+	F	238:v
+	F	239:v
+	F	240:v
+	F	241:v
+	F	242:v
+	F	243:v
+	F	244:v
+	F	245:v
+	F	246:v
+	F	247:v
+	F	248:v
+	F	249:v
+	F	250:v
+	F	251:v
+	F	252:v
+	F	253:v
+	F	254:v
+	F	255:v
+	F	0:w
+	F	1:w
+	F	2:w
+	F	3:w
+	F	4:w
+	F	5:w
+	F	6:w
+	F	7:w
+	F	8:w
+	F	9:w
+	F	10:w
+	F	11:w
+	F	12:w
+	F	13:w
+	F	14:w
+	F	15:w
+	F	16:w
+	F	17:w
+	F	18:w
+	F	19:w
+	F	20:w
+	F	21:w
+	F	22:w
+	F	23:w
+	F	24:w
+	F	25:w
+	F	26:w
+	F	27:w
+	F	28:w
+	F	29:w
+	F	30:w
+	F	31:w
+	F	32:w
+	F	33:w
+	F	34:w
+	F	35:w
+	F	36:w
+	F	37:w
+	F	38:w
+	F	39:w
+	F	40:w
+	F	41:w
+	F	42:w
+	F	43:w
+	F	44:w
+	F	45:w
+	F	46:w
+	F	47:w
+	F	48:w
+	F	49:w
+	F	50:w
+	F	51:w
+	F	52:w
+	F	53:w
+	F	54:w
+	F	55:w
+	F	56:w
+	F	57:w
+	F	58:w
+	F	59:w
+	F	60:w
+	F	61:w
+	F	62:w
+	F	63:w
+	F	64:w
+	F	65:w
+	F	66:w
+	F	67:w
+	F	68:w
+	F	69:w
+	F	70:w
+	F	71:w
+	F	72:w
+	F	73:w
+	F	74:w
+	F	75:w
+	F	76:w
+	F	77:w
+	F	78:w
+	F	79:w
+	F	80:w
+	F	81:w
+	F	82:w
+	F	83:w
+	F	84:w
+	F	85:w
+	F	86:w
+	F	87:w
+	F	88:w
+	F	89:w
+	F	90:w
+	F	91:w
+	F	92:w
+	F	93:w
+	F	94:w
+	F	95:w
+	F	96:w
+	F	97:w
+	F	98:w
+	F	99:w
+	F	100:w
+	F	101:w
+	F	102:w
+	F	103:w
+	F	104:w
+	F	105:w
+	F	106:w
+	F	107:w
+	F	108:w
+	F	109:w
+	F	110:w
+	F	111:w
+	F	112:w
+	F	113:w
+	F	114:w
+	F	115:w
+	F	116:w
+	F	117:w
+	F	118:w
+	F	119:w
+	F	120:w
+	F	121:w
+	F	122:w
+	F	123:w
+	F	124:w
+	F	125:w
+	F	126:w
+	F	127:w
+	F	128:w
+	F	129:w
+	F	130:w
+	F	131:w
+	F	132:w
+	F	133:w
+	F	134:w
+	F	135:w
+	F	136:w
+	F	137:w
+	F	138:w
+	F	139:w
+	F	140:w
+	F	141:w
+	F	142:w
+	F	143:w
+	F	144:w
+	F	145:w
+	F	146:w
+	F	147:w
+	F	148:w
+	F	149:w
+	F	150:w
+	F	151:w
+	F	152:w
+	F	153:w
+	F	154:w
+	F	155:w
+	F	156:w
+	F	157:w
+	F	158:w
+	F	159:w
+	F	160:w
+	F	161:w
+	F	162:w
+	F	163:w
+	F	164:w
+	F	165:w
+	F	166:w
+	F	167:w
+	F	168:w
+	F	169:w
+	F	170:w
+	F	171:w
+	F	172:w
+	F	173:w
+	F	174:w
+	F	175:w
+	F	176:w
+	F	177:w
+	F	178:w
+	F	179:w
+	F	180:w
+	F	181:w
+	F	182:w
+	F	183:w
+	F	184:w
+	F	185:w
+	F	186:w
+	F	187:w
+	F	188:w
+	F	189:w
+	F	190:w
+	F	191:w
+	F	192:w
+	F	193:w
+	F	194:w
+	F	195:w
+	F	196:w
+	F	197:w
+	F	198:w
+	F	199:w
+	F	200:w
+	F	201:w
+	F	202:w
+	F	203:w
+	F	204:w
+	F	205:w
+	F	206:w
+	F	207:w
+	F	208:w
+	F	209:w
+	F	210:w
+	F	211:w
+	F	212:w
+	F	213:w
+	F	214:w
+	F	215:w
+	F	216:w
+	F	217:w
+	F	218:w
+	F	219:w
+	F	220:w
+	F	221:w
+	F	222:w
+	F	223:w
+	F	224:w
+	F	225:w
+	F	226:w
+	F	227:w
+	F	228:w
+	F	229:w
+	F	230:w
+	F	231:w
+	F	232:w
+	F	233:w
+	F	234:w
+	F	235:w
+	F	236:w
+	F	237:w
+	F	238:w
+	F	239:w
+	F	240:w
+	F	241:w
+	F	242:w
+	F	243:w
+	F	244:w
+	F	245:w
+	F	246:w
+	F	247:w
+	F	248:w
+	F	249:w
+	F	250:w
+	F	251:w
+	F	252:w
+	F	253:w
+	F	254:w
+	F	255:w
+	F	0:x
+	F	1:x
+	F	2:x
+	F	3:x
+	F	4:x
+	F	5:x
+	F	6:x
+	F	7:x
+	F	8:x
+	F	9:x
+	F	10:x
+	F	11:x
+	F	12:x
+	F	13:x
+	F	14:x
+	F	15:x
+	F	16:x
+	F	17:x
+	F	18:x
+	F	19:x
+	F	20:x
+	F	21:x
+	F	22:x
+	F	23:x
+	F	24:x
+	F	25:x
+	F	26:x
+	F	27:x
+	F	28:x
+	F	29:x
+	F	30:x
+	F	31:x
+	F	32:x
+	F	33:x
+	F	34:x
+	F	35:x
+	F	36:x
+	F	37:x
+	F	38:x
+	F	39:x
+	F	40:x
+	F	41:x
+	F	42:x
+	F	43:x
+	F	44:x
+	F	45:x
+	F	46:x
+	F	47:x
+	F	48:x
+	F	49:x
+	F	50:x
+	F	51:x
+	F	52:x
+	F	53:x
+	F	54:x
+	F	55:x
+	F	56:x
+	F	57:x
+	F	58:x
+	F	59:x
+	F	60:x
+	F	61:x
+	F	62:x
+	F	63:x
+	F	64:x
+	F	65:x
+	F	66:x
+	F	67:x
+	F	68:x
+	F	69:x
+	F	70:x
+	F	71:x
+	F	72:x
+	F	73:x
+	F	74:x
+	F	75:x
+	F	76:x
+	F	77:x
+	F	78:x
+	F	79:x
+	F	80:x
+	F	81:x
+	F	82:x
+	F	83:x
+	F	84:x
+	F	85:x
+	F	86:x
+	F	87:x
+	F	88:x
+	F	89:x
+	F	90:x
+	F	91:x
+	F	92:x
+	F	93:x
+	F	94:x
+	F	95:x
+	F	96:x
+	F	97:x
+	F	98:x
+	F	99:x
+	F	100:x
+	F	101:x
+	F	102:x
+	F	103:x
+	F	104:x
+	F	105:x
+	F	106:x
+	F	107:x
+	F	108:x
+	F	109:x
+	F	110:x
+	F	111:x
+	F	112:x
+	F	113:x
+	F	114:x
+	F	115:x
+	F	116:x
+	F	117:x
+	F	118:x
+	F	119:x
+	F	120:x
+	F	121:x
+	F	122:x
+	F	123:x
+	F	124:x
+	F	125:x
+	F	126:x
+	F	127:x
+	F	128:x
+	F	129:x
+	F	130:x
+	F	131:x
+	F	132:x
+	F	133:x
+	F	134:x
+	F	135:x
+	F	136:x
+	F	137:x
+	F	138:x
+	F	139:x
+	F	140:x
+	F	141:x
+	F	142:x
+	F	143:x
+	F	144:x
+	F	145:x
+	F	146:x
+	F	147:x
+	F	148:x
+	F	149:x
+	F	150:x
+	F	151:x
+	F	152:x
+	F	153:x
+	F	154:x
+	F	155:x
+	F	156:x
+	F	157:x
+	F	158:x
+	F	159:x
+	F	160:x
+	F	161:x
+	F	162:x
+	F	163:x
+	F	164:x
+	F	165:x
+	F	166:x
+	F	167:x
+	F	168:x
+	F	169:x
+	F	170:x
+	F	171:x
+	F	172:x
+	F	173:x
+	F	174:x
+	F	175:x
+	F	176:x
+	F	177:x
+	F	178:x
+	F	179:x
+	F	180:x
+	F	181:x
+	F	182:x
+	F	183:x
+	F	184:x
+	F	185:x
+	F	186:x
+	F	187:x
+	F	188:x
+	F	189:x
+	F	190:x
+	F	191:x
+	F	192:x
+	F	193:x
+	F	194:x
+	F	195:x
+	F	196:x
+	F	197:x
+	F	198:x
+	F	199:x
+	F	200:x
+	F	201:x
+	F	202:x
+	F	203:x
+	F	204:x
+	F	205:x
+	F	206:x
+	F	207:x
+	F	208:x
+	F	209:x
+	F	210:x
+	F	211:x
+	F	212:x
+	F	213:x
+	F	214:x
+	F	215:x
+	F	216:x
+	F	217:x
+	F	218:x
+	F	219:x
+	F	220:x
+	F	221:x
+	F	222:x
+	F	223:x
+	F	224:x
+	F	225:x
+	F	226:x
+	F	227:x
+	F	228:x
+	F	229:x
+	F	230:x
+	F	231:x
+	F	232:x
+	F	233:x
+	F	234:x
+	F	235:x
+	F	236:x
+	F	237:x
+	F	238:x
+	F	239:x
+	F	240:x
+	F	241:x
+	F	242:x
+	F	243:x
+	F	244:x
+	F	245:x
+	F	246:x
+	F	247:x
+	F	248:x
+	F	249:x
+	F	250:x
+	F	251:x
+	F	252:x
+	F	253:x
+	F	254:x
+	F	255:x
+	F	0:y
+	F	1:y
+	F	2:y
+	F	3:y
+	F	4:y
+	F	5:y
+	F	6:y
+	F	7:y
+	F	8:y
+	F	9:y
+	F	10:y
+	F	11:y
+	F	12:y
+	F	13:y
+	F	14:y
+	F	15:y
+	F	16:y
+	F	17:y
+	F	18:y
+	F	19:y
+	F	20:y
+	F	21:y
+	F	22:y
+	F	23:y
+	F	24:y
+	F	25:y
+	F	26:y
+	F	27:y
+	F	28:y
+	F	29:y
+	F	30:y
+	F	31:y
+	F	32:y
+	F	33:y
+	F	34:y
+	F	35:y
+	F	36:y
+	F	37:y
+	F	38:y
+	F	39:y
+	F	40:y
+	F	41:y
+	F	42:y
+	F	43:y
+	F	44:y
+	F	45:y
+	F	46:y
+	F	47:y
+	F	48:y
+	F	49:y
+	F	50:y
+	F	51:y
+	F	52:y
+	F	53:y
+	F	54:y
+	F	55:y
+	F	56:y
+	F	57:y
+	F	58:y
+	F	59:y
+	F	60:y
+	F	61:y
+	F	62:y
+	F	63:y
+	F	64:y
+	F	65:y
+	F	66:y
+	F	67:y
+	F	68:y
+	F	69:y
+	F	70:y
+	F	71:y
+	F	72:y
+	F	73:y
+	F	74:y
+	F	75:y
+	F	76:y
+	F	77:y
+	F	78:y
+	F	79:y
+	F	80:y
+	F	81:y
+	F	82:y
+	F	83:y
+	F	84:y
+	F	85:y
+	F	86:y
+	F	87:y
+	F	88:y
+	F	89:y
+	F	90:y
+	F	91:y
+	F	92:y
+	F	93:y
+	F	94:y
+	F	95:y
+	F	96:y
+	F	97:y
+	F	98:y
+	F	99:y
+	F	100:y
+	F	101:y
+	F	102:y
+	F	103:y
+	F	104:y
+	F	105:y
+	F	106:y
+	F	107:y
+	F	108:y
+	F	109:y
+	F	110:y
+	F	111:y
+	F	112:y
+	F	113:y
+	F	114:y
+	F	115:y
+	F	116:y
+	F	117:y
+	F	118:y
+	F	119:y
+	F	120:y
+	F	121:y
+	F	122:y
+	F	123:y
+	F	124:y
+	F	125:y
+	F	126:y
+	F	127:y
+	F	128:y
+	F	129:y
+	F	130:y
+	F	131:y
+	F	132:y
+	F	133:y
+	F	134:y
+	F	135:y
+	F	136:y
+	F	137:y
+	F	138:y
+	F	139:y
+	F	140:y
+	F	141:y
+	F	142:y
+	F	143:y
+	F	144:y
+	F	145:y
+	F	146:y
+	F	147:y
+	F	148:y
+	F	149:y
+	F	150:y
+	F	151:y
+	F	152:y
+	F	153:y
+	F	154:y
+	F	155:y
+	F	156:y
+	F	157:y
+	F	158:y
+	F	159:y
+	F	160:y
+	F	161:y
+	F	162:y
+	F	163:y
+	F	164:y
+	F	165:y
+	F	166:y
+	F	167:y
+	F	168:y
+	F	169:y
+	F	170:y
+	F	171:y
+	F	172:y
+	F	173:y
+	F	174:y
+	F	175:y
+	F	176:y
+	F	177:y
+	F	178:y
+	F	179:y
+	F	180:y
+	F	181:y
+	F	182:y
+	F	183:y
+	F	184:y
+	F	185:y
+	F	186:y
+	F	187:y
+	F	188:y
+	F	189:y
+	F	190:y
+	F	191:y
+	F	192:y
+	F	193:y
+	F	194:y
+	F	195:y
+	F	196:y
+	F	197:y
+	F	198:y
+	F	199:y
+	F	200:y
+	F	201:y
+	F	202:y
+	F	203:y
+	F	204:y
+	F	205:y
+	F	206:y
+	F	207:y
+	F	208:y
+	F	209:y
+	F	210:y
+	F	211:y
+	F	212:y
+	F	213:y
+	F	214:y
+	F	215:y
+	F	216:y
+	F	217:y
+	F	218:y
+	F	219:y
+	F	220:y
+	F	221:y
+	F	222:y
+	F	223:y
+	F	224:y
+	F	225:y
+	F	226:y
+	F	227:y
+	F	228:y
+	F	229:y
+	F	230:y
+	F	231:y
+	F	232:y
+	F	233:y
+	F	234:y
+	F	235:y
+	F	236:y
+	F	237:y
+	F	238:y
+	F	239:y
+	F	240:y
+	F	241:y
+	F	242:y
+	F	243:y
+	F	244:y
+	F	245:y
+	F	246:y
+	F	247:y
+	F	248:y
+	F	249:y
+	F	250:y
+	F	251:y
+	F	252:y
+	F	253:y
+	F	254:y
+	F	255:y
+	F	0:z
+	F	1:z
+	F	2:z
+	F	3:z
+	F	4:z
+	F	5:z
+	F	6:z
+	F	7:z
+	F	8:z
+	F	9:z
+	F	10:z
+	F	11:z
+	F	12:z
+	F	13:z
+	F	14:z
+	F	15:z
+	F	16:z
+	F	17:z
+	F	18:z
+	F	19:z
+	F	20:z
+	F	21:z
+	F	22:z
+	F	23:z
+	F	24:z
+	F	25:z
+	F	26:z
+	F	27:z
+	F	28:z
+	F	29:z
+	F	30:z
+	F	31:z
+	F	32:z
+	F	33:z
+	F	34:z
+	F	35:z
+	F	36:z
+	F	37:z
+	F	38:z
+	F	39:z
+	F	40:z
+	F	41:z
+	F	42:z
+	F	43:z
+	F	44:z
+	F	45:z
+	F	46:z
+	F	47:z
+	F	48:z
+	F	49:z
+	F	50:z
+	F	51:z
+	F	52:z
+	F	53:z
+	F	54:z
+	F	55:z
+	F	56:z
+	F	57:z
+	F	58:z
+	F	59:z
--- groff-1.18.orig/font/devX75/DESC
+++ groff-1.18/font/devX75/DESC
@@ -1,5 +1,6 @@
 styles R I B BI
-fonts 6 0 0 0 0 0 S
+fonts 8 0 0 0 0 0 S M G
+ondemand M G
 sizes 8 10 12 14 18 24 0
 res 75
 X11
--- groff-1.18.orig/font/devX75/Makefile.sub
+++ groff-1.18/font/devX75/Makefile.sub
@@ -1,2 +1,13 @@
 DEV=X75
-DEVFILES=DESC TR TI TB TBI CR CI CB CBI HR HI HB HBI NR NI NB NBI S
+DEVFILES=DESC TR TI TB TBI CR CI CB CBI HR HI HB HBI NR NI NB NBI S M G
+CLEANADD=M G
+
+M: M.header
+	@echo Making M
+	@-rm -f M
+	@(cat $(srcdir)/M.header; echo charset) > M
+
+G: M
+	@echo Making G
+	@-rm -f G
+	@sed -e 's/name M/name G/' M > G
--- groff-1.18.orig/font/devX75/M.header
+++ groff-1.18/font/devX75/M.header
@@ -0,0 +1,3 @@
+name M
+spacewidth 11
+fixedkanji 11,9,2 0
--- groff-1.18.orig/font/devX75-12/DESC
+++ groff-1.18/font/devX75-12/DESC
@@ -1,5 +1,6 @@
 styles R I B BI
-fonts 6 0 0 0 0 0 S
+fonts 8 0 0 0 0 0 S M G
+ondemand M G
 sizes 8 10 12 14 18 24 0
 res 75
 X11
--- groff-1.18.orig/font/devX75-12/Makefile.sub
+++ groff-1.18/font/devX75-12/Makefile.sub
@@ -1,2 +1,13 @@
 DEV=X75-12
-DEVFILES=DESC TR TI TB TBI CR CI CB CBI HR HI HB HBI NR NI NB NBI S
+DEVFILES=DESC TR TI TB TBI CR CI CB CBI HR HI HB HBI NR NI NB NBI S M G
+CLEANADD=M G
+
+M: M.header
+	@echo Making M
+	@-rm -f M
+	@(cat $(srcdir)/M.header; echo charset) > M
+
+G: M
+	@echo Making G
+	@-rm -f G
+	@sed -e 's/name M/name G/' M > G
--- groff-1.18.orig/font/devX75-12/M.header
+++ groff-1.18/font/devX75-12/M.header
@@ -0,0 +1,3 @@
+name M
+spacewidth 11
+fixedkanji 11,9,2 0
--- groff-1.18.orig/font/devX100/DESC
+++ groff-1.18/font/devX100/DESC
@@ -1,5 +1,6 @@
 styles R I B BI
-fonts 6 0 0 0 0 0 S
+fonts 8 0 0 0 0 0 S M G
+ondemand M G
 sizes 8 10 12 14 18 24 0
 res 100
 X11
--- groff-1.18.orig/font/devX100/Makefile.sub
+++ groff-1.18/font/devX100/Makefile.sub
@@ -1,2 +1,13 @@
 DEV=X100
-DEVFILES=DESC TR TI TB TBI CR CI CB CBI HR HI HB HBI NR NI NB NBI S
+DEVFILES=DESC TR TI TB TBI CR CI CB CBI HR HI HB HBI NR NI NB NBI S M G
+CLEANADD=M G
+
+M: M.header
+	@echo Making M
+	@-rm -f M
+	@(cat $(srcdir)/M.header; echo charset) > M
+
+G: M
+	@echo Making G
+	@-rm -f G
+	@sed -e 's/name M/name G/' M > G
--- groff-1.18.orig/font/devX100/M.header
+++ groff-1.18/font/devX100/M.header
@@ -0,0 +1,3 @@
+name M
+spacewidth 16
+fixedkanji 16,14,2 0
--- groff-1.18.orig/font/devX100-12/DESC
+++ groff-1.18/font/devX100-12/DESC
@@ -1,5 +1,6 @@
 styles R I B BI
-fonts 6 0 0 0 0 0 S
+fonts 8 0 0 0 0 0 S M G
+ondemand M G
 sizes 8 10 12 14 18 24 0
 res 100
 X11
--- groff-1.18.orig/font/devX100-12/Makefile.sub
+++ groff-1.18/font/devX100-12/Makefile.sub
@@ -1,2 +1,14 @@
 DEV=X100-12
-DEVFILES=DESC TR TI TB TBI CR CI CB CBI HR HI HB HBI NR NI NB NBI S
+DEVFILES=DESC TR TI TB TBI CR CI CB CBI HR HI HB HBI NR NI NB NBI S M G
+CLEANADD=M G
+
+M: M.header
+	@echo Making M
+	@-rm -f M
+	@(cat $(srcdir)/M.header; echo charset) > M
+
+G: M
+	@echo Making G
+	@-rm -f G
+	@sed -e 's/name M/name G/' M > G
+
--- groff-1.18.orig/font/devX100-12/M.header
+++ groff-1.18/font/devX100-12/M.header
@@ -0,0 +1,3 @@
+name M
+spacewidth 16
+fixedkanji 16,14,2 0
--- groff-1.18.orig/font/devhtml/Makefile.sub
+++ groff-1.18/font/devhtml/Makefile.sub
@@ -1,8 +1,8 @@
 DEV=html
 PROTOFONTS=R I B BI CR
 FONTS=$(PROTOFONTS) S
-DEVFILES=$(FONTS) DESC
-CLEANADD=$(FONTS) DESC
+DEVFILES=$(FONTS) DESC M G
+CLEANADD=$(FONTS) DESC M G
 
 RES=240
 CPI=10
@@ -32,3 +32,12 @@
 	    -e "s/^fonts .*$$/fonts `set $(FONTS); echo $$#` $(FONTS)/" \
 	    $(srcdir)/DESC.proto >$@
 
+M: M.header
+	@echo Making M
+	@-rm -f M
+	@(cat $(srcdir)/M.header; echo charset) > M
+
+G: M
+	@echo Making G
+	@-rm -f G
+	@sed -e 's/name M/name G/' M > G
--- groff-1.18.orig/font/devhtml/M.header
+++ groff-1.18/font/devhtml/M.header
@@ -0,0 +1,3 @@
+name M
+spacewidth 16
+fixedkanji 16,14,2 0
--- groff-1.18.orig/font/devlj4/Makefile.sub
+++ groff-1.18/font/devlj4/Makefile.sub
@@ -22,9 +22,9 @@
 	echo "unitwidth `expr 7620000 / $(LJ4RES)`" >>DESC
 	cat $(srcdir)/DESC.in >>DESC
 	if test "$(PAGE)" = A4; then \
-	  echo "papersize a4" >>DESC; \
+	  echo "papersize /etc/papersize a4" >>DESC; \
 	else \
-	  echo "papersize letter" >>DESC; \
+	  echo "papersize /etc/papersize letter" >>DESC; \
 	fi
 	test -z '$(LJ4PRINT)' || echo print '$(LJ4PRINT)' >>DESC
 
--- groff-1.18.orig/font/devlbp/Makefile.sub
+++ groff-1.18/font/devlbp/Makefile.sub
@@ -13,9 +13,9 @@
 	-rm -f DESC
 	cat $(srcdir)/DESC.in >>DESC
 	if test "$(PAGE)" = A4; then \
-	  echo "papersize a4" >>DESC; \
+	  echo "papersize /etc/papersize a4" >>DESC; \
 	else \
-	  echo "papersize letter" >>DESC; \
+	  echo "papersize /etc/papersize letter" >>DESC; \
 	fi
 	test -z '$(LBPPRINT)' || echo print '$(LBPPRINT)' >>DESC
 
--- groff-1.18.orig/font/devascii8/DESC.proto
+++ groff-1.18/font/devascii8/DESC.proto
@@ -0,0 +1,8 @@
+res 240
+hor 24
+vert 40
+unitwidth 10
+sizes 10 0
+fonts 4 R I B BI
+tcommand
+postpro grotty
--- groff-1.18.orig/font/devascii8/Makefile.sub
+++ groff-1.18/font/devascii8/Makefile.sub
@@ -0,0 +1,31 @@
+DEV=ascii8
+FONTS=R I B BI
+DEVFILES=$(FONTS) DESC
+CLEANADD=$(FONTS) DESC
+
+RES=240
+CPI=10
+LPI=6
+
+$(FONTS): R.proto
+	@echo Making $@
+	@-rm -f $@
+	@(charwidth=`expr $(RES) / $(CPI)` ; \
+ 	 sed -e "s/^name [A-Z]*$$/name $@/" \
+	     -e "s/^\\([^	]*\\)	[0-9]+	/\\1	$$charwidth	/" \
+	     -e "s/^spacewidth [0-9]+$$/spacewidth $$charwidth/" \
+	     -e "s/^internalname .*$$/internalname $@/" \
+	     -e "/^internalname/s/BI/3/" \
+	     -e "/^internalname/s/B/2/" \
+	     -e "/^internalname/s/I/1/" \
+	     -e "/^internalname .*[^ 0-9]/d" \
+	     $(srcdir)/R.proto >$@)
+
+DESC: DESC.proto
+	@echo Making $@
+	@-rm -f $@
+	@sed -e "s/^res .*$$/res $(RES)/" \
+	    -e "s/^hor .*$$/hor `expr $(RES) / $(CPI)`/" \
+	    -e "s/^vert .*$$/vert `expr $(RES) / $(LPI)`/" \
+	    -e "s/^fonts .*$$/fonts `set $(FONTS); echo $$#` $(FONTS)/" \
+	    $(srcdir)/DESC.proto >$@
--- groff-1.18.orig/font/devascii8/R.proto
+++ groff-1.18/font/devascii8/R.proto
@@ -0,0 +1,262 @@
+name R
+internalname 0
+spacewidth 24
+charset
+!	24	0	0041
+"	24	0	0042
+dq	"
+lq	"
+rq	"
+#	24	0	0043
+sh	"
+$	24	0	0044
+Do	"
+%	24	0	0045
+&	24	0	0046
+'	24	0	0047
+aa	"
+fm	"
+aq	"
+cq	"
+(	24	0	0050
+)	24	0	0051
+*	24	0	0052
+**	"
++	24	0	0053
+pl	"
+,	24	0	0054
+\-	24	0	0055
+hy	"
+-	"
+mi	"
+en	"
+.	24	0	0056
+/	24	0	0057
+sl	"
+f/	"
+0	24	0	0060
+1	24	0	0061
+2	24	0	0062
+3	24	0	0063
+4	24	0	0064
+5	24	0	0065
+6	24	0	0066
+7	24	0	0067
+8	24	0	0070
+9	24	0	0071
+:	24	0	0072
+;	24	0	0073
+<	24	0	0074
+la	"
+fo	"
+=	24	0	0075
+eq	"
+>	24	0	0076
+ra	"
+fc	"
+?	24	0	0077
+@	24	0	0100
+at	"
+A	24	0	0101
+*A	"
+B	24	0	0102
+*B	"
+C	24	0	0103
+D	24	0	0104
+E	24	0	0105
+*E	"
+F	24	0	0106
+G	24	0	0107
+H	24	0	0110
+*Y	"
+I	24	0	0111
+*I	"
+J	24	0	0112
+K	24	0	0113
+*K	"
+L	24	0	0114
+M	24	0	0115
+*M	"
+N	24	0	0116
+*N	"
+O	24	0	0117
+ci	"
+*O	"
+P	24	0	0120
+*R	"
+Q	24	0	0121
+R	24	0	0122
+S	24	0	0123
+T	24	0	0124
+*T	"
+U	24	0	0125
+V	24	0	0126
+W	24	0	0127
+X	24	0	0130
+*X	"
+Y	24	0	0131
+*U	"
+Z	24	0	0132
+*Z	"
+[	24	0	0133
+lB	"
+\	24	0	0134
+rs	"
+]	24	0	0135
+rB	"
+a^	24	0	0136
+^	"
+ha	"
+_	24	0	0137
+ru	"
+ul	"
+`	24	0	0140
+oq	"
+ga	"
+a	24	0	0141
+b	24	0	0142
+c	24	0	0143
+d	24	0	0144
+e	24	0	0145
+f	24	0	0146
+g	24	0	0147
+h	24	0	0150
+i	24	0	0151
+.i	"
+j	24	0	0152
+k	24	0	0153
+l	24	0	0154
+m	24	0	0155
+n	24	0	0156
+o	24	0	0157
+*o	"
+p	24	0	0160
+q	24	0	0161
+r	24	0	0162
+s	24	0	0163
+t	24	0	0164
+u	24	0	0165
+v	24	0	0166
+w	24	0	0167
+x	24	0	0170
+mu	"
+y	24	0	0171
+z	24	0	0172
+lC	24	0	0173
+{	"
+ba	24	0	0174
+or	"
+bv	"
+br	"
+|	"
+lb	"
+lc	"
+lf	"
+lk	"
+lt	"
+rb	"
+rc	"
+rf	"
+rk	"
+rt	"
+rC	24	0	0175
+}	"
+a~	24	0	0176
+~	"
+ap	"
+ti	"
+char161	24	0	0241
+char162	24	0	0242
+char163	24	0	0243
+char164	24	0	0244
+char165	24	0	0245
+char166	24	0	0246
+char167	24	0	0247
+char168	24	0	0250
+char169	24	0	0251
+char170	24	0	0252
+char171	24	0	0253
+char172	24	0	0254
+char173	24	0	0255 
+char174	24	0	0256
+char175	24	0	0257
+char176	24	0	0260
+char177	24	0	0261
+char178	24	0	0262
+char179	24	0	0263
+char180	24	0	0264
+char181	24	0	0265
+char182	24	0	0266
+char183	24	0	0267
+char184	24	0	0270
+char185	24	0	0271
+char186	24	0	0272
+char187	24	0	0273
+char188	24	0	0274
+char189	24	0	0275
+char190	24	0	0276
+char191	24	0	0277
+char192	24	0	0300
+char193	24	0	0301
+char194	24	0	0302
+char195	24	0	0303
+char196	24	0	0304
+char197	24	0	0305
+char198	24	0	0306
+char199	24	0	0307
+char200	24	0	0310
+char201	24	0	0311
+char202	24	0	0312
+char203	24	0	0313
+char204	24	0	0314
+char205	24	0	0315
+char206	24	0	0316
+char207	24	0	0317
+char208	24	0	0320
+char209	24	0	0321
+char210	24	0	0322
+char211	24	0	0323
+char212	24	0	0324
+char213	24	0	0325
+char214	24	0	0326
+char215	24	0	0327
+char216	24	0	0330
+char217	24	0	0331
+char218	24	0	0332
+char219	24	0	0333
+char220	24	0	0334
+char221	24	0	0335
+char222	24	0	0336
+char223	24	0	0337
+char224	24	0	0340
+char225	24	0	0341
+char226	24	0	0342
+char227	24	0	0343
+char228	24	0	0344
+char229	24	0	0345
+char230	24	0	0346
+char231	24	0	0347
+char232	24	0	0350
+char233	24	0	0351
+char234	24	0	0352
+char235	24	0	0353
+char236	24	0	0354
+char237	24	0	0355
+char238	24	0	0356
+char239	24	0	0357
+char240	24	0	0360
+char241	24	0	0361
+char242	24	0	0362
+char243	24	0	0363
+char244	24	0	0364
+char245	24	0	0365
+char246	24	0	0366
+char247	24	0	0367
+char248	24	0	0370
+char249	24	0	0371
+char250	24	0	0372
+char251	24	0	0373
+char252	24	0	0374
+char253	24	0	0375
+char254	24	0	0376
+char255	24	0	0377
--- groff-1.18.orig/font/devnippon/DESC.proto
+++ groff-1.18/font/devnippon/DESC.proto
@@ -0,0 +1,9 @@
+res 240
+hor 24
+vert 40
+unitwidth 10
+sizes 10 0
+fonts 6 R I B BI M G
+ondemand M G
+tcommand
+postpro grotty
--- groff-1.18.orig/font/devnippon/M.header
+++ groff-1.18/font/devnippon/M.header
@@ -0,0 +1,4 @@
+name M
+internalname 4
+spacewidth 48
+fixedkanji 48 0
--- groff-1.18.orig/font/devnippon/Makefile.sub
+++ groff-1.18/font/devnippon/Makefile.sub
@@ -0,0 +1,44 @@
+DEV=nippon
+FONTS=R I B BI
+WFONTS=M G
+ALLFONTS=$(FONTS) $(WFONTS)
+DEVFILES=$(ALLFONTS) DESC
+CLEANADD=$(ALLFONTS) DESC M G
+
+RES=240
+CPI=10
+LPI=6
+
+$(FONTS): R.proto
+	@echo Making $@
+	@-rm -f $@
+	@(charwidth=`expr $(RES) / $(CPI)` ; \
+ 	 sed -e "s/^name [A-Z]*$$/name $@/" \
+	     -e "s/^\\([^	]*\\)	[0-9]+	/\\1	$$charwidth	/" \
+	     -e "s/^spacewidth [0-9]+$$/spacewidth $$charwidth/" \
+	     -e "s/^internalname .*$$/internalname $@/" \
+	     -e "/^internalname/s/BI/3/" \
+	     -e "/^internalname/s/B/2/" \
+	     -e "/^internalname/s/I/1/" \
+	     -e "/^internalname .*[^ 0-9]/d" \
+	     $(srcdir)/R.proto >$@)
+
+M: M.header
+	@echo Making M
+	@-rm -f M
+	@(cat $(srcdir)/M.header; echo charset) > M
+
+G: M
+	@echo Making G
+	@-rm -f G
+	@sed -e 's/name M/name G/' \
+	    -e 's/internalname 4/internalname 5/' M > G
+		
+DESC: DESC.proto
+	@echo Making $@
+	@-rm -f $@
+	@sed -e "s/^res .*$$/res $(RES)/" \
+	    -e "s/^hor .*$$/hor `expr $(RES) / $(CPI)`/" \
+	    -e "s/^vert .*$$/vert `expr $(RES) / $(LPI)`/" \
+	    -e "s/^fonts .*$$/fonts `set $(ALLFONTS); echo $$#` $(ALLFONTS)/" \
+	    $(srcdir)/DESC.proto >$@
--- groff-1.18.orig/font/devnippon/R.proto
+++ groff-1.18/font/devnippon/R.proto
@@ -0,0 +1,167 @@
+name R
+internalname 0
+spacewidth 24
+charset
+!	24	0	0041
+"	24	0	0042
+dq	"
+lq	"
+rq	"
+#	24	0	0043
+sh	"
+$	24	0	0044
+Do	"
+%	24	0	0045
+&	24	0	0046
+'	24	0	0047
+aa	"
+fm	"
+aq	"
+cq	"
+(	24	0	0050
+)	24	0	0051
+*	24	0	0052
+**	"
++	24	0	0053
+pl	"
+,	24	0	0054
+\-	24	0	0055
+hy	"
+-	"
+mi	"
+en	"
+.	24	0	0056
+/	24	0	0057
+sl	"
+f/	"
+0	24	0	0060
+1	24	0	0061
+2	24	0	0062
+3	24	0	0063
+4	24	0	0064
+5	24	0	0065
+6	24	0	0066
+7	24	0	0067
+8	24	0	0070
+9	24	0	0071
+:	24	0	0072
+;	24	0	0073
+<	24	0	0074
+la	"
+fo	"
+=	24	0	0075
+eq	"
+>	24	0	0076
+ra	"
+fc	"
+?	24	0	0077
+@	24	0	0100
+at	"
+A	24	0	0101
+*A	"
+B	24	0	0102
+*B	"
+C	24	0	0103
+D	24	0	0104
+E	24	0	0105
+*E	"
+F	24	0	0106
+G	24	0	0107
+H	24	0	0110
+*Y	"
+I	24	0	0111
+*I	"
+J	24	0	0112
+K	24	0	0113
+*K	"
+L	24	0	0114
+M	24	0	0115
+*M	"
+N	24	0	0116
+*N	"
+O	24	0	0117
+ci	"
+*O	"
+P	24	0	0120
+*R	"
+Q	24	0	0121
+R	24	0	0122
+S	24	0	0123
+T	24	0	0124
+*T	"
+U	24	0	0125
+V	24	0	0126
+W	24	0	0127
+X	24	0	0130
+*X	"
+Y	24	0	0131
+*U	"
+Z	24	0	0132
+*Z	"
+[	24	0	0133
+lB	"
+\	24	0	0134
+rs	"
+]	24	0	0135
+rB	"
+a^	24	0	0136
+^	"
+ha	"
+_	24	0	0137
+ru	"
+ul	"
+`	24	0	0140
+oq	"
+ga	"
+a	24	0	0141
+b	24	0	0142
+c	24	0	0143
+d	24	0	0144
+e	24	0	0145
+f	24	0	0146
+g	24	0	0147
+h	24	0	0150
+i	24	0	0151
+.i	"
+j	24	0	0152
+k	24	0	0153
+l	24	0	0154
+m	24	0	0155
+n	24	0	0156
+o	24	0	0157
+*o	"
+p	24	0	0160
+q	24	0	0161
+r	24	0	0162
+s	24	0	0163
+t	24	0	0164
+u	24	0	0165
+v	24	0	0166
+w	24	0	0167
+x	24	0	0170
+mu	"
+y	24	0	0171
+z	24	0	0172
+lC	24	0	0173
+{	"
+ba	24	0	0174
+or	"
+bv	"
+br	"
+|	"
+lb	"
+lc	"
+lf	"
+lk	"
+lt	"
+rb	"
+rc	"
+rf	"
+rk	"
+rt	"
+rC	24	0	0175
+}	"
+a~	24	0	0176
+~	"
+ap	"
+ti	"
--- groff-1.18.orig/font/devnippon/createM.pl
+++ groff-1.18/font/devnippon/createM.pl
@@ -0,0 +1,55 @@
+#!/usr/bin/perl
+# cat <header> | ./$0 -{jis|euc} <metric> <type>
+#
+
+$jis=0;
+if ($ARGV[0] =~ /-jis/) {
+  $jis = 1;
+} elsif ($ARGV[0] =~ /-euc/) {
+  $jis = 0;
+} else {
+  print STDERR "$0: -jis or -euc\n"; exit 1;
+}
+$metric=$ARGV[1];
+$type=$ARGV[2];
+
+while (<STDIN>) {
+    print;	
+}
+print "charset\n";
+$WCTABLE_SIZE = 94;
+$WCTABLE_OFFSET = 0xa1;
+
+LOOP: for ($ku = 0; $ku < $WCTABLE_SIZE; $ku++) {
+    for ($ten = 0; $ten < $WCTABLE_SIZE; $ten++) {
+	$wc = (($ku + $WCTABLE_OFFSET) << 8) & 0xff00;
+	$wc |= ($ten + $WCTABLE_OFFSET) & 0xff;
+	if ($wc >= 0xa2af && $wc <= 0xa2b9 ||
+	    $wc >= 0xa2c2 && $wc <= 0xa2c9 ||
+	    $wc >= 0xa2d1 && $wc <= 0xa2db ||
+	    $wc >= 0xa2eb && $wc <= 0xa2f1 ||
+	    $wc >= 0xa2fa && $wc <= 0xa2fd ||
+	    $wc >= 0xa3a1 && $wc <= 0xa3af ||
+	    $wc >= 0xa3ba && $wc <= 0xa3c0 ||
+	    $wc >= 0xa3db && $wc <= 0xa3e0 ||
+	    $wc >= 0xa3fb && $wc <= 0xa3fe ||
+	    $wc >= 0xa4f4 && $wc <= 0xa4fe ||
+	    $wc >= 0xa5f7 && $wc <= 0xa5fe ||
+	    $wc >= 0xa6b9 && $wc <= 0xa6c0 ||
+	    $wc >= 0xa6d9 && $wc <= 0xa6fe ||
+	    $wc >= 0xa7c2 && $wc <= 0xa7d0 ||
+	    $wc >= 0xa7f2 && $wc <= 0xa7fe ||
+	    $wc >= 0xa8c1 && $wc <= 0xaffe ||
+	    $wc >= 0xcfd4 && $wc <= 0xcffe) {
+	    next;
+	} elsif ($wc >= 0xf4a5) {
+	    last LOOP;
+	} else {
+	    printf("%c%c\t%s\t%s\t%#x\n",
+		   $ku + $WCTABLE_OFFSET, $ten + $WCTABLE_OFFSET,
+		   $metric, $type, 
+		   ($jis ? ($wc & 0x7f7f) : $wc));
+	}
+    }
+}
+exit 0;
--- groff-1.18.orig/tmac/Makefile.sub
+++ groff-1.18/tmac/Makefile.sub
@@ -25,15 +25,18 @@
   html.tmac www.tmac \
   eqnrc \
   troffrc troffrc-end \
-  hyphen.us
+  hyphen.us \
+  andocj.tmac \
+  euc-jp.tmac
 SPECIALFILES=an.tmac man.tmac s.tmac ms.tmac
-STRIPFILES=e.tmac doc.tmac doc-old.tmac
-MDOCFILES=doc-common doc-ditroff doc-nroff doc-syms
+STRIPFILES=e.tmac doc.tmac doc-old.tmac docj.tmac
+MDOCFILES=doc-common doc-ditroff doc-nroff doc-syms docj-ditroff docj-nroff
 mdocdir=$(tmacdir)/mdoc
 CLEANADD=\
   stamp-wrap stamp-sed *-wrap man.tmac-sed ms.tmac-sed \
   stamp-strip e.tmac-s doc.tmac-s doc-old.tmac-s \
-  doc-common-s doc-ditroff-s doc-nroff-s doc-syms-s mdoc.local-s
+  doc-common-s doc-ditroff-s doc-nroff-s doc-syms-s mdoc.local-s \
+  docj.tmac-s docj-ditroff-s docj-nroff-s
 tmac_s_prefix=
 tmac_an_prefix=
 tmac_wrap=
--- groff-1.18.orig/tmac/troffrc
+++ groff-1.18/tmac/troffrc
@@ -13,7 +13,9 @@
 .do ds troffrc!X100 X.tmac
 .do ds troffrc!X100-12 X.tmac
 .do ds troffrc!ascii tty.tmac
+.do ds troffrc!ascii8 tty.tmac
 .do ds troffrc!latin1 tty.tmac
+.do ds troffrc!nippon tty.tmac
 .do ds troffrc!utf8 tty.tmac
 .do ds troffrc!cp1047 tty.tmac
 .do ds troffrc!lj4 lj4.tmac
@@ -37,3 +39,6 @@
 .do hpf hyphen.us
 .
 .\" Don't let blank lines creep in here.
+.\"
+.\" for Japanese hack
+.if "\V[LANG]"ja_JP.eucJP" .do mso euc-jp.tmac
--- groff-1.18.orig/tmac/andocj.tmac
+++ groff-1.18/tmac/andocj.tmac
@@ -0,0 +1,12 @@
+.\" Load either tmac.an or tmac.doc.
+.if !\n(.g .ab These macros require groff.
+.de Dd
+.rm Dd
+.do mso tmac.docj
+\\*(Dd\\
+..
+.de TH
+.rm TH
+.do mso tmac.an
+\\*(TH\\
+..
--- groff-1.18.orig/tmac/docj-ditroff
+++ groff-1.18/tmac/docj-ditroff
@@ -0,0 +1,305 @@
+.\" Copyright (c) 1991 The Regents of the University of California.
+.\" All rights reserved.
+.\"
+.\" Redistribution and use in source and binary forms, with or without
+.\" modification, are permitted provided that the following conditions
+.\" are met:
+.\" 1. Redistributions of source code must retain the above copyright
+.\"    notice, this list of conditions and the following disclaimer.
+.\" 2. Redistributions in binary form must reproduce the above copyright
+.\"    notice, this list of conditions and the following disclaimer in the
+.\"    documentation and/or other materials provided with the distribution.
+.\" 3. All advertising materials mentioning features or use of this software
+.\"    must display the following acknowledgement:
+.\"	This product includes software developed by the University of
+.\"	California, Berkeley and its contributors.
+.\" 4. Neither the name of the University nor the names of its contributors
+.\"    may be used to endorse or promote products derived from this software
+.\"    without specific prior written permission.
+.\"
+.\" THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
+.\" ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+.\" IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+.\" ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
+.\" FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+.\" DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+.\" OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+.\" HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+.\" LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+.\" OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+.\" SUCH DAMAGE.
+.\"
+.\"     @(#)doc-ditroff	5.8 (Berkeley) 8/5/91
+.\"
+.\" tmac.mdoc-ditroff
+.if \n(.g .if !rC .nr C 0
+.ds aD \fI\s10
+.ds aR \f(CO\s10
+.ds cM \f(CB\s10
+.ds dF \fR\s10
+.ds eM \fI\s10
+.ds eR \fC\s10
+.ds eV \fC\s10
+.ds fA \f(CO\s10
+.ds fD \f(CB\s10
+.ds fL \f(CB\s10
+.ds fN \f(CB\s10
+.ds fP \fP\s0
+.ds fS \s0
+.ds fT \f(CO\s10
+.ds Hs \fR\s10
+.ds iC \f(CB\s10
+.ds lI \fC
+.ds lP \fR\|(\|\fP\s10
+.ds lp \fR(\fP\s10
+.ds rP \fR\|)\|\fP\s10
+.ds rp \fR)\fP\s10
+.ds lB \fR\^[\^\fP\s10
+.ds rB \fR\^]\fP\s10
+.ds mL \fB\s10
+.ds nM \f(CB\s10
+.ds nO \fR\s10
+.ds nT \s0
+.ds pA \fC\s10
+.ds Pu \fR{\ .\ ,\ :\ ;\ (\ )\ [\ ]\ \fR}
+.ds rA \fR\s10
+.ds rT \f(CO\s10
+.ds sH \fB\s10
+.ds sP \s0
+.ds sY \fB\s10
+.ds sX \fR\s10
+.ds tF \fR
+.ds tN \s9
+.ds vA \fI\s10
+.ds Vs \fR\s10
+.ds vT \f(CB\s10
+.ds xR \fC\s10
+.tr *\(**
+.nr sI \w\fC,u*5
+.nr Ti \n(sIu
+.nr Pp .5v
+.ds lS \0
+.nr lS \w'\0'u
+.nr dI 6n
+.de pL
+.nr Hm .5i
+.nr Fm .5i
+.nr ll 6.5i
+.ll 6.5i
+.nr lt 6.5i
+.lt 6.5i
+.nr po 1i
+.po 1.i
+.nr dV .5v
+..
+.ds <= \(<=
+.ds >= \(>=
+.ie \n(.g \{\
+.	ds Lq \(lq
+.	ds Rq \(rq
+.\}
+.el \{\
+.	ds Lq \&``
+.	ds Rq \&''
+.\}
+.ds ua \(ua
+.ds aa \(aa
+.ds ga \(ga
+.ds sR \&'
+.ds sL \&`
+.ds q \&"
+.ds Pi \(*p
+.ds Ne \(!=
+.ds Le \(<=
+.ds Ge \(>=
+.ds Lt <
+.ds Gt >
+.ds Pm \(+-
+.ds If \(if
+.ds Na \fINaN\fP
+.ds Ba \fR\&|\fP
+.nr gX 0
+.de hK
+.ds hT \\*(dT
+.if !"\\*(cH"Null" \{\
+.       ie !"\\*(gP"Null" .as hT \|(\|\\*(cH\\*(gP\|)
+.       el .as hT \\|(\\|\\*(cH\\|)
+.\}
+.if "\\*(cH"Null" \{\
+.	if !"\\*(gP"Null" .as hT \&\|(\|\\*(gP\|)
+.\}
+.wh 0 hM
+.wh -1.25i fM
+.nr nL \\n(nl
+.ie \\n(gX==1 \{\
+.	rm n1
+.	bp
+.\}
+.el \{\
+'	bp
+.\}
+.if \\n(nL>0 \{\
+.	if !\\nC \{\
+.		nr % 1
+.	\}
+.\}
+.nr gX 0
+.em lM
+..
+.nr fW \w\fC0
+.de sW
+.nr sW \w\fC\\$1
+.ie \\n(sW>=\\n(fW \{\
+.       ie \\n(sW%\\n(fW .nr sW (\\n(sW/\\n(fW)+1
+.       el .nr sW \\n(sW/\\n(fW
+.\}
+.el \{\
+.	ie \\n(sW>0 .nr sW 1
+.	el .nr sW 0
+.\}
+..
+.de aW
+.nr sW \w\fC\\*(A\\$1
+.ie \\n(sW>=\\n(fW \{\
+.       ie \\n(sW%\\n(fW .nr sW (\\n(sW/\\n(fW)+1
+.       el .nr sW \\n(sW/\\n(fW
+.\}
+.el \{\
+.	ie \\n(sW>0 .nr sW 1
+.	el .nr sW 0
+.\}
+..
+.de Ql
+.if \\n(aC==0  \{\
+.	ds mN Ql
+.       ds A1 \\$1
+.       ds A2 \\$2
+.       ds A3 \\$3
+.       ds A4 \\$4
+.       ds A5 \\$5
+.       ds A6 \\$6
+.       ds A7 \\$7
+.       ds A8 \\$8
+. 	nr fV \\n(.$
+. 	fV
+.\}
+.nr aP \\n(aP+1
+.aW \\n(aP
+.nr aP \\n(aP-1
+.if \\n(sW>2 .Li
+.if \\n(sW<=2 \{\
+.	if (\\n(aP>0) \{\
+.		ds A\\n(aP Li
+.		nr aP \\n(aP -1
+.	\}		
+.	if (\\n(aP==0) \{\
+.		rm C0 C1 C2 C3 C4 C5 C6 C7 C8 C9
+.		rm S1 S2 S3 S4 S5 S6 S7 S8 S9
+.		rn A8 A9
+.		rn A7 A8
+.		rn A6 A7
+.		rn A5 A6
+.		rn A4 A5
+.		rn A3 A4
+.		rn A2 A3
+.		rn A1 A2
+.		ds A1 Li
+.	 	nr fV \\n(aC+1
+.		nr aC 0
+.		fV
+.	\}
+.	ds qL \&\\*(sL
+.	ds qR \&\\*(sR
+.	En
+.\}
+..
+.de Sh
+.nr nS 0
+.nr sE 0
+.nr iS 0
+'ad
+.ie "\\$1"NAME" \{\
+.       hK
+'       in 0
+.\}
+.el \{\
+.	ie "\\$1"̾" \{\
+.      		hK
+'		in 0
+.	\}
+.	el \{\
+.		ie "\\$1"̾" \{\
+.       		hK
+'       		in 0
+.		\}
+.		el \{\
+.       		nr nS 0
+.       		nr nA 0
+.			nr nF 0
+.       		nr nT 0
+.       		nr nY 0
+.       		nr oT 0
+.       		if "\\$1"SYNOPSIS" \{\
+.				na
+.				nr nS 1
+.			\}
+.       		if "\\$1"" \{\
+.				na
+.				nr nS 1
+.			\}
+.       		if "\\$1"DESCRIPTION" \{\
+.				nr fY 0
+.				nr fZ 0
+.				nr fB 0
+.				nr Fb 0
+.				ds Fb
+.			\}
+.       		if "\\$1"" \{\
+.				nr fY 0
+.				nr fZ 0
+.				nr fB 0
+.				nr Fb 0
+.				ds Fb
+.			\}
+.       		if "\\$1"" \{\
+.				nr fY 0
+.				nr fZ 0
+.				nr fB 0
+.				nr Fb 0
+.				ds Fb
+.			\}
+.       		if "\\$1"SEE" \{\
+.               		nr nA 1
+.               		na
+.       		\}
+.       		if "\\$1"Ϣ" \{\
+.               		nr nA 1
+.               		na
+.       		\}
+.       		if "\\$1"FILES" .nr nF 1
+.       		if "\\$1"ե" .nr nF 1
+.       		if "\\$1"Ϣե" .nr nF 1
+.       		if "\\$1"STANDARDS" .nr nT 1
+.       		if "\\$1"" .nr nT 1
+.       		if "\\$1"" .nr nT 1
+.       		if "\\$1"AUTHORS" .nr nY 1
+.       		if "\\$1"" .nr nY 1
+.       		if "\\$1"" .nr nY 1
+.			if "\\$1"SEE" .nr sE 1
+.			if "\\$1"Ϣ" .nr sE 1
+.       		in 0
+.       		nr aN 0
+.		\}
+.	\}
+.\}
+.pL
+'sp
+.ns
+.ta .5i 1i 1.5i 2i 2.5i 3i 3.5i 4i 4.5i 5i 5.5i 6i 6.5i
+.if !\\n(cR .ne 3
+'fi
+\&\\*(sH\\$1 \|\\$2 \|\\$3 \|\\$4 \|\\$5 \|\\$6 \|\\$7 \|\\$8 \|\\$9
+\&\fP\s0\&
+.in \\n(.iu+\\n(Tiu
+.ns
+..
--- groff-1.18.orig/tmac/docj-nroff
+++ groff-1.18/tmac/docj-nroff
@@ -0,0 +1,247 @@
+.\" Copyright (c) 1991 The Regents of the University of California.
+.\" All rights reserved.
+.\"
+.\" Redistribution and use in source and binary forms, with or without
+.\" modification, are permitted provided that the following conditions
+.\" are met:
+.\" 1. Redistributions of source code must retain the above copyright
+.\"    notice, this list of conditions and the following disclaimer.
+.\" 2. Redistributions in binary form must reproduce the above copyright
+.\"    notice, this list of conditions and the following disclaimer in the
+.\"    documentation and/or other materials provided with the distribution.
+.\" 3. All advertising materials mentioning features or use of this software
+.\"    must display the following acknowledgement:
+.\"	This product includes software developed by the University of
+.\"	California, Berkeley and its contributors.
+.\" 4. Neither the name of the University nor the names of its contributors
+.\"    may be used to endorse or promote products derived from this software
+.\"    without specific prior written permission.
+.\"
+.\" THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
+.\" ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+.\" IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+.\" ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
+.\" FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+.\" DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+.\" OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+.\" HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+.\" LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+.\" OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+.\" SUCH DAMAGE.
+.\"
+.\"     @(#)doc-nroff	5.6 (Berkeley) 8/5/91
+.\"
+.\" tmac.mdoc-nroff
+.ds aD \fI
+.ds aR \fI
+.ds cM \fB
+.ds dF \fR
+.ds eM \fI
+.ds eR \fR
+.ds eV \fR
+.ds fA \fI
+.ds fD \fB
+.ds fL \fB
+.ds fN \fB
+.ds fP \fP
+.ds fS
+.ds fT \fI
+.ds Hs \fR
+.ds iC \fB
+.ds lI \fR
+.ds lP \fR\|(\fP
+.ds rP \fR\|)\fP
+.ds lp \fR\|(\fP
+.ds rp \fR\|)\fP
+.ds lB \fR\|[\|\fP
+.ds rB \fR\|]\fP
+.ds mL \fB
+.ds nM \fB
+.ds nO \fR
+.ds pA \fI
+.ds Pu {\ .\ ,\ ;\ :\ (\ )\ [\ ]}
+.ds rA \fR
+.ds rT \fI
+.ds sH \fB
+.ds sP
+.ds sY \fB
+.ds sX \fI
+.ds tF \fR
+.ds tN
+.ds vA \fI
+.ds Vs \fR
+.ds vT \fB
+.ds xR \fR
+.nr sI .5i
+.nr Ti .5i
+.nr cR 1
+.nr Pp 1v
+.ds lS \0\0
+.nr lS \w'\0\0'u
+.nr dI 6n
+.de pL
+.ie \\n(cR .nr Hm 0
+.el .nr Hm .5i
+.nr Fm .5i
+.nr ll 78n
+.ll 78n
+.nr lt 78n
+.lt 78n
+.nr po 0i
+.po 0i
+.nr dV 1v
+.ad l
+.na
+..
+.ds <= \&<\&=
+.ds >= \&>\&=
+.ds Rq ''
+.ds Lq ``
+.ds ua ^
+.ds aa \'
+.ds ga \`
+.ds sL `
+.ds sR '
+.ds q \&"
+.ds Pi pi
+.ds Ne !=
+.ds Le <=
+.ds Ge >=
+.ds Lt <
+.ds Gt >
+.ds Pm +-
+.ds If infinity
+.ds Na \fINaN\fP
+.ds Ba \fR\&|\fP
+
+.de hK
+.nr % 1
+.ds hT \\*(dT
+.if !"\\*(cH"Null" \{\
+.	ie !"\\*(gP"Null" .as hT \|(\|\\*(cH\\*(gP\|)
+.	el .as hT \\|(\\|\\*(cH\\|)
+.\}
+.if "\\*(cH"Null" .if !"\\*(gP"Null" .as hT \&\|(\|\\*(gP\|)
+.ie \\n(cR \{\
+.	hM
+.	wh -1v fM
+.\}
+.el \{\
+.	wh 0 hM
+.	wh -1.167i fM
+.\}
+.if \\n(nl==0:\\n(nl==-1 'bp
+.em lM
+..
+.nr fW \w'0'
+.de sW
+.nr sW \w\\$1
+.ie \\n(sW>=\\n(fW \{\
+.       ie \\n(sW%\\n(fW .nr sW (\\n(sW/\\n(fW)+1
+.       el .nr sW \\n(sW/\\n(fW
+.\}
+.el .nr sW 0
+..
+.de aW
+.nr sW \w\\*(A\\$1
+.ie \\n(sW>=\\n(fW \{\
+.       ie \\n(sW%\\n(fW .nr sW (\\n(sW/\\n(fW)+1
+.       el .nr sW \\n(sW/\\n(fW
+.\}
+.el .nr sW 0
+..
+.de Ql
+.if \\n(aC==0  \{\
+.	ds mN Ql
+.	ds A1 \\$1
+.	ds A2 \\$2
+.	ds A3 \\$3
+.	ds A4 \\$4
+.	ds A5 \\$5
+.	ds A6 \\$6
+.	ds A7 \\$7
+.	ds A8 \\$8
+.	ds A9 \\$9
+.	nr fV \\n(.$
+. 	fV
+.\}
+.ds qL \&\\*(sL
+.ds qR \&\\*(sR
+.En \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.de Sh
+.nr nS 0
+.nr sE 0
+.nr iS 0
+.ie "\\$1"NAME" \{\
+.       hK
+'       in 0
+.\}
+.el \{\
+.	ie "\\$1"̾" \{\
+.      		hK
+'       	in 0
+.	\}
+.	el \{\
+.		ie "\\$1"̾" \{\
+.       		hK
+'       		in 0
+.		\}
+.		el \{\
+.       		nr nS 0
+.       		nr nA 0
+.       		nr nF 0
+.       		nr nT 0
+.       		nr nY 0
+.       		nr aN 0
+.       		nr oT 0
+.       		if "\\$1"SEE" .nr nA 1
+.       		if "\\$1"Ϣ" .nr nA 1
+.       		if "\\$1"FILES" .nr nF 1
+.       		if "\\$1"ե" .nr nF 1
+.       		if "\\$1"Ϣե" .nr nF 1
+.       		if "\\$1"STANDARDS" .nr nT 1
+.       		if "\\$1"" .nr nT 1
+.       		if "\\$1"" .nr nT 1
+.       		if "\\$1"SYNOPSIS" .nr nS 1
+.       		if "\\$1"" .nr nS 1
+.       		if "\\$1"DESCRIPTION" \{\
+.               		rr fB
+.               		rr Fb
+.               		ds Fb
+.               		nr fY 0
+.               		nr fZ 0
+.      			\}
+.       		if "\\$1"" \{\
+.               		rr fB
+.               		rr Fb
+.               		ds Fb
+.               		nr fY 0
+.               		nr fZ 0
+.      			 \}
+.       		if "\\$1"" \{\
+.               		rr fB
+.               		rr Fb
+.               		ds Fb
+.               		nr fY 0
+.               		nr fZ 0
+.       		\}
+.			if "\\$1"AUTHORS" .nr nY 1
+.			if "\\$1"" .nr nY 1
+.			if "\\$1"" .nr nY 1
+.     			in 0
+.		\}
+.	\}
+.\}
+.pL
+'sp
+.ns
+.ta .5i 1i 1.5i 2i 2.5i 3i 3.5i 4i 4.5i 5i 5.5i 6i 6.5i
+.if !\\n(cR .ne 3
+'fi
+\&\\*(sH\\$1 \|\\$2 \|\\$3 \|\\$4 \|\\$5 \|\\$6 \|\\$7 \|\\$8 \|\\$9
+\&\fP\s0\&
+.in \\n(.iu+\\n(Tiu
+.if "\\$1"SEE" .nr sE 1
+.ns
+..
--- groff-1.18.orig/tmac/docj.tmac
+++ groff-1.18/tmac/docj.tmac
@@ -0,0 +1,3427 @@
+.\" Copyright (c) 1991 The Regents of the University of California.
+.\" All rights reserved.
+.\"
+.\" Redistribution and use in source and binary forms, with or without
+.\" modification, are permitted provided that the following conditions
+.\" are met:
+.\" 1. Redistributions of source code must retain the above copyright
+.\"    notice, this list of conditions and the following disclaimer.
+.\" 2. Redistributions in binary form must reproduce the above copyright
+.\"    notice, this list of conditions and the following disclaimer in the
+.\"    documentation and/or other materials provided with the distribution.
+.\" 3. All advertising materials mentioning features or use of this software
+.\"    must display the following acknowledgement:
+.\"	This product includes software developed by the University of
+.\"	California, Berkeley and its contributors.
+.\" 4. Neither the name of the University nor the names of its contributors
+.\"    may be used to endorse or promote products derived from this software
+.\"    without specific prior written permission.
+.\"
+.\" THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
+.\" ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+.\" IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+.\" ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
+.\" FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+.\" DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+.\" OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+.\" HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+.\" LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+.\" OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+.\" SUCH DAMAGE.
+.\"
+.\"     @(#)doc	5.8 (Berkeley) 8/5/91
+.\" Modified by jjc@jclark.com as follows: the doc-* files are assumed to be
+.\" installed as mdoc/doc-* rather than tmac.doc-* (the filename
+.\" `tmac.doc-common' would be too long); when using groff, the doc-* files
+.\" are loaded using the `mso' request.
+.\"   
+.\" .mdoc-parse - attempt to parse troff request arguments
+.\"     %beginstrip%
+.if \n(.g \{\
+.cp 0
+.ftr C CR
+.\}
+.if \n(.g .ig
+.de sO
+.so /usr/share/tmac/\\$1
+..
+.if !\n(.g .ig
+.de sO
+.mso mdoc/\\$1
+..
+.if t \{\
+.       sO docj-ditroff
+.\}
+.if n \{\
+.       sO docj-nroff
+.\}
+.sO doc-common
+.sO doc-syms
+.\" NS Db macro - start/stop DEBUG MODE
+.\" NS Db register DEBUG MODE
+.\" NS iN register DEBUG MODE (inline if 1, to stderr if 0 (default))
+.nr Db 0
+.de Db
+.ie \\n(.$==0 \{\
+.	ie \\n(Db==0 \{\
+.tm DEBUGGING ON
+.		nr Db 1
+.	\}
+.	el \{\
+.tm DEBUGGING OFF
+.		nr Db 0
+.	\}
+.\}
+.el \{\
+.	if "\\$1"on" \{\
+.tm DEBUGGING ON
+.		nr Db 1
+.	\}
+.	if "\\$1"off" \{\
+.tm DEBUGGING OFF
+.		nr Db 0
+.	\}
+.\}
+..
+.\" NS aV macro - parse argument vector (recursive) (.aV arg ... )
+.\" NS fV macro - parse argument vector (recursive) (.fV)
+.\" NS aC register argument counter (aV/fV)
+.\" NS fV register argument counter (must set to \\n(.$ prior to reuqest) (fV)
+.\" NS A[0-9] argument vector (aV/fV)
+.\" NS C[0-9] reg. arg type(1=macro, 2=arg, 3=punct-suf, 4=punct-pre) (aV/fV)
+.\" NS S[0-9] space vector (sV)
+.\" NS aP register argument pointer (aV)
+.\" NS yU local string used for debugging
+.\" NS iI local register (indent for inline debug mode)
+.\" NS mN name of calling request (set in each user requestable macro)
+.de aV
+.nr aC \\n(aC+1
+.ie "\\$1"|" \{\
+.	if "\\*(mN"Op" .ds A\\n(aC \fR\\$1\fP
+.	if "\\*(mN"Ar" .ds A\\n(aC \fR\\$1\fP
+.	if "\\*(mN"Fl" .ds A\\n(aC \fR\\$1\fP
+.	if "\\*(mN"Cm" .ds A\\n(aC \fR\\$1\fP
+.	if "\\*(mN"It" .ds A\\n(aC \fR\\$1\fP
+.\}
+.el .ds A\\n(aC \\$1
+.aU \\n(aC
+.nr C\\n(aC \\n(aT
+.s\\n(aT
+.if \\n(Db \{\
+.	if \\n(aT==1 .ds yU Executable
+.	if \\n(aT==2 .ds yU String
+.	if \\n(aT==3 .ds yU Closing Punctuation or suffix
+.	if \\n(aT==4 .ds yU Opening Punctuation or prefix
+.	if \\n(iN==1 \{\
+.		br
+.		nr iI \\n(.iu
+.		in -\\n(iIu
+.		if \\n(aC==1 \{\
+\&\fBDEBUG(argv) MACRO:\fP `.\\*(mN' \fBLine #:\fP \\n(.c
+.		\}
+\&\t\fBArgc:\fP \\n(aC  \fBArgv:\fP `\\*(A\\n(aC'  \fBLength:\fP \\n(sW
+\&\t\fBSpace:\fP `\\*(S\\n(aC'  \fBClass:\fP \\*(yU
+.	\}
+.	if \\n(iN==0 \{\
+.		if \\n(aC==1 \{\
+.			tm DEBUG(argv) MACRO: `.\\*(mN'  Line #: \\n(.c
+.		\}
+.		tm \tArgc: \\n(aC  Argv: `\\*(A\\n(aC'  Length: \\n(sW
+.		tm \tSpace: `\\*(S\\n(aC'  Class: \\*(yU
+.	\}
+.\}
+.ie \\n(.$==1 \{\
+.	nr aP 0
+.	ie \\n(dZ==1 \{\
+.		if \\n(oM>1 .as b1 \\*(S0
+.	\}
+.	el \{\
+.		if \\n(oM>0 \{\
+.			if \\n(fC==0 .as b1 \\*(S0
+.		\}
+.	\}
+.	ds S0 \\*(S\\n(aC
+.	if \\n(Db \{\
+.		if \\n(iN==1 \{\
+\&MACRO REQUEST: \t.\\*(mN \\*(A1 \\*(A2 \\*(A3 \\*(A4 \\*(A5 \\*(A6 \\*(A7 \\*(A8 \\*(A9
+.			br
+.			in \\n(iIu
+.		\}
+.		if \\n(iN==0 \{\
+.tm \tMACRO REQUEST: .\\*(mN \\*(A1 \\*(A2 \\*(A3 \\*(A4 \\*(A5 \\*(A6 \\*(A7 \\*(A8 \\*(A9
+.		\}
+.	\}
+.\}
+.el .aV \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.de fV
+.nr aC \\n(aC+1
+.if "\\*(A\\n(aC"|" \{\
+.	if "\\*(mN"Op" .ds A\\n(aC \fR\\*(A\\n(aC\fP
+.	if "\\*(mN"Ar" .ds A\\n(aC \fR\\*(A\\n(aC\fP
+.	if "\\*(mN"Fl" .ds A\\n(aC \fR\&\\*(A\\n(aC\fP
+.	if "\\*(mN"Cm" .ds A\\n(aC \fR\\*(A\\n(aC\fP
+.	if "\\*(mN"It" .ds A\\n(aC \fR\\*(A\\n(aC\fP
+.\}
+.aU \\n(aC
+.nr C\\n(aC \\n(aT
+.s\\n(aT
+.if \\n(Db \{\
+.	if \\n(aT==1 .ds yU Executable
+.	if \\n(aT==2 .ds yU String
+.	if \\n(aT==3 .ds yU Closing Punctuation or suffix
+.	if \\n(aT==4 .ds yU Opening Punctuation or prefix
+.	if \\n(iN==1 \{\
+.		br
+.		nr iI \\n(.iu
+.		in -\\n(iIu
+.		if \\n(aC==1 \{\
+\&\fBDEBUG(fargv) MACRO:\fP `.\\*(mN'  \fBLine #:\fP \\n(.c
+.		\}
+\&\t\fBArgc:\fP \\n(aC  \fBArgv:\fP `\\*(A\\n(aC'  \fBLength:\fP \\n(sW
+\&\t\fBSpace:\fP `\\*(S\\n(aC'  \fBClass:\fP \\*(yU
+.	\}
+.	if \\n(iN==0 \{\
+.		if \\n(aC==1 \{\
+.			tm DEBUG(fargv) MACRO: `.\\*(mN'  Line #: \\n(.c
+.		\}
+.		tm \tArgc: \\n(aC  Argv: `\\*(A\\n(aC'  Length: \\n(sW
+.		tm \tSpace: `\\*(S\\n(aC'  Class: \\*(yU
+.	\}
+.\}
+.ie \\n(fV==1 \{\
+.	nr aP 0
+.	ie \\n(dZ==1 \{\
+.		if \\n(oM>1 .as b1 \\*(S0
+.	\}
+.	el \{\
+.		if \\n(oM>0 \{\
+.			if \\n(fC==0 .as b1 \\*(S0
+.		\}
+.	\}
+.	ds S0 \\*(S\\n(aC
+.	nr fV 0
+.	if \\n(Db \{\
+.		ie \\n(iN \{\
+\&\tMACRO REQUEST: .\\*(mN \\*(A1 \\*(A2 \\*(A3 \\*(A4 \\*(A5 \\*(A6 \\*(A7 \\*(A8 \\*(A9
+.			br
+.			in \\n(iIu
+.		\}
+.		el \{\
+.tm \tMACRO REQUEST: .\\*(mN \\*(A1 \\*(A2 \\*(A3 \\*(A4 \\*(A5 \\*(A6 \\*(A7 \\*(A8 \\*(A9
+.		\}
+.	\}
+.\}
+.el \{\
+.	nr fV \\n(fV-1
+.	fV
+.\}
+..
+.\" NS aX macro - stuff saved strings into `b1' (used by -diag list)
+.de aX
+.nr aP \\n(aP+1
+.as b1 \&\\*(A\\n(aP
+.ie \\n(fV==1 \{\
+.	nr aP 0
+.	nr fV 0
+.\}
+.el \{\
+.	as b1 \&\\*(sV
+.	nr fV \\n(fV-1
+.	aX
+.\}
+..
+.\" NS aI macro - append arg to arg vector: .aI [arg] [type] (used by .En only)
+.de aI
+.ie \\n(aC<9 \{\
+.	nr aC \\n(aC+1
+.	ds A\\n(aC \\$1
+.	nr C\\n(aC \\$2
+.	s\\$2
+.	ds xV S\\n(aC
+.\}
+.el \{\
+.	tm Usage: Too many arguments (maximum of 8 accepted) (#\\n(.c)
+.	tm \\*(A1 \\*(A2 \\*(A3 \\*(A4 \\*(A5 \\*(A6 \\*(A7 \\*(A8 \\*(A9
+.\}
+..
+.\"
+.\" NS aZ macro - print buffer (pB) and clean up arg vectors (aY)
+.de aZ
+.pB
+.aY
+..
+.\" NS aY macro - clean up arg vector
+.de aY
+.rm C0 C1 C2 C3 C4 C5 C6 C7 C8 C9
+.rm A0 A1 A2 A3 A4 A5 A6 A7 A8 A9
+.rm S1 S2 S3 S4 S5 S6 S7 S8 S9
+.nr aC 0
+.nr aP 0
+..
+.\" NS pB macro - test for end of vector (eol) (print b1 buffer or divert)
+.de pB
+.ie \\n(dZ==1 \{\
+.	if \\n(oM==1 \{\&\\*(b1
+.		rm S0
+.		ds b1
+.	\}
+.	if \\n(oM==0 \{\
+.		x2
+.	\}
+.\}
+.el \{\
+.	ie \\n(oM==0 \{\&\\*(b1
+.		rm S0
+.		ds b1
+.	\}
+.	el \{\
+.		if ((\\n(sM==1)&(\\n(tP==0)) \{\
+.			x1
+.		\}
+.	\}
+.\}
+.hy
+..
+.\" NS x1 macro - save buffer and divert if tP flag set
+.\" NS eB diversion string
+.\" NS b2 string save of buffer
+.\" NS lK register count of lines read from input file
+.de x1
+.nr dZ \\n(dZ+1
+.ds b2 \\*(b1
+.ds b1
+.nr lK \\n(.c
+.ev 2
+.fi
+.di eB
+..
+.\"
+.\" NS x2 macro - end diversion and print
+.\" NS b0 string local temporary
+.de x2
+.br
+.di
+.ev
+.ie (\\n(.c-\\n(lK>1) \{\
+.	ds b0 \&\\*(eB\\
+.	ds b1 \\*(b2\\*(b0\\*(b1
+.\}
+.el .ds b1 \\*(b2\\*(b1
+\&\\*(b1
+.rm eB b2 b0 b1
+.nr dZ \\n(dZ-1
+..
+.\" NS Fl macro - flags (appends - and prints flags)
+.\" NS cF register save current font
+.\" NS cZ register save current font size
+.de Fl
+.as b1 \&\\*(fL
+.if \\n(aC==0 \{\
+.	ie \\n(.$==0 \{\
+.		as b1 \&\|\-\|\fP\s0
+.		pB
+.	\}
+.	el \{\
+.		ds mN Fl
+.		aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.	\}
+.\}
+.if \\n(aC>0 \{\
+.	ie (\\n(aC-\\n(aP)==0 \{\
+.		as b1 \&\|\-\fP\s0
+.		aZ
+.	\}
+.	el \{\
+.		nr aP \\n(aP+1
+.		ie \\n(C\\n(aP==1 \{\
+.			as b1 \&\|\-\fP\s0
+.			\\*(A\\n(aP
+.		\}
+.		el \{\
+.			nr cF \\n(.f
+.			nr cZ \\n(.s
+.			if \\n(C\\n(aP==3 \{\
+.				as b1 \&\|\-\|
+.			\}
+.			fR
+.		\}
+.	\}
+.\}
+..
+.\"
+.\" NS fR macro - Fl flag recursion routine (special handling)
+.\" NS jM local register
+.\" NS jN local register
+.\"
+.de fR
+.hy 0
+.nr jM \\n(C\\n(aP
+.ie \\n(jM==1 \{\
+.	as b1 \&\fP\s0
+.	\\*(A\\n(aP
+.\}
+.el \{\
+.	nr jN \\n(aP
+.	ie \\n(jM==2 \{\
+.		ie !"\\*(A\\n(aP"\\*(Ba" \{\
+.			ie !"\\*(A\\n(aP"\fR|\fP" \{\
+.		               ie "\\*(A\\n(aP"-" .as b1 \&\|\-\^\-\|
+.		               el .as b1 \&\|\-\\*(A\\n(aP
+.			\}
+.			el .as b1 \&\\*(A\\n(aP
+.		\}
+.		el .as b1 \&\\*(A\\n(aP
+.	\}
+.	el .as b1 \&\f\\n(cF\s\\n(cZ\\*(A\\n(aP\fP\s0
+.	ie \\n(aC==\\n(aP \{\
+.		if \\n(jM==4 .as b1 \&\|\-
+.		as b1 \&\fP\s0
+.		aZ
+.	\}
+.	el \{\
+.		nr aP \\n(aP+1
+.		ie ((\\n(C\\n(aP==3)&(\\n(C\\n(jN==4)) .as b1 \&\|\-
+.		el .as b1 \&\\*(S\\n(jN
+.		fR \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.	\}
+.\}
+.rr jM jN
+..
+.\"
+.\" NS nR macro - general name recursion routine
+.\" NS jM local register
+.\" NS jN local register
+.de nR
+.hy 0
+.nr jM \\n(C\\n(aP
+.ie \\n(jM==1 \{\
+.	as b1 \&\f\\n(cF\s\\n(cZ
+.	\\*(A\\n(aP
+.\}
+.el \{\
+.	nr jN \\n(aP
+.	ie \\n(jM==2 .as b1 \&\\*(A\\n(aP
+.	el .as b1 \&\f\\n(cF\s\\n(cZ\\*(A\\n(aP\fP\s0
+.	ie \\n(aC==\\n(aP \{\
+.		as b1 \&\f\\n(cF\s\\n(cZ
+.		aZ
+.	\}
+.	el \{\
+.		nr aP \\n(aP+1
+.		as b1 \&\\*(S\\n(jN
+.		nR
+.	\}
+.\}
+.rr jM jN
+..
+.\" NS Ar macro - command line `argument' macro
+.\"
+.de Ar
+.as b1 \\*(aR
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 \{\
+.		as b1 file\ ...\fP\s0
+.		pB
+.	\}
+.	el \{\
+.		ds mN Ar
+.		aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.	\}
+.\}
+.if \\n(aC>0 \{\
+.	ie (\\n(aC-\\n(aP)==0 \{\
+.		as b1 \&file\ ...\fP\s0
+.		aZ
+.	\}
+.	el \{\
+.		nr aP \\n(aP+1
+.		ie \\n(C\\n(aP==1 \{\
+.			as b1 \&file\ ...\fP\s0
+.			\\*(A\\n(aP
+.               \}
+.               el \{\
+.                       nr cF \\n(.f
+.			nr cZ \\n(.s
+.			if \\n(C\\n(aP==3 \{\
+.				as b1 \&file\ ...
+.			\}
+.                       nR
+.		\}
+.       \}
+.\}
+..
+.\" NS Ad macro - Addresses
+.de Ad
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .Ad address ... \\*(Pu (#\\n(.c)
+.	el \{\
+.		ds mN Ad
+.		aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	as b1 \\*(aD
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.       nR
+.\}
+..
+.\" NS Cd macro - Config declaration (for section 4 SYNOPSIS) (not callable)
+.\" needs work - not very translatable
+.de Cd
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .Cd Configuration file declaration (#\\n(.c)
+. 	el \{\
+.		ds mN Cd
+.               ds A1 \\$1
+.               ds A2 \\$2
+.               ds A3 \\$3
+.               ds A4 \\$4
+.               ds A5 \\$5
+.               ds A6 \\$6
+.               ds A7 \\$7
+.               ds A8 \\$8
+.               ds A9 \\$9
+. 		nr fV \\n(.$
+. 		fV
+.	\}
+.\}
+.br
+.if \\n(aC>\\n(aP \{\
+.	as b1 \\*(nM
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.	ie \\n(nS \{\
+.		if "\\*(mN"Cd" \{\
+.			rs
+.			ie \\n(nS>1 .br
+.			el \{\
+.				if \\n(iS==0 .nr iS \\n(Dsu
+.			\}
+.			in +\\n(iSu
+.			ti -\\n(iSu
+.			nr nS \\n(nS+1
+.		\}
+.	nR
+.	in -\\n(iSu
+.	\}
+.	el .nR
+.\}
+..
+.\" NS Cm macro - Interactive command modifier (flag)
+.de Cm
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .Cm Interactive command modifier ... \\*(Pu (#\\n(.c)
+.	el \{\
+.		ds mN Cm
+.               ds A1 \\$1
+.               ds A2 \\$2
+.               ds A3 \\$3
+.               ds A4 \\$4
+.               ds A5 \\$5
+.               ds A6 \\$6
+.               ds A7 \\$7
+.               ds A8 \\$8
+.               ds A9 \\$9
+.		nr fV \\n(.$
+.		fV
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	as b1 \\*(cM
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.       nR
+.\}
+..
+.\" NS Dv macro - define variable
+.de Dv
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .Dv define_variable ... \\*(Pu (#\\n(.c)
+.	el \{\
+.		ds mN Dv
+.		aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	as b1 \\*(eR
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.       nR
+.\}
+..
+.\" NS Em macro - Emphasis
+.de Em
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 \{\
+.		tm Usage: .Em text ... \\*(Pu (#\\n(.c)
+.	\}
+.	el \{\
+.		ds mN Em
+.               ds A1 \\$1
+.               ds A2 \\$2
+.               ds A3 \\$3
+.               ds A4 \\$4
+.               ds A5 \\$5
+.               ds A6 \\$6
+.               ds A7 \\$7
+.               ds A8 \\$8
+.               ds A9 \\$9
+.		nr fV \\n(.$
+.		fV
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	as b1 \\*(eM
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.       nR
+.\}
+..
+.\" NS Er macro - Errnotype
+.de Er
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .Er ERRNOTYPE ... \\*(Pu (#\\n(.c)
+.	el \{\
+.		ds mN Er
+.		aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	as b1 \\*(eR
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.       nR
+.\}
+..
+.\" NS Ev macro - Environment variable
+.de Ev
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .Ev ENVIRONMENT_VARIABLE ... \\*(Pu (#\\n(.c)
+.	el \{\
+.		ds mN Ev
+.		aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	as b1 \\*(eV
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.       nR
+.\}
+..
+.\" NS Fd macro - function declaration - not callable (& no err check)
+.\" NS fD register subroutine test (in synopsis only)
+.\" NS fY register subroutine count (in synopsis only) (fortran only)
+.\" NS fZ register also subroutine count (in synopsis only)
+.de Fd
+.ds mN Fd
+.if \\n(nS>0 \{\
+.\"	if a variable type was the last thing given, want vertical space
+.	if \\n(fX>0 \{\
+.		Pp
+.		nr fX 0
+.	\}
+.\"	if a subroutine was the last thing given, want vertical space
+.	if \\n(fZ>0 \{\
+.		ie \\n(fD==0 \{\
+.			Pp
+.			rs
+.		\}
+.		el .br
+.	\}
+.	nr fD \\n(fD+1
+.\}
+.nr cF \\n(.f
+.nr cZ \\n(.s
+\&\\*(fD\\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.br
+.ft \\n(cF
+.fs \\n(cZ
+..
+.\" NS Fr macro - function return value - not callable (at the moment)
+.de Fr
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .Fr Function_return_value... \\*(Pu (#\\n(.c)
+.	el \{\
+.		ds mN Fr
+.		aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	as b1 \\*(aR
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.       nR
+.\}
+..
+.\" NS Ic macro - Interactive command
+.de Ic
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .Ic Interactive command ... \\*(Pu (#\\n(.c)
+.	el \{\
+.		ds mN Ic
+.		aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	as b1 \\*(iC
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.       nR
+.\}
+..
+.\" NS Li macro - literals
+.de Li
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage .Li argument ... \\*(Pu (#\\n(.c)
+.       el \{\
+.		ds mN Li
+.               ds A1 \\$1
+.               ds A2 \\$2
+.               ds A3 \\$3
+.               ds A4 \\$4
+.               ds A5 \\$5
+.               ds A6 \\$6
+.               ds A7 \\$7
+.               ds A8 \\$8
+.               ds A9 \\$9
+.               nr fV \\n(.$
+.               fV
+.       \}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	as b1 \\*(lI
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.       nR
+.\}
+..
+.\" NS Or macro - Pipe symbol (OR)
+.de Or
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .Or ... \\*(Pu (#\\n(.c)
+.	el \{\
+.		ds mN Or
+.		aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	as b1 \\*(iC
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.       nR
+.\}
+..
+.\" NS Ms macro - Math symbol
+.de Ms
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .Ms Math symbol ... \\*(Pu (#\\n(.c)
+.	el \{\
+.		ds mN Ms
+.		aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	as b1 \\*(sY
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.       nR
+.\}
+..
+.\" NS Nm macro - Name of command or page topic
+.\" NS n1 string - save first invocation of .Nm
+.\" NS iS register - indent second command line in a synopsis
+.de Nm
+.if \\n(aC==0 \{\
+.	ie \\n(.$==0 \{\
+.		ie "\\*(n1"" .tm Usage: .Nm Name(s) ... \\*(Pu (#\\n(.c)
+.		el \&\\*(nM\\*(n1\fP\s0
+.	\}
+.	el \{\
+.		ds mN Nm
+.               ds A1 \\$1
+.               ds A2 \\$2
+.               ds A3 \\$3
+.               ds A4 \\$4
+.               ds A5 \\$5
+.               ds A6 \\$6
+.               ds A7 \\$7
+.               ds A8 \\$8
+.               ds A9 \\$9
+.               nr fV \\n(.$
+.               fV
+.       \}
+.\}
+.if \\n(aC>0 \{\
+.	ie \\n(aC==\\n(aP \{\
+.		as b1 \&\\*(nM\\*(n1\fP\s0
+.		aZ
+.	\}
+.	el \{\
+.		as b1 \\*(nM
+.		nr aP \\n(aP+1
+.		ie \\n(C\\n(aP==1 \{\
+.			as b1 \&\\*(n1\fP\s0
+.			\\*(A\\n(aP
+.		\}
+.		el \{\
+.			nr cF \\n(.f
+.			nr cZ \\n(.s
+.			if \\n(nS \{\
+.				if "\\*(mN"Nm" \{\
+.					rs
+.					in -\\n(iSu
+.					ie \\n(nS>1 .br
+.					el \{\
+.						if \\n(iS==0 \{\
+.							sw \\$1
+.					nr iS ((\\n(sWu+1)*\\n(fW)u
+.						\}
+.					\}
+.					in +\\n(iSu
+.					ti -\\n(iSu
+.					nr nS \\n(nS+1
+.				\}
+.			\}
+.			if "\\*(n1"" .ds n1 \\*(A\\n(aP
+.			nR
+.		\}
+.	\}
+.\}
+..
+.\" NS Pa macro - Pathname
+.de Pa
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 \&\\*(pA~\fP\s0
+.	el \{\
+.		ds mN Pa
+.		aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	as b1 \\*(pA
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.       nR
+.\}
+..
+.\" NS Sy macro - Symbolics
+.de Sy
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .Sy symbolic_text ... \\*(Pu (#\\n(.c)
+. 	el \{\
+.		ds mN Sy
+.               ds A1 \\$1
+.               ds A2 \\$2
+.               ds A3 \\$3
+.               ds A4 \\$4
+.               ds A5 \\$5
+.               ds A6 \\$6
+.               ds A7 \\$7
+.               ds A8 \\$8
+.               ds A9 \\$9
+. 		nr fV \\n(.$
+. 		fV
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	as b1 \\*(sY
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.       nR
+.\}
+..
+.\" NS Tn macro - Trade Name Macro
+.de Tn
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .Tn Trade_name(s) ... \\*(Pu (#\\n(.c)
+.	el \{\
+.		ds mN Tn
+.		aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	as b1 \\*(tN\\*(tF
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.       nR
+.\}
+..
+.\" NS nN macro - Trade Name Macro for inside of reference
+.de nN
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .Tn Trade_name(s) ... \\*(Pu (#\\n(.c)
+.	el \{\
+.		ds mN Tn
+.		aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	as b1 \\*(tN
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.       rR
+.\}
+..
+.\" NS Va macro - variable name macro
+.de Va
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .Va variable_name(s) ... \\*(Pu (#\\n(.c)
+.	el \{\
+.		ds mN Va
+.		aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	as b1 \\*(vA
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.       nR
+.\}
+..
+.\"
+.\" NS No macro - Normal text macro (default text style if mess up)
+.de No
+.as b1 \\*(nO
+.if \\n(aC==0 \{\
+.	ie \\n(.$==0 .tm Usage: .No must be called with arguments (#\\n(.c)
+.	el \{\
+.		ds mN No
+.		aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	nr aP \\n(aP+1
+.       ie \\n(C\\n(aP==1 \{\
+.		\\*(A\\n(aP
+.       \}
+.       el \{\
+.		nr cF \\n(.f
+.		nr cZ \\n(.s
+.		nR
+.       \}
+.\}
+..
+.\"------------------------------------------------------------------------
+.\" NS Op macro - Option Expression
+.de Op
+.if \\n(aC==0 \{\
+.	ds mN Op
+.\}
+.\" .ds qL \&\\*(lO
+.\" .ds qR \&\\*(rO
+.ds qL \&\\*(lB
+.ds qR \&\\*(rB
+.En \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8
+..
+.\" NS Aq macro - Enclose string in angle brackets
+.de Aq
+.if \\n(aC==0 .ds mN Aq
+.ds qL \&<
+.ds qR \&>
+.En \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\" NS Bq macro - Enclose string in square brackets
+.de Bq
+.if \\n(aC==0 .ds mN Bq
+.ds qL \&\\*(lB
+.ds qR \&\\*(rB
+.En \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\" NS Dq macro - Enclose string in double quotes
+.de Dq
+.if \\n(aC==0 .ds mN Dq
+.ds qL \&\\*(Lq
+.ds qR \&\\*(Rq
+.En \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\" NS Eq macro - Enclose string in double quotes
+.de Eq
+.if \\n(aC==0 .ds mN Eq
+.ds qL \\$1
+.ds qR \\$2
+.En \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\" NS Pq macro - Enclose string in parenthesis
+.de Pq
+.if \\n(aC==0 .ds mN Pq
+.ds qL \&\\*(lP
+.ds qR \&\\*(rP
+.En \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\" NS Ql macro - Quoted literal is in file mdocj-[dit|n|g]roff (too large
+.\" an if-else to carry along recursively for `if n ...')
+.\"
+.\" NS Sq macro - Enclose string in single quotes
+.de Qq
+.if \\n(aC==0 .ds mN Qq
+.ds qL \&\\*q
+.ds qR \&\\*q
+.En \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\" NS Sq macro - Enclose string in single quotes
+.de Sq
+.if \\n(aC==0 .ds mN Sq
+.ds qL \&\\*(sL
+.ds qR \&\\*(sR
+.En \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\"
+.\" NS Es macro - Set up strings for .En call
+.de Es
+.if \\n(aC==0 \{\
+.	ie \\n(.$>2 .aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.	el \{\
+.		ds qL \\$1
+.		ds qR \\$2
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	nr aP \\n(aP+1
+.	ds qL \\*(A\\n(aP
+.	nr aP \\n(aP+1
+.	ds qR \\*(A\\n(aP
+.	ie \\n(aC>\\n(aP .c\\n(C\\n(aP
+.	el .aZ
+.\}
+..
+.\" .tm En beg arg(A[\\n(aP])==\\*(A\\n(aP;
+.\" .tm En oM==\\n(oM; dZ==\\n(dZ; Xt==\\n(Xt; aC==\\n(aC
+.\" NS En macro - Enclose string with given args (eg [ and ] etc)
+.\" NS qL string variable set by calling macro
+.\" NS qR string variable set by calling macro
+.\" NS aJ register (for vR)
+.de En
+.ie \\n(aC==0 \{\
+.	ie \\n(.$==0 \{\
+.		as b1 \&\\*(qL\\*(qR
+.		pB
+.	\}
+.	el \{\
+.\".		as mN (En)
+.		aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.		as b1 \&\\*(qL
+.	\}
+.\}
+.el \{\
+.	as b1 \&\\*(qL
+.\}
+.if \\n(aC>0 \{\
+.	ie (\\n(aC-\\n(aP)==0 \{\
+.		as b1 \&\\*(qR
+.		aZ
+.	\}
+.	el \{\
+.		ie \\n(C\\n(aC==3 \{\
+.			nr aJ \\n(aC-1
+.			vR
+.			nr aJ \\n(aJ+1
+.			ds A\\n(aJ \&\\*(qR\\*(A\\n(aJ
+.			nr aJ 0
+.		\}
+.		el .aI \&\\*(qR 3
+.		nr aP \\n(aP+1
+.		if \\n(C\\n(aP==1 .\\*(A\\n(aP
+.		if \\n(C\\n(aP>1 \{\
+.			nr aP \\n(aP-1
+.			No
+.		\}
+.	\}
+.\}
+..
+.\" NS vR macro - vector routine (for En, trace backwards past trail punct)
+.de vR
+.if \\n(C\\n(aJ==3 \{\
+.	nr aJ \\n(aJ-1
+.	vR
+.\}
+..
+.\"------------------------------------------------------------------------
+.\" NS Ao macro - Angle open
+.de Ao
+.if \\n(aC==0 .ds mN Ao
+.ds qL \&<
+.eO \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\" NS Ac macro - Angle close
+.de Ac
+.if \\n(aC==0 .ds mN Ac
+.ds qR \&>
+.eC \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\" NS Bo macro - Bracket open
+.de Bo
+.if \\n(aC==0 .ds mN Bo
+.ds qL \&[
+.eO \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\" NS Bc macro - Bracket close
+.de Bc
+.if \\n(aC==0 .ds mN Bc
+.ds qR \&]
+.eC \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\" NS Do macro - Double Quote open
+.de Do
+.if \\n(aC==0 .ds mN Do
+.ds qL \&\\*(Lq
+.eO \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\" NS Dc macro - Double Quote close
+.de Dc
+.if \\n(aC==0 .ds mN Dc
+.ds qR \&\\*(Rq
+.eC \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\" NS Eo macro - Enclose open
+.de Eo
+.if \\n(aC==0 .ds mN Eo
+.ds qL \\$1
+.eO \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\" NS Ec macro - Enclose close
+.de Ec
+.if \\n(aC==0 .ds mN Ec
+.ds qR \\$1
+.eC \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\" NS Oo macro - Option open
+.de Oo
+.if \\n(aC==0 .ds mN Oo
+.ds qL \&[
+.eO \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\" NS Oc macro - Option close
+.de Oc
+.if \\n(aC==0 .ds mN Oc
+.ds qR \&]
+.eC \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\" NS Po macro - Parenthesis open
+.de Po
+.if \\n(aC==0 .ds mN Po
+.ds qL \&(
+.eO \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\" NS Pc macro - Parenthesis close
+.de Pc
+.if \\n(aC==0 .ds mN Pc
+.ds qR \&)
+.eC \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\" NS Qo macro - Straight Double Quote open
+.de Qo
+.if \\n(aC==0 .ds mN Qo
+.ds qL \&\\*q
+.eO \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\" NS Qc macro - Straight Double Quote close
+.de Qc
+.if \\n(aC==0 .ds mN Qc
+.ds qR \&\\*q
+.eC \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\" NS So macro - Single Quote open
+.de So
+.if \\n(aC==0 .ds mN So
+.ds qL \&\\*(sL
+.eO \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\" NS Sc macro - Single Quote close
+.de Sc
+.if \\n(aC==0 .ds mN Sc
+.ds qR \&\\*(sR
+.eC \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\" NS Xo macro - Extend open (continue)
+.de Xo
+.if \\n(aC==0 .ds mN Xo
+.\" .nr mN 1
+.ds qL
+.eO \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\" NS Xe macro - Extend close (end)
+.de Xc
+.\" .nr mN 0
+.if \\n(aC==0 .ds mN Xc
+.ds qR
+.eC \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\" NS eO macro - enclose string open
+.\" NS oM register (extension possible)
+.de eO
+.nr oM \\n(oM+1
+.\" .tm eO last arg==A[\\n(aC]==\\*(A\\n(aC; aP==\\n(aP; oM==\\n(oM; dZ==\\n(dZ;
+.ie \\n(aC==0 \{\
+.       ie \\n(.$>0 \{\
+.               aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.		as b1 \\*(qL
+.       \}
+.	el \{\
+.		as b1 \\*(qL
+.		if (\\n(dZ==0)&(\\n(sM==1) \{\
+.			nr dZ \\n(dZ+1
+.			ds b2 \\*(b1
+.			ds b1
+.			nr lK \\n(.c
+.			ev 2
+.			fi
+.			di eB
+.		\}
+.	\}
+.\}
+.el \{\
+.	as b1 \\*(qL
+.\}
+.ie \\n(aC>0 \{\
+.	if \\n(aC>\\n(aP \{\
+.		nr aP \\n(aP+1
+.		ie \\n(C\\n(aP==1 .\\*(A\\n(aP
+.		el  \{\
+.			nr aP \\n(aP-1
+.			No
+.		\}
+.	\}
+.	if \\n(aC==\\n(aP \{\
+.		if \\n(tP==1 \{\
+.\" .tm SETTING Xt!!!
+.			nr Xt 1
+.		\}
+.\".\" .		ds S0
+.\"CHANGED		ds S0 \\*(iV
+.		aY
+.	\}
+.\}
+.el \{\
+.	if \\n(oM>1 .as b1 \\*(sV
+.\}
+..
+.\"
+.\" NS eC macro - enclose string close
+.\" NS aa local register
+.de eC
+.nr oM \\n(oM-1
+.\" tm eC last arg==A[\\n(aC]==\\*(A\\n(aC; aP==\\n(aP; oM==\\n(oM; dZ==\\n(dZ;
+.as b1 \\*(qR
+.if \\n(aC==0 \{\
+.       ie \\n(.$>0 \{\
+.               aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.       \}
+.	el \{\
+.		ie "\\*(xB"" \{\
+.			pB
+.		\}
+.		el \{\
+.			pB
+.\\*(L\\n(lC
+.			nr Xt 0
+.			ds xB
+.		\}
+.	\}
+.\}
+.if \\n(aC>0 \{\
+.	ie \\n(aC==\\n(aP \{\
+.		ie \\n(oM==0 \{\
+.			aZ
+.		\}
+.		el .aY
+.	\}
+.	el \{\
+.		nr aa \\n(aP+1
+.		if \\n(C\\n(aa==2 .as b1 \\*(S\\n(aC
+.\" tm CURRENT arg (aP==\\*(A\\n(aP and ap+1==\\*(A\\n(aa) tP==\\n(tP Xt==\\n(Xt
+.		rr aa
+.		if \\n(tP>0 \{\
+.\" tm UNSETTING Xt==\\n(Xt!!!!
+.			if \\n(Xt>0 .nr Xt \\n(Xt-1
+.\" tm NOW Xt==\\n(Xt!!!!
+.		\}
+.		No
+.	\}
+.\}
+..
+.\"------------------------------------------------------------------------
+.\" NS Pf macro - Prefix (calls .pF)
+.de Pf
+.if \\n(aC==0 .ds mN Pf
+.ds qL \&\\$1
+.pF \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\" NS pF macro - Prefix (for prefixing open quotes, brackets etc)
+.de pF
+.ie \\n(aC==0 \{\
+.	as b1 \&\\*(qL
+.	ie \\n(.$<2 \{\
+.		tm Warning: Missing arguments - prefix .Pf)
+.		pB
+.	\}
+.	el .aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.\}
+.el \{\
+.	ie (\\n(aC-\\n(aP)>1 \{\
+.		nr aP \\n(aP+1
+.		as b1 \&\\*(A\\n(aP
+.	\}
+.	el .tm Warning: .Pf: trailing prefix (#\\n(.c)
+.\}
+.if \\n(aC>0 \{\
+.	ie (\\n(aC-\\n(aP)==0 .aZ
+.	el \{\
+.		nr aP \\n(aP+1
+.		c\\n(C\\n(aP
+.	\}
+.\}
+..
+.\" NS Ns macro - remove space (space remove done by .aV or .fV)
+.de Ns
+.if \\n(aC==0 \{\
+.	ds mN Ns
+.	ie \\n(.$>0 .aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.	el .tm Usage: .Ns must be called with arguments (#\\n(.c)
+.\}
+.No
+..
+.de Ap
+.if \\n(aC==0 \{\
+.	ds mN Ap
+.	tm Usage: Ap "cannot be first request on a line (no .Ap)" (#\\n(.c)
+.\}
+.as b1 \&'
+.No
+..
+.\" NS Hv macro - Hard (unpaddable) Space vector
+.\" NS iV string inter-vector space
+.\" NS sV string inter-argument space
+.de Hv
+.ds iV \\*(sV
+.ds sV \\*(hV
+..
+.\" NS Sv macro - Soft Space vector (troff limitation)
+.de Sv
+.ds sV \\*(iV
+..
+.\" NS Tv macro - Tab Space vector
+.de Tv
+.ds sV \\*(tV
+..
+.\" NS Sm macro - Space mode
+.\" NS sM register - default is one (space mode on)
+.nr sM 1
+.de Sm
+.if \\n(aC==0 \{\
+.	ie \\n(.$==0 .tm "Usage: .Sm [off | on]" (#\\n(.c)
+.	el \{\
+.		ds mN Sm
+.		aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.	\}
+.\}
+.if \\n(aC>0 \{\
+.	nr aP \\n(aP+1
+.	if "\\*(A\\n(aP"on" \{\
+.		ds sV \\*(iV
+.		nr sM 1
+.	\}
+.	if "\\*(A\\n(aP"off" \{\
+.		ds sV
+.		rm S0 S1 S2 S3 S4 S5 S6 S7 S8 S9
+.		nr sM 0
+.	\}
+.	ie \\n(aC>\\n(aP \{\
+.		No
+.	\}
+.	el .aY
+.\}
+..
+.\"------------------------------------------------------------------------
+.\" Size and Argument type macros
+.\" NS aT macro - argument type
+.\" NS aU macro - argument type (same as .aT but uses A[1-9] strings
+.\" NS aT register argument type
+.if \n(.g \{\
+.de aT
+.nr aT 0
+.ie \\n(sW>2:(\A'\\$1'==0) \{\
+.	nr aT 2
+.\}
+.el \{\
+.	if \\n(sW==1 \{\
+.		ie \\n(z\\$1>2 \{\
+.			nr aT \\n(z\\$1
+.		\}
+.		el .nr aT 2
+.	\}
+.	if \\n(sW==2 \{\
+.		ie \\n(\\$1 \{\
+.			nr aT 1
+.		\}
+.		el .nr aT 2
+.	\}
+.\}
+..
+.de aU
+.nr aT 0
+.aW \\$1
+.ie \\n(sW>2:(\A'\\*(A\\$1'==0) .nr aT 2
+.el \{\
+.	if \\n(sW==1 \{\
+.		ie \\n(z\\*(A\\$1>2 \{\
+.			nr aT \\n(z\\*(A\\$1
+.		\}
+.		el .nr aT 2
+.	\}
+.	if \\n(sW==2 \{\
+.		ie (\\n(\\*(A\\$1) \{\
+.			nr aT 1
+.		\}
+.		el .nr aT 2
+.	\}
+.\}
+..
+.\}
+.if !\n(.g \{\
+.de aT
+.nr aT 0
+.ie \\n(sW>2 \{\
+.	nr aT 2
+.\}
+.el \{\
+.	if \\n(sW==1 \{\
+.		ie \\n(z\\$1>2 \{\
+.			nr aT \\n(z\\$1
+.		\}
+.		el .nr aT 2
+.	\}
+.	if \\n(sW==2 \{\
+.		ie \\n(\\$1 \{\
+.			nr aT 1
+.		\}
+.		el .nr aT 2
+.	\}
+.\}
+..
+.de aU
+.nr aT 0
+.aW \\$1
+.ie \\n(sW>2 .nr aT 2
+.el \{\
+.	if \\n(sW==1 \{\
+.		ie \\n(z\\*(A\\$1>2 \{\
+.			nr aT \\n(z\\*(A\\$1
+.		\}
+.		el .nr aT 2
+.	\}
+.	if \\n(sW==2 \{\
+.		ie (\\n(\\*(A\\$1) \{\
+.			nr aT 1
+.		\}
+.		el .nr aT 2
+.	\}
+.\}
+..
+.\}
+.\" NS s1 macro - set spacing for class type 1
+.\" NS s2 macro - set spacing for class type 2
+.\" NS s3 macro - set spacing for class type 3
+.\" NS s1 macro - set spacing for class type 1
+.\" NS s2 macro - set spacing for class type 2
+.\" NS s3 macro - set spacing for class type 3
+.\" NS s4 macro - set spacing for class type 4
+.\" NS S[0-9] string spacing
+.\" NS xX local register
+.\" NS aa local register
+.de s0
+.tm MDOC-ERROR: bogus type 0 (can't set space '\\*(A\\n(aC') (#\\n(.c)
+..
+.de s1
+.if \\n(\\*(A\\n(aC==3 \{\
+.	nr xX \\n(aC-1
+.	rm S\\n(xX
+.	ds S\\n(aC \\*(sV
+.\}
+.if \\n(\\*(A\\n(aC==2 \{\
+.	nr xX \\n(aC-1
+.\" this kludge can probably go away, but need to double check first
+.	ie "\\*(A\\n(aC"Nb" .ds S\\n(xX \\*(hV
+.	el .rm S\\n(xX
+.\}
+..
+.de s2
+.ds S\\n(aC \\*(sV
+..
+.de s3
+.if \\n(aC>1 \{\
+.	nr xX \\n(aC-1
+.	rm S\\n(xX
+.\}
+.ds S\\n(aC \\*(sV
+..
+.de s4
+.nr aa 0
+..
+.\" Class switches (on current argument aP)
+.\" NS c0 macro - catch errors (non-existent class type 0)
+.\" NS c1 macro - call request if type 1
+.\" NS c2 macro - call .No if type 2
+.\" NS c3 macro - call .No if type 3
+.\" NS c4 macro - call .No if type 4
+.de c0
+.tm MDOC-ERROR: bogus class 0 (can't determine '\\*(A\\n(aC') (#\\n(.c)
+..
+.de c1
+.\\*(A\\n(aP
+..
+.de c2
+.nr aP \\n(aP-1
+.No
+..
+.de c3
+.nr aP \\n(aP-1
+.No
+..
+.de c4
+.nr aP \\n(aP-1
+.No
+..
+.\" NS y1 macro - ignore if class 1
+.\" NS y2 macro - ignore if class 2
+.\" NS y3 macro - append if type 3
+.\" NS y4 macro - append if type 4
+.de y1
+.nr aa 1
+..
+.de y2
+.nr aa 1
+..
+.de y3
+.as b1 \\*(A\\n(aP
+.nr aP \\n(aP+1
+.n\\C\\n(aP
+..
+.de y4
+.as b1 \\*(A\\n(aP
+.nr aP \\n(aP+1
+.n\\C\\n(aP
+..
+.\"--------------------------------------------------------------------------
+.\" Ns Bf macro - Begin Font Mode (will be begin-mode/end-mode in groff & TeX)
+.\" Ns Ef macro - End Font Mode
+.de Bf
+.ds mN Bf
+.ie \\n(.$>0 \{\
+.	nr bF \\n(.f
+.	nr bZ \\n(.s
+.	if "\\$1"Em" \&\\*(eM\c
+.	if "\\$1"Li" \&\\*(lI\c
+.	if "\\$1"Sy" \&\\*(sY\c
+.	if "\\$1"-emphasis" \&\\*(eM\c
+.	if "\\$1"-literal" \&\\*(lI\c
+.	if "\\$1"-symbolic" \&\\*(sY\c
+.\}
+.el .tm Usage .Bf [Em | emphasis | Li | literal | Sy | symbolic] (#\\n(.c)
+..
+.de Ef
+.ds mN Ef
+.ie \\n(.$>0 .tm Usage .Ef (does not take arguments) (#\\n(.c)
+.el \&\f\\n(bF\s\\n(bZ
+..
+.\" Ns Bk macro - Begin Keep
+.\" Ns Ek macro - End Keep
+.\" Ns kS string - keep type
+.de Bk
+.ds mN Bk
+.ie \\n(.$==0 \{\
+.tm Usage: .Bk [-lines | -words] (#\\n(.c)
+.\}
+.el \{\
+.	if !"\\*(kS"" .tm .Bk: nesting keeps not implemented yet. (#\\n(.c)
+.	if "\\$1"-lines" .tm .Bd -lines: Not implemented yet. (#\\n(.c)
+.	if "\\$1"-words" .Hv
+.	ds kS \\$1
+.\}
+..
+.de Ek
+.ds mN Ek
+.ie \\n(.$>0 .tm Usage .Ek (does not take arguments) (#\\n(.c)
+.el \{\
+.	if "\\*(kS"-lines" .tm .Bd -lines: Not implemented yet. (#\\n(.c)
+.	if "\\*(kS"-words" .Sv
+.	rm kS
+.\}
+..
+.\" NS Bd macro - Begin Display display-type [offset string]
+.\" NS Ed macro - end Display
+.\" NS O[0-9] registers - stack of indent
+.\" NS d[0-9] registers - display-type stack
+.de Bd
+.ds mN Bd
+.ie \\n(.$==0 \{\
+.tm Usage: .Bd [-literal | -filled | -ragged | -unfilled] [-offset [string]] [-compact] (#\\n(.c)
+.\}
+.el \{\
+.	ds aa
+.	nr bV 0
+.       nr iD 0
+.	nr dP \\n(dP+1
+.       if "\\$1"-literal" \{\
+.		nr iD \\n(iD+1
+.               ds d\\n(dP dL
+.		nr cF \\n(.f
+.		nr cZ \\n(.s
+.		ie t \{\&\\*(lI
+'			ta 9n 18n 27n 36n 45n 54n 63n 72n
+.		\}
+.		el \{\
+'			ta 8n 16n 24n 32n 40n 48n 56n 64n 72n
+.		\}
+.		nf
+.       \}
+.       if "\\$1"-filled" \{\
+.		nr iD \\n(iD+1
+.               ds d\\n(dP dF
+.		br
+.       \}
+.       if "\\$1"-ragged" \{\
+.		nr iD \\n(iD+1
+.               ds d\\n(dP dR
+.		na
+.       \}
+.       if "\\$1"-unfilled" \{\
+.		nr iD \\n(iD+1
+.               ds d\\n(dP dU
+.		nf
+.       \}
+.\" .tm Here is argc: \\n(.$ and here is iD \\n(iD
+.       if ((\\n(iD>=1)&(\\n(.$>\\n(iD)) \{\
+.		bV \\$2 \\$3 \\$4
+.	\}
+.	if \\n(O\\n(dP>0 'in \\n(.iu+\\n(O\\n(dPu
+.	if (\\n(bV==0) \{\
+.		if (\\n(nS==0) \{\
+.			ie "\\*(d\\n(dP"dR" .sp \\n(dVu
+.			el 'sp \\n(dVu
+.		\}
+.	\}
+.	if \\n(cR==0 .ne 2v
+.	nr bV 0
+.	nr iD 0
+.\}
+..
+.\" NS bV macro - resolve remaining .Bd arguments
+.de bV
+.\" .tm in bV with args: \\$1 \\$2 \\$3
+.nr iD 1
+.ds bY
+.if "\\$1"-offset" \{\
+.	ds bY \\$2
+.	if "\\*(bY"left" \{\
+.		nr iD \\n(iD+1
+.		nr O\\n(dP 0
+.	\}
+.	if "\\*(bY"right" \{\
+.		nr iD \\n(iD+1
+.		nr O\\n(dP (\\n(.l/3)u
+.	\}
+.	if "\\*(bY"center" \{\
+.		nr iD \\n(iD+1
+.		nr O\\n(dP (\\n(.l-\\n(.i)/4u
+.	\}
+.	if "\\*(bY"indent" \{\
+.		nr iD \\n(iD+1
+.		nr O\\n(dP \\n(dIu
+.	\}
+.	if "\\*(bY"indent-two" \{\
+.		nr iD \\n(iD+1
+.		nr O\\n(dP \\n(dIu+\\n(dIu
+.	\}
+.	if \\n(iD==1 \{\
+.		nr iD \\n(iD+1
+.		sW "\\*(bY"
+.		ie \\n(sW>2 \{\
+.			ie ((\\*(bY>9n)&(\\*(bY<100n)) \{\
+.				nr O\\n(dP \\*(bY
+.			\}
+.			el .nr O\\n(dP (\\n(sW)*\\n(fWu
+.		\}
+.		el \{\
+.			if \\n(sW==2 .aT \\*(bY
+.			ie \\n(aT==1 \{\
+.				nr O\\n(dP \\n(\\*(bY
+.			\}
+.			el .nr O\\n(dP \\*(bY
+.		\}
+.	\}
+.\}
+.if "\\$1"-compact" \{\
+.	nr bV 1
+.\}
+.if \\n(iD<\\n(.$ \{\
+.	ie "\\*(bY"" \{\
+.		bV \\$2 \\$3
+.	\}
+.	el \{\
+.		bV \\$3
+.	\}
+.\}
+..
+.\" NS Ed macro - end display
+.de Ed
+.ds mN Ed
+.br
+.if \\n(dP==0 .tm mdoc: Extraneous .Ed
+.if "\\*(d\\n(dP"dL" \{\
+.	ft \\n(cF
+.	fz \\n(cZ
+.\}
+.in \\n(.iu-\\n(O\\n(dPu
+.rr O\\n(dP
+.rm d\\n(dP
+.nr dP \\n(dP-1
+.fi
+.if t .ad
+..
+.\"--------------------------------------------------------------------------
+.\" NS Bl macro - begin list (.Bl list-type)
+.\" NS L[0-9] registers - stack of list types
+.de Bl
+.ie \\n(.$==0 \{\
+.tm Usage: .Bl [[-hang | -tag] [-width]] [ -item | -enum | -bullet | -diag] (#\\n(.c)
+.\}
+.el \{\
+.	ds mN Bl
+.	nr aP 0
+.	nr lC \\n(lC+1
+.	ds A1 \\$2
+.	ds A2 \\$3
+.	ds A3 \\$4
+.	ds A4 \\$5
+.	ds A5 \\$6
+.	ds A6 \\$7
+.	ds A7 \\$8
+.	ds A8 \\$9
+.	nr fV \\n(.$-1
+.	if "\\$1"-hang" \{\
+.		nr aP \\n(aP+1
+.		ds L\\n(lC hL
+.		nr w\\n(lC 6n
+.		nr tC  1
+.	\}
+.	if "\\$1"-tag" \{\
+.		nr aP \\n(aP+1
+.		ds L\\n(lC tL
+.		nr tC  1
+.	\}
+.	if "\\$1"-item" \{\
+.		nr aP \\n(aP+1
+.		ds L\\n(lC iT
+.		nr tC  1
+.	\}
+.	if "\\$1"-enum" \{\
+.		nr aP \\n(aP+1
+.		ds L\\n(lC nU
+.		nr w\\n(lC 3n
+.		nr tC  1
+.	\}
+.	if "\\$1"-bullet" \{\
+.		nr aP \\n(aP+1
+.		ds L\\n(lC bU
+.		nr w\\n(lC 2n
+.		nr tC  1
+.	\}
+.	if "\\$1"-dash" \{\
+.		nr aP \\n(aP+1
+.		ds L\\n(lC hU
+.		nr w\\n(lC 2n
+.		nr tC  1
+.	\}
+.	if "\\$1"-hyphen" \{\
+.		nr aP \\n(aP+1
+.		ds L\\n(lC hU
+.		nr w\\n(lC 2n
+.		nr tC  1
+.	\}
+.	if "\\$1"-inset" \{\
+.		nr aP \\n(aP+1
+.		ds L\\n(lC lL
+.		nr tC  1
+.	\}
+.	if "\\$1"-diag" \{\
+.		nr aP \\n(aP+1
+.		ds L\\n(lC mL
+.		nr mL 1
+.	\}
+.	if "\\$1"-ohang" \{\
+.		nr aP \\n(aP+1
+.		ds L\\n(lC oL
+.		nr tC 1
+.	\}
+.	if "\\$1"-column" \{\
+.		nr aP \\n(aP+1
+.		ds L\\n(lC cL
+.	\}
+.	ie \\n(aP==0 \{\
+.	tm \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.	tm Usage: .Bl [[-inset|-tag] -width] [-item|-enum|-bullet|-diag] (#\\n(.c)
+.	\}
+.	el \{\
+.		tY
+.		if (\\n(aP==1)&(\\n(aP<\\n(.$) \{\
+.			nr aP 0
+.			lV
+.			if "\\*(L\\n(lC"cL" \{\
+.				W\\n(wV
+.				nr w\\n(lC 0
+'				in -\\n(eWu
+.				ie \\n(v\\n(lC==1 \{\
+.				       nr aa 0
+.				\}
+.				el \{\
+.					sp \\n(dVu
+.				\}
+.				nf
+.				nr wV 0
+.			\}
+.		\}
+.	\}
+.	nr aP 0
+.\" .	ds b1
+.	aY
+.\" .tm Here is L[\\n(lC]==\\*(L\\n(lC
+.\}
+..
+.if \n(.g \{\
+.	nr i 10
+.	while \ni<100 \{\
+.	     nr num!\nin 1
+.	     nr i +1
+.	\}
+.\}
+.\" NS lV macro - resolve remaining .Bl arguments
+.de lV
+.nr aP \\n(aP+1
+.if \\n(fV>=\\n(aP \{\
+.	nr iD 0
+.	if "\\*(A\\n(aP"-compact" \{\
+.		nr iD 1
+.		nr v\\n(lC 1
+.	\}
+.	if "\\*(A\\n(aP"-width" \{\
+.		nr iD 1
+.		nr aP \\n(aP+1
+.		nr tW 1
+.		ds t\\n(lC TagwidtH
+.		ds tS \\*(A\\n(aP
+.		aW \\n(aP
+.		ie \\n(sW>2 \{\
+.			nr w\\n(lC (\\n(sW)*\\n(fWu
+.			if \\n(sW==3 \{\
+.				ie \\n(.g \{\
+.					if \A'\\*(tS' .if r num!\\*(tS \{\
+.						nr w\\n(lC \\*(tS
+.					\}
+.				\}
+.				el \{\
+.					if (\\*(tS>9n)&(\\*(tS<99n) \{\
+.						nr w\\n(lC \\*(tSu
+.					\}
+.				\}
+.			\}
+.		\}
+.		el \{\
+.			aT \\*(tS
+.			ie \\n(aT==1 \{\
+.				nr w\\n(lC \\n(\\*(tS
+.			\}
+.			el \{\
+.				nr w\\n(lC \\*(tSu
+.			\}
+.		\}
+.	\}
+.	if "\\*(A\\n(aP"-offset" \{\
+.		nr iD 1
+.		nr aP \\n(aP+1
+.		ie "\\*(A\\n(aP"indent" \{\
+.			nr o\\n(lC \\n(Dsu
+.		\}
+.		el \{\
+.			ds tS \\*(A\\n(aP
+.			aW \\n(aP
+.			ie \\n(sW>2 \{\
+.				nr o\\n(lC (\\n(sW)*\\n(fWu
+.				ie \\n(.g \{\
+.					if \A'\\*(tS' .if r num!\\*(tS \{\
+.						nr o\\n(lC \\*(tS
+.					\}
+.				\}
+.				el \{\
+.					if (\\*(tS>9n)&(\\*(tS<100n) \{\
+.						nr o\\n(lC \\*(tS
+.					\}
+.				\}
+.			\}
+.			el \{\
+.				ie \\n(C\\n(aP==1 .nr o\\n(lC \\n(\\*(tS
+.				el .nr o\\n(lC \\*(tS
+.			\}
+.		\}
+.	\}
+.	if \\n(iD==0 \{\
+.		if "\\*(L\\n(lC"cL" \{\
+.			nr wV \\n(wV+1
+.			ds A\\n(wV \\*(A\\n(aP
+.		\}
+.	\}
+.	if \\n(fV>\\n(aP .lV
+.\}
+..
+.\" NS El macro - end list
+.\" NS iD local register
+.de El
+.ie \\n(.$>0 \{\
+.	tm Usage: .El (#\\n(.c)
+.\}
+.el \{\
+.	ds mN El
+.	nr iD 0
+.	if "\\*(L\\n(lC"cL" \{\
+.		nr iD 1
+.		cC
+.	\}
+.	if "\\*(L\\n(lC"nU" \{\
+.		nr nU 0
+.	\}
+.	if \\n(mL>0 \{\
+.		nr iD 1
+.		nr mL 0
+.		tZ
+.		nr lC \\n(lC-1
+.		tY
+.	\}
+.	if "\\*(L\\n(lC"iT" \{\
+'		in \\n(.iu-\\n(o\\n(lCu
+.		tZ
+.		nr lC \\n(lC-1
+.		tY
+.		nr iD 1
+.	\}
+.	if "\\*(L\\n(lC"oL" \{\
+'		in \\n(.iu-\\n(o\\n(lCu
+.		tZ
+.		nr lC \\n(lC-1
+.		tY
+.		nr iD 1
+.	\}
+.	if "\\*(L\\n(lC"lL" \{\
+'		in \\n(.iu-\\n(o\\n(lCu
+.		tZ
+.		nr lC \\n(lC-1
+.		tY
+.		nr iD 1
+.	\}
+.	if \\n(iD==0 \{\
+.		lE
+.	\}
+.	br
+.	nr iD 0
+.\}
+..
+.\" NS It macro - list item
+.\" NS iD local register
+.\" NS aA save pA font string for section FILES (no underline if nroff)
+.de It
+.if "\\*(L\\n(lC"" \{\
+.	tm Usage .Bl -list-type [-width [string] | -compact | -offset [string]] (#\\n(.c)
+.	tm .It \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8
+.\}
+.\" .tm Here is L[\\n(lC]==\\*(L\\n(lC
+.ne 3v
+.ie \\n(.$>0 \{\
+.	ds mN It
+.	ds b1
+.	nr iD 0
+.	ds A1 \\$1
+.	ds A2 \\$2
+.	ds A3 \\$3
+.	ds A4 \\$4
+.	ds A5 \\$5
+.	ds A6 \\$6
+.	ds A7 \\$7
+.	ds A8 \\$8
+.	ds A9 \\$9
+.	nr fV \\n(.$
+.	if "\\*(L\\n(lC"mL" \{\
+.		nr iD 1
+.		nr aP 0
+.		aX
+.		\\*(L\\n(lC
+.	\}
+.	if "\\*(L\\n(lC"cL" \{\
+.		ds b1
+.		nr aP 0
+.		nr iD 1
+.		\\*(L\\n(lC
+.	\}
+.	if "\\*(L\\n(lC"iT" \{\
+.		nr aP 0
+.		nr iD 1
+.		\\*(L\\n(lC
+.	\}
+.	if \\n(iD==0 \{\
+.		fV
+.\" tm ------------------------------------------------------------------------
+.\" tm It list-type==\\*(L\\n(lC, aP==\\n(aP
+.\" tm It beg arg(A[1])==\\*(A1; oM==\\n(oM; dZ==\\n(dZ; Xt==\\n(Xt; aC==\\n(aC
+.		nr oM \\n(oM+1
+.		nr tP 1
+.		nr aP \\n(aP+1
+.		nr tX \\n(C\\n(aP
+.		ds tX \\*(A\\n(aP
+.		if \\n(nF==1 \{\
+.			ds aA \\*(pA
+.			if n .ds pA \\*(nO
+.		\}
+.		ie \\n(C\\n(aP==1 \{\
+.			\\*(A\\n(aP
+.		\}
+.		el \{\
+.			nr aP \\n(aP-1
+.			No
+.		\}
+.\" tm in It here is b1==\\*(b1
+.\" tm It mid arg(A[1])==\\*(A1; oM==\\n(oM; dZ==\\n(dZ; Xt==\\n(Xt; aC==\\n(aC
+.		ie \\n(Xt==1 .ds xB \&\\*(L\\n(lC
+.		el .\\*(L\\n(lC
+.	\}
+.	nr iD 0
+.\}
+.el .\\*(L\\n(lC
+..
+.\" NS lL macro - .It item of list-type inset
+.de lL
+.lY
+.br
+\&\\*(b1
+.nr oM \\n(oM-1
+.nr tP 0
+.ds b1
+.aY
+'fi
+..
+.\" NS hL macro - .It item of list-type hanging label (as opposed to tagged)
+.de hL
+.lX
+.nr bb \\n(w\\n(lCu+\\n(lSu
+.ti -\\n(bbu
+.ie \w\\*(b1u>=(\\n(w\\n(lCu) \&\\*(b1
+.el \&\\*(b1\h'|\\n(bbu'\c
+.nr oM \\n(oM-1
+.ds b1
+.nr tP 0
+.aY
+'fi
+..
+.\" NS oL macro - .It item of list-type overhanging label
+.de oL
+.lY
+\&\\*(b1
+.br
+.nr oM \\n(oM-1
+.ds b1
+.nr tP 0
+.aY
+'fi
+..
+.\" NS iT macro - .It item of list-type [empty label]
+.de iT
+.lY
+.br
+.\" .ds b1
+.aY
+'fi
+..
+.\" NS nU macro - Enumerated list
+.\" NS nU register count
+.\" NS hU macro - Hyphen paragraph list (sub bullet list)
+.\" NS bU macro - Bullet paragraph list
+.de nU
+.nr oM \\n(oM+1
+.nr nU \\n(nU+1
+.ds b1 \&\\n(nU.
+.uL
+..
+.de bU
+.nr oM \\n(oM+1
+.nr bU \\n(bU+1
+.ds b1 \&\\*(sY\&\(bu\fP
+.uL
+..
+.de hU
+.nr oM \\n(oM+1
+.nr bU \\n(bU+1
+.ds b1 \&\\*(sY\&\-\fP
+.uL
+..
+.\" NS uL macro - .It item of list-type enum/bullet/hyphen
+.de uL
+.lX
+.nr bb \\n(w\\n(lCu+\\n(lSu
+.ti -\\n(bbu
+.ie \w\\*(b1u>=(\\n(w\\n(lCu) \&\\*(b1
+.el \&\\*(b1\h'|\\n(bbu'\c
+.nr oM \\n(oM-1
+.\" .nr dZ \\n(dZ+1
+.ds b1
+.nr tP 0
+.aY
+'fi
+..
+.\" NS mL macro - .It item of list-type diagnostic-message
+.de mL
+.nr cF \\n(.f
+.nr cZ \\n(.s
+.ie \\n(mL==1 \{\
+.	nr zB \\n(.c
+.	ie (\\n(zB-\\n(zA)>1 .Pp
+.	el .br
+.	nr zA \\n(zB
+.	nr zB 0
+.\}
+.el \{\
+.	nr zA \\n(.c
+.	br
+.\}
+\&\\*(sY\\*(b1\f\\n(cF\s\\n(cZ\\*(lS\c
+.aY
+.ds b1
+'fi
+..
+.\" NS tL macro - .It item of list-type "tag"
+.de tL
+.\" tm in tL here is b1==\\*(b1
+.if \\n(tW==0 .lW
+.lX
+.nr bb \\n(w\\n(lCu+\\n(lSu
+.ti -\\n(bbu
+.ie (\w\\*(b1u)>(\\n(w\\n(lCu) \{\&\\*(b1
+.       br
+.\}
+.el \&\\*(b1\h'|\\n(bbu'\c
+.if \\n(nF==1 \{\
+.	if n .ds pA \\*(aA
+.\}
+.nr oM \\n(oM-1
+.nr tP 0
+.\" .nr dZ \\n(dZ+1
+.ds b1
+.aY
+'fi
+..
+.\" NS lW macro - resolve unknown label/tag width (if .Bl [inset | tag] only)
+.de lW
+.if !"TagwidtH"\\*(t\\n(lC" \{\
+.       ie \\n(tX==1 \{\
+.               ds t\\n(lN \\*(tX
+.               nr w\\n(lN \\n(\\*(tX
+.       \}
+.       el \{\
+.               ds t\\n(lN No
+.               nr w\\n(lN \\n(No
+.       \}
+.       if !"\\*(t\\n(lC"\\*(t\\n(lN" .nr tC 1
+.\}
+..
+.\" NS lX macro - set up vertical spacing (if compact) and offset+indent (all)
+.de lX
+.ie \\n(tC \{\
+.       nr tC 0
+.       nr tW 0
+.       if \\n(v\\n(lC==0 .sp \\n(dVu
+.       in \\n(.iu+\\n(w\\n(lCu+\\n(o\\n(lCu+\\n(lSu
+.\}
+.el \{\
+.	ie \\n(v\\n(lC==1 \{\
+.	       nr aa 0
+.	\}
+.	el \{\
+.		sp \\n(dVu
+.	\}
+.\}
+.if !\\n(cR .ne 2v
+..
+.\" NS lY macro - set up vertical spacing (if compact) and offset+indent (all)
+.de lY
+.ie \\n(tC \{\
+.       nr tC 0
+.       nr tW 0
+.       if \\n(v\\n(lC==0 .sp \\n(dVu
+.       in \\n(.iu+\\n(o\\n(lCu
+.\}
+.el \{\
+.	ie \\n(v\\n(lC==1 \{\
+.	       nr aa 0
+.	\}
+.	el \{\
+.		sp \\n(dVu
+.	\}
+.\}
+.if !\\n(cR .ne 2v
+..
+.\" NS tS temporary string
+.\" NS hL macro - hanging list function
+.\" NS tS temporary string
+.\" NS hL macro - hanging list function
+.\" NS lT macro - tagged list function
+.\" NS lE macro - list end function
+.\" NS tX string (initial string)
+.\" NS tX register (initial class)
+.\" NS tC parameter change flag
+.\" NS Xt save current list-type flag
+.\" NS lC register - list type stack counter
+.\" NS tP register tag flag (for diversions)
+.\" NS w[0-9] register tag stack (nested tags)
+.\" NS t[0-9] register tag string stack (nested tags)
+.\" NS o[0-9] register offset stack (nested tags)
+.\" NS v[0-9] register vertical tag break stack
+.\" NS h[0-9] register horizontal tag stack (continuous if 1, break if 0)
+.nr lC 0
+.nr wV 0
+.nr w1 0
+.nr o1 0
+.nr v1 0
+.nr h1 0
+.ds t\n(lC
+.de lE
+.\" IN lC o[\\n(lC]==\\n(o\\n(lC, w[\\n(lC]==\\n(w\\n(lC,
+.ie \\n(o\\n(lC>0 \{\
+'	in \\n(.iu-(\\n(w\\n(lCu)-(\\n(o\\n(lCu)-\\n(lSu
+.	rr o\\n(lC
+.\}
+.el 'in \\n(.iu-\\n(w\\n(lCu-\\n(lSu
+.if \\n(lC<=0 .tm Extraneous .El call (#\\n(.c)
+.tZ
+.nr lC \\n(lC-1
+.tY
+..
+.\" NS tY macro - set up next block for list
+.\" NS tZ macro - decrement stack
+.\" NS tY register (next possible lC value)
+.de tY
+.nr tY (\\n(lC+1)
+.nr w\\n(tY 0
+.nr h\\n(tY 0
+.nr o\\n(tY 0
+.ds t\\n(tY \\*(t\\n(lC
+.ds L\\n(tY
+.nr v\\n(tY 0
+..
+.de tZ
+.rm L\\n(tY
+.rr w\\n(tY
+.rr h\\n(tY
+.rr o\\n(tY
+.rm t\\n(tY
+.rr v\\n(tY
+.nr tY \\n(tY-1
+..
+.\" initial values
+.nr w1 0
+.nr o1 0
+.nr h1 0
+.ds t1
+.nr v1 0
+.nr tY 1
+.\" NS Xr macro - cross reference (man page only)
+.de Xr
+.if \\n(aC==0 \{\
+.	ie \\n(.$==0 .tm Usage: .Xr manpage_name [section#] \\*(Pu (#\\n(.c)
+.	el \{\
+.		ds mN Xr
+.		aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	nr aP \\n(aP+1
+.	ie \\n(C\\n(aP==1 .tm Usage: .Xr manpage_name [section#] \\*(Pu (#\\n(.c)
+.	el \{\
+.		ie \\n(C\\n(aP>2 .y\\n(C\\n(aP
+.		el \{\
+.			as b1 \&\\*(xR\\*(A\\n(aP\fP\s0
+.			if \\n(aC>\\n(aP \{\
+.				nr aP \\n(aP+1
+.				if \\n(C\\n(aP==2 \{\
+.					as b1 \&(\\*(A\\n(aP)
+.					nr aP \\n(aP+1
+.				\}
+.				if \\n(aC>=\\n(aP \{\
+.					c\\n(C\\n(aP
+.				\}
+.			\}
+.		\}
+.		aZ
+.       \}
+.\}
+..
+.\" NS Sx macro - cross section reference
+.de Sx
+.if \\n(aC==0 \{\
+.	ie \\n(.$==0 .tm Sx Usage: .Sx Section Header \\*(Pu (#\\n(.c)
+.	el \{\
+.		ds mN Sx
+.		aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.	\}
+.\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	nr aP \\n(aP+1
+.	as b1 \\*(sX
+.	nr cF \\n(.f
+.	nr cZ \\n(.s
+.	nR
+.\}
+..
+.\" NS cC macro - column-list end-list
+.\" NS eW macro - column indent width
+.\" NS cI register - column indent width
+.\" NS W[1-5] macro - establish tabs for list-type column
+.de cC
+'in \\n(.iu-\\n(o\\n(lCu-\\n(w\\n(lCu
+.ta .5i 1i 1.5i 2i 2.5i 3i 3.5i 4i 4.5i 5i 5.5i 6i 6.5i
+.fi
+.tZ
+.nr lC \\n(lC-1
+.tY
+..
+.de W1
+.ta \w\\*(A1    u
+.nr eW \w\\*(A1    u
+'in \\n(.iu+\\n(eWu+\\n(o\\n(lCu
+..
+.de W2
+.ta \w\\*(A1    u +\w\\*(A2    u
+.nr eW \w\\*(A1    u+\w\\*(A2    u
+'in \\n(.iu+\\n(eWu+\\n(o\\n(lCu
+..
+.de W3
+.ta \w\\*(A1    u +\w\\*(A2    u +\w\\*(A3    u
+.nr eW \w\\*(A1    u+\w\\*(A2    u+\w\\*(A3    u
+'in \\n(.iu+\\n(eWu+\\n(o\\n(lCu
+..
+.de W4
+.ta \w\\*(A1    u +\w\\*(A2    u +\w\\*(A3    u +\w\\*(A4    u
+.nr eW \w\\*(A1    u+\w\\*(A2    u +\w\\*(A3    u +\w\\*(A4    u
+'in \\n(.iu+\\n(eWu+\\n(o\\n(lCu
+..
+.de W5
+.ta \w\\*(A1   u +\w\\*(A2   u +\w\\*(A3   u +\w\\*(A4   u +\w\\*(A5   u
+.nr eW \w\\*(A1   u +\w\\*(A2   u +\w\\*(A3   u +\w\\*(A4   u +\w\\*(A5   u
+'	in \\n(.iu+\\n(eWu+\\n(o\\n(lCu
+..
+.\" This is packed abnormally close, intercol width should be an option
+.de W6
+.ta \w\\*(A1 u +\w\\*(A2 u +\w\\*(A3 u +\w\\*(A4 u +\w\\*(A5 u +\w\\*(A6
+.nr eW \w\\*(A1 u +\w\\*(A2 u +\w\\*(A3 u +\w\\*(A4 u +\w\\*(A5 u +\w\\*(A6
+'	in \\n(.iu+\\n(eWu+\\n(o\\n(lCu
+..
+.\" NS cL macro - column items
+.de cL
+.if \\n(w\\n(lC==0 .nr w\\n(lC \\n(eWu
+.if \\n(.u==0 \{\
+.	fi
+'	in \\n(.iu+\\n(eWu
+.\}
+.ti -\\n(eWu
+.fV
+.nr aP \\n(aP+1
+.ie \\n(aC>=\\n(aP  \{\
+.	if "\\*(A\\n(aP"Ta" \{\
+.		nr jJ \\n(aP-1
+.		rm S\\n(jJ
+.		rr jJ
+.	\}
+.	c\\n(C\\n(aP
+.\}
+.el .tm Usage: .It column_string [Ta [column_string ...] ] (#\\n(.c)
+..
+.\" NS Ta macro - append tab (\t)
+.de Ta
+.ie \\n(aC>0 \{\
+.	nr aP \\n(aP+1
+.	ie \\n(aC>=\\n(aP \{\
+.		if "\\*(A\\n(aP"Ta" \{\
+.			nr jJ \\n(aP-1
+.			rm S\\n(jJ
+.			rr jJ
+.		\}
+.		as b1 \\t
+.		c\\n(C\\n(aP
+.	\}
+.	el \{\
+.		as b1 \\t\\c
+.		rm S\\n(aP
+.		pB
+.		aY
+.\" .		ds b1
+.	\}
+.\}
+.el \{\
+.	tm Usage: Ta must follow column entry: e.g. (#\\n(.c)
+.	tm .It column_string [Ta [column_string ...] ]
+.\}
+..
+.\"
+.\" NS Dl macro - display (one line) literal
+.de Dl
+'ta .5i 1i 1.5i 2i 2.5i 3i 3.5i 4i 4.5i 5i 5.5i 6i 6.5i
+.in \\n(.iu+\\n(Dsu
+.ie \\n(aC==0 \{\
+.	ie \\n(.$==0 \{\
+.		tm Usage: .Dl argument ... (#\\n(.c)
+.	\}
+.	el \{\
+.		ds mN Dl
+.               ds A1 \\$1
+.               ds A2 \\$2
+.               ds A3 \\$3
+.               ds A4 \\$4
+.               ds A5 \\$5
+.               ds A6 \\$6
+.               ds A7 \\$7
+.               ds A8 \\$8
+.               ds A9 \\$9
+.		nr fV \\n(.$
+.		fV
+.		Li
+.	\}
+.\}
+.el \{\
+.	tm Usage: .Dl not callable by other macros (#\\n(.c)
+.\}
+.in \\n(.iu-\\n(Dsu
+..
+.\"
+.\" NS D1 macro - display (one line)
+.de D1
+'ta .5i 1i 1.5i 2i 2.5i 3i 3.5i 4i 4.5i 5i 5.5i 6i 6.5i
+.in \\n(.iu+\\n(Dsu
+.ie \\n(aC==0 \{\
+.	ie \\n(.$==0 \{\
+.		tm Usage: .D1 argument ... (#\\n(.c)
+.	\}
+.	el \{\
+.		ds mN D1
+.               ds A1 \\$1
+.               ds A2 \\$2
+.               ds A3 \\$3
+.               ds A4 \\$4
+.               ds A5 \\$5
+.               ds A6 \\$6
+.               ds A7 \\$7
+.               ds A8 \\$8
+.               ds A9 \\$9
+.		nr fV \\n(.$
+.		fV
+.		nr aP \\n(aP+1
+.		ie \\n(C\\n(aP==1 .\\*(A\\n(aP
+.		el .No
+.	\}
+.\}
+.el \{\
+.	tm Usage: .D1 not callable by other macros (#\\n(.c)
+.\}
+.in \\n(.iu-\\n(Dsu
+..
+.\" NS Ex macro - DEFUNCT
+.de Ex
+.tm Ex defunct, Use .D1: \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\"
+.\" NS Ex macro - DEFUNCT
+.de Ex
+.tm Ex defunct, Use .D1: \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+..
+.\"
+.\" NS Vt macro - Variable type (for forcing old style variable declarations)
+.\" this is not done in the same manner as .Ot for fortrash - clean up later
+.de Vt
+.\" if a function declaration was the last thing given, want vertical space
+.if \\n(fD>0 \{\
+.	Pp
+.	nr fD 0
+.\}
+.\"	if a subroutine was the last thing given, want vertical space
+.if \\n(fZ>0 \{\
+.	ie \\n(fX==0 \{\
+.		Pp
+.		rs
+.	\}
+.	el .br
+.\}
+.nr fX \\n(fX+1
+.nr cF \\n(.f
+.nr cZ \\n(.s
+\\*(fT\&\\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.ie \\n(oT==0 .br
+.el \&\ \&
+.ft \\n(cF
+.fs \\n(cZ
+..
+.\"
+.\" NS Ft macro - Function type
+.nr fZ 0
+.de Ft
+.if \\n(nS>0 \{\
+.	if \\n(fZ>0 \{\
+.		Pp
+.		nr fD 0
+.		nr fX 0
+.	\}
+.	if \\n(fD>0 \{\
+.		Pp
+.		nr fD 0
+.		nr fX 0
+.	\}
+.	if \\n(fX>0 \{\
+.		Pp
+.		nr fX 0
+.	\}
+.	nr fY 1
+.\}
+.nr cF \\n(.f
+.nr cZ \\n(.s
+\&\\*(fT\\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.ft \\n(cF
+.fs \\n(cZ
+.\" .br
+..
+.\"
+.\" NS Ot macro - Old Function type (fortran - no newline)
+.\" Ns oT register
+.nr oT 0
+.de Ot
+.nr oT 1
+.if \\n(nS>0 \{\
+.	if \\n(fZ>0 \{\
+.		Pp
+.		nr fD 0
+.		nr fX 0
+.	\}
+.	if \\n(fD>0 \{\
+.		Pp
+.		nr fD 0
+.		nr fX 0
+.	\}
+.	if \\n(fX>0 \{\
+.		Pp
+.		nr fX 0
+.	\}
+.	nr fY 1
+.\}
+.if \\n(.$==4 .as b1 \&\\*(fT\&\\$1 \\$2 \\$3 \\$4
+.if \\n(.$==3 .as b1 \&\\*(fT\&\\$1 \\$2 \\$3
+.if \\n(.$==2 .as b1 \&\\*(fT\&\\$1 \\$2
+.if \\n(.$==1 .as b1 \&\\*(fT\&\\$1
+.as b1 \&\ \fP
+..
+.\"
+.\" NS Fa macro - Function arguments
+.de Fa
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .Fa Function Arguments ... \\*(Pu (#\\n(.c)
+.       el \{\
+.		ds mN Fa
+.               ds A1 \\$1
+.               ds A2 \\$2
+.               ds A3 \\$3
+.               ds A4 \\$4
+.               ds A5 \\$5
+.               ds A6 \\$6
+.               ds A7 \\$7
+.               ds A8 \\$8
+.               ds A9 \\$9
+.		nr fV \\n(.$
+.		fV
+.	\}
+.\}
+.ie \\n(fC>0 \{\
+.	fC
+.\}
+.el \{\
+.	if \\n(aC>\\n(aP \{\
+.		as b1 \\*(fA
+.		nr aP \\n(aP+1
+.		nr cF \\n(.f
+.		nr cZ \\n(.s
+.		nR
+.		if \\n(nS>0 \{\
+.			if \\n(fZ>0 .br
+.		\}
+.	\}
+.\}
+..
+.\" NS fC macro - interal .Fa for .FO and .Fc
+.de fC
+.ie \\n(aC>\\n(aP \{\
+.	nr aP \\n(aP+1
+.\" .	nr aa \\n(aP
+.\" .	if \\n(nS>0 \{\
+.		ds Fb
+.		nr fB 0
+.		nr Fb 0
+.		fB \\*(A\\n(aP
+.		if \\n(fB>1 \{\
+.			rm A\\n(aP
+.			rn Fb A\\n(aP
+.		\}
+.\" .	\}
+.	if \\n(fC>1 \{\
+.		as b1 \&\f\\n(cF\s\\n(cZ,\\*(S\\n(aP\\*(fA\\*(A\\n(aP\fP\s0
+.\" .		as b1 \&\\,\\*(S\\n(aP\fP\s0\\*(fA\\*(A\\n(aP\fP\s0
+.	\}
+.	if \\n(fC==1 \{\
+.		as b1 \&\|\\*(fA\\*(A\\n(aP\fP\s0
+.	\}
+.	nr fC \\n(fC+1
+.	fC
+.\}
+.el  \{\
+.	aY
+.\}
+..
+.\" NS Fn macro - functions
+.\" NS fY register - dick with old style function declarations (fortran)
+.\" NS fZ register - break a line when more than one function in a synopsis
+.\"
+.de Fn
+.if \\n(aC==0 \{\
+.	ie \\n(.$==0 .tm Usage: .Fn function_name function_arg(s) ... \\*(Pu (#\\n(.c)
+.	el \{\
+.		ds mN Fn
+.               ds A1 \\$1
+.               ds A2 \\$2
+.               ds A3 \\$3
+.               ds A4 \\$4
+.               ds A5 \\$5
+.               ds A6 \\$6
+.               ds A7 \\$7
+.               ds A8 \\$8
+.               ds A9 \\$9
+.		nr fV \\n(.$
+.		fV
+.	\}
+.\}
+.if \\n(nS>0 \{\
+.\" if there is/has been more than one subroutine declaration
+.	if \\n(fY==0 \{\
+.		if \\n(fZ>0 \{\
+.			Pp
+.			nr fX 0
+.			nr fD 0
+.		\}
+.	\}
+.	if \\n(fY==1 \{\
+.		br
+.		nr fX 0
+.		nr fD 0
+.		nr fY 0
+.	\}
+.	if \\n(fD>0 \{\
+.		Pp
+.		nr fX 0
+.	\}
+.	if \\n(fX>0 \{\
+.		Pp
+.		nr fD 0
+.	\}
+.	nr fZ \\n(fZ+1
+.	nr fY 0
+.	rs
+.	ie \\n(nS>1 .br
+.	el \{\
+.		if \\n(iS==0 \{\
+.			nr iS ((8)*\\n(fW)u
+.		\}
+.	\}
+.	in +\\n(iSu
+.	ti -\\n(iSu
+.	nr nS \\n(nS+1
+.\}
+.if \\n(aC>\\n(aP \{\
+.	nr aP \\n(aP+1
+.	nr cF \\n(.f
+.	nr cZ \\n(.s
+.	as b1 \\*(fN\\*(A\\n(aP\fP\s0\\*(lp
+.	ie \\n(aC>\\n(aP \{\
+.		as b1 \\*(fA
+.		nr aP \\n(aP+1
+.		f\\n(C\\n(aP
+.	\}
+.	el \{\
+.		as b1 \|\\*(rp
+.		aZ
+.	\}
+.	if \\n(nS>0 \{\
+. 		in -\\n(iSu
+.	\}
+.\}
+..
+.\"
+.\" NS f1 macro - class switch
+.\" NS f2 macro - handle function arguments
+.\" NS f3 macro - punctuation
+.\" NS f4 macro - write out function
+.de f1
+.as b1 \\*(rp\f\\n(cF\s\\n(cZ
+.\\*(A\\n(aP
+..
+.de f2
+.if \\n(nS>0 \{\
+.	ds Fb
+.	nr fB 0
+.	nr Fb 0
+.	fB \\*(A\\n(aP
+.	if \\n(fB>1 \{\
+.		rm A\\n(aP
+.		rn Fb A\\n(aP
+.	\}
+.\}
+.as b1 \\*(A\\n(aP
+.ie \\n(aC>\\n(aP \{\
+.	nr aa \\n(aP
+.	nr aP \\n(aP+1
+.	if \\n(C\\n(aP==2 \{\
+.		as b1 \&\|\f\\n(cF\s\\n(cZ,\\*(S\\n(aa\fP\s0\|
+.	\}
+.	f\\n(C\\n(aP
+.\}
+.el  \{\
+.	as b1 \\*(rp\f\\n(cF\s\\n(cZ
+.	aZ
+.\}
+..
+.de f3
+.as b1 \\*(rp\f\\n(cF\s\\n(cZ\\*(A\\n(aP
+.ie \\n(aC>\\n(aP \{\
+.	No
+.\}
+.el .aZ
+..
+.de f4
+.as b1 \\*(rp\f\\n(cF\s\\n(cZ\\*(S\\n(aP\\*(A\\n(aP
+.ie \\n(aC>\\n(aP \{\
+.	nr aP \\n(aP+1
+.	No
+.\}
+.el .aZ
+..
+.de Fo
+.hy 0
+.if \\n(aC==0 \{\
+.	ie \\n(.$==0 .tm Usage: .Fo function_name
+.	el \{\
+.		ds mN Fo
+.               ds A1 \\$1
+.               ds A2 \\$2
+.               ds A3 \\$3
+.               ds A4 \\$4
+.               ds A5 \\$5
+.               ds A6 \\$6
+.               ds A7 \\$7
+.               ds A8 \\$8
+.               ds A9 \\$9
+.		nr fV \\n(.$
+.		fV
+.	\}
+.\}
+.if \\n(nS>0 \{\
+.\" if there is/has been more than one subroutine declaration
+.	if \\n(fY==0 \{\
+.		if \\n(fZ>0 \{\
+.			Pp
+.			nr fX 0
+.			nr fD 0
+.		\}
+.	\}
+.	if \\n(fY==1 \{\
+.		br
+.		nr fX 0
+.		nr fD 0
+.		nr fY 0
+.	\}
+.	if \\n(fD>0 \{\
+.		Pp
+.		nr fX 0
+.	\}
+.	if \\n(fX>0 \{\
+.		Pp
+.		nr fD 0
+.	\}
+.	nr fZ \\n(fZ+1
+.	nr fY 0
+.	rs
+.	ie \\n(nS>1 .br
+.	el \{\
+.		if \\n(iS==0 \{\
+.			nr iS ((8)*\\n(fW)u
+.		\}
+.	\}
+.	in +\\n(iSu
+.	ti -\\n(iSu
+.	nr nS \\n(nS+1
+.\}
+.if \\n(aC>\\n(aP \{\
+.	nr oM \\n(oM+1
+.	nr fC 1
+.	nr aP \\n(aP+1
+.	nr cF \\n(.f
+.	nr cZ \\n(.s
+.	as b1 \\*(fN\\*(A\\n(aP\fP\s0\\*(lp
+.	aY
+.\}
+..
+.de Fc
+.if \\n(aC==0 \{\
+.	if \\n(.$>0 \{\
+.		ds mN Fo
+.               ds A1 \\$1
+.               ds A2 \\$2
+.               ds A3 \\$3
+.               ds A4 \\$4
+.               ds A5 \\$5
+.               ds A6 \\$6
+.               ds A7 \\$7
+.               ds A8 \\$8
+.               ds A9 \\$9
+.		nr fV \\n(.$
+.		fV
+.	\}
+.\}
+.nr fC 0
+.nr oM \\n(oM-1
+.as b1 \|\\*(rp
+.ie \\n(aC>\\n(aP \{\
+.	nr aP \\n(aP+1
+.	\\*(A\\n(aP
+.\}
+.el \{\
+.	aZ
+.\}
+.if \\n(nS>0 \{\
+.	in -\\n(iSu
+.\}
+.hy
+..
+.\" NS fb macro - if SYNOPSIS, set hard space inbetween function args
+.\" NS fb register - count of words in a function argument
+.\" NS Fb register - counter
+.\" NS Fb string - temporary string
+.de fB
+.\" .tm fB==\\n(fB, Fb==\\n(Fb, 1==\\$1 2==\\$2 3==\\$3 4==\\$4 5==\\$5 6==\\$6
+.if \\n(fB==0 \{\
+.	nr fB \\n(.$
+.	nr Fb 0
+.	ds Fb
+.\}
+.nr Fb \\n(Fb+1
+.as Fb \&\\$1
+.if \\n(Fb<\\n(fB \{\
+.	as Fb \&\\*(hV
+.	fB \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.\}
+..
+.\" NS Fc - Function close - not implemented yet
+.\" NS Fo - Function open - not implemented yet
+.\"
+.\" Very crude references, stash all reference info into strings (usual
+.\" use of b1 buffer, then b1 contents copied to string of retrievable
+.\" naming convention), print out reference on .Re request and clean up.
+.\" Ordering very limited, no fancy citations, but can do articles, journals
+.\" and books - need to add several missing options (like city etc).
+.\" should be able to grab a refer entry, massage it a wee bit (prefix
+.\" a `.' to the %[A-Z]) and not worry (ha!)
+.\"
+.\" NS Rs macro - Reference Start
+.\" NS rS register - Reference Start flag
+.\" NS rS string - Reference Start buffer name for next save (of b1 buffer)
+.de Rs
+.nr rS 1
+.rC
+.if \\n(nA==1 .Pp
+.nr Kl 0
+..
+.\" NS Re macro - Reference End
+.de Re
+.rZ
+.rC
+.nr rS 0
+..
+.\" NS rC macro - reference cleanup
+.de rC
+.nr uK 0
+.nr jK 0
+.nr nK 0
+.nr oK 0
+.nr qK 0
+.nr rK 0
+.nr tK 0
+.nr vK 0
+.nr dK 0
+.nr pK 0
+.nr bK 0
+.ds rS
+.rm U1 U2 U3 U4 U5 U6 U7 U8
+.rm uK jK nK oK rK qK tK vK dK pK bK
+..
+.\" NS rZ macro - reference print
+.de rZ
+.if \\n(uK \{\&\\*(U1,
+.	nr aK 1
+.	if (\\n(uK>1 \{\
+.		aK
+.	\}
+.	nr Kl -\\n(uK
+.\}
+.if \\n(tK \{\
+.	nr Kl \\n(Kl-1
+.	if \\n(Kl==0 \{\
+.		ie (\\n(jK==1):(\\n(bK==1) \{\&\\*q\\*(tK\\*q.
+.		\}
+.		el \{\&\\*(eM\\*(tK\\*(nO.
+.		\}
+.	\}
+.	if \\n(Kl>0 \{\
+.		ie (\\n(jK==1):(\\n(bK==1) \{\&\\*q\\*(tK\\*q,
+.		\}
+.		el \{\&\\*(eM\\*(tK\\*(nO,
+.		\}
+.	\}
+.\}
+.if \\n(bK \{\
+.	nr Kl \\n(Kl-1
+.	if \\n(Kl==0 \&\\*(eM\\*(bK\\*(nO.
+.	if \\n(Kl>0 \&\\*(eM\\*(bK\\*(nO,
+.\}
+.if \\n(jK \{\
+.	nr Kl \\n(Kl-1
+.	if \\n(Kl==0 \&\\*(eM\\*(jK\\*(nO.
+.	if \\n(Kl>0 \&\\*(eM\\*(jK\\*(nO,
+.\}
+.if \\n(rK \{\
+.	nr Kl \\n(Kl-1
+.	if \\n(Kl==0 \&\\*(rK.
+.	if \\n(Kl>0 \&\\*(rK,
+.\}
+.if \\n(nK \{\
+.	nr Kl \\n(Kl-1
+.	if \\n(Kl==0 \&\\*(nK.
+.	if \\n(Kl>0 \&\\*(nK,
+.\}
+.if \\n(vK \{\
+.	nr Kl \\n(Kl-1
+.	if \\n(Kl==0 \&\\*(vK.
+.	if \\n(Kl>0 \&\\*(vK,
+.\}
+.if \\n(pK \{\
+.	nr Kl \\n(Kl-1
+.	if \\n(Kl==0 \&\\*(pK.
+.	if \\n(Kl>0 \&\\*(pK,
+.\}
+.if \\n(qK \{\
+.	nr Kl \\n(Kl-1
+.	if \\n(Kl==0 \&\\*(qK.
+.	if \\n(Kl>0 \&\\*(qK,
+.\}
+.if \\n(dK \{\
+.	nr Kl \\n(Kl-1
+.	if \\n(Kl==0 \&\\*(dK.
+.	if \\n(Kl>0 \&\\*(dK,
+.\}
+.if \\n(oK \{\
+.	nr Kl \\n(Kl-1
+.	if \\n(Kl==0 \&\\*(oK.
+.	if \\n(Kl>0 \&\\*(oK,
+.\}
+.if \\n(Kl>0 .tm unresolved reference problem
+..
+.\" NS aK macro - print out reference authors
+.de aK
+.nr aK \\n(aK+1
+.ie (\\n(uK-\\n(aK)==0 \{\&and \\*(U\\n(aK,
+.\}
+.el \{\&\\*(U\\n(aK,
+.	aK
+.\}
+..
+.\" NS %A macro - reference author(s)
+.\" NS uK register - reference author(s) counter
+.\" NS U[1-9] strings - reference author(s) names
+.de %A
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .%A Author_name (#\\n(.c)
+.	el \{\
+.		nr uK \\n(uK+1
+.		nr Kl \\n(Kl+1
+.		ds rS U\\n(uK
+.		ds mN %A
+.		aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.       rR
+.\}
+..
+.\" NS %B macro - [reference] Book Name
+.\" NS bK string - Book Name
+.\" NS bK register - Book Name flag
+.de %B
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .%B Book Name (#\\n(.c)
+.       el \{\
+.		ds mN %B
+.		if \\n(rS>0 \{\
+.			nr bK \\n(bK+1
+.			nr Kl \\n(Kl+1
+.			ds rS bK
+.		\}
+.               ds A1 \\$1
+.               ds A2 \\$2
+.               ds A3 \\$3
+.               ds A4 \\$4
+.               ds A5 \\$5
+.               ds A6 \\$6
+.               ds A7 \\$7
+.               ds A8 \\$8
+.               ds A9 \\$9
+.		nr fV \\n(.$
+.		fV
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.	ie \\n(rS==0 \{\
+.		as b1 \&\\*(eM
+.		nR
+.	\}
+.	el .rR
+.\}
+..
+.\" NS %D macro - [reference] Date
+.\" NS dK string - Date String
+.\" NS dK register - Date flag
+.de %D
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .%D Date (#\\n(.c)
+.       el \{\
+.		ds mN %D
+.		nr dK \\n(dK+1
+.		nr Kl \\n(Kl+1
+.		ds rS dK
+.               ds A1 \\$1
+.               ds A2 \\$2
+.               ds A3 \\$3
+.               ds A4 \\$4
+.               ds A5 \\$5
+.               ds A6 \\$6
+.               ds A7 \\$7
+.               ds A8 \\$8
+.               ds A9 \\$9
+.		nr fV \\n(.$
+.		fV
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.       rR
+.\}
+..
+.\" NS %J macro - [reference] Journal Name
+.\" NS jK register - [reference] Journal Name flag
+.\" NS jK string - [reference] Journal Name
+.de %J
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .%J Journal Name (#\\n(.c)
+.       el \{\
+.		ds mN %J
+.		nr jK \\n(jK+1
+.		ds rS jK
+.		nr Kl \\n(Kl+1
+.               ds A1 \\$1
+.               ds A2 \\$2
+.               ds A3 \\$3
+.               ds A4 \\$4
+.               ds A5 \\$5
+.               ds A6 \\$6
+.               ds A7 \\$7
+.               ds A8 \\$8
+.               ds A9 \\$9
+.		nr fV \\n(.$
+.		fV
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.       rR
+.\}
+..
+.\" NS %N macro - [reference] issue number
+.\" NS nK register - [reference] issue number flag
+.\" NS nK string - [reference] issue number
+.de %N
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .%N issue number (#\\n(.c)
+.	el \{\
+.		nr nK \\n(nK+1
+.		nr Kl \\n(Kl+1
+.		ds rS nK
+.		ds mN %N
+.		aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.       rR
+.\}
+..
+.\" NS %O macro - [reference] optional information
+.\" NS oK register - [reference] optional information flag
+.\" NS oK string - [reference] optional information
+.de %O
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .%O optional information ... \\*(Pu (#\\n(.c)
+.       el \{\
+.		ds mN %O
+.		nr oK \\n(oK+1
+.		nr Kl \\n(Kl+1
+.		ds rS oK
+.               ds A1 \\$1
+.               ds A2 \\$2
+.               ds A3 \\$3
+.               ds A4 \\$4
+.               ds A5 \\$5
+.               ds A6 \\$6
+.               ds A7 \\$7
+.               ds A8 \\$8
+.               ds A9 \\$9
+.		nr fV \\n(.$
+.		fV
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.       rR
+.\}
+..
+.\" NS %P macro - [reference] page numbers
+.\" NS pK register - [reference] page number flag
+.\" NS pK string - [reference] page number
+.de %P
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .%P page numbers ... \\*(Pu (#\\n(.c)
+.       el \{\
+.		ds mN %P
+.		nr pK \\n(pK+1
+.		nr Kl \\n(Kl+1
+.		ds rS pK
+.               ds A1 \\$1
+.               ds A2 \\$2
+.               ds A3 \\$3
+.               ds A4 \\$4
+.               ds A5 \\$5
+.               ds A6 \\$6
+.               ds A7 \\$7
+.               ds A8 \\$8
+.               ds A9 \\$9
+.		nr fV \\n(.$
+.		fV
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.       rR
+.\}
+..
+.\" NS %Q macro - Corporate or Foreign Author
+.\" NS qK string - Corporate or Foreign Author
+.\" NS qK register - Corporate or Foreign Author flag
+.de %Q
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .%Q Corporate or Foreign Author (#\\n(.c)
+.       el \{\
+.		ds mN %Q
+.		nr qK \\n(qK+1
+.		nr Kl \\n(Kl+1
+.		ds rS qK
+.               ds A1 \\$1
+.               ds A2 \\$2
+.               ds A3 \\$3
+.               ds A4 \\$4
+.               ds A5 \\$5
+.               ds A6 \\$6
+.               ds A7 \\$7
+.               ds A8 \\$8
+.               ds A9 \\$9
+.		nr fV \\n(.$
+.		fV
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.       rR
+.\}
+..
+.\" NS %R macro - [reference] report name
+.\" NS rK string - [reference] report name
+.\" NS rK register - [reference] report flag
+.de %R
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .%R reference report (#\\n(.c)
+.       el \{\
+.		ds mN %R
+.		nr rK \\n(rK+1
+.		nr Kl \\n(Kl+1
+.		ds rS rK
+.               ds A1 \\$1
+.               ds A2 \\$2
+.               ds A3 \\$3
+.               ds A4 \\$4
+.               ds A5 \\$5
+.               ds A6 \\$6
+.               ds A7 \\$7
+.               ds A8 \\$8
+.               ds A9 \\$9
+.		nr fV \\n(.$
+.		fV
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.       rR
+.\}
+..
+.\" NS %T macro - reference title
+.\" NS tK string - reference title
+.\" NS tK register - reference title flag
+.de %T
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .%T (#\\n(.c)
+.       el \{\
+.		ds mN %T
+.		if \\n(rS>0 \{\
+.			nr tK \\n(tK+1
+.			nr Kl \\n(Kl+1
+.			ds rS tK
+.		\}
+.               ds A1 \\$1
+.               ds A2 \\$2
+.               ds A3 \\$3
+.               ds A4 \\$4
+.               ds A5 \\$5
+.               ds A6 \\$6
+.               ds A7 \\$7
+.               ds A8 \\$8
+.               ds A9 \\$9
+.		nr fV \\n(.$
+.		fV
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.\" .	ie \\n(jS==1 \{\
+.\" .		nr cF \\n(.f
+.\" .		nr cZ \\n(.s
+.\" .		ds qL \&\\*(Lq\\*(rA
+.\" .		ds qR \&\\*(Rq\f\\n(cF\s\\n(cZ
+.\" .		En \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.\" .	\}
+.\" .	el \{\
+.		nr aP \\n(aP+1
+.		nr cF \\n(.f
+.		nr cZ \\n(.s
+.		ie \\n(rS==0 \{\
+.			as b1 \&\\*(eM
+.			nR
+.		\}
+.		el .rR
+.\" .	\}
+.\}
+..
+.\" NS %V macro - reference volume
+.\" NS vK string - reference volume
+.\" NS vK register - reference volume flag
+.de %V
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .%V Volume , ... \\*(Pu (#\\n(.c)
+.	el \{\
+.		ds mN %V
+.		nr vK \\n(vK+1
+.		nr Kl \\n(Kl+1
+.		ds rS vK
+.		aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.       rR
+.\}
+..
+.\" NS rR macro - reference recursion routine
+.\" NS jM local register
+.\" NS jN local register
+.de rR
+.hy 0
+.nr jM \\n(C\\n(aP
+.ie \\n(jM==1 \{\
+.\" .	as b1 \&\f\\n(cF\s\\n(cZ
+.	ie "\\*(A\\n(aP"Tn" \{\
+.		nN
+.	\}
+.	el \{\
+.		if \\n(aC>8 .tm Usage: \\*(mN - maximum 8 arguments (#\\n(.c)
+.		aI rR 1
+.		\\*(A\\n(aP
+.	\}
+.\}
+.el \{\
+.	nr jN \\n(aP
+.	ie \\n(jM==2 .as b1 \&\\*(A\\n(aP
+.	el .as b1 \&\\*(A\\n(aP
+.\" .	el .as b1 \&\f\\n(cF\s\\n(cZ\\*(A\\n(aP\fP\s0
+.	ie \\n(aC==\\n(aP \{\
+.\" .		as b1 \&\f\\n(cF\s\\n(cZ
+.		rD
+.	\}
+.	el \{\
+.		nr aP \\n(aP+1
+.		as b1 \&\\*(S\\n(jN
+.		rR
+.	\}
+.\}
+.rr jM jN
+..
+.\" NS rD macro - save b1 buffer in to appropriate name
+.de rD
+.as \\*(rS \\*(b1
+.ds b1
+.ds rS
+.aY
+..
+.\" NS Hf macro - source include header files.
+.de Hf
+.Pp
+File:
+.Pa \\$1
+.Pp
+.nr cF \\n(.f
+.nr cZ \\n(.s
+.ie t \{\
+\&\\*(lI
+.br
+.ta +9n 18n 27n 36n 45n 54n 63n 72n
+.\}
+.el \{\
+.ta +8n 16n 24n 32n 40n 48n 56n 64n 72n
+.\}
+.nf
+.so  \\$1
+.fi
+.ft \\n(cF
+.fz \\n(cZ
+.Pp
+..
+.\" NS An macro - author name
+.\" NS aN register
+.nr aN 0
+.de An
+.if \\n(nY==1 \{\
+.	ie \\n(aN==1 \{\
+.		br
+.	\}
+.	el \{\
+.		nr aN 1
+.	\}
+.\}
+.if \\n(aC==0 \{\
+.       ie \\n(.$==0 .tm Usage: .An author_name ... \\*(Pu (#\\n(.c)
+.	el \{\
+.		ds mN An
+.		aV \\$1 \\$2 \\$3 \\$4 \\$5 \\$6 \\$7 \\$8 \\$9
+.	\}
+.\}
+.if \\n(aC>\\n(aP \{\
+.	nr aP \\n(aP+1
+.       nr cF \\n(.f
+.	nr cZ \\n(.s
+.       nR
+.\}
+..
+.\" NS Sf macro -defunct
+.de Sf
+.tm .Sf defunct, use prefix or Ns
+..
+.ds rV "function returns the value 0 if successful; otherwise the value -1 is returned and the global variable \\*(vAerrno\fP is set to indicate the error.
+.\" Ns Rv macro - return values
+.\" Ns rV string - standard return message
+.de Rv
+.ie \\n(.$==0 \{\
+.tm Usage: .Rv [-std] (#\\n(.c)
+.\}
+.el \{\
+.	ds mN Rv
+.\" .	nr aP 0
+.\" .	nr lR \\n(lR+1
+.\" .	ds A1 \\$2
+.\" .	ds A2 \\$3
+.\" .	ds A3 \\$4
+.\" .	ds A4 \\$5
+.\" .	ds A5 \\$6
+.\" .	ds A6 \\$7
+.\" .	ds A7 \\$8
+.\" .	ds A8 \\$9
+.\" .	nr fV \\n(.$-1
+.	if "\\$1"-std" \{\
+.	nr cH \\*(cH
+.	if (\\n(cH<2):(\\n(cH>3) .tm Usage: .Rv -std sections 2 and 3 only
+.		br
+\&The
+.Fn \\$2
+\&\\*(rV
+.	\}
+.\}
+..
--- groff-1.18.orig/tmac/euc-jp.tmac
+++ groff-1.18/tmac/euc-jp.tmac
@@ -0,0 +1,7 @@
+.\" euc-jp.tmac
+.\"
+.cflags 256 ,:;>}
+.cflags 256 ˡ͡ϡѡס١ۤä硼
+.cflags 256 å
+.cflags 512 ʡ̡ΡС֡ء
+.hc 
--- groff-1.18.orig/Makefile.in
+++ groff-1.18/Makefile.in
@@ -130,7 +130,11 @@
 # directory will be always added.
 # `troffrc' and `troffrc-end' (and `eqnrc') are searched neither in the
 # current nor in the home directory.
+ifeq (,$(extratmacdirs))
 tmacpath=$(systemtmacdir):$(localtmacdir):$(tmacdir)
+else
+tmacpath=$(systemtmacdir):$(localtmacdir):$(tmacdir):$(extratmacdirs)
+endif
 
 # sys_tmac_prefix is prefix (if any) for system macro packages
 sys_tmac_prefix=@sys_tmac_prefix@
@@ -189,6 +193,9 @@
 man7ext=7
 man7dir=$(manroot)/man$(man7ext)
 
+# DVI file format.
+DVIFORMAT=@DVIFORMAT@
+
 # the configure script checks whether all necessary utility programs for
 # grohtml are available -- only then we can build the HTML documentation
 make_html=@make_html@
@@ -254,6 +261,8 @@
 # -DRETSIGTYPE=int		if signal handlers return int not void	
 # -DIS_EBCDIC_HOST		if the host's encoding is EBCDIC
 # -DPAGEA4			if the the printer's page size is A4
+# -DNIPPON			enable Japanese extension
+# -DHAVE_LANGINFO_CODESET	if you have nl_langinfo(CODESET)
 DEFINES=@DEFS@
 
 # Include
@@ -383,7 +392,8 @@
   "PERLPATH=$(PERLPATH)" \
   "SH_SCRIPT_SED_CMD=$(SH_SCRIPT_SED_CMD)" \
   "PURIFY=$(PURIFY)" \
-  "PURIFYCCFLAGS=$(PURIFYCCFLAGS)"
+  "PURIFYCCFLAGS=$(PURIFYCCFLAGS)" \
+  "DVIFORMAT=$(DVIFORMAT)"
 
 SHELL=/bin/sh
 INCDIRS=src/include
@@ -425,8 +435,10 @@
   font/devhtml
 ALLTTYDEVDIRS=\
   font/devascii \
+  font/devascii8 \
   font/devlatin1 \
   font/devutf8 \
+  font/devnippon \
   font/devcp1047
 OTHERDIRS=\
   man \
@@ -471,7 +483,7 @@
 	fi
 
 do=all
-dodirs=$(ALLDIRS) dot
+dodirs=$(DISTDIRS) 
 # Default target for subdir_Makefile
 subdir=src/roff/troff
 
--- groff-1.18.orig/aclocal.m4
+++ groff-1.18/aclocal.m4
@@ -415,6 +415,47 @@
 AC_MSG_RESULT([$tmac_wrap])
 AC_SUBST(tmac_wrap)])dnl
 dnl
+dnl codeset.m4 from gettext, by Bruno Haible.
+dnl
+AC_DEFUN(GROFF_LANGINFO_CODESET,
+[AC_CACHE_CHECK([for nl_langinfo and CODESET], groff_cv_langinfo_codeset,
+    [AC_TRY_LINK([#include <langinfo.h>],
+      [char* cs = nl_langinfo(CODESET);],
+      groff_cv_langinfo_codeset=yes,
+      groff_cv_langinfo_codeset=no)
+    ])
+  if test $groff_cv_langinfo_codeset = yes; then
+    AC_DEFINE(HAVE_LANGINFO_CODESET, 1,
+      [Define if you have <langinfo.h> and nl_langinfo(CODESET).])
+  fi
+])dnl
+dnl
+dnl Support Japanese Code (EUC)
+dnl
+AC_DEFUN(GROFF_NIPPON,
+[AC_MSG_CHECKING([enable japanese extension])
+ AC_ARG_ENABLE(japanese, [  --enable-japanese  Enable Japanese extension],
+  japanese=$enableval, japanese=no)
+if test "$japanese" = yes; then
+  AC_MSG_RESULT(yes)
+  AC_DEFINE(NIPPON, 1,
+	[Define if you want to use Japanese extension.])
+  GROFF_LANGINFO_CODESET
+fi
+])dnl
+dnl
+dnl
+AC_DEFUN(GROFF_DVIFORMAT,
+[AC_MSG_CHECKING([japanese dvi file format])
+if test "x$dvi_format" != "xASCII"; then
+  DVIFORMAT=NTT
+else
+  DVIFORMAT=ASCII
+fi
+AC_MSG_RESULT([$DVIFORMAT])
+AC_SUBST(DVIFORMAT)
+])dnl
+dnl
 dnl
 AC_DEFUN(GROFF_G,
 [AC_MSG_CHECKING([for existing troff installation])
@@ -481,7 +522,7 @@
  AC_DEFINE(IS_EBCDIC_HOST, 1,
 	   [Define if the host's encoding is EBCDIC.]),
 groff_cv_ebcdic="no"
- TTYDEVDIRS="font/devascii font/devlatin1"
+ TTYDEVDIRS="font/devascii font/devlatin1 font/devascii8 font/devnippon"
  OTHERDEVDIRS="font/devlj4 font/devlbp"
  AC_MSG_RESULT(no))
 AC_SUBST(TTYDEVDIRS)
--- groff-1.18.orig/configure
+++ groff-1.18/configure
@@ -827,6 +827,11 @@
 
   cat <<\_ACEOF
 
+Optional Features:
+  --disable-FEATURE       do not include FEATURE (same as --enable-FEATURE=no)
+  --enable-FEATURE[=ARG]  include FEATURE [ARG=yes]
+  --enable-japanese  Enable Japanese extension
+
 Some influential environment variables:
   CC          C compiler command
   CFLAGS      C compiler flags
@@ -2469,7 +2474,7 @@
   echo "$as_me: failed program was:" >&5
 cat conftest.$ac_ext >&5
 groff_cv_ebcdic="no"
- TTYDEVDIRS="font/devascii font/devlatin1"
+ TTYDEVDIRS="font/devascii font/devlatin1 font/devascii8 font/devnippon"
  OTHERDEVDIRS="font/devlj4 font/devlbp"
  echo "$as_me:$LINENO: result: no" >&5
 echo "${ECHO_T}no" >&6
@@ -5938,6 +5943,90 @@
 esac
 
 
+echo "$as_me:$LINENO: checking enable japanese extension" >&5
+echo $ECHO_N "checking enable japanese extension... $ECHO_C" >&6
+ # Check whether --enable-japanese or --disable-japanese was given.
+if test "${enable_japanese+set}" = set; then
+  enableval="$enable_japanese"
+  japanese=$enableval
+else
+  japanese=no
+fi;
+if test "$japanese" = yes; then
+  echo "$as_me:$LINENO: result: yes" >&5
+echo "${ECHO_T}yes" >&6
+
+cat >>confdefs.h <<\_ACEOF
+#define NIPPON 1
+_ACEOF
+
+  echo "$as_me:$LINENO: checking for nl_langinfo and CODESET" >&5
+echo $ECHO_N "checking for nl_langinfo and CODESET... $ECHO_C" >&6
+if test "${groff_cv_langinfo_codeset+set}" = set; then
+  echo $ECHO_N "(cached) $ECHO_C" >&6
+else
+  cat >conftest.$ac_ext <<_ACEOF
+#line $LINENO "configure"
+#include "confdefs.h"
+#include <langinfo.h>
+#ifdef F77_DUMMY_MAIN
+#  ifdef __cplusplus
+     extern "C"
+#  endif
+   int F77_DUMMY_MAIN() { return 1; }
+#endif
+int
+main ()
+{
+char* cs = nl_langinfo(CODESET);
+  ;
+  return 0;
+}
+_ACEOF
+rm -f conftest.$ac_objext conftest$ac_exeext
+if { (eval echo "$as_me:$LINENO: \"$ac_link\"") >&5
+  (eval $ac_link) 2>&5
+  ac_status=$?
+  echo "$as_me:$LINENO: \$? = $ac_status" >&5
+  (exit $ac_status); } &&
+         { ac_try='test -s conftest$ac_exeext'
+  { (eval echo "$as_me:$LINENO: \"$ac_try\"") >&5
+  (eval $ac_try) 2>&5
+  ac_status=$?
+  echo "$as_me:$LINENO: \$? = $ac_status" >&5
+  (exit $ac_status); }; }; then
+  groff_cv_langinfo_codeset=yes
+else
+  echo "$as_me: failed program was:" >&5
+cat conftest.$ac_ext >&5
+groff_cv_langinfo_codeset=no
+fi
+rm -f conftest.$ac_objext conftest$ac_exeext conftest.$ac_ext
+
+fi
+echo "$as_me:$LINENO: result: $groff_cv_langinfo_codeset" >&5
+echo "${ECHO_T}$groff_cv_langinfo_codeset" >&6
+  if test $groff_cv_langinfo_codeset = yes; then
+
+cat >>confdefs.h <<\_ACEOF
+#define HAVE_LANGINFO_CODESET 1
+_ACEOF
+
+  fi
+
+fi
+
+echo "$as_me:$LINENO: checking japanese dvi file format" >&5
+echo $ECHO_N "checking japanese dvi file format... $ECHO_C" >&6
+if test "x$dvi_format" != "xASCII"; then
+  DVIFORMAT=NTT
+else
+  DVIFORMAT=ASCII
+fi
+echo "$as_me:$LINENO: result: $DVIFORMAT" >&5
+echo "${ECHO_T}$DVIFORMAT" >&6
+
+
 ac_config_files="$ac_config_files stamp-h"
 
 ac_config_files="$ac_config_files Makefile doc/Makefile src/xditview/Imakefile"
@@ -6542,6 +6631,7 @@
 s,@psselect@,$psselect,;t t
 s,@make_html@,$make_html,;t t
 s,@make_install_html@,$make_install_html,;t t
+s,@DVIFORMAT@,$DVIFORMAT,;t t
 CEOF
 
 _ACEOF
--- groff-1.18.orig/configure.ac
+++ groff-1.18/configure.ac
@@ -68,6 +68,8 @@
 GROFF_G
 GROFF_TMAC
 GROFF_HTML_PROGRAMS
+GROFF_NIPPON
+GROFF_DVIFORMAT
 AC_CONFIG_FILES(stamp-h, [echo timestamp > stamp-h])
 AC_CONFIG_FILES([Makefile doc/Makefile src/xditview/Imakefile])
 AC_OUTPUT
--- groff-1.18.orig/mdate.sh
+++ groff-1.18/mdate.sh
@@ -2,41 +2,4 @@
 
 # Print the modification date of $1 `nicely'.
 
-# Don't want foreign dates.
-
-LANGUAGE=
-LC_ALL=C; export LC_ALL
-
-
-(date;
-if ls -L /dev/null 1>/dev/null 2>&1; then ls -L -l $1; else ls -l $1; fi
-) | awk '
-BEGIN {
-	full["Jan"] = "January"; number["Jan"] = 1;
-	full["Feb"] = "February"; number["Feb"] = 2;
-	full["Mar"] = "March"; number["Mar"] = 3;
-	full["Apr"] = "April"; number["Apr"] = 4;
-	full["May"] = "May"; number["May"] = 5;
-	full["Jun"] = "June"; number["Jun"] = 6;
-	full["Jul"] = "July"; number["Jul"] = 7;
-	full["Aug"] = "August"; number["Aug"] = 8;
-	full["Sep"] = "September"; number["Sep"] = 9;
-	full["Oct"] = "October"; number["Oct"] = 10;
-	full["Nov"] = "November"; number["Nov"] = 11;
-	full["Dec"] = "December"; number["Dec"] = 12;
-}
-
-NR == 1 {
-	month = $2;
-	year = $NF;
-}
-
-NR == 2 {
-	if ($(NF-1) ~ /:/) {
-		if (number[$(NF-3)] > number[month])
-			year--;
-	}
-	else
-		year = $(NF-1);
-	print $(NF-2), full[$(NF-3)], year
-}'
+perl -MPOSIX -le 'print strftime("%d %B %Y", localtime((stat $ARGV[0])[9]))' $1
--- groff-1.18.orig/debian/changelog
+++ groff-1.18/debian/changelog
@@ -0,0 +1,707 @@
+groff (1.18-1) unstable; urgency=low
+
+  * New upstream release. Highlights:
+    - Colour support (although see below).
+    - New macro set, mom, mainly for non-scientific writers. The aim of
+      these macros is to make groff accessible for ordinary use with a
+      minimum of convoluted syntax.
+    - 'eu' and 'Eu' characters available for Euro support.
+    - Improved support for TeX hyphenation files.
+    - New means of setting the line length, which now works for -mdoc manual
+      pages as well as -man. Use man-db >= 2.4.0 to take advantage of this.
+    - Documentation of the differences between groff and Unix troff is now
+      in groff_diff(7).
+    - groff_mwww(1) has been renamed to groff_www(1).
+    - groff_ms(7) has been completely rewritten.
+    - New scripts: groffer, pic2graph, and eqn2graph.
+    - Substantial improvements in grohtml (although it's still alpha),
+      including dealing with overstriking properly (closes: #67545).
+
+  * Many thanks, again, to Fumitoshi UKAI for forward-porting the Japanese
+    patch.
+  * Disable the new ANSI colour/bold/underline escapes in nroff mode,
+    because most pagers either fail to cope with it or need special options
+    to do so. It can be re-enabled by editing /etc/groff/man.local and
+    /etc/groff/mdoc.local, or by setting the environment variable GROFF_SGR
+    to something non-empty.
+  * Drop most current /etc/papersize patches, as the 'papersize' DESC
+    keyword is now available upstream. We now only patch the DESC files and
+    extend the papersize keyword to allow falling back to something else if
+    /etc/papersize doesn't exist.
+  * Fix the removal of final newlines when reading /etc/papersize.
+  * Translate the 'oq' character to an apostrophe (0x27) rather than a
+    backquote (0x60) when using devices other than utf8 (closes: #149086).
+
+  * Merge groff-x11 back into groff, since this release doesn't have to
+    worry so much about smooth upgrades from potato (closes: #129835).
+  * Accordingly, remove the debconf note about this, since it was an abuse
+    of debconf anyway. README.Debian describes the package organization.
+  * Include more documentation in the main groff package (closes: #121475).
+  * Build-depend on gs, netpbm, and psutils for HTML documentation. Mention
+    in README.build that people bootstrapping a new port or otherwise
+    building the base system from scratch don't need these three.
+  * Recommend these three packages for the grohtml driver.
+  * Recommend imagemagick for pic2graph and eqn2graph.
+  * Downgrade libpaperg dependency to a recommendation, since we fall back
+    to a4 now if it's not installed.
+  * Use debhelper v3 mode.
+  * Upstream ships pre-built info files now, so use them. You need texinfo
+    (>= 4.2) if you want to regenerate them.
+
+ -- Colin Watson <cjwatson@debian.org>  Sun, 21 Jul 2002 18:33:04 +0100
+
+groff (1.17.2-17) unstable; urgency=low
+
+  * Back to unstable, now that there's no concern about disrupting woody.
+    Merge changes from -15.woody.1 (unstable) and -16 (experimental).
+  * Delete excess charset information in M and G font files that also use
+    the fixedkanji directive, after consultation with Fumitoshi UKAI. This
+    saves over 1.6Mb.
+  * Move ps device to base, now that it isn't quite so large. It's needed
+    there because it's the default device (closes: #131410).
+  * Update the descriptions of groff-base and groff for the move of the
+    PostScript device.
+
+ -- Colin Watson <cjwatson@debian.org>  Sat,  4 May 2002 18:03:40 +0100
+
+groff (1.17.2-16) experimental; urgency=low
+
+  * Experimental upload for the benefit of the NetBSD porters.
+  * Document the build-dependency loop with xfree86, and allow people
+    constructing new ports to override this temporarily with
+    DEB_BUILD_OPTIONS=no-groff-x11 (closes: #130312).
+  * Import AM_LANGINFO_CODESET macro from gettext, and use it for
+    --enable-japanese to provide an emulation of nl_langinfo(CODESET) for
+    systems that don't have it (closes: #130356).
+  * Fix build without --enable-japanese.
+  * Build-depend on a version of debhelper which pulls in debconf-utils
+    (closes: #130357).
+  * Test that Makefile.clean doesn't exist before clobbering it in the
+    configure target.
+
+ -- Colin Watson <cjwatson@debian.org>  Tue, 22 Jan 2002 18:34:22 +0000
+
+groff (1.17.2-15.woody.1) unstable; urgency=medium
+
+  * New Danish debconf translation (thanks, Rune B. Broberg;
+    closes: #131092).
+  * New French debconf translation (thanks, Philippe Batailler;
+    closes: #138515).
+
+ -- Colin Watson <cjwatson@debian.org>  Sun, 17 Mar 2002 04:11:50 +0000
+
+groff (1.17.2-15) unstable; urgency=high
+
+  * Fix buffer overflow in grn (closes: #129261).
+
+ -- Colin Watson <cjwatson@debian.org>  Tue, 15 Jan 2002 00:22:19 +0000
+
+groff (1.17.2-14) unstable; urgency=low
+
+  * Upstream patch to make .TH respect the line length (closes: #125826).
+
+ -- Colin Watson <cjwatson@debian.org>  Mon, 14 Jan 2002 02:49:45 +0000
+
+groff (1.17.2-13) unstable; urgency=high
+
+  * Fix peekbyte() to return correctly (closes: #122702).
+
+ -- Colin Watson <cjwatson@debian.org>  Thu,  6 Dec 2001 17:15:20 +0000
+
+groff (1.17.2-12) unstable; urgency=high
+
+  * Use -fno-strength-reduce on hppa, as a temporary workaround for a
+    compiler bug.
+  * Display package-split note when reconfiguring (closes: #122420).
+
+ -- Colin Watson <cjwatson@debian.org>  Wed,  5 Dec 2001 17:24:08 +0000
+
+groff (1.17.2-11) unstable; urgency=high
+
+  * Use lpr as the print spooler, even if it happens not to be installed on
+    the build system. This broke 'groff -l' (thanks, Mike Fontenot).
+
+ -- Colin Watson <cjwatson@debian.org>  Fri, 30 Nov 2001 21:41:29 +0000
+
+groff (1.17.2-10) unstable; urgency=high
+
+  * Install lbp.tmac (closes: #121765).
+
+ -- Colin Watson <cjwatson@debian.org>  Thu, 29 Nov 2001 20:28:18 +0000
+
+groff (1.17.2-9) unstable; urgency=low
+
+  * Add Fumitoshi UKAI to Uploaders, in case of emergencies.
+  * Move refer to groff, as this saves over 100K in groff-base and I don't
+    think refer is very useful without additional macro packages.
+  * Document refer in groff's description.
+  * Move ChangeLog.jp and README.jp to groff-base.
+  * Replace createM.c with a Perl implementation to aid cross-compilation
+    (thanks, Fumitoshi UKAI; closes: #114338).
+
+ -- Colin Watson <cjwatson@debian.org>  Sun, 14 Oct 2001 04:35:20 +0100
+
+groff (1.17.2-8) unstable; urgency=medium
+
+  * The "Texas Armadillo" release.
+  * Policy version 3.5.6 (support build-arch and build-indep targets).
+  * Reduce size of devnippon fonts, and include devnippon in groff-base
+    (thanks, Fumitoshi UKAI and GOTO Masanori; closes: #112622).
+  * Upstream fix for overzealous warnings from -mm and -ms (closes: #69129).
+  * Fix building in a subdirectory (closes: #111229).
+  * Remove spurious substitutions of '..' for '.' in groff_man(7).
+  * groff depends on libpaperg so that /etc/papersize is always present.
+  * Urgency medium as the above has broken some builds of other packages.
+  * Correct quoted-printable remnant in Brazilian Portugese debconf template
+    (thanks, Andre Luis Lopes; closes: #110192).
+  * New Russian debconf template (thanks, Ilgiz Kalmetev; closes: #112653).
+
+ -- Colin Watson <cjwatson@debian.org>  Wed, 19 Sep 2001 01:34:21 +0100
+
+groff (1.17.2-7) unstable; urgency=low
+
+  * Back with a new GPG key after a disk crash. Thanks for the NMU in the
+    meantime (closes: #107998, #108705).
+  * Document that -E can't suppress messages output to stderr by macro
+    packages using .tm or .tm1 (fix from upstream CVS; closes: #69130).
+  * src/devices/grotty/tty.cc: Correct one instance of putchar() on a
+    potential UTF-8 character to put_char() (thanks, Mike Fabian and Michael
+    Schroeder; closes: #110008).
+
+ -- Colin Watson <cjwatson@debian.org>  Sun, 26 Aug 2001 00:15:42 +0100
+
+groff (1.17.2-6.1) unstable; urgency=low
+
+  * Non Maintainer Upload
+  * fix hyphen character problem in EUC-JP encoding
+    (closes: Bug#107998).
+
+ -- Fumitoshi UKAI <ukai@debian.or.jp>  Fri, 17 Aug 2001 02:06:21 +0900
+
+groff (1.17.2-6) unstable; urgency=medium
+
+  * src/devices/grohtml/post-html.cc: Put characters into the right places
+    in the output buffer so that HTML output no longer ends up as gibberish
+    (closes: #107788).
+
+ -- Colin Watson <cjwatson@debian.org>  Wed,  8 Aug 2001 00:33:13 +0100
+
+groff (1.17.2-5) unstable; urgency=high
+
+  * src/preproc/pic/pic.y: Fix format string vulnerability that could allow
+    the -S flag to be disabled (closes: #107459). Patch adapted from one by
+    Zenith Parsec <zen-parse@gmx.net>.
+  * Add a note to README.Debian about where to find documentation.
+
+ -- Colin Watson <cjwatson@debian.org>  Thu,  2 Aug 2001 20:36:18 +0100
+
+groff (1.17.2-4) unstable; urgency=low
+
+  * src/preproc/eqn/text.cc: Initialize wc to the value of the current
+    character even if it isn't a wide character. Otherwise eqn would output
+    nulls instead of normal characters (closes: #106551).
+  * Conflict with jgroff as well as with pre-split versions of ordinary
+    groff, and make references to jgroff versioned to avoid triggering on
+    groff's Provides: field.
+
+ -- Colin Watson <cjwatson@debian.org>  Wed, 25 Jul 2001 22:40:52 +0100
+
+groff (1.17.2-3) unstable; urgency=low
+
+  * Remove spare newline from troffrc, which broke e.g. the ms macros
+    (closes: #105777).
+
+ -- Colin Watson <cjwatson@debian.org>  Thu, 19 Jul 2001 00:07:18 +0100
+
+groff (1.17.2-2) unstable; urgency=medium
+
+  * Urgency medium to get a halfway recent groff into testing for the base
+    system freeze. This version should be a significant improvement for
+    non-ASCII/Latin-1 users.
+
+  * New Japanese patch from Fumitoshi UKAI:
+
+    groff (1.17.2-1.ukai.1) unstable; urgency=low
+
+      * fix tmac/euc-jp.tmac (fix coding-system)
+
+     -- Fumitoshi UKAI <ukai@debian.or.jp>  Sun, 15 Jul 2001 21:14:56 +0900
+
+    groff (1.17.2-1.ukai.0) unstable; urgency=low
+
+      * revised Japanese patch evaluation build
+        - refactoring, cleanups
+          not completed (for example src/xditview)
+
+     -- Fumitoshi UKAI <ukai@debian.or.jp>  Sun, 15 Jul 2001 15:27:59 +0900
+
+    Also added dq and cq characters to the ascii8 and nippon devices.
+
+  * Make groff-base and groff-x11 conflict with pre-split groff
+    (closes: #105276).
+  * Move ascii8 device to groff-base (closes: #105627).
+  * Remove stray + in groff(1) (closes: #105530).
+  * New Brazilian Portugese debconf translation (thanks, Andre Luis Lopes;
+    closes: #105367).
+
+ -- Colin Watson <cjwatson@debian.org>  Tue, 17 Jul 2001 17:58:23 +0100
+
+groff (1.17.2-1) unstable; urgency=low
+
+  * New upstream release. Fixes \s[0] escape (affects non-tty use of mdoc).
+  * debian/rules:
+    - The clean target now cleans the source tree better.
+    - Use version detection from Makefile.in: it's friendlier to syntax
+      highlighting.
+
+ -- Colin Watson <cjwatson@debian.org>  Mon,  9 Jul 2001 03:35:20 +0100
+
+groff (1.17.1-3) unstable; urgency=low
+
+  * New Spanish debconf translation (thanks, Carlos Valdivia Yage;
+    closes: #102897).
+
+ -- Colin Watson <cjwatson@debian.org>  Sat, 30 Jun 2001 20:05:18 +0100
+
+groff (1.17.1-2) unstable; urgency=low
+
+  * Conflict with pmake (<< 1.45-7), which had problems with the new
+    location of groff's macros (see #101973).
+
+ -- Colin Watson <cjwatson@debian.org>  Sun, 24 Jun 2001 03:45:43 +0100
+
+groff (1.17.1-1) unstable; urgency=low
+
+  * New upstream release.
+  * Of course, the library directory has moved with the new version number.
+    Add a symlink, /usr/share/groff/current, which points to the current
+    library directory; also add a versioned conflicts on troffcvt, which I'm
+    about to fix to cope with this. If you rely on some particular version,
+    use it; if not, use current.
+  * Autogenerate debian/groff-base.files and debian/groff-base.links.
+
+ -- Colin Watson <cjwatson@debian.org>  Sat, 23 Jun 2001 00:54:37 +0100
+
+groff (1.17-4) unstable; urgency=low
+
+  * Back out patch supporting transparent decompression of groff's input
+    stream. Since programs using groff have to support systems where *roff
+    doesn't know how to decompress things, it doesn't really simplify
+    anything else greatly; more importantly, using gzip means that argument
+    parsing didn't always work the way we expected (closes: #75990).
+  * The lj4 and ps drivers already support /etc/papersize due to an earlier
+    Debian patch, and it turns out that lbp supports it upstream but wasn't
+    previously configured to use it. Altered its DESC file to meet libpaper
+    standards (closes: #19681, #19722).
+  * Move the error unwind for groff-base's preinst into its postrm (oops).
+  * New German debconf translation (thanks, Sebastian Feltel;
+    closes: #100681).
+  * Add README.Debian, describing the recent package reorganization.
+  * Update copyright file to describe all upstream-relevant patches.
+
+ -- Colin Watson <cjwatson@debian.org>  Wed, 20 Jun 2001 00:43:45 +0100
+
+groff (1.17-3) unstable; urgency=low
+
+  * Restore /usr/share/groff/tmac to the macro path, as some third-party
+    programs install macros there (should fix #100139, but I'll leave it to
+    the vgrind maintainer to check that groff 1.17 hasn't broken anything
+    else).
+
+ -- Colin Watson <cjwatson@debian.org>  Fri,  8 Jun 2001 19:06:15 +0100
+
+groff (1.17-2) unstable; urgency=low
+
+  * Brown paper bag bug: move grotty to groff-base!
+  * Also move the doc macros to groff-base; some man pages use them. (This
+    and the above bloat -base by some 200K, I'm afraid.)
+  * Mention in the debconf note that groff-base supports Latin-1 and UTF-8
+    as well as ASCII.
+  * /usr/share/groff/site-tmac contains mdoc.local as well as man.local as
+    of 1.17, so make that whole directory a symlink to /etc/groff and
+    migrate the old /etc/tmac.man.local conffile to /etc/groff/man.local.
+    This seems to need some ugly migration code.
+  * Back out the autoconf 2.50 diffs for now, as they were polluting the
+    .diff.gz. I've sent them upstream, though.
+
+ -- Colin Watson <cjwatson@debian.org>  Wed,  6 Jun 2001 17:02:12 +0100
+
+groff (1.17-1) unstable; urgency=low
+
+  * New maintainer (ciao, Fabrizio).
+  * Thanks for the NMUs (closes: #75722, #90765).
+  * New upstream release, with corresponding debian/copyright updates.
+  * Follow upstream's move to versioned subdirectories of /usr/share/groff.
+  * The components of groff required to support normal use of man-db are now
+    in a separate package, groff-base (thanks, Elrond; closes: #53225).
+  * Also split out gxditview and the devices that use it into the groff-x11
+    package. I'd have preferred them to stay part of groff, as discussed on
+    -devel, but the necessary xlibs dependency would mean that everybody
+    dist-upgrading from a potato base system would get the X libraries.
+    Added a debconf note to avoid silent loss of functionality; maybe in
+    woody+1 they can be merged back into groff.
+
+  * New packaging, using debhelper.
+    - This shouldn't generate invalid syntax in the prerm (closes: #86437).
+    - All binaries should be correctly stripped now (closes: #96786).
+  * Add build dependencies (thanks, Daniel Schepler; closes: #80844).
+  * Don't bother running configure in the clean target.
+  * Touch configure in debian/rules to avoid a build-dep on autoconf. This
+    means I have to remember to run the autotools manually every time. Ugh.
+  * Support DEB_BUILD_OPTIONS debug and nostrip.
+  * Mark /etc/X11/app-defaults/GXditview as a conffile.
+  * All this brings us to Standards-Version: 3.5.2.
+
+  * New Japanese patch (version 0.0.2) from Fumitoshi UKAI. This may not be
+    quite right yet; please let me know if there are any problems.
+  * Replace mdate.sh with something whose results are more predictable
+    (thanks, Florian Lohoff; closes: #62554).
+  * Force LC_ALL to C so that makeinfo doesn't insert some localized strings
+    for the package builder's environment (closes: #84370).
+  * s/man/man-db/ in the package description.
+  * Remove an autoconf hack from aclocal.m4; the bug it's working around is
+    now fixed and the hack broke with autoconf 2.50 (closes: #98916).
+  * Set gxditview's fontpath in debian/rules, restoring
+    /usr/local/share/groff/font.
+  * Preserve the Makefile to avoid a large diff.
+  * Back out single-page an.tmac patch; upstream did it more neatly.
+
+ -- Colin Watson <cjwatson@debian.org>  Sat,  2 Jun 2001 20:18:14 +0100
+
+groff (1.16-3.4) unstable; urgency=medium
+
+  * Non-maintainer upload
+  * gcc 3.0 fixes (needed by PARISC port).  fixes #90765.
+
+ -- LaMont Jones <lamont@debian.org>  Wed, 25 Apr 2001 00:19:29 -0600
+
+groff (1.16-3.3) unstable; urgency=medium
+
+  * Non-maintainer upload
+  * fixed font count in font/devdvi/DESC.in as suggested in bug
+    report from John P. Cummings <cummij@rpi.edu>, closes: #75722
+
+ -- Paul Bame <bame@debian.org>  Sat, 24 Feb 2001 17:16:47 -0700
+
+groff (1.16-3.2) unstable; urgency=high
+
+  * Added ascii8 device and fixed bug with (non-latin1&&non-CJK) man-pages 
+    viewing (before this polish, russian etc. manpages couldn't be viewed), 
+    closes: #81148, #71744, #66928, #74535
+
+ -- Peter Novodvorsky <nidd@debian.org>  Sun, 14 Jan 2001 01:09:24 +0300
+
+groff (1.16-3.1) unstable; urgency=low
+
+  * Rebuilt on a system with Xfree 4 and toasted contents of /usr/X11R6/lib,
+    closes: #76813, #77024, #77515, #77608, #77684, #78054, #78905, #79472,
+    #80559
+
+ -- Robert Woodcock <rcw@debian.org>  Thu, 28 Dec 2000 20:51:34 -0800
+  
+groff (1.16-3) unstable; urgency=low
+
+  * oops: had left generated files in the diff.
+  * In new macro checking for gzcat (aclocal.m4), added use of option -f
+    to permit transparent fallback to 'normal' cat.
+  * In src/roff/groff/groff.cc , added gzcat command before soelim; it
+    permits transparent use of zipped or not sources.
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Sun, 27 Aug 2000 18:13:10 +0300
+
+groff (1.16-2) unstable; urgency=low
+
+  * now going into woody (previous were experimental).
+  * Added check for gzip in configure.in
+  * Applyed correction to patch #64551, thanx to Werner LEMBERG.
+  * Added single final footer to an macro, thanx to Werner LEMBERG;
+    closes: #65735. (waiting for the same for the doc macro)
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Mon,  3 Jul 2000 00:13:23 +0300
+
+groff (1.16-1) experimental; urgency=low
+
+  * Fixed src/roff/nroff.sh, which was too much different from the
+    previous one to apply the dumb patch. 
+    Thanx to Taketoshi Sano for the right patch!
+    (that was exactly the reason for using experimental instead of
+    unstable: uploading something broken and ask for help to fix it,
+    yeah!)
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Fri, 16 Jun 2000 11:33:47 +0300
+
+groff (1.16-0) experimental; urgency=low
+
+  * New upstream release.
+  * Manually applyed all the nippon and ascii8 changes.
+    Failed for: src/roff/nroff.sh, 
+  * Added new info document.
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Wed,  7 Jun 2000 19:09:17 +0300
+
+groff (1.15.3-2) unstable; urgency=low
+
+  * Applied patch proposed by Karl M.Hegbloom to get a single page from
+    manpages when in nroff mode.  Closes: #64551.
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Thu, 25 May 2000 13:43:18 +0300
+
+groff (1.15.3-1) unstable; urgency=low
+
+  * re-enabled default font in Dvi.c, thanx to Kevin Ryde.
+    closes: #63491, but opens probably some other i18n related bug,
+    sigh.
+  * changed version to 1.15.3 (waiting for 1.16 :-) to be grater than
+    the version in slink and than the one in potato.
+    This means that I must reupload the sources ... which were gone from
+    woody anyway (why it's possible?).
+  * Applyed patch submitted by Tomohiro KUBOTA:
+    * Added a new device type 'ascii8', which is 8 bit clean (like latin1)
+      but does not use Latin-1 character for hyphenation and so on (like
+      ascii).  This device is intended to be used for codesets other than
+      ASCII and ISO-8859-1.  This device should be temporal till all
+      charsets (ISO-8859-*, KOI8-R, EUC-KR, EUC-ZH, TIS620, and so on so on)
+      in the world are implemented, though this is almost impossible.
+    * Added a new character 'sy', which is soft hyphen.  This character is
+      defined only for latin1 device.  This 'sy' is used for hyphenation
+      instead of [char173], because [char173] may not be a soft hyphen,
+      though [char173] is a soft hyphen in ISO-8859-1.
+      Tomohiro KUBOTA <kubota@debian.or.jp>  Wed, 19 Apr 2000 23:47:18 +0900
+    This closes: #62840.
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Thu, 11 May 2000 10:44:14 +0300
+
+groff (1.15-3.ja.3) unstable; urgency=low
+
+  * Corrected bug that segfaults when reading manpage printf(1), thanx
+    to David Schmitt who submitted the bug (closes: #60096) and to
+    Fumitoshi UKAI who submitted the patch to fix it. It was the same
+    bug that jgroff had (#59628).
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Mon, 13 Mar 2000 12:50:02 +0200
+
+groff (1.15-3.ja.2) unstable; urgency=low
+
+  * Included changes proposed by Fumitoshi UKAI and Taketoshi Sano.
+  * corrected groff_man manpage which didn't parse correctly for mandb.
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Fri, 25 Feb 2000 20:57:40 +0200
+
+groff (1.15-3.ja.1) experimental; urgency=low
+
+  * Added japanes patch for join with jgroff.
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Sun, 30 Jan 2000 15:36:03 +0200
+
+groff (1.15-3) frozen unstable; urgency=high
+
+  * mm and mse macros were missing (thanx to Daniel Quinlan to make me
+    discover this grave bug); closes: #55428.
+  * corrected wrong .so request in macro mse
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Mon, 17 Jan 2000 15:25:06 +0200
+
+groff (1.15-2) unstable; urgency=low
+
+  * quick fix to a bug reported only mainstream.
+    postscript device fails if paper format is not a4 or letter.
+    Fixed using "letter" for all other formats, as it _was_ before.
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Fri, 14 Jan 2000 12:21:38 +0200
+
+groff (1.15-1) unstable; urgency=low
+
+  * new upstream release: only minor bugfixes.
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Thu,  6 Jan 2000 18:23:41 +0200
+
+groff (1.12-1) unstable; urgency=low
+
+  * new upstream release.
+    Got all previous changes (except papersize),
+    plus: new HTML device! (expermental).
+  * leaved version numeric only: closes: #31739, thanx to 
+    Jonathan H N Chin <jhnc@pfaff.newton.cam.ac.uk>.
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Fri, 17 Dec 1999 14:40:46 +0200
+
+groff (1.11b-1) unstable; urgency=low
+
+  * updated to policy 3.1.0.
+  * new imminent release 1.12; this use groff-current renamed
+    groff-1.11b.  Not to be uploaded until 1.12 is released.
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Sun, 12 Dec 1999 18:15:26 +0200
+
+groff (1.11a-9) unstable; urgency=low
+
+  * not uploaded due to imminent 1.12
+  * added management of /etc/papersize in driver lj4.
+    todo: the same in driver ps.
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Sun,  5 Dec 1999 14:26:18 +0200
+
+groff (1.11a-8) unstable; urgency=low
+
+  * moved tmac.local to /etc (as tmac.man.local) and symlinked from the
+    original place; made it a conffile. Thanx to Decklin Foster
+    <decklin@home.com>, closes: #39043
+  * recompiled with libstdc++2.10 . closes: #49392.
+  * added manpages groff_mdoc(7) and groff_mdoc.samples(7) taken from
+    netBSD, thanks to Ben Harris <bjh21@cam.ac.uk>. closes: #49159.
+  * added Y2K corrections from the beta-12, from Paul Eggert.
+  * Got rid of old and unusefull checks in postinst.
+  * added symlink from /usr/doc, and added -e to script; closes: #39410
+  * Bugs fixed in previous releases: closes: #27016, #28097.
+  * Updated to std policy 3.0.1
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Tue, 26 Oct 1999 14:39:10 +0300
+
+groff (1.11a-7) unstable; urgency=low
+
+  * Applied patch to add include path search to groff e gsoelim, provided by 
+    Peter Miller <millerp@canb.auug.org.au> needed by aegis.
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Sat, 17 Oct 1998 23:45:27 +0300
+
+groff (1.11a-6) unstable; urgency=low
+
+  * Recompiled to generate new dependencies into libs
+    (closes: #27790, thanx to Zephaniah E, Hull.)
+    [Previous attempt wasn't succesful.]
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Sat, 17 Oct 1998 02:39:10 +0300
+
+groff (1.11a-5) unstable; urgency=low
+
+  * Recompiled to generate new dependencies into libs
+    (closes: #27790, thanx to Zephaniah E, Hull.)
+  * added mime file as suggested by Brian White 
+    (closes: #27016)
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Tue, 13 Oct 1998 18:54:55 +0300
+
+groff (1.11a-4) unstable; urgency=low
+
+  * Added groff_man(7) manpage for tmac.an macro written by Susan Kleinmann.
+  * Added patch from Andy Dougherty to let groff pass the -U flag along to
+    troff. (closes: #20628)
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Sat,  4 Apr 1998 23:46:42 +0300
+
+groff (1.11a-2) unstable; urgency=low
+
+  * groff (1.11a-2) unstable; urgency=low
+  * groff (1.11a-0bo2) bo-unstable; urgency=low
+
+  * (lintian): added a symlink for neqn manpage.
+  * (lintian): changed mode of manpage gxditview.1x to 644.
+  * (lintian): changed mode of app-defaults/GXditview to 644.
+  * (lintian): updated the debian/copyright file (previously
+    debian/README), to point to the actual postal address of the FSF,
+    even if the sources in the distribution, including the COPYING file)
+    still point tro the old file (this should be reported as a bug to
+    upstream :-) .  Now it says:
+        A copy of the GNU General Public License is available in
+        /usr/doc/copyright/GPL (as installed by package base-files);
+        if not, write to the Free Software Foundation, Inc.,
+        59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+  * commented creation of ctags file in debian/rules (closes: #15825,
+    #16006).
+  * checked correct build of fontpath (closes: #16007).
+  * added gzipping of X11 manpage (closes: #17455), tx to David ROCHER.
+  * reverted security changes done in 1.10-3.5 due to added use of safer
+    macro.  Added -U flag to nroff/troff/groff/pic to revert to old
+    unsecure behaviour:
+    - nroff script defaults calling groff -S
+    - troff defaults as called with -msafer
+    - groff defaults as called with -S
+    - pic defaults as called with -S
+    Updated manpages nroff(1), groff(1), troff(1), pic(1) for the -U option.
+  * changed reference to me and msafer manpages in groff(1), to reflect
+    the change in their names (done in 1.10-3.5 and 1.10-5).
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Sun, 15 Feb 1998 13:09:27 +0200
+
+groff (1.11a-1) unstable; urgency=low
+
+  * changed Standards Version to 2.3.0.1
+  * corrected names of copyright and chnagelog files.
+  * added full copyright from MIT (for gzditview).
+  * avoid gzipping of copyright file (oops!)
+  * new upstream version 1.11a (fixes #12130) including:
+    - new document for pic.
+    - changes to groff manpage.
+  * full libc6 version (fixes #14592) Since there aren't changes to
+     code, there's no need for a libc5 version.
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Mon, 17 Nov 1997 11:00:21 +0200
+
+groff (1.10-3.5) stable; urgency=high
+
+  * Compiled under debian-1.3.1 (libc5) as a security bugfix; used
+     version number 3.5 (instead of 5) to avoid downgrading for hamm.
+  * Avoided execution of arbitrary code embedded in documents;
+     added warning WARN_SECURITY, enabled by default, to warn about .sy
+     directives, but not yet documented in manpage. Warning mode enabled
+     by default via ifdef, should be toggled by option flag. (need
+     coordination with upstream maintainer.)
+  * Applied patch from Brian Mays <bem5r@virginia.edu> to pic/tex.cc to
+     cast a long double value to double (fixes #13788)
+  * Changed name of manpages me and msafer to groff_me and groff_msafer.
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Wed, 15 Oct 1997 23:15:08 +0300
+
+groff (1.10-4) unstable; urgency=low
+
+  * libc6 version
+  * added explicit link to libc to let ld.so find libc dependencies.
+  * added dinamic dependence as Suggest for gxditview.
+  * forced configure to use /usr/bin/perl (fixes bug#11149 and #13239)
+  * added debian version number to option -v
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Sun, 28 Sep 1997 09:09:22 +0300
+
+groff (1.10-3) frozen unstable; urgency=low
+
+  * Applied changes to avoid problem with bash-2 (bug#8755)
+  * Added gxditview notice in file copyright.debian
+  * Compiled to supply gxditview, to let groff -X and man -X work.
+     (changed font path in device.c)
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Wed, 16 Apr 1997 22:50:58 +0300
+
+groff (1.10-2) frozen unstable; urgency=low
+
+    * corrected shlibs.local for libstd++ depenedency (fixes #5401)
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Thu, 14 Nov 1996 08:39:25 +0200
+
+groff (1.10-1) frozen; urgency=low
+
+    * new maintainer: Fabrizio Polacco <fpolacco@debian.org>
+    * changed description in control file (fixes bug #4013 part 2)
+    * new upstream sources 1.10 (fixes bug #4013 part 1)
+    * added symlinks for geqn, gpic, gtbl (bug #4754)
+    * compressed manpages.
+    * Updated to Standards-Version 2.1.1.0
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Fri, 8 Nov 1996 13:50:09 +0200
+
+groff (1.09-12) frozen; urgency=low
+
+    * this version was never uploaded
+    * new maintainer: Fabrizio Polacco <fpolacco@debian.org>
+    * built using original upstream sources 1.09 + patch 1.09-11
+    * Updated to Standards-Version 2.1.1.0
+
+ -- Fabrizio Polacco <fpolacco@debian.org>  Wed, 6 Nov 1996 15:15:10 +0200
+
+Changes:
+ 2-Jul-1995 Alvar Bray <alvar@meiko.co.uk>
+	Set permissions of /usr/doc/groff dir in post install script.
+	Previous versions of this package may have got these wrong and
+	replacing the package will not fix them.
+ 5-Mar-1995 Bruce Perens <Bruce@Pixar.com>
+	Added Debian GNU/Linux package maintenance system files.
+
--- groff-1.18.orig/debian/control
+++ groff-1.18/debian/control
@@ -0,0 +1,68 @@
+Source: groff
+Section: text
+Priority: important
+Maintainer: Colin Watson <cjwatson@debian.org>
+Uploaders: Fumitoshi UKAI <ukai@debian.or.jp>
+Standards-Version: 3.5.6
+Build-Depends: byacc, debhelper (>= 3.0.9), gs, netpbm, psutils, xutils, libxaw7-dev | libxaw-dev, xlibs-dev
+
+Package: groff-base
+Architecture: any
+Depends: ${shlibs:Depends}
+Suggests: groff
+Replaces: groff (<< 1.17.2-17), jgroff (<< 1.17-1)
+Conflicts: groff (<< 1.17-1), jgroff (<< 1.17-1), pmake (<< 1.45-7), troffcvt (<< 1.04-14)
+Description: GNU troff text-formatting system (base system components)
+ This package contains the traditional UN*X text formatting tools
+ troff, nroff, tbl, eqn, and pic. These utilities, together with the
+ man-db package, are essential for displaying the on-line manual pages. 
+ .
+ groff-base is a stripped-down package containing the necessary components
+ to read manual pages in ASCII, Latin-1, and UTF-8, plus the PostScript
+ device (groff's default). Users who want a full groff installation, with
+ the standard set of devices, fonts, macros, and documentation, should
+ install the groff package.
+
+Package: groff
+Priority: optional
+Architecture: any
+Depends: groff-base (= ${Source-Version}), ${shlibs:Depends}
+Recommends: gs, imagemagick, libpaperg, netpbm, psutils
+Provides: jgroff, groff-x11
+Conflicts: jgroff (<< 1.17-1), groff-x11 (<< 1.18-1)
+Replaces: jgroff (<< 1.17-1), groff-base (<< 1.17.2-9), groff-x11 (<< 1.18-1)
+Description: GNU troff text-formatting system
+ This package contains optional components of the GNU troff text-formatting
+ system. The core package, groff-base, contains the traditional tools like
+ troff, nroff, tbl, eqn, and pic. This package contains additional devices
+ and drivers for output to DVI, HTML (when the recommended packages gs,
+ netpbm, and psutils are installed), HP LaserJet printers, and Canon CAPSL
+ LBP-4 and LBP-8 printers.
+ .
+ The X75, X75-12, X100, and X100-12 devices, which allow groff output to be
+ conveniently viewed on an X display using the standard X11 fonts, are now
+ included here. They were previously in a separate package, groff-x11.
+ .
+ Besides these, the groff package contains man pages describing the language
+ and its macro sets, info documentation, and a number of supplementary
+ programs:
+ .
+  - gxditview, which is used to display the output of the X* devices, and
+    can also be used to view PostScript output from groff;
+  - grn, a preprocessor for pictures in the 'gremlin' format;
+  - tfmtodit, which creates font files for use with 'groff -Tdvi';
+  - hpftodit, which creates font files for use with 'groff -Tlj4';
+  - afmtodit, which creates font files for use with 'groff -Tps';
+  - refer, which preprocesses bibliographic references for use with groff;
+  - indxbib, which creates inverted indices for bibliographic databases used
+    by 'refer';
+  - lkbib and lookbib, which search bibliographic databases;
+  - addftinfo, which adds metric information to troff font files for use
+    with groff;
+  - pfbtops, which translates a PostScript font in .pfb format to ASCII for
+    use with groff;
+  - mmroff, a simple groff preprocessor which expands references in mm;
+  - pic2graph, which converts PIC diagrams into cropped image files;
+  - eqn2graph, which converts EQN equations into cropped image files.
+ .
+ All the standard macro packages are supported.
--- groff-1.18.orig/debian/rules
+++ groff-1.18/debian/rules
@@ -0,0 +1,184 @@
+#! /usr/bin/make -f
+#
+# rules to debianize groff
+
+export DH_COMPAT=3
+export DH_OPTIONS
+
+CC  = gcc
+CXX = g++
+ifeq (,$(findstring debug,$(DEB_BUILD_OPTIONS)))
+CFLAGS = -O2 -Wall
+else
+CFLAGS = -O2 -g -Wall
+endif
+
+# Temporary fix for broken hppa compiler
+DEB_HOST_ARCH := $(shell dpkg-architecture -qDEB_HOST_ARCH)
+ifeq ($(DEB_HOST_ARCH),hppa)
+CFLAGS := $(CFLAGS) -fno-strength-reduce
+endif
+
+# From Makefile.in
+version  = $(shell cat VERSION)
+revision = $(shell sed -e 's/^0$$//' -e 's/^[1-9].*$$/.&/' REVISION)
+upstream = $(version)$(revision)
+datadir  = usr/share/groff/$(upstream)
+
+fontpath := /$(datadir)/font:/usr/local/share/groff/font
+fontpath := $(fontpath):/usr/local/lib/font:/usr/lib/font
+
+gbtmp = debian/groff-base
+gtmp  = debian/groff
+
+devbase = ascii ascii8 latin1 nippon ps utf8
+devx11  = X100 X100-12 X75 X75-12
+
+ifeq (,$(findstring no-groff-x11,$(DEB_BUILD_OPTIONS)))
+GROFF_X11 := yes
+else
+GROFF_X11 := no
+endif
+
+ifeq ($(GROFF_X11),yes)
+BUILD_TARGETS  := build-groff build-groff-x11
+else
+BUILD_TARGETS  := build-groff
+endif
+BINARY_TARGETS := binary-groff-base binary-groff
+DH_EXCLUDE     := -Ngroff-x11
+
+configure: configure-stamp
+configure-stamp:
+	if [ ! -f Makefile.clean ]; then cp -p Makefile Makefile.clean; fi
+	-rm -f config.log config.cache
+	CC="$(CC)" CXX="$(CXX)" CFLAGS="$(CFLAGS)" CXXFLAGS="$(CFLAGS)" \
+		PSPRINT=lpr PAGE=A4 \
+		./configure --prefix=/usr --mandir=\$${prefix}/share/man \
+			    --infodir=\$${prefix}/share/info --enable-japanese
+	touch $@
+
+src/xditview/Makefile: configure
+	cd src/xditview && xmkmf
+
+build-arch: $(BUILD_TARGETS)
+build-indep:
+build: build-arch build-indep
+
+build-groff: configure
+	dh_testdir
+	touch configure		# avoid autoconf build-dependency
+	$(MAKE) extratmacdirs=/usr/share/groff/tmac
+	touch $@
+
+ifeq ($(GROFF_X11),yes)
+build-groff-x11: src/xditview/Makefile
+	dh_testdir
+	touch configure		# avoid autoconf build-dependency
+	$(MAKE) -C src/xditview depend
+	$(MAKE) -C src/xditview FONTPATH=$(fontpath)
+	touch $@
+endif
+
+clean:
+	dh_testdir
+	dh_testroot
+	touch configure		# avoid autoconf build-dependency
+	rm -f man/index.* 
+	find . -name tags | xargs -r rm -f
+	find . -name '*.cc.combine' | xargs -r rm -f
+	-$(MAKE) -i realclean extraclean
+	-$(MAKE) -C doc -i extraclean
+	-$(MAKE) -C src/xditview extraclean
+	rm -f src/xditview/Imakefile src/xditview/Makefile
+	dh_clean configure-stamp build-stamp
+	rm -f debian/groff-base.files debian/groff-base.links
+	rm -f config.log config.cache config.status
+	if [ -f Makefile.clean ]; then mv -f Makefile.clean Makefile; fi
+
+%: %.in
+	sed -e 's/@VERSION@/$(upstream)/g' $< > $@
+
+install: DH_OPTIONS=
+install: build debian/groff-base.files
+	dh_testdir
+	dh_testroot
+	dh_clean -k -a
+	dh_installdirs -a
+	$(MAKE) install prefix=$(CURDIR)/$(gtmp)/usr \
+			docdir=$(CURDIR)/$(gtmp)/usr/share/doc/groff-base \
+			INSTALL_INFO=:
+	dh_movefiles -pgroff-base --sourcedir=debian/groff
+	dh_installdirs -pgroff-base $(datadir)/font
+	set -e; for x in $(devbase); do \
+		mv $(gtmp)/$(datadir)/font/dev$$x $(gbtmp)/$(datadir)/font/; \
+	done
+ifeq ($(GROFF_X11),yes)
+	$(MAKE) -C src/xditview install install.man DESTDIR=$(CURDIR)/$(gtmp)
+else
+	set -e; for x in $(devx11); do \
+		rm -rf $(gtmp)/$(datadir)/font/dev$$x; \
+	done
+endif
+
+binary-indep:
+
+binary-groff-base: DH_OPTIONS=-pgroff-base
+binary-groff-base: install debian/groff-base.links
+	dh_testdir
+	dh_testroot
+	# Conffiles should go in /etc
+	mv $(gbtmp)/usr/share/groff/site-tmac $(gbtmp)/etc/groff
+	# Debian additions to *.local
+	cat debian/mandoc.local >> $(gbtmp)/etc/groff/man.local
+	cat debian/mandoc.local >> $(gbtmp)/etc/groff/mdoc.local
+	# Scripts should be executable
+	chmod +x $(gbtmp)/$(datadir)/font/devps/generate/afmname \
+		 $(gbtmp)/$(datadir)/font/devps/generate/symbol.sed
+	dh_installdocs
+	dh_installmime
+	dh_installchangelogs ChangeLog
+	dh_link
+
+binary-groff: DH_OPTIONS=-pgroff
+binary-groff: install
+	dh_testdir
+	dh_testroot
+	# Scripts should be executable
+	chmod +x $(gtmp)/$(datadir)/font/devdvi/generate/CompileFonts
+	# Now in groff-base
+	rmdir $(gtmp)/usr/lib/groff/site-tmac   || true
+	rmdir $(gtmp)/usr/share/groff/site-tmac || true
+	# 'make install' creates this directory when installing documentation.
+	dh_link usr/share/doc/groff-base usr/share/doc/groff
+	dh_installdocs -Xcopyright
+ifeq ($(GROFF_X11),yes)
+	install -m644 src/xditview/ChangeLog \
+		      $(gtmp)/usr/share/doc/groff/ChangeLog.gxditview
+endif
+	dh_installinfo doc/groff doc/groff-[0-9]*
+	dh_link
+
+binary-arch: DH_OPTIONS=-a $(DH_EXCLUDE)
+binary-arch: $(BINARY_TARGETS)
+	dh_strip
+	dh_compress
+	dh_fixperms
+	dh_installdeb
+	dh_shlibdeps
+	dh_gencontrol
+	dh_md5sums
+	dh_builddeb
+ifneq ($(GROFF_X11),yes)
+	@echo
+	@echo "=========================================================="
+	@echo "WARNING! groff has been built without X support."
+	@echo "Please do not upload these packages to the Debian archive!"
+	@echo "=========================================================="
+	@echo
+endif
+
+binary: binary-indep binary-arch
+
+.PHONY: configure build build-arch build-indep clean install
+.PHONY: binary binary-arch binary-indep binary-groff-base binary-groff
--- groff-1.18.orig/debian/README.build
+++ groff-1.18/debian/README.build
@@ -0,0 +1,20 @@
+Debian groff build process
+--------------------------
+
+People starting new ports of Debian should be aware that there is a circular
+build-dependency between the groff and xfree86 source packages. Fortunately,
+in both cases this is in order to build optional components: xfree86 needs
+groff to build some of its documentation, and groff needs xfree86 to build
+the gxditview display program.
+
+To build groff without xfree86 installed, set the DEB_BUILD_OPTIONS
+environment variable to include the string "no-groff-x11". Please do not
+upload packages to the Debian archive that have been built in this way.
+
+The gs, netpbm, and psutils build-dependencies need not be satisfied while
+bootstrapping. They are only necessary to build HTML documentation.
+
+Once a new port has been fully bootstrapped, there should be no problems
+building groff routinely as with any other package.
+
+ -- Colin Watson <cjwatson@debian.org>  Tue, 22 Jan 2002 14:18:58 +0000
--- groff-1.18.orig/debian/copyright
+++ groff-1.18/debian/copyright
@@ -0,0 +1,88 @@
+This is the Debian GNU/Linux prepackaged version of the GNU groff
+document formatting system. 
+GNU groff was written by James Clark <jjc@jclark.com>.  
+It is now maintained by Ted Harding <ted.harding@nessie.mcc.ac.uk> and
+Werner Lemberg <wl@gnu.org>.
+
+This Debian package was previously maintained by Fabrizio Polacco
+<fpolacco@debian.org>.
+It is now maintained by Colin Watson <cjwatson@debian.org>.
+
+The original tarball came from <URL:ftp://groff.ffii.org/pub/groff/>:
+  31474119d1ef2ded0bd0692132d50d05  groff-1.18.tar.gz
+and was simply renamed to groff_1.18.orig.tar.gz.
+
+Some patches have been applied to groff outside the debian directory. The
+most visible of these is a patch for Japanese support (contributed by
+Fumitoshi UKAI and others in the jgroff team), which adds the ascii8 and
+nippon devices and a number of font files. This has been discussed on the
+upstream mailing list, and the opinion there was that multi-byte language
+support would be better implemented using preprocessors and a UTF-8 core.
+However, at the time of writing, there are no known problems caused by this
+patch, and until a more complete solution is implemented upstream this
+provides a useful service to Japanese users of Debian.
+
+The Debian diff also appends /usr/share/groff/tmac to the default macro path
+for compatibility with versions of groff earlier than 1.17 (patch by Colin
+Watson), and alters the 'papersize' DESC keyword to accept multiple
+arguments which it tries in turn until one succeeds (patch also by Colin
+Watson).
+
+=========================================================================
+
+Copyright (C) 1989-2000 Free Software Foundation, Inc.
+     Written by James Clark (jjc@jclark.com)
+
+This file is part of groff.
+
+groff is free software; you can redistribute it and/or modify it under
+the terms of the GNU General Public License as published by the Free
+Software Foundation; either version 2, or (at your option) any later
+version.
+
+groff is distributed in the hope that it will be useful, but WITHOUT ANY
+WARRANTY; without even the implied warranty of MERCHANTABILITY or
+FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+for more details.
+
+You should have received a copy of the GNU General Public License along
+with groff; see the file COPYING.  If not, write to the Free Software
+Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+
+On Debian systems, a copy of the GNU General Public License is available
+in /usr/share/common-licenses/GPL as part of the base-files package.
+
+=========================================================================
+
+Included in this release are implementations of troff, pic, eqn, tbl,
+grn, refer, -man, -mdoc, and -ms macros, and drivers for PostScript, TeX
+dvi format, HP LaserJet 4 printers, Canon CAPSL printers, HTML format
+(still alpha), and typewriter-like devices.  Also included is a modified
+version of the Berkeley -me macros, an enhanced version of the X11
+xditview previewer, and an implementation of the -mm macros contributed
+by Joergen Haegg (jh@axis.se).
+
+xditview is copyrighted by MIT under the usual X terms.
+
+/*
+ * Copyright 1991 Massachusetts Institute of Technology
+ *
+ * Permission to use, copy, modify, distribute, and sell this software and its
+ * documentation for any purpose is hereby granted without fee, provided that
+ * the above copyright notice appear in all copies and that both that
+ * copyright notice and this permission notice appear in supporting
+ * documentation, and that the name of M.I.T. not be used in advertising or
+ * publicity pertaining to distribution of the software without specific,
+ * written prior permission.  M.I.T. makes no representations about the
+ * suitability of this software for any purpose.  It is provided "as is"
+ * without express or implied warranty.
+ *
+ * M.I.T. DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL M.I.T.
+ * BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
+ * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION
+ * OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
+ * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ */
+
--- groff-1.18.orig/debian/groff.dirs
+++ groff-1.18/debian/groff.dirs
@@ -0,0 +1 @@
+usr
--- groff-1.18.orig/debian/mandoc.local
+++ groff-1.18/debian/mandoc.local
@@ -0,0 +1,12 @@
+.
+.if n \{\
+.  \" Debian: Map \(oq to ' rather than ` in nroff mode for devices other
+.  \" than utf8.
+.  if !'\*[.T]'utf8' \
+.    tr \[oq]'
+.
+.  \" Debian: Disable the use of SGR (ANSI colour) escape sequences by
+.  \" grotty.
+.  if '\V[GROFF_SGR]'' \
+.    output x X tty: sgr 0
+.\}
--- groff-1.18.orig/debian/groff.postinst
+++ groff-1.18/debian/groff.postinst
@@ -0,0 +1,17 @@
+#! /bin/sh -e
+
+[ "$1" = configure ] || exit 0
+
+if dpkg --compare-versions "$2" lt-nl 1.17-1; then
+    # dpkg won't replace the directory /usr/share/doc/groff with a symlink,
+    # so do that now.
+    if [ ! -L /usr/share/doc/groff -a -d /usr/share/doc/groff ]; then
+	if rmdir /usr/share/doc/groff 2>/dev/null; then
+	    ln -sf groff-base /usr/share/doc/groff
+	fi
+    fi
+fi
+
+#DEBHELPER#
+
+exit 0
--- groff-1.18.orig/debian/groff-base.dirs
+++ groff-1.18/debian/groff-base.dirs
@@ -0,0 +1,2 @@
+etc
+usr/lib/groff/site-tmac
--- groff-1.18.orig/debian/groff.links
+++ groff-1.18/debian/groff.links
@@ -0,0 +1,2 @@
+usr/share/man/man1/grohtml.1.gz usr/share/man/man1/post-grohtml.1.gz
+usr/share/man/man1/grohtml.1.gz usr/share/man/man1/pre-grohtml.1.gz
--- groff-1.18.orig/debian/groff-base.files.in
+++ groff-1.18/debian/groff-base.files.in
@@ -0,0 +1,50 @@
+usr/bin/eqn
+usr/bin/groff
+usr/bin/grog
+usr/bin/grops
+usr/bin/grotty
+usr/bin/neqn
+usr/bin/nroff
+usr/bin/pic
+usr/bin/soelim
+usr/bin/tbl
+usr/bin/troff
+usr/share/man/man1/eqn.1
+usr/share/man/man1/groff.1
+usr/share/man/man1/grog.1
+usr/share/man/man1/grops.1
+usr/share/man/man1/grotty.1
+usr/share/man/man1/neqn.1
+usr/share/man/man1/nroff.1
+usr/share/man/man1/pic.1
+usr/share/man/man1/soelim.1
+usr/share/man/man1/tbl.1
+usr/share/man/man1/troff.1
+usr/share/groff/@VERSION@/eign
+usr/share/groff/@VERSION@/tmac/an-old.tmac
+usr/share/groff/@VERSION@/tmac/an.tmac
+usr/share/groff/@VERSION@/tmac/andoc.tmac
+usr/share/groff/@VERSION@/tmac/doc.tmac
+usr/share/groff/@VERSION@/tmac/doc-old.tmac
+usr/share/groff/@VERSION@/tmac/eqnrc
+usr/share/groff/@VERSION@/tmac/euc-jp.tmac
+usr/share/groff/@VERSION@/tmac/hyphen.us
+usr/share/groff/@VERSION@/tmac/latin1.tmac
+usr/share/groff/@VERSION@/tmac/man.tmac
+usr/share/groff/@VERSION@/tmac/mandoc.tmac
+usr/share/groff/@VERSION@/tmac/mdoc.tmac
+usr/share/groff/@VERSION@/tmac/mdoc/doc-common
+usr/share/groff/@VERSION@/tmac/mdoc/doc-ditroff
+usr/share/groff/@VERSION@/tmac/mdoc/doc-nroff
+usr/share/groff/@VERSION@/tmac/mdoc/doc-syms
+usr/share/groff/@VERSION@/tmac/pic.tmac
+usr/share/groff/@VERSION@/tmac/ps.tmac
+usr/share/groff/@VERSION@/tmac/psatk.tmac
+usr/share/groff/@VERSION@/tmac/psold.tmac
+usr/share/groff/@VERSION@/tmac/pspic.tmac
+usr/share/groff/@VERSION@/tmac/safer.tmac
+usr/share/groff/@VERSION@/tmac/troffrc
+usr/share/groff/@VERSION@/tmac/troffrc-end
+usr/share/groff/@VERSION@/tmac/tty-char.tmac
+usr/share/groff/@VERSION@/tmac/tty.tmac
+usr/share/groff/site-tmac
--- groff-1.18.orig/debian/groff-base.docs
+++ groff-1.18/debian/groff-base.docs
@@ -0,0 +1,9 @@
+BUG-REPORT
+ChangeLog.jp
+MORE.STUFF
+NEWS
+PROBLEMS
+PROJECTS
+README
+README.jp
+TODO
--- groff-1.18.orig/debian/groff-base.mime
+++ groff-1.18/debian/groff-base.mime
@@ -0,0 +1 @@
+application/x-troff-man; /usr/bin/nroff -mandoc -Tlatin1; copiousoutput; print=/usr/bin/nroff -mandoc -Tlatin1 | print text/plain:-
--- groff-1.18.orig/debian/groff-base.preinst
+++ groff-1.18/debian/groff-base.preinst
@@ -0,0 +1,30 @@
+#! /bin/sh -e
+
+case $1 in
+    install|upgrade)
+	if dpkg --compare-versions "$2" lt 1.17-2; then
+	    if [ -d /usr/share/groff/site-tmac ]; then
+		if [ -d /etc/groff ]; then
+		    # Erm. This shouldn't happen.
+		    echo "Moving /usr/share/groff/site-tmac out of the way."
+		    mv -f /usr/share/groff/site-tmac \
+			  /usr/share/groff/site-tmac.old
+		else
+		    echo "Moving /usr/share/groff/site-tmac to /etc/groff."
+		    mv -f /usr/share/groff/site-tmac /etc/groff
+		    touch /usr/share/groff/site-tmac.moved-by-preinst
+		fi
+	    fi
+	    if [ -e /etc/tmac.man.local ]; then
+		echo "Moving /etc/tmac.man.local to /etc/groff/man.local."
+		mkdir -p /etc/groff
+		mv -f /etc/tmac.man.local /etc/groff/man.local
+		touch /etc/tmac.man.local.moved-by-preinst
+	    fi
+	fi
+	;;
+esac
+
+#DEBHELPER#
+
+exit 0
--- groff-1.18.orig/debian/groff-base.postinst
+++ groff-1.18/debian/groff-base.postinst
@@ -0,0 +1,16 @@
+#! /bin/sh -e
+
+case $1 in
+    configure)
+	if [ -e /etc/tmac.man.local.moved-by-preinst ]; then
+	    rm -f /etc/tmac.man.local.moved-by-preinst
+	fi
+	if [ -e /usr/share/groff/site-tmac.moved-by-preinst ]; then
+	    rm -f /usr/share/groff/site-tmac.moved-by-preinst
+	fi
+	;;
+esac
+
+#DEBHELPER#
+
+exit 0
--- groff-1.18.orig/debian/groff-base.postrm
+++ groff-1.18/debian/groff-base.postrm
@@ -0,0 +1,21 @@
+#! /bin/sh -e
+
+case $1 in
+    abort-install|abort-upgrade)
+	if [ -e /etc/tmac.man.local.moved-by-preinst ]; then
+	    mv -f /etc/groff/man.local /etc/tmac.man.local
+	    rm -f /etc/tmac.man.local.moved-by-preinst
+	fi
+	if [ -e /usr/share/groff/site-tmac.moved-by-preinst ]; then
+	    mv -f /etc/groff /usr/share/groff/site-tmac
+	    rm -f /usr/share/groff/site-tmac.moved-by-preinst
+	fi
+	if [ -d /usr/share/groff/site-tmac.old ]; then
+	    mv -f /usr/share/groff/site-tmac.old /usr/share/groff/site-tmac
+	fi
+	;;
+esac
+
+#DEBHELPER#
+
+exit 0
--- groff-1.18.orig/debian/README.Debian
+++ groff-1.18/debian/README.Debian
@@ -0,0 +1,22 @@
+groff for Debian
+----------------
+
+As of version 1.17-1, Debian groff was split into three packages:
+groff-base, groff, and groff-x11. At version 1.18-1 the groff-x11 package
+was merged back into groff. The current organization is as follows:
+
+  groff-base - a stripped-down groff package containing the components
+               required to read man pages in ASCII, Latin-1, UTF-8, and
+               PostScript
+  groff      - all other components
+
+If you only need groff in order to read man pages in common formats, you can
+remove the main groff package and save some disk space. For more
+information, please see 'dpkg --print-avail <package>' or 'apt-cache show
+<package>'.
+
+Where is the groff documentation? It's not easy to find when you're
+unfamiliar with the system (as I well remember). The 'SEE ALSO' section of
+the roff(7) man page has a good index.
+
+ -- Colin Watson <cjwatson@debian.org>  Thu, 11 Jul 2002 17:29:43 +0100
--- groff-1.18.orig/debian/groff-base.links.in
+++ groff-1.18/debian/groff-base.links.in
@@ -0,0 +1,8 @@
+etc/groff usr/share/groff/site-tmac
+usr/bin/eqn usr/bin/geqn
+usr/bin/tbl usr/bin/gtbl
+usr/bin/pic usr/bin/gpic
+usr/share/groff/@VERSION@ usr/share/groff/current
+usr/share/man/man1/eqn.1.gz usr/share/man/man1/geqn.1.gz
+usr/share/man/man1/tbl.1.gz usr/share/man/man1/gtbl.1.gz
+usr/share/man/man1/pic.1.gz usr/share/man/man1/gpic.1.gz
--- groff-1.18.orig/ChangeLog.jp
+++ groff-1.18/ChangeLog.jp
@@ -0,0 +1,273 @@
+2002-06-16  Fumitoshi UKAI  <ukai@debian.or.jp>
+
+	* based on groff 1.18pre? (2002/06/15 CVS current)
+
+2001-07-15  Fumitoshi UKAI  <ukai@debian.or.jp>
+
+	* based on groff 1.17.2-1
+	* use src/include/encoding.h instead of eucmac.h
+	* introduce src/libs/libgroff/encoding.cc
+	* introduce tmac/euc-jp.tmac for EUC-JP documents
+
+2001-05-24  Fumitoshi UKAI  <ukai@debian.or.jp>
+
+	* Apply for groff-1.17
+
+2000-01-06  Yoshiaki Yanagihara  <yochi@debian.or.jp>
+
+	* Apply japanese patch "jgroff-0.101"
+	  (thanks hanataka@abyss.rim.or.jp).
+	* Added japanese extention option at configure.in, aclocal.m4.
+
+Sat Jan  1 17:10:32 JST 2000  HANATAKA Shinya  <hanataka@abyss.rim.or.jp>
+
+	* jgroff-0.100 򤽤Τޤ groff-1.14 ŬѤ jgroff-101
+	  Ȥ
+	* grohtml ܸб롣
+	* ܸޥ˥奢Ѥ tmac.docj  tmac.andocj ޥɲá
+
+Sun Mar 15 18:23:12 1998  Yoshiaki Yanagihara  <yochi@debian.or.jp>
+
+	* jgroff Υ١ groff-1.11a ѹjgroff-0.99ѥå
+	  ŬѤΤ jgroff-0.100 Ȥ
+	  Ū jgroff-0.99 ȵǽƱ *Ϥ*
+
+Fri Dec 22 11:47:46 1995  Kitagawa Toshiyuki  <tm-kita@kh.rim.or.jp>
+
+	* С0.99
+
+Mon Dec 18 18:28:37 1995  Kitagawa Toshiyuki  <tm-kita@kh.rim.or.jp>
+
+	* tmac/Makefile.sub: å stamp-wrapuninstall_sub 
+	OSshǹʸ顼Ȥʤ륪ꥸʥХ
+
+Wed Dec 13 15:09:26 1995  Kitagawa Toshiyuki  <tm-kita@kh.rim.or.jp>
+
+	* jgroff.sh: ꥸʥǥ󥹥ȡѥѹ줿Τ˹碌
+	GROFF_TMAC_PATHGROFF_FONT_PATHshare/groff۲ѹ
+
+Sat Dec  9 15:28:36 1995  Kitagawa Toshiyuki  <tm-kita@kh.rim.or.jp>
+
+	* wchar.heucmac.h˥ե̾ѹ
+
+Fri Dec  8 12:15:47 1995  Yoshio Takaeda  <shio@yinyan.bekkoame.or.jp>
+
+	* troff/env.cc(add_char): ASCIIʸ + ԥ + EUCʸ٤Ȥ
+	ѥλԥɤڡѴʤХ
+
+Thu Dec  7 21:35:06 1995  Yanagihara Yoshiaki  <yosiaki@bsd2.kbnes.nec.co.jp>
+
+	* troff/input.cc (process_input_stack): gcc-2.7.0ѿ
+	ȿȤʤäƤޤս
+
+Thu Dec  7 21:35:06 1995  Yanagihara Yoshiaki  <yosiaki@bsd2.kbnes.nec.co.jp>
+
+	* jgroffΥ١groff-1.10ѹ
+
+Thu Apr  6 16:56:32 1995  Kitagawa Toshiyuki  <kitagawa@bsd2.kbnes.nec.co.jp>
+
+	* devdvi/M.proto-NTT: DNPpkեȤΥåͤ0ʤΤǡ
+	˹碌checksumͤ0ѹ
+
+Mon Apr  3 20:36:37 1995  Kitagawa Toshiyuki  <kitagawa@bsd2.kbnes.nec.co.jp>
+
+	* troff/env.cc (possibly_break_line):
+	lineꥹkword_space_nodeĴǡlineˤΥΡ
+	ޤޤƤʤϽ򥹥åפ褦ˤ(EUCɤޤ
+	ʤroffˤkword_space_nodeϸʤΤǽ®
+	)
+
+Mon Apr  3 20:36:37 1995  Kitagawa Toshiyuki  <kitagawa@bsd2.kbnes.nec.co.jp>
+
+	* troff/env.cc (add_char): hwkernvlowerνdevice
+	˰٤ԤɤΤenvironment饹Υ󥹥ȥ饯Ǥ
+	Ԥ褦ѹ
+
+Sat Apr  1 17:57:23 1995  Kitagawa Toshiyuki  <kitagawa@bsd2.kbnes.nec.co.jp>
+
+	* troff/input.cc (mount_on_demand): on demandǥޥȤե
+	̾ǥХȤDESCեǻǤ褦ѹ
+	ǥ쥯ƥondemandǻꤷեȤon demandǥޥȤ롣
+
+Fri Mar 31 20:23:43 1995  Kitagawa Toshiyuki  <kitagawa@bsd2.kbnes.nec.co.jp>
+
+	* libgroff/font.cc (load): եȥեѤ˥ǥ쥯ƥ
+	fixedkanjiɲáϳʸΥȥåƱǤ
+	ΤǡfixedkanjiꤵƤcharsetɾʤ
+	եȤΥɤ®
+
+Thu Mar 30 18:20:24 1995  Kitagawa Toshiyuki  <kitagawa@bsd2.kbnes.nec.co.jp>
+
+	* troff: node̤ʸӤǹԤäƤ®ΤӤ
+	ѹ
+
+Wed Mar 29 20:20:49 1995  Kitagawa Toshiyuki  <kitagawa@bsd2.kbnes.nec.co.jp>
+
+	* troff/input.cc: ե(MG)on demandǥޥȤ褦
+	ѹˤäƴޤޤʤroffեν֤®
+	줿
+
+Fri Mar 10 15:34:26 1995  Shigeki Yoshida <shige@theta.iis.u-tokyo.ac.jp>
+
+	* troff/input.cc (process): geqnǡ
+
+		.EQ
+		 sub 
+		.EN
+
+	ȡ"illegal token in argument to \Z"ȤʤäƤޤХ
+	(\Z󥹤ΰEUCʸ褿бϳ)
+
+Mon Feb  6 11:22:33 1995  Yoshio Takaeda <e50110@sakura.kudpc.kyoto-u.ac.jp>
+
+	* troff/input.cc: Ƭ§ʸEUCɤΰ
+
+Mon Jan 30 14:02:54 1995  Kitagawa Toshiyuki  <kitagawa@bsd2.kbnes.nec.co.jp>
+
+	* С0.97
+
+Fri Dec 10 14:26:14 1994  Kazutaka YOKOTA <yokota@zodiac.mech.utsunomiya-u.ac.jp>
+
+	* devdvi/M.proto: NTT JTeXASCIIܸTeXξdviե򰷤褦
+	M.protoեѹ
+
+Fri Dec  9 14:26:14 1994  Kazutaka YOKOTA <yokota@zodiac.mech.utsunomiya-u.ac.jp>
+
+	* troff/node.cc: boldfont_list[]˥ե̾ B ϿƤʤ
+	ᡢdviե˥åΤϤƤʤä
+
+Fri Dec  9 14:23:22 1994  Kazutaka YOKOTA <yokota@zodiac.mech.utsunomiya-u.ac.jp>
+
+	* grotty/tty.cc (add_char): EUCʸФWCHAR_MODEꤷƤ
+	ʤäᡢttyϤǥåΤǤƤʤä
+
+Fri Dec  9 14:19:33 1994  Kazutaka YOKOTA <yokota@zodiac.mech.utsunomiya-u.ac.jp>
+
+	* devdvi/Makefile.sub: եȥե G ǡnameǥ쥯ƥ֤
+	`name M'ˤʤäƤ롣
+
+Wed Nov 30 13:24:54 1994  Kitagawa Toshiyuki  <kitagawa@bsd2.kbnes.nec.co.jp>
+
+	* С0.96
+
+	* grodvi/dvi.cc: FreeBSD 1.1.5Rstrcmp(3)Ǥϰ˥̥ݥ󥿤
+	ϤȥפƤޤΤǡ򤹤륳ɤɲä
+
+Tue Nov 29 13:52:54 1994  Kitagawa Toshiyuki  <kitagawa@bsd2.kbnes.nec.co.jp>
+
+	* troff/input.cc: EUCΥڡʸ(0xa1a1)ASCIIΥڡʸ
+	ƽ褦
+
+	* devnippon/createM: JISX0208ˤʸ̤ʬˤĤƤ
+	եȥե˽Ϥʤ褦
+
+Mon Nov 28 18:15:31 1994  Kitagawa Toshiyuki  <kitagawa@bsd2.kbnes.nec.co.jp>
+
+	* grodvi/dvi.cc: grodviܸ첽
+
+Fri Nov 25 15:39:05 1994  Kitagawa Toshiyuki  <kitagawa@bsd2.kbnes.nec.co.jp>
+
+	* troff/env.cc: EUCʸǻϤޤԤФƶդԤ줿
+	硢Ƭ;ʬʶäΤǤ
+
+Fri Nov 18 20:19:55 1994  Masubuchi Toshimichi <tmasu@st.rim.or.jp>
+
+	* devnippon/createM.c: createMνλơˤʤ뤿ᡢ
+	makeλƤޤcreateMνλơ0ˤʤ褦
+
+	* devnippon/Makefile.sub: PATHĶѿ˥ȥǥ쥯ȥ꤬ޤ
+	Ƥʤ硢devnippon/MmakecreateMĤ餺make
+	顼ˤʤХ
+
+Thu Nov 17 17:11:26 1994  Kitagawa Toshiyuki  <kitagawa@bsd2.kbnes.nec.co.jp>
+
+	* devnippon/createM.c: gets()fgets()ѹ
+
+Sat Nov 12 13:38:19 1994  Kitagawa Toshiyuki  <kitagawa@bsd2.kbnes.nec.co.jp>
+
+	* С0.95
+
+	* troff/env.cc: .stt ꥯȤɲ(ʥޥ˥奢񼰤˹
+	碌뤿 -> ΥꥯȤ)
+
+	* troff/input.cc (init_charset_table): ASCIIιƬ§ʸȤ
+	,:;>}ɲä
+
+	* EUCեȥեϡmake˥ġˤä褦ѹ
+	ˤpatchʤ꾮ʤä
+
+Fri Nov 11 20:53:00 1994  Kitagawa Toshiyuki  <kitagawa@bsd2.kbnes.nec.co.jp>
+
+	* troff/env.cc (add_char): <EUCʸ> + <ASCIIʸ>ξ硢֤
+	϶§˰ȿʤ֥졼ǽʶ褦
+
+
+Tue Oct 25 04:46:09 1994  Kitagawa Toshiyuki  (kitagawa@bsd2.kbnes.nec.co.jp)
+
+	* С0.94
+
+	* libdriver/input.cc (do_file): -Tlatin1EUCǤϤʤʸɤ
+	EUCȽǤƤޤХ
+
+Mon Oct 24 07:16:19 1994  Kitagawa Toshiyuki  (kitagawa@bsd2.kbnes.nec.co.jp)
+
+	* troff/node.cc (is_boldfont): FreeBSD 1.1.5ǡϻȤΤᥳ
+	פХ
+
+	* indxbib/dirnamemax.c: FreeBSD 1.1.5pathconf()äƤʤΤ
+	_POSIX_VERSIONundef
+
+	* С0.93
+
+	* geqnܸ첽
+
+	* devps/DESCwcharkernꤹȹƬ˶äƤޤХ
+	ˡѹ
+
+Sat Oct 22 08:19:15 1994  Kitagawa Toshiyuki  (kitagawa@bsd2.kbnes.nec.co.jp)
+
+	* С0.90
+
+	* xtotroffܸ첽
+
+Fri Oct 21 05:33:02 1994  Kitagawa Toshiyuki  (kitagawa@bsd2.kbnes.nec.co.jp)
+
+	* devps/DESCwcharkernꤹȹƬ˶äƤޤ
+	äΤǡ
+
+	* pre-releaseС
+
+	* gxditviewܸ첽(եȥȥåμФø)
+
+Thu Oct 20 05:23:09 1994  Kitagawa Toshiyuki  (kitagawa@bsd2.kbnes.nec.co.jp)
+
+	* եֹ3˥ܡΰʳΥեȤޥȤ硢ե
+	ȤåΤˤʤäƤޤХ
+
+Wed Oct 19 06:48:55 1994  Kitagawa Toshiyuki  (kitagawa@bsd2.kbnes.nec.co.jp)
+
+	* betaС
+
+Tue Oct 18 05:02:59 1994  Kitagawa Toshiyuki  (kitagawa@bsd2.kbnes.nec.co.jp)
+
+	* pic: 
+	gpicܸб
+
+	* tbl: 
+	gtblܸб
+
+	* troff/troff: 
+	Times-BoldʳΥܡΤȥեȤλեȤ
+	åڤؤʤХ
+
+	* troff/troff: 
+	DESC˥ǥ쥯ƥwcharkernɲäASCIIʸEUCʸδ֤ˡ
+	ꤷunitbreakԲǽʶ褦ˤ
+
+	* troff/troff: 
+	DESC˥ǥ쥯ƥlowerwcharɲäASCIIʸФEUCʸ
+	ꤷunit褦ˤ(ASCIIʸǸ뤿)
+	
+Fri Oct 14 08:29:06 1994  Kitagawa Toshiyuki  (kitagawa@bsd2.kbnes.nec.co.jp)
+
+	* aplahС
--- groff-1.18.orig/README.jp
+++ groff-1.18/README.jp
@@ -0,0 +1,142 @@
+
+                ܸб groff-1.12 (jgroff-0.101)
+
+
+                                             (Kitagawa Toshiyuki)
+                                                     tm-kita@kh.rim.or.jp
+
+                                            μ (Yanagihara Yoshiaki)
+                                                      yochi@debian.or.jp
+
+ GNUroffեޥågroff(version 1.12)ܸбԤʤޤ
+ ̸ߴȤʤäƤޤΤǡܸޤޤʤroffǡϥꥸʥ
+ưˤʤޤܸ첽˴ؤ뽤ʬˤĤƤGNU
+General Public License Version 2 ˽ޤ(ܺ٤COPYING)
+
+ ܸgroff(jgroff)θС0.101(ǽ)ǤΥС
+ǤϰʲΥ⥸塼뤬ܸ첽Ƥޤ
+
+	groff	  ...	groffɥ饤
+ 	gtroff	  ...	groff
+	grotty	  ...	üѥݥȥץå
+	grops	  ...	PostScriptѥݥȥץå
+        grohtml   ...   HTMLѥݥȥץå(Thanks HANATAKA Shinya
+                                               <hanataka@abyss.rim.or.jp>)
+	grodvi	  ...	DVIѥݥȥץå (NTT JTeX or ASCIIܸTeX)
+	gxditview ...	Xɥѥݥȥץå
+	gtbl	  ...	tblޥѥץץå
+	gpic	  ...	picޥѥץץå
+	geqn	  ...	eqnޥѥץץå
+	xtotroff  ...	XΥեȤgroffѥեȥե
+	            	ġ
+
+ lj4ݥȥץåbibϢΥޥɤܸ̤бǤ
+
+
+ 󥹥ȡ
+
+ ʲδĶmake뤳ȤǧƤޤ
+
+	  FreeBSD 2.1.0-RELEASE
+	    XFree86-3.1.2, gcc 2.6.3
+
+	  Debian GNU/Linux 2.2
+
+	  NEC EWS/4800/310
+	    SVR4.2 Release9.1 Rev.B, X11R5, gcc 2.6.0
+
+ (1) ꥸʥƱconfigure¹Ԥ塢make & installƲ
+    ܤINSTALL򻲾ȤƤ
+
+    *) grodviNTT JTeXޤASCIIܸTeXDVIե򥵥ݡ
+       ȤƤޤgroffϤDVIեASCIIܸTeX
+       configure --JTeX=ASCIIȤƤ
+       --JTeXץꤷʤäNTT JTeXˤʤޤ
+
+ (2) groffmakeθ塢gxditview(groffXɥѥݥȥץå)
+    makeޤȥåץǥ쥯ȥľxditviewcdơ
+
+	% xmkmf
+	% make depend
+	% make all
+	% make install install.man
+
+    ǡ󥹥ȡ봰λǤ
+
+
+ Ȥ
+
+ groff-Tץ-Tnippon(üɽ)ɲäʳϥꥸʥΤ
+ޤǤ
+ʲϻ㡣
+
+ ()  groff -Tnippon -man groff.jman
+
+ ܸޤroffե(groff.jman)manޥȤäƥեޥåȤ
+üɽޤ
+ 
+ ()  groff -Tps -man groff.jman
+
+ ܸޤroffեեޥåȤPostScriptѴޤ
+
+ ()  groff -TX100 -man groff.jman
+
+ ܸޤroffեեޥåȤXɥɽޤ
+
+ ()  groff -Tdvi -man groff.jman
+
+ ܸޤroffեեޥåȤDVIեϤޤ
+
+
+ ܸ첽ˤĤ
+
+ ܸʸɤܸEUC(Υɥå1)ΤߥݡȤƤޤ
+
+ ܸեȤˤĤƤϡȥեȤܡΤλϥ
+   ΤˡʳΥե(ޥ󡢥ååܡ
+   )ȥեȤλīΤˡưŪڤؤޤܸ
+   եȤľܻꤹ뤳ȤϽޤ
+
+   () եȥե̾'B'ǽäƤե(BTBHNBʤ)
+        ܡɥեȤȤƤޤ
+
+ Ƭӹ§бƤޤ줾ζ§ʸϡ
+
+   Ƭ§ʸ:	  ˡ͡ϡѡס١
+			ä祡å
+			. ? ! " ' ) ] * , : ; > }
+   §ʸ:	 ̡ΡС֡ء
+
+   Ƥޤ
+
+ -Tpsꤷ硢EUCʸASCIIʸδ֤ˤϡζ򤬼ư
+   Ūޤζdevps/DESCwcharkernǻꤷޤ
+   unitñ̤Ǥ0ꤹȶʤʤޤ
+
+ -Tpsꤷ硢EUCʸASCIIʸФƾƽϤ
+   (ΤޤޤASCIIʸǸ뤿)β
+   devps/DESClowerwcharǻꤷޤunitñ̤Ǥ0ꤹȻ
+   ϹԤʤޤ
+
+ ꥸʥǤϲԥɤ̵˥ڡʸѴޤEUC
+   ʸǰϤޤ줿ԥɤϥڡѴ̵뤹褦ˤޤ
+
+ EUCΥڡʸ(0xa1a1)ASCIIΥڡʸȤƽޤ
+
+
+ ռ
+
+grodviASCIIܸTeXбϡԵؤβĤ󤬹ԤʤäƤ
+grohtmlܸ(EUC)бϡֿ󿮺Ȥ󤬹ԤäƤޤ
+ޤ¿Х˴ؤ𡢽᡼äĺޤ
+涨ϤäͤˤϤȤƤⴶդƤޤͭ񤦤ޤ
+
+
+ ꤤ
+
+СǤlj4ݥȥץåbibϢΥޥɷܸ첽
+Ƥޤ󡣤ܸ첽ԤäƤ罸פƤޤ
+Ҹ涨Ϥޤܸбgroff˴ؤƸո˾
+ʹλͤˤĺޤ(Х
+ޤǤ)
+ʾE-Mailˤơtm-kita@kh.rim.or.jpˤ꤯
--- groff-1.18.orig/stamp-h
+++ groff-1.18/stamp-h
@@ -0,0 +1 @@
+timestamp
